<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" >
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS3468Style.xsl"/>
<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<!-- Defines the stage of the data, e.g. original or latest -->

<xsl:param name="Form3468Data" select="$RtnDoc/IRS3468" />


<xsl:template match="/">

<html>
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form3468Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 3468" />
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>
    <style type="text/css">  
      <xsl:if test="not($Print) or $Print=''">
        <xsl:call-template name="IRS3468Style"></xsl:call-template>        
    <xsl:call-template name="AddOnStyle"></xsl:call-template>    
  </xsl:if>
</style>    
  <xsl:call-template name="GlobalStylesForm"/>
</head>

  <body class="styBodyClass">

    <form name="Form3468">
      <xsl:call-template name="DocumentHeader"/>  
      <!-- Begin Form Number and Name -->
      <div class="styTBB" style="width:187mm;height:20mm;">
        <div class="styFNBox" style="width:34mm;height:20mm;">
          <div style="height:13.25mm;">
            Form <span class="styFormNumber" >3468</span><br/>
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form3468Data" />
            </xsl:call-template>
          </div>
          <div style="height:6mm;font-family:arial;font-size:7pt;" >
            <span class="styAgency">Department of the Treasury</span><br/>
            <span class="styAgency">Internal Revenue Service</span> <span class="styAgency" style="padding-left:3mm;">(99)</span> 
          </div>        
        </div>
        <div class="styFTBox" style="width:122mm;height:20mm;">
            <div class="styMainTitle" style="height:12mm;">
              Investment Credit 
            </div>
            <div class="styFBT">
              <img src="{$ImagePath}/3468_Bullet.gif" alt="bullet image"/> Attach to your tax return.
            </div>        
        </div>
        <div class="styTYBox" style="width:30mm;height:20mm;line-height:110%;">
          <div class="styOMB" style="height:2mm;">
            OMB No. 1545-0155
          </div>
          <div class="styTY" style="height:7mm;font-size:25pt;line-height:110%;">
            20<span class="styTYColor">05</span>
          </div>
          <div style="height:6mm;text-align:left;padding-left:3mm;">
            Attachment<br/>
            Sequence No. <span class="styBoldText">52</span>
          </div>
        </div>
      </div>
      <!-- End Form Number and Name section -->
      <!-- Begin Names and Identifying number section -->
      <div class="styBB" style="width:187mm;">
        <div class="styNameBox" style="width:156mm;height:8mm;font-size:7pt;font-weight:normal;">
          Name(s) shown on return<br/>
          <span>
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
          </span>            
        </div>
        <div class="styEINBox" style="width:30mm;height:4mm;font-size:7pt;font-weight:bold;padding-left:2mm;">
          Identifying number<br/><br />
          <span style="width:25mm;text-align:left;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>          
          </span>      
        </div>
      </div>    
      <!-- End Names and Identifying number section -->
      <!-- Begin Current Year Credit Section -->
      <div class="styBB" style="width:187mm;">
        <div class="styPartName">Part I</div>
        <div class="styPartDesc">
          Current Year Credit
        </div>
      </div>
      <div class="styBB" style="width:187mm;">
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">
            1
          </div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;">
            Rehabilitation credit
            (see instructions for requirements that must be met):
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">a</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;">
            <label>
              <xsl:call-template name="PopulateLabel">
                <xsl:with-param name="TargetNode" select="$Form3468Data/RehabilitationExpendituresUsed" />
              </xsl:call-template>            
              Check this box if you are electing under section 47(d)(5) to
              take your qualified rehabilitation expenditures into account
              for the tax year in which paid (or, for self-rehabilitated
              property, when capitalized). See instructions.
              <span class = "styBoldText">Note: </span>
              <span class = "styItalicText">This election applies to the
                current tax year and to all later tax years. You may
                not revoke this election without IRS consent
              </span>
            </label>
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:12px;"></span>
            </span>
            <img src="{$ImagePath}/3468_Bullet.gif" width="7" alt="bullet image"/>
            <input type="checkbox" class="styCkbox" onclick="return false;" >
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form3468Data/RehabilitationExpendituresUsed" />
              </xsl:call-template>
            </input>
            <br/>Enter the amount of qualified rehabilitation expenditures
            and multiply by the percentage shown:
       
          </div>
          <div class="styLNRightNumBox" style="background-color:lightgrey;height:17mm; border-bottom-width: 0px"></div>
          <div class="styLNAmountBox" style="height: 17mm;border-bottom-width: 0px"></div>
        </div>

        <div style="width:187mm;">
             <div class="styLNDesc" style="width:145.9mm;height:4mm;padding-left:8mm;font-size:6pt;">
             (*For property located in the Gulf Opportunity Zone, multiply by applicable percentage in the instructions.):
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">b</div>
          <div class="styLNDesc" style="width:80mm;height:4mm;">
            Pre-1936 buildings
        
                <xsl:call-template name="SetFormLinkInline">
		             <xsl:with-param name="TargetNode" select="$Form3468Data/CalcExpendPre1936Buildings" />
		           </xsl:call-template>
        
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.              
            </span>
          </div>
          <span class ="styUnderlineAmount" style ="width:2mm">$</span>
          <div class ="styUnderlineAmount" style ="width:32.9mm;">
 
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/QlfyRehbltPre1936Buildings" />
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:18mm;padding-top:.5mm;"><span style="width:19mm;padding-left:.5mm;">X 10% (.10)*</span></div>
          <div class="styGenericDiv" style="width:4mm;"></div>
          <div class="styLNRightNumBox">
            1b
          </div>
          <div class="styLNAmountBox" > 
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/CalcExpendPre1936Buildings" />
            </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">c</div>
          <div class="styLNDesc" style="width:80mm;height:4mm;padding-top:0mm;padding-bottom:1mm;">
            Certified historic structures
                 <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="$Form3468Data/CalcExpendituresCertHistStrctr" />
                </xsl:call-template>
                <span style="width:3px;"/>
            <!-- Adding pen image -->
            <span style="padding-bottom:2mm;">
            <xsl:call-template name="LinkToLeftoverBooleanDataTableInline">
              <xsl:with-param name="Desc">Line 1c - Certified Historic Structure on File</xsl:with-param>
              <xsl:with-param name="TargetNode" select="$Form3468Data/CertifiedHistoricStructures/@historicStructureCertOnFile"/>
            </xsl:call-template> 
            </span> 
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
           <span class ="styUnderlineAmount" style ="width:2mm">$</span>
          <div  class ="styUnderlineAmount" style ="width:32.9mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/CertifiedHistoricStructures " />                  
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:18mm;"><span style="width:19mm;padding-left:.5mm; padding-top:1mm;">X 20% (.20)*</span></div>
          <div class="styGenericDiv" style="width:4mm;"></div>
          <div class="styLNRightNumBox" style="height:5.2mm;padding-top:1mm;">
            1c
          </div>
          <div class="styLNAmountBox" style="height:5.2mm; padding-top:1mm;">
	          <xsl:call-template name="PopulateAmount">
	            <xsl:with-param name="TargetNode" select="$Form3468Data/CalcExpendituresCertHistStrctr" />
	          </xsl:call-template>            
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="width:6mm;"></div>        
          <div class="styIRS3468LNSLeftLtrBoxBB" style="height:4mm;padding-left:0.5mm;">(1)</div>
          <div class="styLNDesc" style="width:92mm;height:4mm;">
            Enter the assigned NPS project number or the pass-through
            entity's employer identification number (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class ="styUnderlineAmount" style ="width:35.75mm;height:4mm;padding-top:3mm;text-align:left;">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="$Form3468Data/QualifiedRehabilitationNPS" />                  
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:4mm;"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 7.5mm"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="width:6mm;"></div>        
          <div class="styIRS3468LNSLeftLtrBoxBB" style="height:4mm;padding-left:0.5mm">(2)</div>
          <div class="styLNDesc" style="width:101.75mm;height:4mm;">
            Enter the date that the NPS approved the Request for Certification of <br/>
            Completed Work (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class ="styUnderlineAmount" style ="height:4mm;padding-top:3mm;width:26mm;text-align:left;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="$Form3468Data/DateOfNPSApproval" />
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:4mm;"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 7.5mm"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="width:6mm;">d</div>
          <div class="styIRS3468LNSLeftLtrBoxBB" style="padding-left:0.5mm;">(1)</div>  
          <div class="styLNDesc" style="width:50mm;">
            Enter the date on which the 24-or<br/>
            60-month measuring period begins
          </div>
          <div class="styUnderlineAmount" style="width:30mm;text-align:left;padding-top:3.5mm;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="$Form3468Data/RehbltTestPeriodBeginningDate" />                  
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="padding-top:3.5mm;width:18mm;text-align:center;">
            and ends
          </div>                      
          <div class="styUnderlineAmount" style="width:30mm;text-align:left;padding-top:3.5mm;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="$Form3468Data/RehbltTestPeriodEndDate" />                    
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:4mm;"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 7.5mm"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="width:6mm;"></div>        
          <div class="styIRS3468LNSLeftLtrBoxBB" style="height:4mm;padding-left:0.5mm;">(2)</div>
          <div class="styLNDesc" style="width:94mm;height:4mm;">
            Enter the adjusted basis of the building as of the beginning
            date above (or the first day of your holding period, if later)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <!-- check-2 -->
          <span class ="styUnderlineAmount" style ="width:2mm;height:4mm;padding-top:3mm;">$</span>
          <div class ="styUnderlineAmount" style ="width:32mm;height:4mm;padding-top:3mm;">
              
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form3468Data/AdjustedBasisOfBuildingAmount" />                  
              </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:3.75mm;"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 7.5mm"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="width:6mm;"></div>        
          <div class="styIRS3468LNSLeftLtrBoxBB" style="height:4mm;padding-left:0.5mm;">(3)</div>
          <div class="styLNDesc" style="width:94mm;height:4mm;">
            Enter the amount of the qualified rehabilitation expenditures
            incurred, <br/>or treated as incurred, during the period on line
            1d(1) above
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          
          <!-- Check -->
          
            <span class ="styUnderlineAmount" style ="width:2mm;height:4mm;padding-top:3mm;">$</span>
         
          <div class ="styUnderlineAmount" style ="height:4mm;padding-top:3mm;width:32mm;">
               <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/QlfyRehbltExpendituresAmt" />
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:3.75mm;"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 7.5mm"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">e</div>
          <div class="styLNDesc" style="width:137.8mm;height:4mm;">
            Rehabilitation credit from an electing large partnership
            (Schedule K-1 (Form 1065-B), box 9)
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">
            1e
          </div>
          <div class="styLNAmountBox" style="height:4.5mm;">
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/RehabilitationCredit" />
           </xsl:call-template>           

          </div>
        </div>


        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">2</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;font-size:7pt;">
        <div class="styGenericDiv">   Energy credit for periods ending before January 1, 2006. Basis of property using solar or geothermal </div>   
         <div class="styGenericDiv" style=" font-size 7pt; width:85mm;" > energy placed in service during the tax year (see instructions) </div>
           <span class ="styUnderlineAmount" style ="width:1mm;height:4mm;padding-top:0mm;">$</span>
             <span class ="styUnderlineAmount" style="width:30.2mm;height:4mm;padding-top:0mm;">
               <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/PreJAN012006EnergyCredit" />                      
            </xsl:call-template>    
          </span>
          <span class="styGenericDiv" style="font-size:7pt; padding-top:1mm; padding-left:2mm;" >X 10% (.10)</span>
          </div>
                
          <div class="styLNRightNumBox" style="height:8.5mm;padding-top:5mm">2
          </div>
          <div class="styLNAmountBox" style="height:8.5mm;padding-top:5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/CalcPreJAN012006EnergyCredit" />
            </xsl:call-template>
          </div>
        </div>

        
       <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:1mm; ">3</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;">
         Energy credit for periods ending after December 31, 2005: </div>
    
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   

        </div>    
        
       
            
        <!-- start here -->    
     <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">a</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;font-size:9px;">
          
   Basis of property using geothermal energy placed in service during the </div>
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   
        </div>    
         <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
          <div class="styLNDesc" style="width:40.4mm;height:4.5mm;font-size:9px; ">
           tax year (see instructions)

         </div>
             <span class ="styUnderlineAmount" style ="width:2mm;height:3.5mm;">$</span>
                       <div class ="styUnderlineAmount" style="width:29.5mm;height:3.5mm;">
                         <xsl:call-template name="PopulateAmount">
                               <xsl:with-param name="TargetNode" select="$Form3468Data/GeothermalEnergyPropertyBasis" />                      
                               </xsl:call-template>      
                        </div>
                         <div class="styGenericDiv" style="width:25.8mm;height:4.5mm;padding-top:2mm;"><span style="width:4px;"></span>X10% (.10)            </div>

           
          <div class="styLNRightNumBox" style="height:5.5mm;">3a</div>
          <div class="styLNAmountBox" style="height:5.5mm;">
                              <xsl:call-template name="PopulateAmount">
                               <xsl:with-param name="TargetNode" select="$Form3468Data/CalcGeothermalEnergyPropBssCr" />                      
                               </xsl:call-template>   
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
          <div class="styLNAmountBoxNBB" style="height: 5.5mm"></div>   
        </div>
    
     <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">b</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;font-size:8px;">
             Basis of property using solar illumination or solar energy placed in service during the</div>
         
    
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;">
        
          </div>
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   
        </div>    
        
         <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
          <div class="styLNDesc" style="width:42mm;height:4.5mm;font-size:8px;">
           tax year (see instructions)

         </div>
             <span class ="styUnderlineAmount" style ="width:2mm;height:3.5mm;">$</span>
                       <div class ="styUnderlineAmount" style="width:30mm;height:3.5mm;">
                         <xsl:call-template name="PopulateAmount">
                               <xsl:with-param name="TargetNode" select="$Form3468Data/SolarIllumOrEnergyPropBss" />                      
                               </xsl:call-template>      
                        </div>
                         <div class="styGenericDiv" style="width:23.7mm;height:4.5mm;padding-top:2mm;"><span style="width:4px;"></span>X 30% (.30)            </div>

           
          <div class="styLNRightNumBox" style="height:4.5mm;">3b</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
                      <xsl:call-template name="PopulateAmount">
                       <xsl:with-param name="TargetNode" select="$Form3468Data/CalcSolarIllumOrEngeryPropBss" />                      
                       </xsl:call-template>      
     
          </div>
          
     <!--  Start Here -->     
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
          <div class="styLNAmountBoxNBB" style="height: 5.5mm"></div>   
        </div>
            
                    <div style="width:187mm;">
             <div class="styLNDesc" style="width:145.9mm;height:4mm;padding-left:8mm;">
            Qualified fuel cell property (see instructions):          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
        </div>

            
       <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">c</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;font-size:9px;">
          Basis of property installed during the tax year</div>
         
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   
        </div>    
        
         <div style="width:187mm;">
                 <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
                 <span class ="styUnderlineAmount" style ="width:2mm;height:3.5mm;">$</span>
                  <div class ="styUnderlineAmount" style="width:33mm;height:3.5mm;">
                        <xsl:call-template name="PopulateAmount">
                        <xsl:with-param name="TargetNode" select="$Form3468Data/QualifiedFuelCellPropertyBasis" />                      
                         </xsl:call-template>       
                   </div>
                   <div class="styGenericDiv" style="width:18mm;height:4.5mm;padding-top:2mm;"><span style="width:22.8mm;">X 30% (.30)</span>            </div>
           
                  <div class="styLNRightNumBox" style="height:5.5mm;">3c</div>
                  <div class="styLNAmountBox" style="height:5.5mm;">
                      <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$Form3468Data/CalcQualifiedFuelCellPropBasis" />                      
                      </xsl:call-template>       
                  </div>
    
                  <div class="styLNAmountBoxNBB" style="height: 5.5mm;width:40mm;background-color:lightgrey;"></div> 
                 <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
                 <div class="styLNAmountBoxNBB" style="height: 5.5mm; "></div>   
  
        </div>
       
       
       
            <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">d</div>
          <div class="styLNDesc" style="width:58mm;height:4.5mm;font-size:9px;">
           Kilowatt capacity of property in <span style="font-weight:bold;"> c </span>above</div>
         
    
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;">
        
          </div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;background-color:lightgrey;width:40mm;"></div>   
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   
        </div>    
        
         <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
          <div class="styLNDesc" style="width:12mm;height:4.5mm;font-size:8px;">
           <span class="styBoldText">
                <span style="width:10px;">.</span>
                <span style="width:10px;">.</span>
                <span style="width:10px;">.</span>
                
           </span>


              <img src="{$ImagePath}/3468_Bullet.gif"  style="float"   alt="right arrow"/>
         </div>
    
                       <div class ="styUnderlineAmount" style="width:29mm;height:3.5mm;">
                              <xsl:call-template name="PopulateAmount">
                               <xsl:with-param name="TargetNode" select="$Form3468Data/QlfyFuelCellPropKwCapacity" />                      
                               </xsl:call-template>      
                        </div>
                         <div class="styGenericDiv" style="width:17mm;height:4.5mm;padding-top:2mm;"><span style="width:4px;"></span>X $1000  </div>

           
          <div class="styLNRightNumBox" style="height:5.5mm;">3d</div>
          <div class="styLNAmountBox" style="height:5.5mm;">
                <xsl:call-template name="PopulateAmount">
                 <xsl:with-param name="TargetNode" select="$Form3468Data/CalcQlfyFuelCellPropKwCapacity" />                      
                  </xsl:call-template>      
  
          </div>
    

      
          <div class="styLNAmountBoxNBB" style="height: 5.5mm;width:40mm;background-color:lightgrey;"></div> 
                     <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
          <div class="styLNAmountBoxNBB" style="height: 5.5mm"></div>   

  
        </div>

            
            
           <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">e</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Enter the lesser of line 3c or 3d
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:4px;"></span>
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">3e</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/AdjQlfyFuelCellPropertyCredit" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>


            
            
        <div style="width:187mm;">
             <div class="styLNDesc" style="width:145.9mm;height:4mm;padding-left:8mm;">
             Qualified microturbine property (see instructions):
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
        </div>
      
    
      
             <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">f</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;font-size:9px;">
          Basis of property installed during the tax  year</div>
         
    
    
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   

        </div>    
        
         <div style="width:187mm;">
                 <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
                 <span class ="styUnderlineAmount" style ="width:2mm;height:3.5mm;">$</span>
                  <div class ="styUnderlineAmount" style="width:29mm;height:3.5mm;">
                         <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" select="$Form3468Data/QlfyMircroturbinePropBasis" />                      
                          </xsl:call-template>    
                   </div>
                   <div class="styGenericDiv" style="width:18mm;height:4.5mm;padding-top:2mm;"><span style="width:26.8mm;">X 10% (.10)</span>            </div>
                   <div class="styLNRightNumBox" style="height:5.5mm;">3f</div>
                   <div class="styLNAmountBox" style="height:5.5mm;">
                                <xsl:call-template name="PopulateAmount">
                               <xsl:with-param name="TargetNode" select="$Form3468Data/CalcQlfyMircroturbinePropBasis" />                      
                               </xsl:call-template>    
 
          </div>
  
          <div class="styLNAmountBoxNBB" style="height: 5.5mm;background-color:lightgrey;width:40mm;"></div> 
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
          <div class="styLNAmountBoxNBB" style="height: 5.5mm"></div>   

          </div>
       
       
       
  
  
         <div style="width:187mm;">
              <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">g</div>
              <div class="styLNDesc" style="width:58mm;height:4.5mm;font-size:9px;">
               Kilowatt capacity of property in <span style="font-weight:bold:"> f </span>above </div>
              <div class="styLNRightNumBoxNBB" style="height:4.5mm;"></div>
              <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;background-color:lightgrey;width:40mm;"></div>   
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   

        </div>    
        
         <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
          <div class="styLNDesc" style="width:13mm;height:4.5mm;font-size:8px;">
            <span class="styBoldText">
                <span style="width:10px;">.</span>
                <span style="width:10px;">.</span>
                <span style="width:10px;">.</span>
   
           </span>
           <img src="{$ImagePath}/3468_Bullet.gif"  style="float"   alt="right arrow"/>
         </div>
          

    
                       <div class ="styUnderlineAmount" style="width:29mm;height:3.5mm;">
                             <xsl:call-template name="PopulateAmount">
                             <xsl:with-param name="TargetNode" select="$Form3468Data/QlfyMicroturbinePropKwCapacity" />                      
                             </xsl:call-template> 
                        </div>
                         <div class="styGenericDiv" style="width:16mm;height:4.5mm;padding-top:2mm;"><span style="width:4px;"></span>X $200  </div>

           
          <div class="styLNRightNumBox" style="height:5.5mm;">3g</div>
          <div class="styLNAmountBox" style="height:5.5mm;">
                <xsl:call-template name="PopulateAmount">
                 <xsl:with-param name="TargetNode" select="$Form3468Data/TotQlfyMicroturbinePropKwCap" />                      
                  </xsl:call-template>      
  
          </div>
      
          <div class="styLNAmountBoxNBB" style="height: 5.5mm;width:40mm;background-color:lightgrey;"></div> 
                     <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
          <div class="styLNAmountBoxNBB" style="height: 5.5mm"></div>   

  
        </div>
        
     
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">h</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Enter the lesser of line 3f or 3g
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:4px;"></span>
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">3h</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/AdjQlfyMircroturbinePropBasis" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>


               
        
        <div style="width:187mm;">
            <div class="styLNLeftLtrBox" style="height:4mm;">i</div>
            <div class="styLNDesc" style="width:137.8mm;height:4mm;">
          Total. Add lines 3a, 3b, 3e, and 3h
                      <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:8px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.

            </span>

          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">
            3i
          </div>
          <div class="styLNAmountBox" style="height:4.5mm;">
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/PostDEC312005EnergyCredit" />
           </xsl:call-template>           
          </div>
        </div>

        
          <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">
            4
          </div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;">
  Qualifying advanced coal project credit for periods ending after August 8, 2005 (see instructions):
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
        </div>
      
    
        
     <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">a</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;font-size:8px;">
             Basis of qualified investment in property other than in a above placed in service</div>
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   
        </div>    
         <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
          <div class="styLNDesc" style="width:28mm;height:4.5mm;font-size:8px;">
           during the tax year

         </div>
             <span class ="styUnderlineAmount" style ="width:2mm;height:3.5mm;">$</span>
                       <div class ="styUnderlineAmount" style="width:34mm;height:3.5mm;">
                              <xsl:call-template name="PopulateAmount">
                               <xsl:with-param name="TargetNode" select="$Form3468Data/IntgrtGasCombCycPropInvstBasis" />                      
                               </xsl:call-template>       
                        </div>
                         <div class="styGenericDiv" style="width:33.7mm;height:4.5mm;padding-top:2mm;"><span style="width:4px;"></span>X 20% (.20)            </div>

           
          <div class="styLNRightNumBox" style="height:5.5mm;">4a</div>
          <div class="styLNAmountBox" style="height:5.5mm;">
                     <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$Form3468Data/CalcGasCombinedCycPropInvstCr" />                      
                      </xsl:call-template>       
  
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
          <div class="styLNAmountBoxNBB" style="height: 5.5mm"></div>   
        </div>


   
    
     <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; ">b</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;font-size:8px;">
             Basis of qualified investment in property other than in a above placed in service</div>
         
    
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;">
        
          </div>
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm"></div>   
        </div>    
        
         <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm; padding-left:3mm; "></div>
          <div class="styLNDesc" style="width:28mm;height:4.5mm;font-size:8px;">
           during the tax year

         </div>
             <span class ="styUnderlineAmount" style ="width:2mm;height:3.5mm;">$</span>
                       <div class ="styUnderlineAmount" style="width:34mm;height:3.5mm;">
                         <xsl:call-template name="PopulateAmount">
                               <xsl:with-param name="TargetNode" select="$Form3468Data/OtherQlfyInvstPropertyBasis" />                      
                               </xsl:call-template>      
                        </div>
                         <div class="styGenericDiv" style="width:33.7mm;height:4.5mm;padding-top:2mm;"><span style="width:4px;"></span>X 15% (.15)            </div>

           
          <div class="styLNRightNumBox" style="height:4.5mm;">4b</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
                 <xsl:call-template name="PopulateAmount">
                   <xsl:with-param name="TargetNode" select="$Form3468Data/CalcOtherQlfyInvstPropCredit" />                      
                   </xsl:call-template>      

          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:5.5mm"></div>
          <div class="styLNAmountBoxNBB" style="height: 5.5mm"></div>   
        </div>
        
    
        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">c</div>
          <div class="styLNDesc" style="width:137.8mm;height:4mm;">
          Total. Add lines 4a and 4b
                      <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:8px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
             </span>

          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">
            4c
          </div>
          <div class="styLNAmountBox" style="height:4.5mm;">
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/PostAUG082005QlfyAdvncCoalCr" />
           </xsl:call-template>           

          </div>
        </div>
        
        
                <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">5</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;;">
        <div class="styGenericDiv" style="font-size:6pt">   Qualifying gasification project credit for periods ending after August 8, 2005 (see instructions).  Basis of </div>   
         <div class="styGenericDiv" style=" font-size:6pt; width:85mm;" > qualified  investment in property placed in service during the tax year</div>
           <span class ="styUnderlineAmount" style ="width:1mm;height:4mm;padding-top:0mm;">$</span>
             <span class ="styUnderlineAmount" style="width:30.2mm;height:4mm;padding-top:0mm;">
               <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/PostAUG082005QlfyGasPropBss" />                      
            </xsl:call-template>    
          </span>
          <span class="styGenericDiv" style="font-size:7pt; padding-top:1mm; padding-left:2mm;" >X 20% (.20)</span>
          </div>
                
          <div class="styLNRightNumBox" style="height:8.5mm;padding-top:5mm">5
          </div>
          <div class="styLNAmountBox" style="height:8.5mm;padding-top:5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/CalcPostAUG082005QlfyGasBasis" />
            </xsl:call-template>
          </div>
        </div>

        
     <!--   
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">5</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm; font-size:8px;">
            Qualifying gasification project credit for periods ending after August 8, 2005 (see instructions).  Basis of </div>
            <div class="styLNRightNumBoxNBB" style="height:4.3mm;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.3mm;"></div>
           <span class="styLNDesc" style="width:92mm; padding-left:8mm;height:4mm; font-size:8px;">
        qualified  investment in property placed in service during the tax year
            </span>
           
         <span class ="styUnderlineAmount" style ="width:1mm;height:4mm;padding-top:0mm;">$</span>
          <div class ="styUnderlineAmount" style="width:30.2mm;height:4mm;padding-top:0mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/PostAUG082005QlfyGasPropBss" />                      
            </xsl:call-template>
          </div>
          <div class="styGenericDiv" style="width:17.7mm;height:4mm;padding-top:1mm;"><span style="width:4px;"></span>X 20% (.20)            </div>
          <div class="styGenericDiv" style="width:4mm;"></div>
          <div class="styLNRightNumBox" style="height:7.3mm;padding-top:3mm">5
          </div>
          <div class="styLNAmountBox" style="height:7.3mm;padding-top:3mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/CalcPostAUG082005QlfyGasBasis" />                      </xsl:call-template>
          </div>
        </div>

          -->
        
        
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">6</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;">
            Credit from cooperatives.  Enter the unused investment credit from
            cooperatives.
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:8px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">6</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/CreditFromCooperatives" />
            </xsl:call-template>
          </div>
          
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">7</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;padding-top:0mm;padding-bottom:0mm;">
            <span class="styBoldText">
              Current year credit. </span>
            Add lines 1b through 6
                   
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBoxNBB" style="height:4mm;">7
          </div>
          <div class="styLNAmountBoxNBB" style="height:4mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/TotalCurrentYearInvestmentCr" />                  </xsl:call-template>
          </div>
        </div>
      </div>

    <!--footer -->
    <div style="width:187mm;clear:both;padding-top:1mm;" class="pageend">
      <div style="width:90mm;font-weight:bold;" class="styGenericDiv">For Paperwork Reduction Act Notice, see instructions.</div>
      <div style="width:55mm;text-align:center;" class="styGenericDiv">Cat. No. 12276E</div>
      <div style = "float:right;" class="styGenericDiv">Form <span class="styBoldText">3468</span> (2005)</div>
    </div>
    <!-- header -->
    <div style="width:187mm;clear:both;padding-bottom:.5mm;" class="styBB">
      <div style="width:90mm;" class="styGenericDiv">Form 3468 (2005)</div>
      <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
      <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">2</span></div>
    </div>    


      <!-- Begin Allowable credit section-->
      <div class="styBB" style="width:187mm;">
        <div class="styPartName">Part II</div>
        <div class="styPartDesc" style="font-size:8pt;width:172mm;">
          Allowable Credit
          <span class="styNormalText">
            (See
          </span> 
          Who must file Form 3800 
          <span class="styNormalText">
            to find out if you complete Part II or file Form 3800.)
          </span>          
        </div>
      </div>

      <div class="styBB" style="width:187mm;">
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">8</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;">
            Regular tax before credits:
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4mm"></div>
        <!-- Line 6, three bullet points -->
          <div style="width:100mm;float:left;clear:none;">
	          <div class="styLNDesc" style="height:4mm;position:relative;left:8mm;">
	            <!-- First bullet point -->
	            <img src="{$ImagePath}/3468_Bullet_Round.gif" alt="Bullet image" /><span style="width:3px;"/>
	            Individuals. Enter the amount from Form 1040, line 44
	            <!--Dotted Line-->
	            <span class="styBoldText">
	                <span style="letter-spacing:16px;">............</span>
	            </span>
	          </div>
	          <!-- Second bullet point -->
	          <div class="styLNDesc" style="height:4mm;position:relative;left:8mm;">
	            <img src="{$ImagePath}/3468_Bullet_Round.gif" alt="Bullet Image" /><span style="width:3px;"/>
	            Corporations. Enter the amount from Form 1120, Schedule J, line 3; Form 1120-A, Part <br />I, line 1; or the applicable line of your return
	            <!--Dotted Line-->
	            <span class="styBoldText">
	                <span style="letter-spacing:16px;">...............</span>
	            </span>
	          </div>
	          <!-- Third bullet point -->
	          <div class="styLNDesc" style="height:4mm;position:relative;left:8mm;">
	            <img src="{$ImagePath}/3468_Bullet_Round.gif" alt="Bullet image" /><span style="width:3px;"/>
	            Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G, lines <br />1a and 1b, or the amount from the applicable line of your return
	            <!--Dotted Line-->
	            <span class="styBoldText">
	                <span style="letter-spacing:16px;">..........</span>
	            </span>
	          </div>
	       </div>
	       <!-- Bracket that groups the three bullet points -->
         <div style="width:7.8mm;float:left;clear:none; ">
           <img src="{$ImagePath}/3468_Bracket_Lg.gif"  style="height:18mm" alt="Large bracket image" /><span style="width:3px;"/>
         </div>
         <!-- Grey columns and empty amount boxes -->
         <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:14.5mm"></div>
         <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 14.5mm"></div>
         <!-- Amount box for line 5 -->         
         <div class="styLNRightNumBoxNBB" style="height:4mm;border-bottom-width:1px;">8</div>
         <div class="styLNAmountBox" style="border-bottom-width: 1px; height: 4mm">
	         <xsl:call-template name="PopulateAmount">
	           <xsl:with-param name="TargetNode" select="$Form3468Data/RegularTaxBeforeCredits" />                  
	         </xsl:call-template>
         </div>
       </div>
                       
        <div style="width:187mm;">
          <!-- Line 6 - first line of description -->
          <div class="styLNLeftNumBox" style="height:7.5mm; padding-top:.3mm;">9</div>
          <div class="styLNDesc" style="width:137.9mm;height:7.5mm; padding-top:.3mm; ">
            Alternative minimum tax: Enter the alternative minimum tax (AMT) from the following line of the
            appropriate form or schedule
          <!--Dotted Line-->
            <span class="styBoldText">
              <span style="letter-spacing:16px;">....................</span>
            </span>
          </div>
          <!-- Line 9 amount box -->
          <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3.5mm; ">9
          </div>
          <div class="styLNAmountBox" style="height:7.5mm; padding-top:3.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/AlternativeMinimumTax" />                  </xsl:call-template>
          </div>
          <!-- Line 6 bullet points -->
          <div style="width:137.9mm;float:left;clear:none;">
	          <div class="styLNDesc" style="height:4mm;position:relative;left:8mm;">
	            <!-- First bullet point -->
	            <img src="{$ImagePath}/3468_Bullet_Round.gif" alt="Bullet image" /><span style="width:3px;"/>
	            Individuals: Form 6251, line 35
	            <!--Dotted Line-->
	            <span class="styBoldText">
	                <span style="letter-spacing:16px;">.................</span>
	            </span>
	          </div>
	          <!-- Second bullet point -->
	          <div class="styLNDesc" style="height:4mm;position:relative;left:8mm;">
	            <img src="{$ImagePath}/3468_Bullet_Round.gif" alt="Bullet Image" /><span style="width:3px;"/>
	            Corporations: Form 4626, line 14
	            <!--Dotted Line-->
	            <span class="styBoldText">
	                <span style="letter-spacing:16px;">................</span>
	            </span>
	          </div>
	          <!-- Third bullet point -->
	          <div class="styLNDesc" style="height:4mm;position:relative;left:8mm;">
	            <img src="{$ImagePath}/3468_Bullet_Round.gif" alt="Bullet image" /><span style="width:3px;"/>
	            Estates and trusts: Form 1041, Schedule I, line 56
	            <!--Dotted Line-->
	            <span class="styBoldText">
	                <span style="letter-spacing:16px;">............</span>
	            </span>
	          </div>
	        </div>
	   <!-- Line 6 Bracket -->
	   <div style="width:7.8mm;height:13mm;float:left;clear:none;padding-top:1mm">
            <img src="{$ImagePath}/3468_Bracket_Md.gif" alt="Bracket image"/><span style="width:3px;"/>
          </div>
          <!-- Grey columns and empty amount boxes -->
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:13mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 13mm"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">10</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;">
            Add lines 8 and 9
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:15px;"></span>.
              <span style="width:8px;"></span>
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">10
          </div>
          <div class="styLNAmountBox" style="height:4mm;">            
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/RegularTaxPlusAltMinimumTax" />                  </xsl:call-template>
          </div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">11a</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Foreign tax credit
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:4px;"></span>
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">11a</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/ForeignTaxCredit" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4.5mm;">b</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Credits from Form 1040, lines 48 through 54
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">11b</div>
          <div class="styLNAmountBox" style="height:4.5mm;"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4.5mm;">c</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Possessions tax credit (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">11c</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/PossessionsTaxCredit" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4.5mm;">d</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
 Nonconventional source fuel credit (Form 8907, line 23)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
 
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">11d</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/FuelCreditNonconventional" />
            </xsl:call-template></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4.5mm;">e</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
 Other specified credits (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;padding-top:.5mm;">11e</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/OtherSpecifiedCredits" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>
 
        <!-- Old (pre-2004 schema) lines 9f-9l would go here -->
        <div style="width:187mm;">
<!--          <div class="styLNLeftLtrBox" style="height:4mm;">m</div>-->
          <div class="styLNLeftLtrBox" style="height:4mm;">f</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;">
            Add  lines 11a through 11e
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:8px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
<!--          <div class="styLNRightNumBox" style="height:4mm;">9m-->
          <div class="styLNRightNumBox" style="height:4mm;">11f
          </div>
          <div class="styLNAmountBox" style="height:4mm;">            
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/TotalCredits" />
            </xsl:call-template>
          </div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">12</div>
          <div class="styLNDesc" style="width:137.9mm;height:4mm;font-size:7pt;">
            Net income tax.  Subtract line 11f from line 10.  If zero, skip lines 13 through 16 and enter - 0- on line 17
    <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:6px;"></span>
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                 <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>          
          </div>
                
          <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm">12
          </div>
          <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/NetIncomeTax" />
            </xsl:call-template>
          </div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">13</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Net regular tax.  Subtract line 11f from line 8.  If zero
            or less, enter -0-
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">13</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/NetRegularTax" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">14</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Enter 25% (.25) of the excess, if any, of line 13 over
            $25,000 (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:6px;"></span>
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm">14</div>
          <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/ExcessNetRegularTax" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 7.5mm"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">15</div>
          <div class="styLNDesc" style="width:98mm;height:4.5mm;">
            Tentative minimum tax
            (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:12px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          
          <div class="styLNRightNumBox" style="height:4.5mm;">15</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/TentativeMinimumTax" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm"></div>
          <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 4.5mm"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">16</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;">
            Enter the greater of line 14 or line 15
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:10px;"></span>
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">16</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/AdjustedMinimumTax" />
            </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">17</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;">
            Subtract line 16 from line 12.  If zero or less, enter -0-
            <!--Dotted Line-->
            <span class="styBoldText">
                <span style="width:8px;"></span>
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">17</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/AdjustedNetIncomeTax" />
            </xsl:call-template>
          </div>
        </div>
         
        <div style="width:187mm;float:left;clear:none;">
          <div class="styLNLeftNumBox" style="height:4.5mm;">18</div>
          <div class="styLNDesc" style="width:137.9mm;height:4.5mm;">
            <span class="styBoldText">Credit allowed for the current year.</span>
            Enter the <span style="font-weight:bold;">smaller</span> of line7  or line 17 here and
            on Form 1040, line 55; Form 1120, Schedule J, line 6d;
            Form 1120-A, Part I, line 2; Form 1041,
            Schedule G, line 2c;  
          </div>
          <div class="styLNRightNumBoxNBB" style="height:7.3mm;background-color:lightgrey;"></div>
          <div class="styLNAmountBoxNBB" style="height:7.3mm;"></div>
          <div class="styLNDesc" style="width:145.7mm;height:4.5mm;padding-left:8mm;padding-top:0px;">
            or the applicable line of your return.
            If line 17 is smaller than line 7, see instructions.
            <span class="styBoldText">
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
                <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;">18</div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3468Data/InvestmentCreditAllowedCY" />
            </xsl:call-template>
	        </div>
         </div>
      </div>
      
      <div style="width:187mm;float:left;clear:none;padding-top:1mm;">
        <div style="width:110mm;float:left;clear:none;font-weight:bold;">For Paperwork Reduction Act Notice, see instructions.</div>
        <div style="width:40mm;float:left;clear:none;">Cat. No. 12276E</div>
        <div style = "width:35mm;float:left;clear:none;text-align:right">Form <span style="font-weight:bold;">3468</span> (2005)</div>
      </div>        
    <!-- Adding page break -->

  <p class="pageend"></p>
<!-- Begininning of write-in data -->
    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" TabIndex="1" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form3468Data" />
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
      <!-- Added the xsl:if clause here as the <tr> needs to shown only when the attribute exists.  And also added xsl:choose block if not both templates will be called resulting in display problems as both templates insert the span tag for id's.For more information look for defect 9101-->
      <xsl:if test="$Form3468Data/CertifiedHistoricStructures/@historicStructureCertOnFile">
       <tr>
          <td class="styLeftOverTableRowDesc" style="width:110mm;" scope="row">
            Line 1c - Certified Historic Structure on File:
          </td>
          <td class="styLeftOverTableRowAmount" style="width:100mm;text-align:left;">
            <xsl:choose>
              <xsl:when test="$Form3468Data/CertifiedHistoricStructures/@historicStructureCertOnFile = '1'">
                <xsl:call-template name="PopulateYesBoxText">
                  <xsl:with-param name="TargetNode" select="$Form3468Data/CertifiedHistoricStructures/  @historicStructureCertOnFile"/>
                </xsl:call-template>
              </xsl:when>
              <xsl:otherwise>
                <xsl:call-template name="PopulateNoBoxText">
                  <xsl:with-param name="TargetNode" select="$Form3468Data/CertifiedHistoricStructures/  @historicStructureCertOnFile"/>
                </xsl:call-template>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
      </xsl:if>
      <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Line 5 - Tax Reform Indicator</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form3468Data/TotalCurrentYearInvestmentCr/@taxReformIndicator"/>
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
      <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Line 5 - Tax Reform Act Section</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form3468Data/TotalCurrentYearInvestmentCr/@taxReformActSection"/>
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
    </table>

    
    
    
    
    
    
    
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
