<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS3800Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<!-- Defines the stage of the data, e.g. original or latest -->
<xsl:param name="Form3800Data" select="$RtnDoc/IRS3800" />
<xsl:param name="Form3800ScheduleAData" select="$RtnDoc/IRS3800/IRS3800ScheduleA" />



<xsl:template match="/">

<html>
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form3800Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 3800" />
    
    
    
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>
    <style type="text/css">  
      <xsl:if test="not($Print) or $Print=''">
        <xsl:call-template name="IRS3800Style"></xsl:call-template>
    <xsl:call-template name="AddOnStyle"></xsl:call-template> 
  </xsl:if>
</style>        
  <xsl:call-template name="GlobalStylesForm"/>
</head>

  <body class="styBodyClass">

    <form name="Form3800" style="font-size:7pt;">
      <!-- BEGIN WARNING LINE -->
        <xsl:call-template name="DocumentHeader"  />  
      <!-- END WARNING LINE -->
      <!-- Begin Form Number and Name -->
      <div class="styTBB" style="width:187mm;height:21mm;">
        <div class="styFNBox" style="width:34mm;height:21mm;">
          <div style="height:13mm;">
            Form<span class="styFormNumber">  3800</span><br/>
          </div>
          <div style="height:8mm;padding-top:.75mm;" >
            <span class="styAgency">Department of the Treasury</span><br/>
            <span class="styAgency">Internal Revenue Service (99)</span>
          </div>        
        </div>    
        <div class="styFTBox" style="width:122mm;height:21mm;">
          <div class="styMainTitle" style="height:11mm;">
            General Business Credit
          </div>
          <div class="styFST" style="height:5mm;font-size:7pt;padding-top:1mm;">
            <img src="{$ImagePath}/3800_Bullet.gif" alt="bullet image"/>
            See instructions.
          </div>
          <div class="styFST" style="height:4mm;font-size:7pt;padding-top:.5mm;">
            <img src="{$ImagePath}/3800_Bullet.gif" alt="bullet image"/>
            Attach to your tax return.
          </div>
        </div>
        <div class="styTYBox" style="width:30mm;height:21mm;">
          <div class="styOMB" style="height:2mm;">
            OMB No. 1545-0895
          </div>
          <div class="styTaxYear" style="height:9mm;padding-top:0;">20<span class="styTYColor">05</span></div>
          <div style="text-align:left;padding-left:3mm;">Attachment Sequence No. <span class="styBoldText">22</span></div>
        </div>
      </div>
      <!-- End Form Number and Name section -->
      <!-- Begin Names and Identifying number section -->
      <div class="styBB" style="width:187mm;">
        <div class="styNameBox" style="width:156mm;height:8mm;font-size:7pt;font-weight:normal;">
          Name(s) shown on return<br/>
          <span>
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
          </span>
        </div>
        <div class="styEINBox" style="width:30mm;height:4mm;padding-left:2mm;font-size:7pt;font-weight:bold;">
          Identifying number<br/><br/>
          <span style="width:25mm;text-align:left;font-weight:normal;">
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>      
          </span>
        </div>
      </div>    
      <!-- End Names and Identifying number section -->
      <!-- Begin Part I (Tentative Credit) Section -->      
      <div class="styBB" style="width:187mm;">
        <div class="styPartName" style="background-color:black;">Part I</div>
        <!-- Revisit:-->
        <div class="styPartDesc"><span style="width:8px;"></span>Current Year Credit</div>
      </div>
      <div class="styBB" style="width:187mm;">
      <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">
            1<span class="position: relative; left: 1mm;">a</span>
          <!-- Position makes the 'a' in "1a" line up with the other letters. -->
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            Investment credit
            (Form 3468)<span style="width:3px;"></span>
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:12px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:12px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:12px;"></span>.
             
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1a
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearInvestmentCredit" />
            </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->
      
          <div class="styLNLeftLtrBox" style="height:4mm;">
            b
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Work opportunity credit
            (Form 5884)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:12px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
            1b
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearWorkOpportunityCr" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            c
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Welfare-to-work credit
            (Form 8861)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1c
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearWelfareToWorkCredit" />                  </xsl:call-template>
          </div>
        </div>
       
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            d
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Credit for increasing research activities
            (Form 6765)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1d
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYIncreasingResearchCr" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
        
    <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->
       
          <div class="styLNLeftLtrBox" style="height:4mm;">
            e
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Low-income housing credit
            (Form 8586)
            <!--Dotted Line-->
            <span class="styBoldText">
                   <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1e
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYLowIncomeHousingCr" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
  
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            f
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Enhanced oil recovery credit
            (Form 8830)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:15px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:14px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1f
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYEnhancedOilRecoveryCr" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
        
      <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->
     
          <div class="styLNLeftLtrBox" style="height:4mm;">
            g
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Disabled access credit
            (Form 8826)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>. 
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1g
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearDisabledAccessCr" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
        
    <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            h
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Renewable electricity production credit
            (Form 8835, Section A only)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:10px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1h
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYRenewableElectricityCredit" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
 
    <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            i
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Indian employment credit
            (Form 8845)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.    
              <span style="width:16px;"></span>.   
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1i
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearIndianEmplmnCr" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
        
    <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            j
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            <span  style="font-family:arial;">
               Credit for employer social security and
              Medicare taxes paid on certain employee tips
              (Form 8846)
            </span>
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:2px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1j
          </div>
          <div class="styLNAmountBox" style="height:4mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYTaxesOnEmployeeTipsCr" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
  
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            k
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Orphan drug credit
            (Form 8820)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:1px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>. 
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1k
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearOrphanDrugCredit" />                  </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            l
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             New markets credit
            (Form 8874)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.    
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1l
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearNewMarketsCredit" />      
            </xsl:call-template>    
          </div>
        </div>  
        <!-- The following doesn't have a matching shcme elements for them-->
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            m
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Credit for small employer pension plan startup
            costs
            (Form 8881)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:8px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>. 
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1m
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYSmallEmployerPensionPlanCr" />    
            </xsl:call-template>    
          </div>
        </div>
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            n
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Credit for employer-provided child care
            facilities and services
            (Form 8882)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:6px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1n
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYEmplrProvChildCareFcltsCr" />      
            </xsl:call-template>    
          </div>
        </div>
    <!-- JMI -->
  	<div style="width:187mm;">
  	
   <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            o
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
		  Qualified railroad track maintenance credit 
		  (Form 8900)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:6px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
			<span style="width:16px;"></span>.
			<span style="width:16px;"></span>.
			<span style="width:16px;"></span>.
			<span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1o
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYQlfyRRTrackMaintenanceCr" />      
            </xsl:call-template>    
          </div>
        </div>

  <!-- JMI -->
  	  <div style="width:187mm;">
  	  
    <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">p</div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Biodiesel and renewable diesel fuels credit
            (Form 8864)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.              
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1p
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearBiodieselFuelCredit" />      
            </xsl:call-template>    
          </div>
        </div>
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            q
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Low sulfur diesel fuel production credit
            (Form 8896)
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYLowSulfurDieselCredit" />
              <xsl:with-param name="TabOrder" select="2"/>
            </xsl:call-template>
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1q
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYLowSulfurDieselCredit" />      
            </xsl:call-template>  
          </div>
        </div>        
     <!-- JMI -->
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            r
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            Distilled spirits credit (Form 8906)
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form3800Data/DistilledSpiritsCredit" />
              <xsl:with-param name="TabOrder" select="2"/>
            </xsl:call-template>
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1r
          </div>
             <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/DistilledSpiritsCredit" />      
            </xsl:call-template>  
      
          </div>
        </div>        

 <!-- /JMI -->        
        <!-- End elements -->      
              
        <div style="width:187mm;">
        
    <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            s
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Nonconventional source fuel credit
            (Form 8907)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:8px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
                 
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
            1s
          </div>
          <div class="styLNAmountBox">     <!-- Note - for 2004v2.0 and 2004v3.0 schemas this data is for line p on the old pdf -->   
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYNonconventionalFuelCredit" />                  
            </xsl:call-template>
          </div>
        </div>        
        <div style="width:187mm;">
        
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

          <div class="styLNLeftLtrBox" style="height:4mm;">
            t
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
          Energy efficient home credit (Form 8908)
            
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:12px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
            1t
          </div>
          <div class="styLNAmountBox">  <!-- Note - for 2004v2.0 and 2004v3.0 schemas this data is for line q on the old pdf -->
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYEnergyEfficientHomeCredit" />                  
            </xsl:call-template>
          </div>
        </div>    
        <!-- No matching XML shcema for this -->    
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">
            u
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Alternative motor vehicle credit
             (Form 8910)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1u
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYAlternativeMotorVehicleCrdt" />                  
            </xsl:call-template>
          </div>
        </div>
<!--  line 1v -->        
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">
            v
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             Alternative fuel vehicle refueling property credit
             (Form 8911)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1v
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYAlternativeRefuelingCredit" />                  
            </xsl:call-template>
          </div>
        </div>
        
            <!-- line 1w -->
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">
            w
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
          Credit for contributions to selected community development corporations
           (Form 8847).
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
          
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1w
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYCommunityContributionDevCr" />                  
            </xsl:call-template>
          </div>
        </div>
            <!-- Line 1x-->

<!--    <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$Form1120SData/NetGainLoss"/>
      </xsl:call-template>
          -->


        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">
            x
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
             <span>Trans-Alaska pipeline liability fund credit (see instructions)</span>
          
                 <xsl:call-template name="SetFormLinkInline">
                 <xsl:with-param name="TargetNode" select="$Form3800Data/CYAlaskaPipelineFundCredit"/>
                  </xsl:call-template>
          
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
             <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1x
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYAlaskaPipelineFundCredit" />                  
            </xsl:call-template>
          </div>
        </div>
        
        
            <!-- line 1y -->
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">
            y
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
          General credits from an electing large partnership 
             (Schedule K-1 (Form 1065-B))
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
                           
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1y
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYGenBusCrElectingLargePrtshp" />                  
            </xsl:call-template>
          </div>
        </div>
        
            <!-- line 1z -->
        <div style="width:187mm;">
          <div class="styLNLeftLtrBox" style="height:4mm;">
            z
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
              Credits for employers affected by Hurricane Katrina, Rita, or Wilma (Form 5884-A)
             
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  

            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          1z
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CYKatrinaEmpRetentionCredit" />                  
            </xsl:call-template>
          </div>
        </div>
            <!-- End -->
        
            <!-- End -->
              <div style="width:187mm;">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">
            2
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            <span class ="styBoldText">Current year credit.</span>
            <!-- Revisit -->
            Add lines 1a through 1z
            <span style="width:1px;"></span>
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:6px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          2
          </div>
          <div class="styLNAmountBox">            
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearGeneralBusCr" />      
            </xsl:call-template>    
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">
            3
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            Passive activity credits included on line 2
            (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:10px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          3
          </div>
          <div class="styLNAmountBox">            
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearPassiveActyCredits" />      
            </xsl:call-template>    
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">
            4
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            Subtract line 3 from line 2
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:7px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          4
          </div>
          <div class="styLNAmountBox">            
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/AdjustedCurrentYearGenBusCr" />      
            </xsl:call-template>    
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">
            5
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
              <!-- Revisit: Changing year 2002 to 2003 -->
            <!--Passive activity credits allowed for 2002-->
            Passive activity credits allowed for 2005
            (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          5
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/PssvActyCreditsAllowedCY" />      
            </xsl:call-template>  
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">
            6
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            <!-- Revisit: Changing year 2002 to 2003 -->
            <!--Carryforward of general business credit to 2002. See
            instructions for the schedule to attach-->
            Carryforward of general business credit to 2005. See
            instructions for the schedule to attach
            <!-- setting the push pin image -->
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form3800Data/GeneralBusCrCarryforwardCY" />
              <xsl:with-param name="TabOrder" select="2"/>
            </xsl:call-template>
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:14px;"></span>
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
          6
          </div>
          <div class="styLNAmountBox">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/GeneralBusCrCarryforwardCY" />      
            </xsl:call-template>
          </div>
        </div>
        <!-- No xml schema for the following element-->
        <div style="width:187mm;">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">
            7
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            <!-- Revisit:Changing year from 2003 to 04.-->
            <!--Carryback of general business credit from 2003-->
            Carryback of general business credit from 2006
            (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:4px;"></span>
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">
            7
          </div>
          <div class="styLNAmountBox">
            <!--<xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form3800Data/GeneralBusCrCarryforwardCY" />      
            </xsl:call-template>-->
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">
            8
          </div>
          <div class="styLNDesc" style="width:139mm;height:4mm;">
            <span class="styBoldText">Current year credit. </span>
            Add lines 4 through 7
            <!-- Revisit: -->
            <!--span class="styBoldText">
              Current year general business credit
            </span-->
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:12px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
          </div>
          <div class="styLNRightNumBoxNBB" style="height:4mm;">
            8
          </div>
          <div class="styLNAmountBoxNBB">
            <xsl:call-template name="PopulateAmount">
              <!--<xsl:with-param name="TargetNode" select="$Form3800Data/TentativeGeneralBusinessCredit" />-->
              <!--Because of schema changes the name has been changed CurrentYearGeneralBusinessCr -->      
              <xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearGeneralBusinessCr" />
            </xsl:call-template>
          </div>
        </div>        
      </div>
      <!-- End Part I -->
     <!--footer -->
    <div style="width:187mm;clear:both;padding-top:1mm;" class="pageend">
      <div style="width:90mm;font-weight:bold;" class="styGenericDiv">For Paperwork Reduction Act Notice, see instructions.</div>
      <div style="width:55mm;text-align:center;" class="styGenericDiv">Cat. No. 12392F</div>
      <div style = "float:right;" class="styGenericDiv">Form <span class="styBoldText">3800</span> (2005)</div>
    </div>
    <!-- header -->
    <div style="width:187mm;clear:both;padding-bottom:.5mm;" class="styBB">
      <div style="width:90mm;" class="styGenericDiv">Form 3800 (2005)</div>
      <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
      <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">2</span></div>
    </div>    
      
      <!--  begin Part II -->
      <div class="styBB" style="width:187mm;">
        <div class="styPartName" style="background-color:black;">
          Part II
        </div>
        <div class="styPartDesc">
          <span style="width:8px;"></span>Allowable Credit
        </div>
      </div>
      <!--div class="styBB" style="width:187mm;"-->
            <div style="width:187mm">  
	              <div class="styLNLeftNumBoxSD">
	              9
	              </div>
	        <div class="styLNDesc" style="width:139mm;height:4mm;">
		       Regular tax before credits (see instructions)
		          <!--Dotted Line-->
		          <span class="styBoldText">
		            <span style="width:10px;"></span>
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.
		            <span style="width:16px;"></span>.		            
		          </span>		          
		       </div> 		       
                    <div class="styLNRightNumBox" style="height:4.5mm;">
                    9
                   </div>  
                	<div class="styLNAmountBox" style="height:4.5mm;width:32.25mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form3800Data/RegularTaxBeforeCredits"/>
                  </xsl:call-template>
                </div>    
              </div>

 

      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">
          10
        </div>
        <div class="styLNDesc" style="width:139mm;height:4mm;">
          Alternative minimum tax (see instructions)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:10px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">
          10
        </div>
        <div class="styLNAmountBox">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/AlternativeMinimumTax" />      
          </xsl:call-template>
        </div>
      </div>
      
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">
          11
        </div>
        <div class="styLNDesc" style="width:139mm;height:4mm;">
          Add lines 9 and 10
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:15px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">
          11
        </div>
        <div class="styLNAmountBox">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/AdjustedRegTaxBeforeCredits" />      
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
      
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px; background-color:lightgrey;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

        <div class="styLNLeftNumBox" style="height:4.5mm;">12a</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Foreign tax credit
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:8px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">12a</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/ForeignTaxCredit" />      
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      
      <!-- The following form element does not have a matching element in the schema -->
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;padding-left:4.3mm;">b</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Credits from Form 1040, lines 48 through 54
                    <span class="styBoldText">
            <span style="width:5px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">12b</div>
        <div class="styLNAmountBox" style="height:4.5mm;"></div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;padding-left:4.3mm;">c</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Possessions tax credit (Form 5735, line 17 or 27)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:15px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">12c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/PossessionsTaxCredit" />
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;padding-left:4.3mm;">d</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Nonconventional source fuel credit (Form 8907,  line 23)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:5px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">12d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/NonconventionalFuelSourceCr" />
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;padding-left:4.3mm;">e</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Other specified credits (see instructions)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:9px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">12e</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/OtherSpecifiedCredits" />
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      <div style="width:187mm;">
      
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px; background-color:lightgrey;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

        <div class="styLNLeftLtrBox" style="height:4.5mm;padding-left:4.3mm;">f</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Add lines 12a through 12e
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:4px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">12f</div>
         <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/TotalTaxCredits" />
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">13</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          <span style="font-family:arial;">Net income tax. Subtract line 12f from line 11. If zero,
          skip lines 14 through 17 and enter -0- on line 18</span>          
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:10px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">13</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/NetIncomeTax" />                    </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
      
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px; background-color:lightgrey;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

        <div class="styLNLeftNumBox" style="height:4.5mm;">14</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Net regular tax. Subtract line 12f from line 9.
          If zero or less, enter -0-
          <span class="styBoldText">
              <span style="width:10px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm; ">14</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/NetRegularTax" />                    </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">15</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          <span style="font-family:arial;">
            Enter 25% (.25) of the excess, if any, of line 14 over
          </span>
          $25,000 (see instructions)
          <span class="styBoldText">
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">15</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/ExcessNetRegularTax" />                  </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">16</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Tentative minimum tax (see instructions)
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/TentativeMinimumTax" />                  </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;width:8.2mm;border-right-width:1px"></div>
      </div>
      <div style="width:187mm;">
       
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px; background-color:lightgrey;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->

        <div class="styLNLeftNumBox" style="height:4.5mm;">17</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Enter the greater of line 15 or line 16
          <span class="styBoldText">
            <span style="width:11px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">17</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/AdjustedExcessNetRegularTax" />                </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
      
     <!--     Extra Space   -->
            <div style="width:187mm;">
               <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
               <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px;"></div>
               <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
            </div>
       <!-- extra space -->
       <!-- check here -->
        <div class="styLNLeftNumBox" style="height:4.5mm;">18</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Subtract line 17 from line 13. If zero or less,
          enter -0-
          <span class="styBoldText">
            <span style="width:14px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">18</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/AdjustedNetIncomeTax" />                  </xsl:call-template>
        </div>
      </div>
    <!--/div-->
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">19</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          <span class="styBoldText">
            Credit allowed for the current year.
          </span>
          Enter the <span class="styBoldText">smaller</span> of line 8 or line 18 here and on Form
          1040, line 55; Form 1120, Schedule J, line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule
          G, line 2c; or the applicable line of your return. If line 19 is smaller than line 8, see instructions.
          <span class="styBoldText">
            Individuals, estates, and trusts:
          </span>
          See instructions if claiming the research credit.
          <span class="styBoldText">
            C corporations:
          </span>
          See Schedule A if claiming any regular investment credit carryforward and the line 19 instructions
          if there has been an ownership change, acquisition, or reorganization
          <!-- Schema changes of 2003 - Name got changed to CreditAllowedForTheCurrentYear -->
          <!-- setting the push pin image -->
          <xsl:call-template name="SetFormLinkInline">
            <!--<xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearGeneralBusinessCr" />-->
            <xsl:with-param name="TargetNode" select="$Form3800Data/CreditAllowedForTheCurrentYear" />
            <xsl:with-param name="TabOrder" select="2"/>
          </xsl:call-template>
          <xsl:call-template name="LinkToLeftoverDataTableInline">
            <xsl:with-param name="Desc">Line 19 - Other Credit Allowed Type</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form3800Data/CreditAllowedForTheCurrentYear/@otherCreditAllowedType"/>
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>
          <xsl:call-template name="LinkToLeftoverDataTableInline">
            <xsl:with-param name="Desc">Line 19 - Section 383 or Section 384 Indicator</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form3800Data/CreditAllowedForTheCurrentYear/@sec383Or384Indicator"/>
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>

          <span class="styBoldText">
            <span style="width:4px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:20.5mm; padding-top:0mm;">
          <div style="height:16.5mm;background-color:lightgrey;">
          </div>
          19
        </div>
        <div class="styLNAmountBoxNBB" style="height:20.5mm;padding-top:0mm;">
        <div style="height:16mm;">
                  </div>

          <xsl:call-template name="PopulateAmount">
            <!--<xsl:with-param name="TargetNode" select="$Form3800Data/CurrentYearGeneralBusinessCr" />-->                          <xsl:with-param name="TargetNode" select="$Form3800Data/CreditAllowedForTheCurrentYear" />                        </xsl:call-template>
        </div>
      </div>
    </div>  
    <!-- End of part II -->
       
    <!-- Schedule A -->
    <div class="styBB" style="width:187mm;float:none;clear:none;">
      <div class = "styIRS3800ScheduleName" style="font-size:8pt; width: 23mm;">
        Schedule A&#151;</div>
      <div class="styPartDesc" style="font-weight:normal;font-size:8pt;padding-left:0;width: 164mm;">
        <span class="styBoldText">Additional General Business Credit Allowed by
          Code Section 38(c)(2)</span> <span style="font-type:normal"> (Before Repeal by the Revenue
          Reconciliation Act of 1990)</span> <span style="font-weight:bold;">&#151;Only Applicable to C Corporations</span>
      </div>
    </div>
    <div class="styBB" style="width:187mm;float:none;clear:none;">
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">20</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Enter the portion of the credit shown on line 6 that is attributable to the regular investment credit
          under section 46 (before amendment by the Revenue Reconciliation Act of 1990)
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:7mm;padding-top:4mm;">20</div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/RegularInvestmentCredit" />                  </xsl:call-template>
        </div>
      </div>
      
      <!-- Blank line between 20 and 21 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;border-right-width:1px;width:8.2mm;"></div>
        <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;width:31mm;"></div>
      </div>

      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">21</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Tentative minimum tax (from line 16)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">21</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/TentativeMinimumTax" />                  </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;border-right-width:1px;width:8.2mm;"></div>
      </div>
      
      <!-- Blank line between 21 and 22 -->
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">22</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Multiply line 21 by 25% (.25)
          <span class="styBoldText">
            <span style="width:8px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">22</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/PercentageOfMinTax" />                  </xsl:call-template>
        </div>
      </div>
      
      <!-- Blank line between 22 and 23 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;border-right-width:1px;width:8.2mm;"></div>
        <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;width:31mm;"></div>
      </div>

      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">23</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Enter the amount from line 18
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:10px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">23</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/AdjustedNetIncomeTax" />                  </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;border-right-width:1px;width:8.2mm;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">24</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          Enter the portion of the credit shown on line 8 that is not attributable
          to <br/>the regular investment credit under section 46 (before amendment
          by the Revenue Reconciliation Act of 1990)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:17px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:17px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:10.5mm;padding-top:6mm;">24</div>
        <div class="styLNAmountBox" style="height:10.5mm;padding-top:6mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/NonRegularInvestmentCredit" />                  </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:10.5mm;border-right-width:1px;width:8.2mm;"></div>
      </div>
      
      <!-- Blank line between 24 and 25 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;border-right-width:1px;width:8.2mm;"></div>
        <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;width:31mm;"></div>
      </div>

      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">25</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Subtract line 24 from line 23. If zero or less, enter -0-
          <span class="styBoldText">
            <span style="width:12px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">25</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/ReAdjustedNetIncomeTax" />                  </xsl:call-template>
        </div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">26</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Subtract line 25 from line 20. If zero or less, enter -0-
          <span class="styBoldText">
            <span style="width:12px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">26</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/AdjustedRegularInvestmentCr" />                </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">27</div>
        <div class="styLNDesc" style="width:99mm;height:4.5mm;">
          For purposes of this line only, refigure the amount on Form 4626, line
          10, by using zero on Form 4626, line 6, and enter the result here
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:15px;"></span>.
            <span style="width:14px;"></span>.
            <span style="width:15px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:7.3mm;padding-top:3.2mm;">27</div>
        <div class="styLNAmountBox" style="height:7.3mm;padding-top:3.2mm;">  
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/ReAdjustedAMTI" />                    </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.3mm;border-right-width:1px;width:8.2mm;"></div>
      </div>
      
      <!-- Blank line between 27 and 28 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;"></div>
        <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width:0px; background-color:lightgrey;"></div>
        <div class="styLNAmountBox" style="height:4.5mm;border-left-width:0px;border-bottom-width:0px;border-left-width:1px;"></div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">28</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Multiply line 27 by 10% (.10)
          <span class="styBoldText">
            <span style="width:8px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">28</div>
        <div class="styLNAmountBox" style="height:4.5mm;">         
           <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/PercentageOfReAdjustedAMTI" />
           </xsl:call-template>           
        </div>
      </div>
      
       <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">29</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Net income tax (from line 13)
          <span class="styBoldText">
            <span style="width:5px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">29</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/NetIncomeTax" />                    </xsl:call-template>
        </div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">30</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Enter the amount from line 19
          <span class="styBoldText">
            <span style="width:6px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:15px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:15px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">30</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800Data/CreditAllowedForTheCurrentYear" />                </xsl:call-template>
        </div>
      </div>
       
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">31</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Subtract line 30 from line 29
          <span class="styBoldText">
            <span style="width:11px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:15px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:15px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">31</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/ModifiedNetIncomeTax" />                  </xsl:call-template>
        </div>
      </div>
      
       <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">32</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Subtract line 28 from line 31
          <span class="styBoldText">
            <span style="width:13px;"></span>
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">32</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/RecalculatedNetIncomeTax" />                  </xsl:call-template>
        </div>
      </div>
      
       <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">33</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Enter the smallest of line 22, line 26, or line 32
          <span class="styBoldText">
            <span style="width:4px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">33</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/SmallestInterimValue" />                  </xsl:call-template>
        </div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">34</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Subtract line 33 from line 21
          <span class="styBoldText">
            <span style="width:9px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/AdjustmentTentativeMinTax" />                  </xsl:call-template>
        </div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">35</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Enter the greater of line 15 or line 34
          <span class="styBoldText">
            <span style="width:12px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">35</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/GreatestInterimValue" />                  </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">36</div>
        <div class="styLNDesc" style="width:139mm;height:4.5mm;">
          Subtract line 35 from line 29. Also enter this amount on line 19
          instead of the amount previously figured on that line. Write
          "Sec. 38(c)(2)" next to your entry on line 19
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:7mm;padding-top:4mm;">36</div>
        <div class="styLNAmountBoxNBB" style="height:7mm;padding-top:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form3800ScheduleAData/GeneralBusinessCredit" />                  </xsl:call-template>
        </div>
      </div>
    </div>
      
      
    <!-- capturing the page bottom info -->
  
    <div style="width:187mm;padding-top:1mm;">
      <div style="float:left;">
      </div>
      <div style="float:right;">
        <span style="width:80px;"></span>  
        Form <span class="styBoldText">3800</span> (2005)
      </div>
    </div>

    
<!-- Adding page break -->
  <p class="pageend"></p>

    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" tabindex="1" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form3800Data" />
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
      <xsl:call-template name="PopulateLeftoverRow">
            <xsl:with-param name="Desc">Line 19 - Other Credit Allowed Type</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form3800Data/CreditAllowedForTheCurrentYear/@otherCreditAllowedType"/>
            <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
      <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Line 19 - Section 383 or Section 384 Indicator</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form3800Data/CreditAllowedForTheCurrentYear/@sec383Or384Indicator"/>
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
    </table>
    
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
