<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS4136Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<!-- Defines the stage of the data, e.g. original or latest -->
<xsl:param name="IRS4136Data" select="$RtnDoc/IRS4136" />

<xsl:template match="/">

<html>
<head>

<title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($IRS4136Data)"></xsl:with-param></xsl:call-template></title>
<meta http-equiv="Pragma" content="no-cache"/>
<meta http-equiv="Cache-Control" content="no-cache"/>
<meta http-equiv="Expires" content="0"/>
<meta http-equiv="Cache-Control" content="private"/>
<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
<meta name="Description" content="IRS Form 4136"/>
<META name="GENERATOR" content="IBM WebSphere Studio"/>


<script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
<xsl:call-template name="InitJS"></xsl:call-template>
<style type="text/css">
   <xsl:if test="not($Print) or $Print=''">
    <xsl:call-template name="IRS4136Style"></xsl:call-template>    
     <xsl:call-template name="AddOnStyle"></xsl:call-template>
   </xsl:if>
</style>

<xsl:call-template name="GlobalStylesForm"/>
</head>
<body class="styBodyClass">
<form name="IRS4136">
<xsl:call-template name="DocumentHeader"></xsl:call-template>

<!--   BEGIN FORM HEADER   -->
<div class="styIRS4136BB" style="width:187mm;">
  <div class="styIRS4136FN" style="width:31mm; height: 21mm">
    <div>
      <span>Form <span style="width: 4px"></span></span>
      <span class="styFormNumber">4136</span>
      <br />
      <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data"/>
      </xsl:call-template>        
    </div>
    <div class="styIRS4136Agency" style="padding-top:4mm;">
      Department of the Treasury Internal Revenue Service
    </div>
  </div>
  <div class="styGenericDiv" style="width:125mm;height:21mm;text-align:center;font-weight:bold;">
    <div class="styMainTitle">Credit for Federal Tax Paid on Fuels</div>
    <div style="padding-top:7mm;">
      <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/> See the Instructions on page 3.
    </div>
    <div style="padding-top:2mm;">
      <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/> Attach this form to your income tax return.
    </div>
  </div>
  <div class="styIRS4136TYBox" style="height: 21mm">
    <div class="styIRS4136OMB">OMB No. 1545-0162</div>
    <div class="styIRS4136TY">20<span class="styTYColor">05</span></div>
    <div class="styIRS4136Sequence">Attachment<br/>Sequence No. <b>23</b></div>
  </div>
</div>
<!--   END FORM HEADER   -->

<!--   BEGIN TAXPAYER INFO   -->
<div style="width:187mm;">
  <div class="styIRS4136BusinessName" style="font-size: 7pt; font-weight: normal;">Name (as shown on your income tax return)
    <br/>
    <span style="font-family: verdana, arial, sans-serif;font-size: 7pt; font-weight: normal;">
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
    </span>
  </div>
  <div class="styEINBox" style="padding-left: 2mm;font-size:7pt;font-weight:bold;">Taxpayer identification number
    <div style="padding-top:3mm;font-weight:normal;">
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>          
    </div>
  </div>
</div>
<!--   END TAXPAYER INFO   -->

<!--   BEGIN NOTE HEADER   -->
<div class="styIRS4136CautionHdr">
  <span class="styIRS4136CautionHdrTitle" >
    Caution:
  </span>
  <span style="width:164mm;float:left;font-size:7pt;">
    <img src="{$ImagePath}/4136_Bullet_Round.gif" alt="Bullet"/><span class="styIRS4136NBSP"></span>Claims for diesel fuel and kerosene (other than kerosene used in aviation) used on a farm for farming purposes
on new lines 3e and 4c are made only by the ultimate purchaser after September 30, 2005.
     <span style="float:left;">
      <img src="{$ImagePath}/4136_Bullet_Round.gif" alt="Bullet"/><span class="styIRS4136NBSP"></span>Claims on lines 5 and 8 for aviation-grade kerosene can be made only for uses or sales before October 1, 2005. See
line 14 and the worksheets in the instructions for claims for kerosene used in aviation after September 30, 2005.
    </span>
    <span style="float:left;">
      <img src="{$ImagePath}/4136_Bullet_Round.gif" alt="Bullet"/><span class="styIRS4136NBSP"></span>There are two credit rates in effect for most fuels during 2005. The *  rate is applicable after Sept. 30, 2005.
    </span>
  </span>  
</div>

<!--   END NOTE HEADER   -->

<!--   BEGIN BLOCK 1   -->
<!--   BEGIN LINE 1   -->

<!-- Count the number of rows in the table -->
<xsl:variable name="table1RowCount" select="2 + count($IRS4136Data/OtherNontaxableUseOfGasoline)"/>

<div class="styIRS4136NumLine" style="border-top-width: 0px;">
  <span style="float:left;clear:none;"> 1<span class="styIRS4136NBSP"></span> Nontaxable Use of Gasoline</span>
  <span style="width:7mm;text-align:right;float:right; clear: none">
    <xsl:call-template name="SetDynamicTableToggleRowCount">
       <xsl:with-param name="DataRowCount" select="$table1RowCount"/>
       <xsl:with-param name="containerHeight" select="3"/>
       <xsl:with-param name="containerID" select=" 'NGctn' "/>
     </xsl:call-template>
   </span>
</div>

<div class="styIRS4136TableContainer1" id="NGctn">
  <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
  <!-- Declare all varaible that hold the count of the repeating elements in this block -->
  <xsl:variable name="AFRowCount" select="count($IRS4136Data/OtherNontaxableUseOfGasoline)"/>
  <table class="styIRS4136Table" cellspacing="0">
  <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px;"><span class="styIRS4136TableCellPad"></span></th> 
      <th class="styIRS4136TableCellA" style="text-align: center"><b>(a) Type of use</b> </th>
      <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
    <!--  Row 1A OFF-HIGHWAY BUSINESS USE OF GASOLINE  -->
    <tr>
      <td class="styIRS4136LetterCell"><b>a</b></td>
      <td class="styIRS4136TableCellLine">Off-highway business use of gasoline</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellB" style="width:14mm;">$ .184/.183*</td>
      <td class="styIRS4136TableCellC" style="text-align:left;">
        <xsl:if test="($AFRowCount &lt;=1) or  ($AFRowCount &gt;1) and $Print != $Separated">           
          <xsl:attribute name="style">text-align:right;</xsl:attribute>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="3" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/OffHwyBusinessGasolineGallons" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="($AFRowCount &gt;1 and $Print = $Separated)">
            <!-- Hard coded the string.  Reason is the element that could be used for the target node in additional data table may not be present.  So the message is will not be seen.  Other method is to call the mutually exclusive xsl:if calling different PopulateAdditionalDataTableMessage with different targetnodes.-->
            See Add'l Data
        </xsl:if>
       <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces" rowspan="3">
        <!-- When the row count of Line 1C is less than 3, then add a border under the bracket to close out the row -->
        <xsl:choose>
          <xsl:when test="$AFRowCount &lt;2">
            <xsl:attribute name="style">border-bottom-width: 1px</xsl:attribute>
          </xsl:when>
          <xsl:when test="$Print = $Separated">
            <xsl:attribute name="style">border-bottom-width: 1px</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="style">border-bottom-width: 0px</xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        <img src="{$ImagePath}/4136_Bracket_L6.gif" alt="bracket"/>
      </td>
      <td class="styIRS4136TableCellD" style="text-align:left;vertical-align:top;">
        <xsl:choose>
          <xsl:when test="$AFRowCount &lt;2">
            <xsl:attribute name="rowspan">3</xsl:attribute>
          </xsl:when>
          <xsl:when test="$Print = $Separated">
            <xsl:attribute name="rowspan">3</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount + 2"></xsl:value-of></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="($AFRowCount &lt;=1) or ($AFRowCount &gt;1 and $Print != $Separated)">
            <xsl:attribute name="style">text-align:right;vertical-align:middle;</xsl:attribute>      
        </xsl:if>
        $
        <xsl:if test="($AFRowCount &lt;=1) or ($AFRowCount &gt;1 and $Print != $Separated)"> 
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseOfGasolineCredit" />
            </xsl:call-template>
          </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        <xsl:choose>
          <xsl:when test="$AFRowCount &lt; 2">
            <xsl:attribute name="rowspan"><xsl:number value="3"></xsl:number></xsl:attribute>
          </xsl:when>
          <xsl:when test="$Print = $Separated">
            <xsl:attribute name="rowspan">3</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount + 2"></xsl:value-of></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        362
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
      
      <!--  Row 1B USE OF GASOLINE ON A FARM FOR FARMING PURPOSES -->
      <tr>
      <td class="styIRS4136LetterCell"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use of gasoline on a farm for farming purposes</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.184/.183*</td>
      <td class="styIRS4136TableCellC">
        <xsl:if test="($AFRowCount &lt;=1) or  ($AFRowCount &gt;1) and $Print != $Separated">           
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="3" />
              <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesGasolineGallons" />
            </xsl:call-template>
          </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
      <!--  Loop  -->
      <!--  Row 1C OTHER NONTAXABLE USE OF GASOLINE  -->
       <xsl:if test="$AFRowCount = 0 or (($AFRowCount &gt;1) and ($Print = $Separated))">
        <tr>  
          <td class="styIRS4136LetterCell" style="vertical-align:middle;border-bottom-width:1px;"><b>c</b></td>
          <td class="styIRS4136TableCellLine" style="vertical-align:middle;">Other nontaxable use of gasoline</td>
          <td class="styIRS4136TableCellA">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TypeOfUse" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellB" style="padding-left:3mm;">.184/.183*</td>
          <td class="styIRS4136TableCellC">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="Gallons" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
        </tr>
      </xsl:if>     
      <xsl:if test="($AFRowCount &lt;=1)  or  ($Print != $Separated)"> 
        <xsl:for-each select="$IRS4136Data/OtherNontaxableUseOfGasoline">
          <tr>
            <xsl:if test="position()=1">      
              <td class="styIRS4136LetterCell" style="vertical-align:middle;border-bottom-width:1px;">
                <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount"></xsl:value-of></xsl:attribute>
                <b>c</b>
              </td>
              <td class="styIRS4136TableCellLine" style="vertical-align:middle;">
                <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount"></xsl:value-of></xsl:attribute>
                Other nontaxable use of gasoline
              </td>
            </xsl:if>
            <td class="styIRS4136TableCellA">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="TypeOfUse" />
              </xsl:call-template>
              <span class="styIRS4136TableCellPad"></span>
            </td>
            <td class="styIRS4136TableCellB" style="padding-left:3mm;">.184/.183*</td>
            <td class="styIRS4136TableCellC">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="MaxSize" select="9" />
                <xsl:with-param name="TargetNode" select="Gallons" />
              </xsl:call-template>
              <span class="styIRS4136TableCellPad"></span>
            </td>
            <!--If this is the last repeating row in line 1C, then add a blank cell with a bottom border to close out --> 
            <!--column under the bracket --> 
            <xsl:if test="position()=$AFRowCount">
              <td class="styIRS4136Braces">
                 <span class="styIRS4136TableCellPad"></span>
               </td>
             </xsl:if>
          </tr>
        </xsl:for-each>
      </xsl:if>
    <!-- End Loop  -->
      
    </tbody>
  </table>
</div>
<xsl:call-template name="SetInitialDynamicTableHeightRowCount">
    <xsl:with-param name="DataRowCount" select="$table1RowCount"/>
    <xsl:with-param name="containerHeight" select="3"/>
    <xsl:with-param name="containerID" select=" 'NGctn' "/>
</xsl:call-template>
<!--  END LINE 1   -->


<!--   BEGIN BLOCK 2   -->
<!--   BEGIN LINE 2   -->

<!-- Track the number of rows in table 2-->
<xsl:variable name="table2RowCount" select="1 + count($IRS4136Data/NontaxableAviationGasoline)" />

<div class="styIRS4136NumLine" style="float:none">
  <span style="float:left;clear:none;"> 2<span class="styIRS4136NBSP"></span>  Nontaxable Use of Aviation Gasoline</span>
  <span style="width:7mm;text-align:right;float:right; clear: none">
     <xsl:call-template name="SetDynamicTableToggleRowCount">
       <xsl:with-param name="DataRowCount" select="$table2RowCount"/>
       <xsl:with-param name="containerHeight" select="2"/>
       <xsl:with-param name="containerID" select=" 'AGctn' "/>
     </xsl:call-template>
   </span>
</div>

<div class="styIRS4136TableContainer2" id="AGctn">
  <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellA" style="text-align: center"><b>(a) Type of use</b> </th>
      <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 2A USE IN COMMERCIAL AVIATION (OTHER THAN FOREIGN TRADE) -->
    <tr>
      <td class="styIRS4136LetterCell"><b>a</b></td>
      <td class="styIRS4136TableCellLine">Use in commercial aviation (other than foreign trade)</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        <span style="width: 5px"> </span> $ .15
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC">
        
        <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableAviationGasoline) &lt;= 1)">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationGasolineGallons" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test=" ((count($IRS4136Data/NontaxableAviationGasoline) &gt; 1) and ($Print = $Separated))">
          <xsl:attribute name="style">text-align:left;</xsl:attribute>
            <xsl:call-template name="PopulateAdditionalDataTableMessage">
                <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableAviationGasoline"/>     
                <xsl:with-param name="ShortMessage" select=" 'true' " />                 
            </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD" style="text-align:left;">
          <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableAviationGasoline) &lt;= 1)">
            <xsl:if test="not(count($IRS4136Data/NontaxableAviationGasoline) = 0) ">
             <xsl:attribute name="style">text-align:right;</xsl:attribute>
           </xsl:if>
        </xsl:if>
      $
          <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableAviationGasoline) &lt;= 1)">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationGasolineCredit" />
            </xsl:call-template>
          </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        354
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 2B OTHER NONTAXABLE USE  -->
    <!-- LOOP -->
    <xsl:variable name="AGRowCount" select="count($IRS4136Data/NontaxableAviationGasoline)"></xsl:variable>
      <xsl:if test="$AGRowCount = 0 or ((count($IRS4136Data/NontaxableAviationGasoline) &gt; 1) and ($Print = $Separated))">
      <tr>
        <td class="styIRS4136LetterCell" style="vertical-align:middle;border-bottom-width:1px;"><b>b</b></td>
        <td class="styIRS4136TableCellLine" style="vertical-align:middle;">Other nontaxable use
      </td>
      <td class="styIRS4136TableCellA">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">.194/.193*</td>
      <td class="styIRS4136TableCellC" style="text-align:left;">
          <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        324
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
      </xsl:if>

<!-- Adding check for the SRD -->
    <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableAviationGasoline) &lt;= 1) "> 
      <xsl:for-each select="$IRS4136Data/NontaxableAviationGasoline">
    <tr>
      <xsl:if test="position()=1">
        <td class="styIRS4136LetterCell" style="vertical-align:middle;border-bottom-width:1px">
          <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
          <b>b</b>
        </td>
        <td class="styIRS4136TableCellLine" style="vertical-align:middle;">
          <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
           Other nontaxable use
        </td>
      </xsl:if>
          <td class="styIRS4136TableCellA">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TypeOfUse" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellB">.194/.193*</td>
          <td class="styIRS4136TableCellC">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="Gallons" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <xsl:if test="position()=1">
            <td class="styIRS4136TableCellD">
              <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableAviationGasolineCr" />
              </xsl:call-template>
              <span class="styIRS4136TableCellPad"></span>
            </td>
            <td class="styIRS4136TableCellE">
              <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
              324
              <span class="styIRS4136TableCellPad"></span>
            </td>
          </xsl:if>
      </tr> 
    </xsl:for-each> 
  </xsl:if>           
      <!--  END LOOP  -->
    </tbody>
  </table>
</div>
<xsl:call-template name="SetInitialDynamicTableHeightRowCount">
    <xsl:with-param name="DataRowCount" select="$table2RowCount"/>
    <xsl:with-param name="containerHeight" select="2"/>
    <xsl:with-param name="containerID" select=" 'AGctn' "/>
</xsl:call-template>
<!--  LINE 2   -->

<!--   BEGIN BLOCK 3   -->
<!--   BEGIN LINE 3   -->
<div class="styIRS4136NumLine" style="float: none">3<span class="styIRS4136NBSP"></span>  Nontaxable Use of Undyed Diesel Fuel</div>
<!--   END LINE 3   -->

<!-- Number of rows in table 3 -->
<xsl:variable name="table3RowCount" select="4 + count($IRS4136Data/NontaxableUseOfUndyedDiesel)" />


<!--   BEGIN BLOCK DESCRIPTION   -->
<div class="styIRS4136DescLine" style="margin-left: 5mm; margin-right: 5mm;">
  Claimant certifies that the diesel fuel did not contain visible evidence of dye.
</div>
<div class="styBB" style="width:182mm;margin-left:2.75mm;font-size:6pt;">
  <div style="float:left;padding-top:1mm;">
    <label>
      <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselUseException" />
      </xsl:call-template>
      <b>Exception.</b> If any of the diesel fuel included in this claim <b>did</b> 
      contain visible evidence of dye, attach an explanation; check here
    </label> 
  </div>
  <div style="float:right;padding-right:.5mm;">
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselUseException"/>
      <xsl:with-param name="TabOrder" select="1"/>
    </xsl:call-template>    
    <span style="letter-spacing:10px;font-weight:bold;">........</span>
    <span style="margin-left: 1mm; margin-right:1mm">
      <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/>
    </span>
    <input type="checkbox" class="styIRS4136Ckbox" name="UndyedFuel">
      <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselUseException" />
      </xsl:call-template>
    </input>  
    <xsl:call-template name="SetDynamicTableToggleRowCount">
      <xsl:with-param name="DataRowCount" select="$table3RowCount"/>
      <xsl:with-param name="containerHeight" select="5"/>
      <xsl:with-param name="containerID" select=" 'NUDctn' "/>
    </xsl:call-template>
  </div>
</div>

<div class="styIRS4136TableContainer3" id="NUDctn">
  <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="text-align: left;padding-left:0px;border-bottom-width:0px;border-top-width:0px;"><b>Caution: </b><i>Claims for diesel fuel used on a farm for farming purposes are made only by the ultimate purchaser on line 3e after September 30, 2005.</i></th>
      <th class="styIRS4136TableCellA" style="text-align: center"><b>(a) Type of use</b> </th>
        <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
    <!--  Row 3A NONTAXABLE USE  -->
    <!-- LOOP -->
    <xsl:variable name="UDRowCount" select="count($IRS4136Data/NontaxableUseOfUndyedDiesel)"></xsl:variable>
    <xsl:if test="$UDRowCount = 0 or ((count($IRS4136Data/NontaxableUseOfUndyedDiesel) &gt; 1) and ($Print = $Separated))">
      <tr>
         <td class="styIRS4136LetterCell"><b>a</b></td>
        <td class="styIRS4136TableCellLine">
          Nontaxable use
        </td>  
        <td class="styIRS4136TableCellA">
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellB" >$ .244/.243*</td>
        <td class="styIRS4136TableCellC" style="text-align:left;">
          <xsl:call-template name="PopulateAdditionalDataTableMessage">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseOfUndyedDiesel"/>        
            <xsl:with-param name="ShortMessage" select="'true'" />              
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
        <td class="styIRS4136TableCellD" style="text-align:left;">$
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE">360</td>
      </tr> 
    </xsl:if>
    <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 1) "> 
      <xsl:for-each select="$IRS4136Data/NontaxableUseOfUndyedDiesel">
        <tr>
          <xsl:if test="position()=1">
            <td class="styIRS4136LetterCell">
              <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>
              <b>a</b>        
            </td>
            <td class="styIRS4136TableCellLine">
              <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>
              Nontaxable use
            </td>
          </xsl:if>
              <td class="styIRS4136TableCellA">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="TypeOfUse" />
                </xsl:call-template>
                <span class="styIRS4136TableCellPad"></span>
              </td>
              <td class="styIRS4136TableCellB">
                <xsl:if test="position()=1">$ .244/.243*</xsl:if>
                <xsl:if test="position()!=1"><span style="padding-left:3mm;">.244/.243*</span></xsl:if>
              </td>
              <td class="styIRS4136TableCellC">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="MaxSize" select="9" />
                  <xsl:with-param name="TargetNode" select="Gallons" />
                </xsl:call-template>
                <span class="styIRS4136TableCellPad"></span>
              </td>
              <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
              <xsl:if test="position()=1">
                <td class="styIRS4136TableCellD">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>$
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseOfUndyedDieselCr" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellE">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>
                  360
                  <span class="styIRS4136TableCellPad"></span>
                </td>
              </xsl:if>
          </tr>  
        </xsl:for-each>
      </xsl:if>
      <!--  END LOOP  -->
        <!--  Row 3B USE IN TRAINS JANUARY 1 -->
    <tr>
      <td class="styIRS4136LetterCell"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use in trains, January 1, 2005 – June 30, 2005</td>
      <!--td class="styIRS4136TableCellLine"><b>b</b> Use in trains</td-->
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        <span style="width: 10px"></span>
        .21
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC">
      <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 1) "> 
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/TrainUseOfUndyedDieselGallons" />
        </xsl:call-template>
      </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces" rowspan="2"><img src="{$ImagePath}/4136_Bracket_L2L3L4.gif" alt="bracket"/></td>
      <td class="styIRS4136TableCellD" rowspan="2">
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 1) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/TrainUseOfUndyedDieselCredit" />
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE" rowspan="2">
        353
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

        <!--  Row 3C USE IN TRAINS JULY 1-->
    <tr>
      <td class="styIRS4136LetterCell"><b>c</b></td>
      <td class="styIRS4136TableCellLine">Use in trains, July 1, 2005 – December 31, 2005</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.22</td>
      <td class="styIRS4136TableCellC">
      <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 1) "> 
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/TrainUseOfUndyedDieselGal" />
        </xsl:call-template>
      </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

      <!--  Row 3D USE IN CERTAIN INTECITY AND LOCAL BUSES   -->
    <tr>
      <td class="styIRS4136LetterCell" ><b>d</b></td>
      <td class="styIRS4136TableCellLine">
        Use in certain intercity and local buses
      </td>
      <!--td class="styIRS4136TableCellLine"><b>c</b> Use in certain intercity and local buses</td-->
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.17</td>
      <td class="styIRS4136TableCellC">
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 2) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfUndyedDieselBusesGallons" />
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>      
      <td class="styIRS4136TableCellD">
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 2) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfUndyedDieselInBusesCredit" />
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        350
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

      <!--  Row 3E USE ON A FARM  -->
    <tr>
      <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>e</b></td>
      <td class="styIRS4136TableCellLine">Use on a farm for farming purposes after Sept. 30, 2005</td>
      <!--td class="styIRS4136TableCellLine"><b>c</b> Use in certain intercity and local buses</td-->
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.243</td>
      <td class="styIRS4136TableCellC">
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 2) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselForFarmingGallons" />
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad">        
        </span>
      </td>
      
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>      
      <td class="styIRS4136TableCellD">
      
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &lt;= 2) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselForFarmingCredit" />
          </xsl:call-template>
        </xsl:if>

      
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        360
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
    </tbody>
  </table>
</div>
<xsl:call-template name="SetInitialDynamicTableHeightRowCount">
  <xsl:with-param name="DataRowCount" select="$table3RowCount"/>
  <xsl:with-param name="containerHeight" select="5"/>
  <xsl:with-param name="containerID" select=" 'NUDctn' "/>
</xsl:call-template>
<!--   END LINE 3   -->


<!--   BEGIN BLOCK 4   -->
<!--   BEGIN LINE 4   -->
<div class="styIRS4136NumLine" style="float:none">
  <div class="styGenericDiv" style="width:5mm;">4</div>
  <div class="styGenericDiv">Nontaxable Use of Undyed Kerosene (Other Than Aviation-Grade Kerosene and Kerosene Used in Aviation)</div>
</div>

<!-- Number of rows in table 4 -->
<xsl:variable name="table4RowCount" select="count($IRS4136Data/NontaxableUseOfUndyedKerosene)" />


<!--   BEGIN BLOCK DESCRIPTION   -->
<div class="styIRS4136DescLine" style="margin-left: 5mm; margin-right: 5mm;">
  Claimant certifies that the kerosene did not contain visible evidence of dye.
</div>

<div class="styBB" style="width:182mm;margin-left: 2.75mm;font-size:6pt;">
  <div style="float:left;padding-top:1mm;">
    <label>
      <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneUseException" />
      </xsl:call-template>
      <b>Exception.</b> If any of the kerosene included in this claim <b>did</b> 
      contain visible evidence of dye, attach an explanation; check here
    </label>
  </div>
  <div style="float:right;padding-right:.5mm;">
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneUseException"/>
      <xsl:with-param name="TabOrder" select="3"/>
    </xsl:call-template>
    <span style="letter-spacing:10px;font-weight:bold;">........</span>
    <span style="margin-left: 1mm; margin-right:1mm">
      <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/>
    </span>
    <input type="checkbox" class="styIRS4136Ckbox" name="UndyedKerosene">
      <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneUseException" />
      </xsl:call-template>
    </input>
    <xsl:call-template name="SetDynamicTableToggleRowCount">
       <xsl:with-param name="DataRowCount" select="$table4RowCount"/>
       <xsl:with-param name="containerHeight" select="3"/>
       <xsl:with-param name="containerID" select=" 'UKctn' "/>
    </xsl:call-template>
  </div>
</div>

<div class="styIRS4136TableContainer4" id="UKctn">
  <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
  <table class="styIRS4136Table" cellspacing="0" >
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="text-align:left; border-bottom:0;font-size:6pt;">
        <b>Caution: </b><i>Claims for kerosene used on a farm for farming
        purposes are made only by the ultimate purchaser on line 4c after
        September 30, 2005. See the instructions for an exception
        for kerosene used in aviation.</i></th>
      <th class="styIRS4136TableCellA" style="text-align: center"><b>(a) Type of use</b> </th>
      <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
    <!--  Row 4A NONTAXABLE USE  -->
    <!-- LOOP -->
    <xsl:variable name="UKRowCount" select="count($IRS4136Data/NontaxableUseOfUndyedKerosene)"></xsl:variable>
    <xsl:if test="$UKRowCount = 0 or ((count($IRS4136Data/NontaxableUseOfUndyedKerosene) &gt; 1) and ($Print = $Separated))">
      <tr>
        <td class="styIRS4136LetterCell"><b>a</b></td>
        <td class="styIRS4136TableCellLine">Nontaxable use</td>  
        <td class="styIRS4136TableCellA"><span class="styIRS4136TableCellPad"></span></td>
        <td class="styIRS4136TableCellB" >$ .244/.243*</td>
        <td class="styIRS4136TableCellC">
          <xsl:attribute name="style">text-align:left;</xsl:attribute>
          <xsl:call-template name="PopulateAdditionalDataTableMessage">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseOfUndyedKerosene"/>    
            <xsl:with-param name="ShortMessage" select=" 'true' " />                  
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellD" style="text-align:left;">$
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE">346<span class="styIRS4136TableCellPad"></span></td>
      </tr>
    </xsl:if>
    <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedKerosene) &lt;= 1) "> 
      <xsl:for-each select="$IRS4136Data/NontaxableUseOfUndyedKerosene">
      <tr>
      <xsl:if test="position()=1">
        <td class="styIRS4136LetterCell">
          <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>
          <b>a</b><span style="width:1px;"/>
        </td>
        <td class="styIRS4136TableCellLine">
          <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>
          Nontaxable use
        </td>
      </xsl:if>
          <td class="styIRS4136TableCellA">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TypeOfUse" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellB">
            <xsl:if test="position()=1">$ .244/.243*</xsl:if>
            <xsl:if test="position()!=1"><span style="padding-left:3mm;">.244/.243*</span></xsl:if>
          </td>
          <td class="styIRS4136TableCellC">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="Gallons" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <xsl:if test="position()=1">
            <td class="styIRS4136TableCellD">
              <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>$
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseUndyedKeroseneCr" />
              </xsl:call-template>
              <span class="styIRS4136TableCellPad"></span>
            </td>
            <td class="styIRS4136TableCellE">
              <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>
              346
              <span class="styIRS4136TableCellPad"></span>
            </td>
          </xsl:if>
      </tr>    
      </xsl:for-each>  
    </xsl:if>
    <!--  Row 4B USE IN CERTAIN INTECITY AND LOCAL BUSES   -->
    <tr>
      <td class="styIRS4136LetterCell"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use in certain intercity and local buses</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.17</td>
      <td class="styIRS4136TableCellC">
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedKerosene) &lt;= 1) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneBusesGallons" />
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD">
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedKerosene) &lt;= 1) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfUndyedKeroseneCredit" />
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        350
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 4C USE IN CERTAIN INTECITY AND LOCAL BUSES   -->
    <tr>
      <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>c</b></td>
      <td class="styIRS4136TableCellLine">Use on a farm for farming purposes, after Sept. 30, 2005</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.243</td>
      <td class="styIRS4136TableCellC">
       <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedKerosene) &lt;= 1) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneForFarmingGal" />
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD">
      <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseOfUndyedKerosene) &lt;= 1) "> 
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneForFarmingCredit" />
          </xsl:call-template>
        </xsl:if>

      
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        346
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
      <!--  END LOOP  -->
    </tbody>
  </table>
</div>
<xsl:call-template name="SetInitialDynamicTableHeightRowCount">
    <xsl:with-param name="DataRowCount" select="$table4RowCount"/>
    <xsl:with-param name="containerHeight" select="3"/>
    <xsl:with-param name="containerID" select=" 'UKctn' "/>
</xsl:call-template>
<!--   END LINE 4   -->


<!--   BEGIN LINE 5   -->

<!-- Number of rows in table 5 -->
<xsl:variable name="table5RowCount" select="2 + count($IRS4136Data/NontaxableUseAviationFuel)" />

<div class="styIRS4136NumLine" style="float:none; clear: both">
  <span style="float:left;clear:none;">5<span class="styIRS4136NBSP"></span>  Nontaxable Use of Aviation-Grade Kerosene Before Oct. 1, 2005</span>

</div>

<!--   BEGIN BLOCK DESCRIPTION   -->
<div class="styIRS4136DescLine" style="margin-left: 5mm; margin-right: 5mm;">
  Claimant certifies that the aviation-grade kerosene did not contain visible evidence of dye.
</div>

<div style="width:182mm;margin-left:5.25mm;">
    <label>
      <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneUseException" />
      </xsl:call-template>
      <b>Exception.</b> If any of the aviation-grade kerosene included in this claim <b>did</b> 
      contain visible evidence of dye
    </label>
    , attach a detailed explanation 
</div>

<div class="styBB" style="width:182mm;margin-left:2.75mm;">
  <div style="float:left;padding-bottom:1mm;">
    and check here
  </div>
  <div style="float:right;padding-right:.5mm;">
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationFuelUseException"/>
      <xsl:with-param name="TabOrder" select="3"/>
    </xsl:call-template>
    <span style="letter-spacing:10px;font-weight:bold;">...........................................</span>
    <span style="margin-left: 1mm; margin-right:1mm">
      <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/>
    </span>
    <input type="checkbox" class="styIRS4136Ckbox" name="UndyedKerosene">
      <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationFuelUseException" />
      </xsl:call-template>
    </input>
  </div>
</div>

<div style="width:188mm;">
  <span class="styIRS4136DescLine" style="margin-left:5mm;width:178mm;">
    <b>Caution: </b><i>Line 5 applies to claims for aviation-grade kerosene before October 1, 2005. See line 14 and the worksheets in the instructions for kerosene used in aviation after September 30, 2005.</i>
  </span>
  <span class="styIRS4136DescLine" style="width:4mm;">
       <xsl:call-template name="SetDynamicTableToggleRowCount">
         <xsl:with-param name="DataRowCount" select="$table5RowCount"/>
         <xsl:with-param name="containerHeight" select="3"/>
         <xsl:with-param name="containerID" select=" 'AFctn' "/>
       </xsl:call-template>
  </span>
</div>

<div class="styIRS4136TableContainer5" id="AFctn">
  <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px;border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellA" style="text-align: center;border-top-width:1px;"><b>(a) Type of use</b> </th>
        <th class="styIRS4136TableCellB" style="text-align: center;border-top-width:1px;"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center;border-top-width:1px;"><b>(c) Gallons</b></th>
      <th class="styIRS4136TableCellD" style="text-align: center;border-top-width:1px;"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center;border-top-width:1px;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 5A USE IN COMMERCIAL AVIATION (OTHER THAN FOREIGN TRADE) -->
      <xsl:variable name="Line5bcount" select="count($IRS4136Data/NontaxableUseAviationFuel)" />
    <tr>
      <td class="styIRS4136LetterCell "><b>a</b></td>
      <td class="styIRS4136TableCellLine">Use in commercial aviation (other than foreign trade)</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        $ .175
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC" style="text-align:left;">
        <xsl:if test="($Line5bcount &lt;=1) or ($Print != $Separated and ($Line5bcount &gt;1))">  
          <xsl:attribute name="style">text-align:right;</xsl:attribute>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationFuelGallons" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$Line5bcount &gt;1 and $Print = $Separated">
          <xsl:call-template name="PopulateAdditionalDataTableMessage">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseAviationFuel"/>   
            <xsl:with-param name="ShortMessage" select=" 'true' " />                   
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD" style="text-align:left;">
        <xsl:if test="($Line5bcount &lt;=1) or ($Print != $Separated and ($Line5bcount &gt;1))">  
          <xsl:if test="$IRS4136Data/AviationFuelCredit">
            <xsl:attribute name="style">text-align:right;</xsl:attribute>
          </xsl:if>  
        </xsl:if>
       $
        <xsl:if test="($Line5bcount &lt;=1) or ($Print != $Separated and ($Line5bcount &gt;1))">  
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationFuelCredit" />
            </xsl:call-template>
          </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        355
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 5B OTHER NONTAXABLE USE  -->
       <xsl:variable name="UseRowCount" select="count($IRS4136Data/NontaxableUseAviationFuel)"></xsl:variable>
       <xsl:if test="$UseRowCount = 0 or (((count($IRS4136Data/NontaxableUseAviationFuel) &gt;1)) and ($Print = $Separated))">
       <tr>
        <td class="styIRS4136LetterCell"><b>b</b></td>
        <td class="styIRS4136TableCellLine">
          Other nontaxable use
        </td>
        <td class="styIRS4136TableCellA">
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellB">
          <span style="width: 11px"> </span> .219
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellC">
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellD">
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE">369
          <span class="styIRS4136TableCellPad"></span>
        </td>
      </tr>
      </xsl:if> 
        <xsl:if test="($Print != $Separated) or (count($IRS4136Data/NontaxableUseAviationFuel) &lt;= 1)">
       <xsl:for-each select="$IRS4136Data/NontaxableUseAviationFuel">
          <xsl:variable name="RowCount" select="count(NontaxableUseAviationFuel)"/>
            <tr>
              <xsl:if  test="position()=1">
                <td class="styIRS4136LetterCell">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                  <b>b</b>
               </td>
                <td class="styIRS4136TableCellLine">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                  Other nontaxable use
                </td>
              </xsl:if>
                <td class="styIRS4136TableCellA">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="TypeOfUse" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="MaxSize" select="9" />
                    <xsl:with-param name="TargetNode" select="Gallons" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <xsl:if test="position()=1">
                  <td class="styIRS4136TableCellD">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseAviationFuelCr" />
                    </xsl:call-template>
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                  <td class="styIRS4136TableCellE">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                    369
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                </xsl:if> 
              </tr> 
          </xsl:for-each>
        </xsl:if>
      <!--  END LOOP  -->
      
     <!--  Row 5C OTHER NONTAXABLE USES  -->  
              <tr>
                <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>c</b></td>
                <td class="styIRS4136TableCellLine">Use in foreign trade</td>
                <td class="styIRS4136TableCellA" style="background-color: lightgrey"><span class="styIRS4136TableCellPad"></span></td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .044
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC">
                  <xsl:if test="($Line5bcount &lt;=1) or ($Print != $Separated and ($Line5bcount &gt;1))">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="MaxSize" select="9" />
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseInForeignTrade" />
                    </xsl:call-template>
                  </xsl:if>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellD">
                  <xsl:if test="($Line5bcount &lt;=1) or ($Print != $Separated and ($Line5bcount &gt;1))">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$IRS4136Data/UseInForeignTrade" />
                  </xsl:call-template>
                  </xsl:if>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellE">
                  377
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                </tr>  
      <!--  END LOOP  -->
    </tbody>
  </table>
</div>
<xsl:call-template name="SetInitialDynamicTableHeightRowCount">
    <xsl:with-param name="DataRowCount" select="$table5RowCount"/>
    <xsl:with-param name="containerHeight" select="3"/>
    <xsl:with-param name="containerID" select=" 'AFctn' "/>
</xsl:call-template>

<!--   END LINE 5   -->

<!--   BEGIN BLOCK 6   -->
<!--   BEGIN LINE 6   -->
<div class="styIRS4136NumLine" style="float: none; clear: both">
  6<span class="styIRS4136NBSP"></span>  Sales by Registered Ultimate Vendors of Undyed Diesel Fuel <span style="width:10mm;"></span> Registration No.
  <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/><span style="width:8px;"/>
   <span style="font-weight:normal">
    <xsl:call-template name="PopulateText">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/RegistrationUndyedDiesel" />
    </xsl:call-template>
     </span>
</div>
<!--   END LINE 6   -->

<!--   BEGIN BLOCK DESCRIPTION   -->
<div class="styIRS4136DescLine" style="font-size: 7pt; margin-left: 5mm; margin-right: 15mm; padding-right:10mm">
Claimant certifies that it sold the diesel fuel at a tax-excluded price, repaid the amount of tax to the buyer, or has obtained written
consent of the buyer to make the claim. Claimant certifies that the diesel fuel did not contain visible evidence of dye.
</div>









<!--   BEGIN BLOCK DESCRIPTION   -->
<div class="styIRS4136DescLine" style="margin-left: 5mm; margin-right: 5mm;">
  Claimant certifies that the diesel fuel did not contain visible evidence of dye.
</div>
<div class="styBB" style="width:182mm;margin-left:2.75mm;font-size:6pt;">
  <div style="float:left;padding-top:1mm;">
    <label>
      <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselSalesException" />
      </xsl:call-template>
      <b>Exception.</b> If any of the diesel fuel included in this claim <b>did</b> contain 
      visible evidence of dye, attach an explanation and check here
    </label> 
  </div>
  <div style="float:right;padding-right:.5mm;">
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselSalesException"/>
    </xsl:call-template>
    <span style="letter-spacing:10px;font-weight:bold;">........</span>
    <span style="margin-left: 1mm; margin-right:1mm">
      <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/>
    </span>
    <input type="checkbox" class="styIRS4136Ckbox" name="VendorsFuel" id="VendorsFuel" value="">
      <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselSalesException" />
      </xsl:call-template>
    </input>
  </div>
</div>

<div class="styIRS4136DescLine" style="margin-left:5mm; border: solid black 1px;border-top-width:0px;border-left-width:0px;border-right-width:0px;border-bottom-width:0px;width:182mm;">
  <b>Caution: </b><i>Registered ultimate vendors cannot make claims for diesel fuel sold 
  for use on a farm for farming purposes after Sept. 30, 2005.</i>
</div>

<div style="width:187mm;float:left;clear:left;" id="UDctn">
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px;border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellA" style="text-align: center;border-top-width:1px;"><b>(a) Type of use</b> </th>
        <th class="styIRS4136TableCellB" style="text-align: center;border-top-width:1px;"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center;border-right-width:0;border-top-width:1px;"><b>(c) Gallons</b></th>
      <th class="styIRS4136Braces" style="border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellD" style="text-align: center;border-top-width:1px;"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center;border-top-width:1px;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 6A USE ON A FARM FOR FARMING PURPOSES -->
    <tr>
      <td class="styIRS4136LetterCell"><b>a</b></td>
      <td class="styIRS4136TableCellLine">Use on a farm for farming purposes before Oct. 1, 2005</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">$ .244</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesDieselGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces" rowspan="2"><img src="{$ImagePath}/4136_Bracket_L2L3L4.gif" alt="bracket"/></td>
      <td class="styIRS4136TableCellD" rowspan="2">
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/DieselSoldCredit"/>
          <xsl:with-param name="TabOrder" select="4"/>
        </xsl:call-template>      
        $<xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/DieselSoldCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE" rowspan="2">
        360
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 6B USE BY A STATE OR LOCAL GOVERNMENT  -->
    <tr>
      <td class="styIRS4136LetterCell"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use by a state or local government</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.244/.243*</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtDieselGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>  

    <!--  Row 6C USE BY A STATE OR LOCAL GOVERNMENT  -->
    <tr>
      <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>c</b></td>
      <td class="styIRS4136TableCellLine">Use in certain intercity and local buses</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.17</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselFuelBusesGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
  
      <td class="styIRS4136TableCellD">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselFuelBusesCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        350
        <span class="styIRS4136TableCellPad"></span>
      </td>     
      </tr>          
      </tbody>
  </table>
</div>

<!--  END LINE 6  -->

<!--BEGIN FOOTER-->
<div style="width:187mm">
  <div style="float: left; clear: none;"><span class="styBoldText">For Paperwork Reduction Act Notice, see the instructions.</span></div>        
  <div style="float:right">
    Cat. No. 12625R
    <span style="width:70px"></span>
    Form <span class="styBoldText" style="font-size: 8pt">4136</span> (2005)
  </div>      
</div>     
<div class="pageEnd"></div>
<!--END FOOTER-->  
        
<!--BEGIN HEADER-->
<div class="styBB" style="width:187mm">
  <div style="float: left; clear: none">Form 4136 (2005)</div>        
  <div style="float:right">
    Page <span class="styBoldText" style="font-size: 8pt">2</span>
  </div>      
</div> 
<!--END HEADER-->

<!--   BEGIN BLOCK 7   -->
<!--   BEGIN LINE 7   -->
<div class="styGenericDiv">
<table class="styIRS4136Table" style="width:187mm;border-bottom:1px solid black;">
  <tbody>
    <tr class="styIRS4136NumLine">
        <td style="float: none; padding-top: 2mm; border-bottom-width: 0px;border-top-width: 0px" rowspan="2">
          7<span class="styIRS4136NBSP"></span> 
          Sales by Registered Ultimate Vendors of Undyed Kerosene (Other 
          <br/><span style="width:4mm;" />
          Than Aviation-Grade Kerosene and Kerosene Used in Aviation)
        </td>
        <td style="padding-top:5mm;">
          Registration No.<span style="width:8px"></span><img src="{$ImagePath}/4136_Bullet.gif"  alt="Bullet"/>
          <span style="width:8px;"></span>
          <span style="font-weight:normal">
          <xsl:call-template name="PopulateText">
           <xsl:with-param name="TargetNode" select="$IRS4136Data/RegistrationUndyedKerosene" />
          </xsl:call-template>
          </span>
       </td>
     </tr>
  </tbody>
</table>
</div>

<!--   END LINE 7   -->

<!--   BEGIN BLOCK DESCRIPTION   -->
<br/>
<div class="styIRS4136DescLine" style="font-size: 7pt; margin-left: 5mm; margin-right: 15mm; padding-right:10mm">
Claimant certifies that it sold the kerosene at a tax-excluded price, repaid the amount of tax to the buyer, or has obtained the written consent
of the buyer to make the claim. Claimant certifies that the kerosene did not contain visible evidence of dye.
</div>

<div style="width:188mm;">
<div class="styIRS4136DescLine" style="font-size: 7pt; width: 172mm; margin-top:1mm;margin-left: 2.5mm;float:left;clear:none; margin-right: 1mm; border-style: solid; border-bottom-width: 0px; border-top-width: 0px; border-left-width: 0px; border-right-width: 0px;">
  <label><xsl:call-template name="PopulateLabel"><xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneSalesException" /></xsl:call-template>
  <b>Exception.</b> If any of the kerosene included in this claim <b>did</b> contain visible evidence of dye, attach an explanation and check here</label>
  <span style="letter-spacing:10px;font-weight:bold;padding-bottom:2mm;">.............................................</span> 
      <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneSalesException"/>
      </xsl:call-template>     
</div>
<div class="styIRS4136DescLine" style="width:10mm; float:left;clear:none;padding-top:4mm;">
    <span style="margin-right:2mm;margin-left:1mm;"><img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/></span>
  <input type="checkbox" class="styIRS4136Ckbox" name="VendorsKerosene">
    <xsl:call-template name="PopulateCheckbox">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneSalesException" />
    </xsl:call-template>
  </input>
</div>
</div>
<div style="margin-left:4mm;width:182mm;border:solid black 1px; border-right-width:0; border-left-width:0; border-bottom-width:0;"><b>Caution: </b><i>Registered ultimate vendors cannot make claims for kerosene sold for use on a farm for farming purposes after September 30, 2005.</i></div>
<div style="width:187mm;float:left;clear:left;" id="UVctn">
  <table class="styIRS4136Table" style="width:187mm;" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th class="styIRS4136TableCellLine" style="width:3mm;height:4mm;border-bottom-width:0px;border-right-width:0;border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px;border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellA" style="text-align: center;border-top-width:1px;"><b>(a) Type of use</b> </th>
        <th class="styIRS4136TableCellB" style="text-align: center;border-top-width:1px;"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center;border-top-width:1px;"><b>(c) Gallons</b></th>
      <th class="styIRS4136Braces" style="border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellD" style="text-align: center;border-top-width:1px;"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center;border-top-width:1px;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 7A USE ON A FARM FOR FARMING PURPOSES -->
    <tr>
      <td class="styIRS4136LetterCell"><b>a</b></td>
      <td class="styIRS4136TableCellLine">Use on a farm for farming purposes before Oct. 1, 2005
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesKeroseneGallons"/>
          <xsl:with-param name="TabOrder" select="6"/>
        </xsl:call-template>
      </td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB"><span style="width:4mm;"/>$.244</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesKeroseneGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces" rowspan="3"><img src="{$ImagePath}/4136_Bracket_L6.gif" alt="bracket"/></td>
      <td class="styIRS4136TableCellD" rowspan="3">
        $<xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/KeroseneSoldCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE" rowspan="3">
        346
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 7B USE BY A STATE OR LOCAL GOVERNMENT  -->
    <tr>
      <td class="styIRS4136LetterCell"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use by a state or local government
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtKeroseneGallons"/>
          <xsl:with-param name="TabOrder" select="7"/>
        </xsl:call-template>
      </td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.244/.243*</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtKeroseneGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>  
      <!--  Row 7C SALES FROM A BLOCKED PUMP   -->
    <tr>
      <td class="styIRS4136LetterCell"><b>c</b></td>      
      <td class="styIRS4136TableCellLine">Sales from a blocked pump</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.244/.243*</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/BlockedPumpKeroseneGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>  
      <!--  Row 7D USE ON A FARM FOR FARMING PURPOSES -->
    <tr>
      <td class="styIRS4136LetterCell"  style="border-bottom-width:1px;"><b>d</b></td>
      <td class="styIRS4136TableCellLine">Use in certain intercity and local buses</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.17</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/UseInCertainBusesGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/UseIncCertainBusesCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        350
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
    </tbody>
  </table>
</div>

<!--   END LINE 7    -->

<!--   BEGIN BLOCK 8   -->
<!-- Number of rows in table 8 -->
<xsl:variable name="table8RowCount" select="3 + count($IRS4136Data/OtherNontaxUseAviationGrade)" />
<!--   BEGIN LINE 8   -->
<div class="styIRS4136NumLine" style="float: none; clear: both">
  8<span class="styIRS4136NBSP"></span>  Sales by Registered Ultimate Vendors of Aviation-Grade Kerosene<br /><span style="width:5mm;" /> before Oct. 1, 2005<span style="width:100mm;"></span> Reg. No.
  <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/><span style="width:6px;"/>
   <span style="font-weight:normal">
    <xsl:call-template name="PopulateText">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/RegistrationVendorsAviation" />
    </xsl:call-template>
     </span>
</div>
<div class="styIRS4136DescLine">
  <div class="styBB" style="width:182mm;margin-left:2.75mm;">
    Claimant sold the aviation-grade kerosene at a tax-excluded price and has not 
    collected the amount of tax from the buyer, repaid the amount of tax to the 
    buyer, or has obtained written consent of the buyer to make the claim.
  </div>
</div>
<div style="width:188mm;">
<span class="styIRS4136DescLine" style="margin-left:5mm;width:178mm;"><b>Caution: </b><i>Line 8 applies to claims for aviation-grade kerosene before October 1, 2005. See line 14 and the worksheets in the instructions for sales of kerosene for use in aviation after September 30, 2005.</i></span>
<span class="styIRS4136DescLine" style="width:4mm;">
     <xsl:call-template name="SetDynamicTableToggleRowCount">
       <xsl:with-param name="DataRowCount" select="$table8RowCount"/>
       <xsl:with-param name="containerHeight" select="4"/>
       <xsl:with-param name="containerID" select=" '8bFctn' "/>
     </xsl:call-template>
</span>
</div>

<div class="styIRS4136TableContainer5" style="height:24mm;" id="8bFctn">
  <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
  <table class="styIRS4136Table"  cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px;border-top-width:1px;border-right-width:0;width:3mm;height:4mm;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px;border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellA" style="text-align: center;border-top-width:1px;"><b>(a) Type of use</b> </th>
      <th class="styIRS4136TableCellB" style="text-align: center;border-top-width:1px;"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center;border-top-width:1px;"><b>(c) Gallons</b></th>
      <th class="styIRS4136Braces" style="border-top-width:1px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellD" style="text-align: center;border-top-width:1px;"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center;border-top-width:1px;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 8A USE IN COMMERCIAL AVIATION (OTHER THAN FOREIGN TRADE) -->
      <xsl:variable name="Line8bcount" select="count($IRS4136Data/OtherNontaxUseAviationGrade)" />
    <tr>
      <td class="styIRS4136LetterCell "><b>a</b></td>
      <td class="styIRS4136TableCellLine">Use in commercial aviation (other than foreign trade)</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        $ .175
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC" style="text-align:left;">
        <xsl:if test="($Line8bcount &lt;=1) or ($Print != $Separated and ($Line8bcount &gt;1))">  
          <xsl:attribute name="style">text-align:right;</xsl:attribute>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseCommercialAviationKerosene" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$Line8bcount &gt;1 and $Print = $Separated">
          <xsl:call-template name="PopulateAdditionalDataTableMessage">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/OtherNontaxUseAviationGrade"/>   
            <xsl:with-param name="ShortMessage" select=" 'true' " />                   
          </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD" style="text-align:left;">
        <xsl:if test="($Line8bcount &lt;=1) or ($Print != $Separated and ($Line8bcount &gt;1))">  
          <xsl:if test="$IRS4136Data/AviationFuelCredit">
            <xsl:attribute name="style">text-align:right;</xsl:attribute>
          </xsl:if>  
        </xsl:if>
       $
        <xsl:if test="($Line8bcount &lt;=1) or ($Print != $Separated and ($Line8bcount &gt;1))">  
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/UseInCommercialAviationCredit" />
            </xsl:call-template>
          </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        355
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 8B OTHER NONTAXABLE USE  -->
       <xsl:variable name="UseRowCount" select="count($IRS4136Data/OtherNontaxUseAviationGrade)"></xsl:variable>
       <xsl:if test="$UseRowCount = 0 or (((count($IRS4136Data/OtherNontaxUseAviationGrade) &gt;1)) and ($Print = $Separated))">
       <tr>
        <td class="styIRS4136LetterCell"><b>b</b></td>
        <td class="styIRS4136TableCellLine">Other nontaxable use</td>
        <td class="styIRS4136TableCellA">
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellB">
          <span style="width: 11px"> </span> .219
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellC">
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136Braces" rowspan="3">
          <img src="{$ImagePath}/4136_Bracket_L6.gif" alt="bracket"/>
        </td>
        <td class="styIRS4136TableCellD" rowspan="3">
          <xsl:if test="$UseRowCount = 0">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationCredit" />
            </xsl:call-template>        
          </xsl:if>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE" rowspan="3">369
          <span class="styIRS4136TableCellPad"></span>
        </td>
      </tr>
      </xsl:if> 
      <xsl:if test="($Print != $Separated) or (count($IRS4136Data/OtherNontaxUseAviationGrade) &lt;= 1)">
       <xsl:for-each select="$IRS4136Data/OtherNontaxUseAviationGrade">
          <xsl:variable name="RowCount" select="count(OtherNontaxUseAviationGrade)"/>
            <tr>
              <xsl:if  test="position()=1">
                <td class="styIRS4136LetterCell">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                  <b>b</b>
               </td>
                <td class="styIRS4136TableCellLine">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                  Other nontaxable use
                </td>
              </xsl:if>
                <td class="styIRS4136TableCellA">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="TypeOfUse" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="MaxSize" select="9" />
                    <xsl:with-param name="TargetNode" select="Gallons" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <xsl:if test="position()=1">
                  <td class="styIRS4136Braces" style="vertical-align:top;">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount + 2"></xsl:value-of></xsl:attribute>
                    <img src="{$ImagePath}/4136_Bracket_L6.gif" alt="bracket"/>
                  </td>
                  <td class="styIRS4136TableCellD">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount + 2"></xsl:value-of></xsl:attribute>
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationCredit" />
                    </xsl:call-template>
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                  <td class="styIRS4136TableCellE">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount + 2"></xsl:value-of></xsl:attribute>
                    369
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                </xsl:if> 
              </tr> 
          </xsl:for-each>
        </xsl:if>
      <!--  END LOOP  -->
      
     <!--  Row 8C  -->  
              <tr>
                <td class="styIRS4136LetterCell"><b>c</b></td>
                <td class="styIRS4136TableCellLine">Use on a farm for farming purposes
                  <xsl:if test="($Line8bcount &lt;=1) or ($Print != $Separated and ($Line8bcount &gt;1))">
                    <!-- Form to Form Link -->
                    <xsl:call-template name="SetFormLinkInline">
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesAviationGallons"/>            
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="styIRS4136TableCellA" style="background-color: lightgrey"><span class="styIRS4136TableCellPad"></span></td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC">
                  <xsl:if test="($Line8bcount &lt;=1) or ($Print != $Separated and ($Line8bcount &gt;1))">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="MaxSize" select="9" />
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesAviationGallons" />
                    </xsl:call-template>
                  </xsl:if>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
              </tr>  

     <!--  Row 8D -->  
              <tr>
                <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>d</b></td>
                <td class="styIRS4136TableCellLine">Use by a state or local government
                  <xsl:if test="($Line8bcount &lt;=1) or ($Print != $Separated and ($Line8bcount &gt;1))">
                    <!-- Form to Form Link -->
                    <xsl:call-template name="SetFormLinkInline">
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationGallons"/>            
                    </xsl:call-template>
                  </xsl:if>                
                </td>
                <td class="styIRS4136TableCellA" style="background-color: lightgrey"><span class="styIRS4136TableCellPad"></span></td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC">
                  <xsl:if test="($Line8bcount &lt;=1) or ($Print != $Separated and ($Line8bcount &gt;1))">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="MaxSize" select="9" />
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationGallons" />
                    </xsl:call-template>
                  </xsl:if>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
              </tr>  
    </tbody>
  </table>
</div>
<xsl:call-template name="SetInitialDynamicTableHeightRowCount">
    <xsl:with-param name="DataRowCount" select="$table8RowCount"/>
    <xsl:with-param name="containerHeight" select="4"/>
    <xsl:with-param name="containerID" select=" '8bFctn' "/>
</xsl:call-template>
<!--   END LINE 8   -->

<!--   BEGIN BLOCK 9   -->
<!--   BEGIN LINE 9   -->
<div class="styIRS4136NumLine" style="float: none; clear: both">
  9<span class="styIRS4136NBSP"></span>  Sales by Registered Ultimate Vendors of Gasoline<span style="width:39mm;"></span> Registration No.
  <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/><span style="width:8px;"/>
   <span style="font-weight:normal">
    <xsl:call-template name="PopulateText">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/RegistrationNumberGasoline" />
    </xsl:call-template>
     </span>
</div>
<div class="styIRS4136DescLine" style="font-size: 7pt;">
  <div style="width:5mm;float:left;clear:none;"></div>
  <div style="width:182mm;border:solid black 1; border-top-width:0px;border-right-width:0px;border-left-width:0px;float:left;clear:none;">
    Claimant sold the gasoline at a tax-excluded price and has not collected the amount of tax from the buyer, repaid the amount of tax to the buyer,
    or has obtained written consent of the buyer to make the claim; and obtained an unexpired certificate from the buyer and has no reason to believe
    any information in the certificate is false. See the instructions for additional information to be submitted.
  </div>
</div>
<div style="width:187mm;float:left;clear:left;" id="UVctn">
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 9A -->
    <tr>
      <td class="styIRS4136LetterCell"><b>a</b></td>
      <td class="styIRS4136TableCellLine" style="width:100mm;">Use by a nonprofit educational organization
        <!-- Form to Form Link -->
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/NonprofitEducationalOrgGallons"/>            
        </xsl:call-template>
      </td>
      <td class="styIRS4136TableCellB">$ .184/.183*</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/NonprofitEducationalOrgGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD">
        $<xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/NonprofitEducationalOrgCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE" rowspan="2">362<span class="styIRS4136TableCellPad"></span></td>
    </tr>
    <!--  Row 9B  -->
    <tr>
      <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use by a state or local government
        <!-- Form to Form Link -->
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/GasStateLocalGovernmentGallons"/>            
        </xsl:call-template>      
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.184/.183*</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/GasStateLocalGovernmentGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/GasStateLocalGovernmentCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>  
    </tbody>
  </table>
</div>
<!--   END LINE 9   -->

<!--   BEGIN BLOCK 10   -->
<!--   BEGIN LINE 10   -->
<div class="styIRS4136NumLine" style="float: none; clear: both">
  10<span class="styIRS4136NBSP"></span>  Sales by Registered Ultimate Vendors of Aviation Gasoline<span style="width:22mm;"></span> Registration No.
  <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/><span style="width:8px;"/>
   <span style="font-weight:normal">
    <xsl:call-template name="PopulateText">
      <xsl:with-param name="TargetNode" select="$IRS4136Data/RegistrationNumberAviationGas" />
    </xsl:call-template>
     </span>
</div>
<div class="styIRS4136DescLine" style="font-size: 7pt;">
  <div style="width:5mm;float:left;clear:none;"></div>
  <div style="width:182mm;border:solid black 1; border-top-width:0px;border-right-width:0px;border-left-width:0px;float:left;clear:none;">
    Claimant sold the aviation gasoline at a tax-excluded price and has not collected the amount of tax from the buyer, repaid the amount of tax to
    the buyer, or has obtained written consent of the buyer to make the claim; and obtained an unexpired certificate from the buyer and has no reason
    to believe any information in the certificate is false. See the instructions for additional information to be submitted.
  </div>
</div>
<div style="width:187mm;float:left;clear:left;" id="UVctn">
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 10A -->
    <tr>
      <td class="styIRS4136LetterCell"><b>a</b></td>
      <td class="styIRS4136TableCellLine" style="width:100mm;">Use by a nonprofit educational organization
        <!-- Form to Form Link -->
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationGasNonprofitEducGallon"/>            
        </xsl:call-template>            
      </td>
      <td class="styIRS4136TableCellB">$ .194/.193*</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationGasNonprofitEducGallon" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD">
        $<xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationGasNonprofitEducCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE" rowspan="2">324<span class="styIRS4136TableCellPad"></span></td>
    </tr>
    <!--  Row 9B  -->
    <tr>
      <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use by a state or local government
        <!-- Form to Form Link -->
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationGasGals"/>            
        </xsl:call-template>                  
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.194/.193*</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationGasGals" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellD">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationGasCr" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>  
    </tbody>
  </table>
</div>
<!--   END LINE 10   -->


<!--   BEGIN BLOCK 11   -->
<!--   BEGIN LINE 11   -->
    <xsl:variable name="RowCount11C" select="count($IRS4136Data/OtherNontaxableUse)"></xsl:variable>

<div class="styIRS4136NumLine" style="float:none">
  <span style="float:left;clear:none;">
  11<span class="styIRS4136NBSP"></span> Nontaxable Use of Liquefied Petroleum Gas (LPG)
  </span>
 <span style="width:7mm;text-align:right;float:right; clear: none">
    <xsl:call-template name="SetDynamicTableToggleRowCount">
      <xsl:with-param name="DataRowCount" select="$RowCount11C + 2"/>
      <xsl:with-param name="containerHeight" select="3"/>
      <xsl:with-param name="containerID" select=" 'LPctn' "/>
    </xsl:call-template>
 </span>
</div>

<div class="styIRS4136TableContainer11" id="LPctn">
  <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellA" style="text-align: center"><b>(a) Type of use</b> </th>
        <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 11A USE IN CERTAIN INTERCITY AND LOCAL BUSES -->
    <tr>
      <td class="styIRS4136LetterCell"><b>a</b></td>
      <td class="styIRS4136TableCellLine">Use in certain intercity and local buses</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        $ .062
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC">
        <xsl:if test="($RowCount11C &lt;=1) or ($Print != $Separated and ($RowCount11C &gt;1))">      
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfLPGInBusesGallons" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$RowCount11C &gt;1 and $Print = $Separated">
          <xsl:call-template name="PopulateAdditionalDataTableMessage">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/OtherNontaxableUse"/>   
            <xsl:with-param name="ShortMessage" select=" 'true' " />                   
          </xsl:call-template>
        </xsl:if>        
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD">
        $
        <xsl:if test="($RowCount11C &lt;=1) or ($Print != $Separated and ($RowCount11C &gt;1))">      
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfLPGInBusesCredit" />
        </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        352
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 11B USE IN QUALIFIED LOCAL AND SCHOOL BUSES  -->
    <tr>
      <td class="styIRS4136LetterCell"><b>b</b></td>
      <td class="styIRS4136TableCellLine">Use in qualified local buses or school buses</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        <span style="width: 10px"> </span> .136
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC">
        <xsl:if test="($RowCount11C &lt;=1) or ($Print != $Separated and ($RowCount11C &gt;1))">      
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/QualifiedUseLPGInBusesGallons" />
        </xsl:call-template>
        </xsl:if>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD">
        <xsl:if test="($RowCount11C &lt;=1) or ($Print != $Separated and ($RowCount11C &gt;1))">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/QualifiedUseLPGInBusesCredit" />
        </xsl:call-template>
        </xsl:if>        
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        361
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 11C  -->
    <xsl:if test="$RowCount11C= 0 or (($RowCount11C &gt; 1) and ($Print = $Separated))">
      <tr>
        <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>c</b></td>
        <td class="styIRS4136TableCellLine">Other nontaxable use</td>
        <td class="styIRS4136TableCellA"><span class="styIRS4136TableCellPad"></span></td>
        <td class="styIRS4136TableCellB">
          <span style="width: 10px"> </span> .136
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellC"><span class="styIRS4136TableCellPad"></span></td>
        <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
        <td class="styIRS4136TableCellD"><span class="styIRS4136TableCellPad"></span></td>
        <td class="styIRS4136TableCellE">361
          <span class="styIRS4136TableCellPad"></span>
        </td>
        </tr>
    </xsl:if>
    <xsl:if test="($Print != $Separated) or ($RowCount11C &lt;= 1)">
      <xsl:for-each select="$IRS4136Data/OtherNontaxableUse">
        <tr>
          <xsl:if  test="position()=1">
            <td class="styIRS4136LetterCell"  style="border-bottom-width:1px;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>
              <b>c</b>
            </td>
            <td class="styIRS4136TableCellLine">
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>
              Other nontaxable use
            </td>
          </xsl:if>        
          <td class="styIRS4136TableCellA">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TypeOfUse" />
            </xsl:call-template>          
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellB">
            <span style="width: 10px"> </span> .136
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellC">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="Gallons" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
          <xsl:if test="position()=1">          
            <td class="styIRS4136TableCellD">
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>            
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$IRS4136Data/OtherNontaxableUseLPGCredit" />
              </xsl:call-template>
              <span class="styIRS4136TableCellPad"></span>
            </td>
            <td class="styIRS4136TableCellE">
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>            
              361
              <span class="styIRS4136TableCellPad"></span>
            </td>
          </xsl:if>
        </tr>
      </xsl:for-each>
    </xsl:if>

    </tbody>  
  </table>
</div>
<xsl:call-template name="SetInitialDynamicTableHeightRowCount">
  <xsl:with-param name="DataRowCount" select="$RowCount11C + 2"/>
  <xsl:with-param name="containerHeight" select="3"/>
  <xsl:with-param name="containerID" select=" 'LPctn' "/>
</xsl:call-template>

<!--   END LINE 11   -->

<!--   BEGIN LINE 12   -->
<div class="styIRS4136NumLine" style="float: none; clear: both">
    12
    <span class="styIRS4136NBSP"></span>  
    Alcohol Fuel Mixture Credit
    <span style="width:76mm;"></span> 
    Registration No.
    <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/><span style="width:8px;"/>
    <span style="font-weight:normal">
      <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/RegistrationNumberAlcoholFuel" />
      </xsl:call-template>
    </span>
</div>
<div class="styIRS4136DescLine" style="font-size: 7pt;">
  <div style="width:5mm;float:left;clear:none;"></div>
  <div style="width:182mm;border:solid black 1; border-top-width:0px;border-right-width:0px;border-left-width:0px;float:left;clear:none;">
    Claimant produced an alcohol fuel mixture by mixing taxable fuel with alcohol. The alcohol 
    fuel mixture was sold by the claimant to any person for use as a fuel or was used as a fuel 
    by the claimant.
  </div>
</div>
<div style="width:187mm;float:left;clear:left;" id="UVctn">
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 12A -->
      <tr>
        <td class="styIRS4136LetterCell"><b>a</b></td>
        <td class="styIRS4136TableCellLine" style="width:100mm;">Alcohol fuel mixtures containing ethanol</td>
        <td class="styIRS4136TableCellB">$ .51</td>
        <td class="styIRS4136TableCellC">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AlcoholFuelMixtureEthanolGals" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellD">
          $<xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AlcoholFuelMixtureEthanolCr" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE">393<span class="styIRS4136TableCellPad"></span></td>
      </tr>
      <!--  Row 12B  -->
      <tr>
        <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>b</b></td>
        <td class="styIRS4136TableCellLine" style="width:100mm;">Alcohol fuel mixtures containing alcohol (other than ethanol)</td>
        <td class="styIRS4136TableCellB" style="padding-left:3mm;">.60</td>
        <td class="styIRS4136TableCellC">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AlcoholFuelMixtureAlcoholGals" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellD">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AlcoholFuelMixtureAlcoholCr" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE">394<span class="styIRS4136TableCellPad"></span></td>
      </tr>  
    </tbody>
  </table>
</div>
<!--   END LINE 12   -->



<!--   BEGIN LINE 13   -->
<div class="styIRS4136NumLine" style="float: none; clear: both">
    13
    <span class="styIRS4136NBSP"></span>  
    Biodiesel Mixture Credit
    <span style="width:82mm;"></span> 
    Registration No.
    <img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/><span style="width:8px;"/>
    <span style="font-weight:normal">
      <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$IRS4136Data/RegistrationNumberBiodiesel" />
      </xsl:call-template>
    </span>
</div>
<div class="styIRS4136DescLine" style="font-size: 7pt;">
  <div style="width:5mm;float:left;clear:none;"></div>
  <div style="width:182mm;border:solid black 1; border-top-width:0px;border-right-width:0px;border-left-width:0px;float:left;clear:none;">
    Claimant produced a biodiesel mixture by mixing diesel fuel with biodiesel. The biodiesel 
    mixture was sold by the claimant to any person for use as fuel or was used as a fuel by the 
    claimant. Claimant has a certificate from the producer or importer of the biodiesel which 
    identifies the percentage of biodiesel and agri-biodiesel in the product, and has no reason 
    to believe the information is false. See the instructions for line 13 to see if you must 
    attach the certificate.
  </div>
</div>
<div style="width:187mm;float:left;clear:left;" id="UVctn">
  <table class="styIRS4136Table" cellspacing="0">
    <thead class="styIRS4136TableThead">
    <tr>
      <th style="width:3mm;height:4mm;"></th>
      <th class="styIRS4136TableCellLine" style="border-bottom-width:0px"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styIRS4136TableCellB" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styIRS4136TableCellC" style="text-align: center"><b>(c) Gallons</b></th>
      <th class="styIRS4136TableCellD" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styIRS4136TableCellE" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 13A -->
      <tr>
        <td class="styIRS4136LetterCell"><b>a</b></td>
        <td class="styIRS4136TableCellLine" style="width:100mm;">Biodiesel (other than agri-biodiesel) mixtures</td>
        <td class="styIRS4136TableCellB">$ .50</td>
        <td class="styIRS4136TableCellC">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/BiodieselMixtureGallons" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellD">
          $<xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/BiodieselMixtureCredit" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE">388<span class="styIRS4136TableCellPad"></span></td>
      </tr>
      <!--  Row 13B  -->
      <tr>
        <td class="styIRS4136LetterCell" style="border-bottom-width:1px;"><b>b</b></td>
        <td class="styIRS4136TableCellLine" style="width:100mm;">Agri-biodiesel mixtures</td>
        <td class="styIRS4136TableCellB" style="padding-left:3mm;">1.00</td>
        <td class="styIRS4136TableCellC">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AgriBiodieselMixtureGallons" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellD">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AgriBiodieselMixtureCredit" />
          </xsl:call-template>
          <span class="styIRS4136TableCellPad"></span>
        </td>
        <td class="styIRS4136TableCellE">390<span class="styIRS4136TableCellPad"></span></td>
      </tr>  
    </tbody>
  </table>
</div>
<!--   END LINE 13   -->

<!--   BEGIN LINE 14   -->
<div class="styIRS4136NumLine" style="float:none;clear:both">
    14
    <span class="styIRS4136NBSP"></span>  
    Kerosene For Use in Aviation, After September 30, 2005.
    <span style="font-weight:normal">
      See the instructions for worksheets to figure the
      <br/>
      <span style="width:6mm;"/>
      amount of credit.
    </span>
</div>

<table class="styTable" style="width:186mm;border-bottom:1px solid black;" cellspacing="0"> 
    <tr style="width:187mm;height:4mm;font-size:7pt;float:none;clear:both;">
      <td class="styGenericDiv" style="width:6mm;height:4mm;font-weight:bold;padding-left:1mm;">
      </td>
      <td class="styGenericDiv" style="width:137mm;height:4mm;padding-left:5px;">
      </td>
      <td class="styGenericDiv" style="width:32mm;height:4mm;padding-left:2mm;font-weight:bold;border-left:1 solid black;border-bottom:1px solid black;">
        (d) Amount of credit
      </td>
      <td class="styGenericDiv" style="width:11.5mm;height:4mm;text-align:center;font-weight:bold;border-left:1px solid black;border-bottom:1px solid black;">
        (e)<span style="width:.3mm;"/> CRN
      </td>
    </tr>
    
    <tr style="width:187mm;height:4mm;font-size:7pt;float:none;clear:both;">
      <td class="styGenericDiv" style="width:6mm;height:4mm;padding-left:2mm;font-weight:bold;padding-left:1mm;">
        a
      </td>
      <td class="styGenericDiv" style="width:137mm;height:4mm;padding-left:5px;border-bottom:1px solid black;">
        Use in commercial aviation (other than foreign trade)
      </td>
      <td class="styGenericDiv" style="width:32mm;height:4mm;text-align:right;padding-right:1mm;border-bottom:1px solid black;border-left:1 solid black;">
         $<xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/KeroseneUsedCommercialAviation" />
         </xsl:call-template>
      </td>
      <td class="styGenericDiv" style="width:11.5mm;height:4mm;text-align:center;border-bottom:1px solid black;border-left:1px solid black;">
        355
      </td>
    </tr>

    <tr class="styBB" style="width:187mm;height:4mm;font-size:7pt;float:none;clear:both;">
      <td class="styGenericDiv" style="width:6mm;height:4mm;padding-left:2mm;font-weight:bold;padding-left:1mm;">
        b
      </td>
      <td class="styGenericDiv" style="width:137mm;height:4mm;padding-left:5px;">
        Sales by registered ultimate vendors
        <xsl:call-template name="LinkToLeftoverDataTableInline">
          <xsl:with-param name="Desc">Form 4136, Line 14b(d) - UA Registration Number</xsl:with-param>
          <xsl:with-param name="TargetNode" select="$IRS4136Data/OtherNonTaxableUses/@UARegistrationNumber"/>
        </xsl:call-template>
      </td>
      <td class="styGenericDiv" style="width:32mm;height:4mm;text-align:right;padding-right:1mm;border-left:1 solid black;">
         $<xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/OtherNonTaxableUses" />
          </xsl:call-template>
      </td>
      <td class="styGenericDiv" style="width:11.5mm;height:4mm;text-align:center;border-left:1px solid black;">
        369
      </td>
    </tr>
</table>    
<!--   END LINE 14   -->

<!--   BEGIN BLOCK 15   -->
<!--   BEGIN LINE 15   -->
    <div class="styBB" style="width:187mm;font-size:7pt;float:none;clear:both;">
      <div class="styGenericDiv" style="width:6mm;height:10mm;font-weight:bold;padding-left:1mm;font-size:8pt;">
        15
      </div>
      <div class="styGenericDiv" style="width:128mm;height:11mm;padding-left:5px;">
        <b>Total income tax credit claimed.</b> Add lines 1 through 14, column (d). 
        Enter here and on Form 1040, line 70 (also check box b on line 70); Form 1120, l
        ine 32f(2); Form 1120-A, line 28f(2); Form 1120S, line 23c; Form 1041, line 24g; 
        or the proper line of other returns.
        <span style="padding-left:8mm"><img src="{$ImagePath}/4136_Bullet.gif" alt="Bullet"/></span>
      </div>
      <div class="styGenericDiv" style="width:9mm;height:11mm;font-weight: bold;text-align:center;padding-top:6mm;border-left:1 solid black;">15</div>
      <div class="styGenericDiv" style="width:32mm;height:11mm;padding-top:6mm;text-align:right;padding-right:1mm;border-left:1 solid black;">
          $
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/TotalIncomeTaxCreditClaimed" />
          </xsl:call-template>
      </div>
      <div class="styGenericDiv" style="width:11.5mm;height:11mm;border-left:1px solid black;background-color:lightgrey">
        <span style="width:1px;"/>
      </div>
    </div>
<!--   END LINE 15   -->
<!--   END BLOCK 15   -->

<!--   BEGIN FORM FOOTER  -->
<div class="pageEnd" style="width:187mm;padding-top:.5mm;">
  <div style="float:right">
    <span style="width:80px"/>Form <span class="styBoldText">4136</span> (2005)
  </div>
</div>
<!--   END FORM FOOTER   -->
      <!-- <br/>
      <div class="pageEnd"></div> -->
      
      <div class="styLeftOverTitleLine" id="LeftoverData">
        <div class="styLeftOverTitle">
          Additional Data        
        </div>
        <div class="styLeftOverButtonContainer">
          <input class="styLeftoverTableBtn" TabIndex="1" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
        </div>      
      </div>
      
      <table class="styLeftOverTbl">
        <xsl:call-template name="PopulateCommonLeftover">
          <xsl:with-param name="TargetNode" select="$IRS4136Data" />
          <xsl:with-param name="DescWidth" select="100"/>
        </xsl:call-template>
        <xsl:call-template name="PopulateLeftoverRow">
          <xsl:with-param name="Desc">Form 4136, Line 14b(d) - UA Registration Number</xsl:with-param>
          <xsl:with-param name="TargetNode" select="$IRS4136Data/OtherNonTaxableUses/@UARegistrationNumber"/>
          <xsl:with-param name="DescWidth" select="100"/>
        </xsl:call-template>
      </table>  
 
      
      <!-- Begin Separated Repeating data -->
      <!-- Begin SRD for line 1 -->
      <xsl:variable name="AFRowCount" select="count($IRS4136Data/OtherNontaxableUseOfGasoline)"/>
      <xsl:if test="($Print = $Separated) and  ($AFRowCount &gt; 1) "> 
        <span class="styRepeatingDataTitle">Form 4136, Line 1 - Nontaxable Use of Gasoline</span>
          <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
            <thead class="styTableThead">
              <tr class="styDepTblHdr">
                <th class="styDepTblCell" style="width:3mm;height:4mm;border-right-width:0px;"></th>
                <th class="styDepTblCell" style="width:77mm;border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
                <th class="styDepTblCell" style="text-align: center;width:16mm;border-left-width:0px;"><b>(a) Type of use</b> </th>
                <th class="styDepTblCell" style="text-align: center;width:13mm;"><b>(b) Rate</b></th>
                <th class="styDepTblCell" style="text-align: center;width:32mm;border-right-width:0px;"><b>(c) Gallons</b></th>
                <th class="styDepTblCell" style="width:3mm;border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
                <th class="styDepTblCell" style="text-align: center;width:32mm;"><b>(d) Amount of credit</b></th>
                <th class="styDepTblCell" style="text-align: center;width:9mm;"><b>(e) CRN</b></th>
              </tr>
            </thead>
          <tfoot/>
          <tbody>
    <!--  Row 1A OFF-HIGHWAY BUSINESS USE OF GASOLINE  -->
    <tr>
      <xsl:attribute name="class">
        <xsl:choose>
           <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
           <xsl:otherwise>styDepTblRow2</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>a</b></td>
      <td class="styDepTblCell" style="text-align:left;border-left-width:0px;padding-top:1.2mm;">Off-highway business use of gasoline</td>
      <td class="styIRS4136TableCellA" style="background-color:lightgrey;">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-top:2mm;">
        $ .184/.183*
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC" style="text-align:right;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/OffHwyBusinessGasolineGallons" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces" style="border-bottom-width: 0px;border-right-width:1px;">
        <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount + 2" /></xsl:attribute>
        <img src="{$ImagePath}/4136_Bracket_L6.gif" alt="bracket"/>
      </td>
      <td class="styIRS4136TableCellD" style="vertical-align:top;padding-top:2mm;">
        <xsl:choose>
          <xsl:when test="$AFRowCount &lt;2">
            <xsl:attribute name="rowspan">3</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount + 2"></xsl:value-of></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>$
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseOfGasolineCredit" />
            </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE" style="text-align:center;vertical-align:top;padding-top:2mm;">
        <xsl:choose>
          <xsl:when test="$AFRowCount &lt; 2">
            <xsl:attribute name="rowspan"><xsl:number value="3"></xsl:number></xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount + 2"></xsl:value-of></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        362
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
      
      <!--  Row 1B USE OF GASOLINE ON A FARM FOR FARMING PURPOSES -->
      <tr class="styDepTblRow2">
      <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>b</b></td>
      <td class="styDepTblCell" style="border-left-width:0px;text-align:left;padding-top:1.2mm;">Use of gasoline on a farm for farming purposes</td>
      <td class="styIRS4136TableCellA" style="background-color:lightgrey;">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;padding-top:2mm;">
            .184/.183*
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC">
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesGasolineGallons" />
            </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
      <!--  Loop  -->
      <xsl:for-each select="$IRS4136Data/OtherNontaxableUseOfGasoline">
        <tr>
          <xsl:attribute name="class">
            <xsl:choose>
               <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
               <xsl:otherwise>styDepTblRow2</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:if test="position()=1">      
            <td class="styDepTblCell" style="vertical-align:top;border-right-width:0px;text-align:left;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount"></xsl:value-of></xsl:attribute>
              <b>c</b>
            </td>
            <td class="styDepTblCell" style="vertical-align:top;border-left-width:0px;text-align:left;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$AFRowCount"></xsl:value-of></xsl:attribute>
              Other nontaxable use of gasoline
            </td>
          </xsl:if>
          <td class="styIRS4136TableCellA">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TypeOfUse" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellB" style="padding-left:3mm;">.184/.183*</td>
          <td class="styIRS4136TableCellC">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="Gallons" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td> 
      </tr>
      </xsl:for-each>
      <!-- End Loop  -->
    </tbody>
  </table>
  <br />
</xsl:if>      
      
      <!-- Begin SRD for Line 2-->
       <xsl:if test="($Print = $Separated) and (count($IRS4136Data/NontaxableAviationGasoline) &gt; 1)">
          <span class="styRepeatingDataTitle">Form 4136, Line 2 - Nontaxable Use of Aviation Gasoline</span>
            <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
              <thead class="styTableThead">
                <tr class="styDepTblHdr">
                  <th class="styDepTblCell" style="width:3mm;height:4mm;border-right-width:0px;"></th>
                  <th class="styDepTblCell" style="width:77mm;border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
                  <th class="styDepTblCell" style="text-align: center;width:16mm;border-left-width:0px;"><b>(a) Type of use</b> </th>
                  <th class="styDepTblCell" style="text-align: center;width:13mm;"><b>(b) Rate</b></th>
                  <th class="styDepTblCell" style="text-align: center;width:32mm;border-right-width:0px;"><b>(c) Gallons</b></th>
                  <th class="styDepTblCell" style="text-align: center;width:32mm;"><b>(d) Amount of credit</b></th>
                  <th class="styDepTblCell" style="text-align: center;width:9mm;"><b>(e) CRN</b></th>
                </tr>
              </thead>
            <tfoot/>
            <tbody>
            <!--  Row 2A USE IN COMMERCIAL AVIATION (OTHER THAN FOREIGN TRADE) -->
              <tr>
                  <xsl:attribute name="class">
                    <xsl:choose>
                       <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                       <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                    </xsl:choose>
                  </xsl:attribute>
                <td class="styDepTblCell" style="width:3mm;border-right-width:0px;text-align:left;"><b>a</b></td>
                <td class="styDepTblCell" style="width:77mm;border-left-width:0px;text-align:left;">Use in commercial aviation (other than foreign trade)</td>
                <td class="styDepTblCell" style="width:16mm;background-color:lightgrey;">
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="width:13mm;">
                  <span style="width: 5px"> </span> $ .15
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="width:32mm;border-right-width:0px;text-align:right;">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="MaxSize" select="9" />
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationGasolineGallons" />
                    </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="width:32mm;text-align:right;">$
                      <xsl:call-template name="PopulateAmount">
                        <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationGasolineCredit" />
                      </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="width:9mm;">
                  354
                  <span class="styIRS4136TableCellPad"></span>
                </td>
              </tr>
              <!--  Row 2B OTHER NONTAXABLE USE  -->
              <!-- LOOP -->
              <xsl:variable name="AGRowCount" select="count($IRS4136Data/NontaxableAviationGasoline)"></xsl:variable>
              <xsl:for-each select="$IRS4136Data/NontaxableAviationGasoline">
                <tr>
                  <xsl:attribute name="class">
                    <xsl:choose>
                       <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                       <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                    </xsl:choose>
                  </xsl:attribute>
                  <xsl:if test="position()=1">
                    <td class="styDepTblRow2Cell" style="vertical-align:top;width:3mm;border-right-width:0px;text-align:left;">
                          <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
                      <b>b</b>
                    </td>
                    <td class="styDepTblRow2Cell" style="vertical-align:top;width:77mm;border-left-width:0px;text-align:left;">
                          <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
                      Other nontaxable use
                    </td>
                  </xsl:if>
                  <td class="styDepTblCell" style="width:16mm;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="TypeOfUse" />
                    </xsl:call-template>
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                  <td class="styDepTblCell" style="padding-left:3mm;">.194/.193*</td>
                  <td class="styDepTblCell" style="width:32mm;border-right-width:0px;text-align:right;">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="MaxSize" select="9" />
                      <xsl:with-param name="TargetNode" select="Gallons" />
                    </xsl:call-template>
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                  <xsl:if test="position()=1">
                    <td class="styDepTblRow2Cell" style="width:32mm;text-align:right;">
                      <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
                      <xsl:call-template name="PopulateAmount">
                        <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableAviationGasolineCr" />
                      </xsl:call-template>
                      <span class="styIRS4136TableCellPad"></span>
                    </td>
                    <td class="styDepTblRow2Cell" style="width:9mm;">
                      <xsl:attribute name="rowspan"><xsl:value-of select="$AGRowCount"></xsl:value-of></xsl:attribute>
                      324
                      <span class="styIRS4136TableCellPad"></span>
                    </td>
                 </xsl:if>
              </tr> 
          </xsl:for-each> 
      </tbody>
    </table>
    <br />
</xsl:if>

<!-- Begin Line 3 SRD -->
 <xsl:if test="($Print = $Separated) and (count($IRS4136Data/NontaxableUseOfUndyedDiesel) &gt; 1)">
  <span class="styRepeatingDataTitle">Form 4136, Line 3 - Nontaxable Use of Undyed Diesel Fuel</span>
  <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
    <thead class="styTableThead">
    <tr class="styDepTblHdr">
      <th style="width:3mm;height:4mm;border-right-width:0px;" class="styDepTblCell"></th>
      <th class="styDepTblCell" style="width:77mm;border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="width:16mm;"><b>(a) Type of use</b> </th>
        <th class="styDepTblCell" style="width:13mm;"><b>(b) Rate</b></th>
      <th class="styDepTblCell" style="width:32mm;border-right-width:0px;"><b>(c) Gallons</b></th>
      <th class="styDepTblCell" style="border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="width:32mm;"><b>(d) Amount of credit</b></th>
      <th class="styDepTblCell" style="width:9mm;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
    <!--  Row 3A NONTAXABLE USE  -->
    <!-- LOOP -->
    <xsl:variable name="UDRowCount" select="count($IRS4136Data/NontaxableUseOfUndyedDiesel)"></xsl:variable>
    <xsl:for-each select="$IRS4136Data/NontaxableUseOfUndyedDiesel">
        <tr>
          <xsl:attribute name="class">
            <xsl:choose>
               <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
               <xsl:otherwise>styDepTblRow2</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:if test="position()=1">
            <td class="styDepTblCell" style="text-align:left;border-right-width:0px;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>
              <b>a</b>        
            </td>
            <td class="styDepTblCell" style="vertical-align:top;border-left-width:0px;text-align:left;">
              <xsl:choose>
                <xsl:when test="$UDRowCount &lt; 3">
                  <xsl:attribute name="rowspan"><xsl:number value="2"></xsl:number></xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>
                </xsl:otherwise>
              </xsl:choose>Nontaxable use
            </td>
          </xsl:if>
              <td class="styIRS4136TableCellA">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="TypeOfUse" />
                </xsl:call-template>
                <span class="styIRS4136TableCellPad"></span>
              </td>
              <td class="styIRS4136TableCellB" style="padding-top:1mm;">
                <xsl:if test="position()=1">$ </xsl:if>
               
                <xsl:if test="position()!=1"><span style="padding-left:3mm;"></span></xsl:if>
                .244/.243*
              </td>
              <td class="styIRS4136TableCellC">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="MaxSize" select="9" />
                  <xsl:with-param name="TargetNode" select="Gallons" />
                </xsl:call-template>
                <span class="styIRS4136TableCellPad"></span>
              </td>
              <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
              <xsl:if test="position()=1">
                <td class="styIRS4136TableCellD" style="vertical-align:top;padding-top:1mm;">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>$
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseOfUndyedDieselCr" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="vertical-align:top;">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UDRowCount"></xsl:value-of></xsl:attribute>
                  360
                  <span class="styIRS4136TableCellPad"></span>
                </td>
              </xsl:if>
          </tr>  
        </xsl:for-each>
        <!--  Row 3B USE IN TRAINS -->
    <tr class="styDepTblRow2">
      <td class="styDepTblCell" style="border-right-width:0px;text-align:left;"><b>b</b></td>
      <td class="styDepTblCell" style="border-left-width:0px;text-align:left;">Use in trains, January 1, 2005 – June 30, 2005</td>
      <td class="styIRS4136TableCellA" style="background-color:lightgrey;">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.21</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/TrainUseOfUndyedDieselGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="" rowspan="2" style="border:1 solid black;border-left-width:0px;"><img src="{$ImagePath}/4136_Bracket_L2L3L4.gif" alt="bracket"/></td>
      <td class="styIRS4136TableCellD" style="padding-bottom:8.5mm;" rowspan="2">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/TrainUseOfUndyedDieselCredit" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell" rowspan="2">
        353
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

        <!--  Row 3C USE IN TRAINS -->
    <tr class="styDepTblRow1">
      <td class="styDepTblCell" style="border-right-width:0px;text-align:left;"><b>c</b></td>
      <td class="styDepTblCell" style="border-left-width:0px;text-align:left;">Use in trains, July 1, 2005 – December 31, 2005</td>
      <td class="styIRS4136TableCellA" style="background-color:lightgrey;">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.22</td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/TrainUseOfUndyedDieselGal" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
    </tr>

      <!--  Row 3D USE IN CERTAIN INTECITY AND LOCAL BUSES   -->
    <tr class="styDepTblRow2">
      <td class="styDepTblCell" style="border-right-width:0px;text-align:left;"><b>d</b></td>
      <td class="styDepTblCell" style="text-align:left;border-left-width:0px;">
        Use in certain intercity and local buses
      </td>
      <td class="styIRS4136TableCellA" style="background-color:lightgrey;">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.17</td>
      <td class="styIRS4136TableCellC">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfUndyedDieselBusesGallons" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfUndyedDieselInBusesCredit" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell">
        350
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
      
      <!--  Row 3E USE IN CERTAIN INTECITY AND LOCAL BUSES   -->
    <tr class="styDepTblRow1">
      <td class="styDepTblCell" style="border-right-width:0px;text-align:left;"><b>e</b></td>
      <td class="styDepTblCell" style="text-align:left;border-left-width:0px;">Use on a farm for farming purposes, after Sept. 30, 2005</td>
      <td class="styIRS4136TableCellA" style="background-color:lightgrey;">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell" style="padding-left:3mm;text-align:left;">.243</td>
      <td class="styIRS4136TableCellC" style="text-align:right;padding-bottom:10px;">
       <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselForFarmingGallons" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces">
         <span class="styIRS4136TableCellPad"></span></td>
    
      <td class="styIRS4136TableCellD" style="text-align:right;padding-bottom:10px;">
      <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedDieselForFarmingCredit" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell">
        360
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>      
    </tbody>
  </table>
  <br />
</xsl:if>

  <!-- Begin line 4 SRD table -->
 <xsl:if test="($Print = $Separated) and (count($IRS4136Data/NontaxableUseOfUndyedKerosene) &gt; 2)">
  <span class="styRepeatingDataTitle">Form 4136, Line 4 - Nontaxable Use of Undyed Kerosene (Other Than Aviation-Grade Kerosene and Kerosene Used in Aviation)</span>
  <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
    <thead class="styTableThead">
    <tr class="styDepTblHdr">
      <th style="width:3mm;height:4mm;border-right-width:0px;" class="styDepTblCell"></th>
      <th class="styDepTblCell" style="width:77mm;border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="width:16mm;"><b>(a) Type of use</b> </th>
      <th class="styDepTblCell" style="width:13mm;"><b>(b) Rate</b></th>
      <th class="styDepTblCell" style="width:32mm;border-right-width:0px;"><b>(c) Gallons</b></th>
      <th class="styDepTblCell" style="width:32mm;"><b>(d) Amount of credit</b></th>
      <th class="styDepTblCell" style="width:9mm;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
    <!--  Row 4A NONTAXABLE USE  -->
    <!-- LOOP -->
    <xsl:variable name="UKRowCount" select="count($IRS4136Data/NontaxableUseOfUndyedKerosene)"></xsl:variable>
      <xsl:for-each select="$IRS4136Data/NontaxableUseOfUndyedKerosene">
      <tr>
          <xsl:attribute name="class">
            <xsl:choose>
               <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
               <xsl:otherwise>styDepTblRow2</xsl:otherwise>
            </xsl:choose>
          </xsl:attribute>
          <xsl:if test="position()=1">
            <td class="styDepTblCell" style="border-right-width:0px;">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>
             <b>a</b><span style="width:1px;"/>
            </td>
            <td class="styDepTblCell" style="vertical-align:top;border-left-width:0px;text-align:left;width:77mm;border-right-width:1px;">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>
                  Nontaxable use
            </td>
          </xsl:if>    
            <td class="styDepTblCell" style="border:1 solid black;border-left-width:1px;width:16mm;">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TypeOfUse" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td style="border-bottom:1 solid black;padding-top:2mm;">
            <xsl:if test="position()=1">$</xsl:if>
            <xsl:if test="position()!=1"><span style="padding-left:3mm;"></span></xsl:if>
            .244/243*
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styDepTblCell" style="border:1 solid black;text-align:right;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="Gallons" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <xsl:if test="position()=1">
            <td class="styDepTblCell" style="text-align:right;border-right:1 solid black;vertical-align:top;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>$
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseUndyedKeroseneCr" />
              </xsl:call-template>
              <span class="styIRS4136TableCellPad"></span>
            </td>
            <td class="styDepTblCell" style="text-align:center;border-left:1 solid black;vertical-align:top;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$UKRowCount"></xsl:value-of></xsl:attribute>
              346
              <span class="styIRS4136TableCellPad"></span>
            </td>
          </xsl:if>
      </tr>    
      </xsl:for-each> 
   
    <!--  Row 4B USE IN CERTAIN INTECITY AND LOCAL BUSES   -->
    <tr class="styDepTblRow2">
      <td class="styDepTblCell" style="border-right-width:0px;"><b>b</b>
      <span style="width:1px;"/>
      </td>
         <td class="styDepTblCell" style="vertical-align:top;border-left-width:0px;text-align:left;width:77mm;border-right-width:1px;">
          Use in certain intercity and local buses
       </td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB" style="padding-left:3mm;">.17</td>
      <td class="styDepTblCell" style="text-align:right;">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneBusesGallons" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell" style="text-align:right;">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfUndyedKeroseneCredit" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        350
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 4C USE IN CERTAIN INTECITY AND LOCAL BUSES   -->
    <tr class="styDepTblRow1">
      <td class="styDepTblCell" style="border-right-width:0px;text-align:top;">
            <b>c</b> <span style="width:1px;"/>
      </td>
      <td class="styDepTblCell" style="vertical-align:top;border-left-width:0px;text-align:left;width:77mm;border-right-width:1px;">
      Use on a farm for farming purposes, after Sept. 30, 2005</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell" style="padding-left:3mm;text-align:left;">.243</td>
       <td class="styDepTblCell" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneForFarmingGal" />
       </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
            <td class="styDepTblCell" style="text-align:right;">
      <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UndyedKeroseneForFarmingCredit" />
       </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell">
        346
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>
             
    </tbody>
  </table>
  <br />
  </xsl:if>

<!-- Begin Line 5 SRD table -->
 <xsl:if test="($Print = $Separated) and (count($IRS4136Data/NontaxableUsesAviationFuel) &gt;1 or count($IRS4136Data/NontaxableUseAviationFuel) &gt; 1)">
  <span class="styRepeatingDataTitle">Form 4136, Line 5 - Nontaxable Use of Aviation-Grade Kerosene Before Oct. 1, 2005</span>
  <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
    <thead class="styTableThead">
    <tr class="styDepTblHdr">
      <th style="width:3mm;height:4mm;border-right-width:0px;" class="styDepTblCell"></th>
      <th class="styDepTblCell" style="width:77mm;border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="width:16mm;"><b>(a) Type of use</b> </th>
        <th class="styDepTblCell" style="width:13mm;"><b>(b) Rate</b></th>
      <th class="styDepTblCell" style="width:32mm;border-right-width:0px;"><b>(c) Gallons</b></th>
      <th class="styDepTblCell" style="border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="width:32mm;"><b>(d) Amount of credit</b></th>
      <th class="styDepTblCell" style="width:9mm;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 5A USE IN COMMERCIAL AVIATION (OTHER THAN FOREIGN TRADE) -->
    <tr>
      <xsl:attribute name="class">
        <xsl:choose>
           <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
           <xsl:otherwise>styDepTblRow2</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>a</b></td>
      <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;">Use in commercial aviation (other than foreign trade)</td>
      <td class="styDepTblCell" style="width:16mm;background-color:lightgrey;">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell" style="width:13mm;">
        $ .175
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell" style="width:32mm;text-align:right;border-right-width:0px;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationFuelGallons" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styDepTblCell" style="width:32mm;text-align:right;">
           $<xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/AviationFuelCredit" />
            </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styDepTblCell" style="width:9mm;">
        355
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 5B OTHER NONTAXABLE USE  -->
    <!-- Row 5b Filler row -->
       <xsl:variable name="UseRowCount" select="count($IRS4136Data/NontaxableUseAviationFuel)"></xsl:variable>
         <xsl:if test="$UseRowCount = 0">
         <tr class="styDepTblRow2">
          <td class="styDepTblCell" style="border-right-width:0px;"><b>b</b></td>
          <td class="styDepTblCell" style="border-left-width:0px;text-align:left;">
            Other nontaxable use
          </td>
          <td class="styDepTblCell">
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styDepTblCell">
            <span style="width: 11px"> </span> .219
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styDepTblCell" style="border-right-width:0px;">
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
          <td class="styDepTblCell">
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styDepTblCell">369
            <span class="styIRS4136TableCellPad"></span>
          </td>
        </tr>
        </xsl:if> 
        <xsl:variable name="RowCount" select="count($IRS4136Data/NontaxableUseAviationFuel)"/>
       <xsl:for-each select="$IRS4136Data/NontaxableUseAviationFuel">
            <tr>
                <xsl:attribute name="class">
                  <xsl:choose>
                     <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                     <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                  </xsl:choose>
                </xsl:attribute>
              <xsl:if  test="position()=1">
                <td class="styDepTblRow2Cell" style="text-align:left;border-right-width:0px;">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                  <b>b</b>
               </td>
                <td class="styDepTblRow2Cell" style="text-align:left;border-left-width:0px;">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                  Other nontaxable use
                </td>
              </xsl:if>
                <td class="styDepTblCell">
                  <xsl:if test="$RowCount = 1">
                    <xsl:attribute name="class">styDepTblRow2Cell </xsl:attribute>
                  </xsl:if>
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="TypeOfUse" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell">
                  <xsl:if test="$RowCount = 1">
                    <xsl:attribute name="class">styDepTblRow2Cell </xsl:attribute>
                  </xsl:if>
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="text-align:right;border-right-width:0px;">
                  <xsl:if test="$RowCount = 1">
                    <xsl:attribute name="class">styDepTblRow2Cell </xsl:attribute>
                  </xsl:if>
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="MaxSize" select="9" />
                    <xsl:with-param name="TargetNode" select="Gallons" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="border-left-width:0px;">
                  <xsl:if test="$RowCount = 1">
                    <xsl:attribute name="class">styDepTblRow2Cell</xsl:attribute>
                  </xsl:if>
                <span class="styIRS4136TableCellPad"></span></td>
                <xsl:if test="position()=1">
                  <td class="styDepTblRow2Cell" style="text-align:right;">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseAviationFuelCr" />
                    </xsl:call-template>
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                  <td class="styDepTblRow2Cell" style="text-align:center;">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                    369
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                </xsl:if> 
              </tr> 
          </xsl:for-each>
      <!--  END LOOP  -->
      
     <!--  Row 5C OTHER NONTAXABLE USES  -->  
              <tr class="styDepTblRow1">
                <td class="styDepTblCell" style="text-align:left;border-right-width:0px;">
                      <b>c</b>
                </td>
                <td class="styDepTblCell" style="text-align:left;border-left-width:0px;">
                    Use in foreign trade
                </td>
                <td class="styDepTblCell" style="background-color:lightgrey;">

                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell">
                  <span style="width: 11px"> </span> .044
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell" style="text-align:right;border-right-width:0px;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="MaxSize" select="9" />
                    <xsl:with-param name="TargetNode" select="$IRS4136Data/NontaxableUseInForeignTrade" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
                <td class="styDepTblCell" style="text-align:right;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$IRS4136Data/UseInForeignTrade" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styDepTblCell">
                  377
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                </tr>  
    </tbody>
  </table>
  <br />
  </xsl:if>  
  
  <xsl:if test="(count($IRS4136Data/OtherNontaxUseAviationGrade) &gt;1) and ($Print = $Separated)">
  <span class="styRepeatingDataTitle">Form 4136, Line 8 - Sales by Registered Ultimate Vendors of Aviation-Grade Kerosene before Oct. 1, 2005</span>
  <div style="width:187mm;">
  <table class="styDepTbl" cellspacing="0"  style="font-size:7pt;">
    <thead class="styIRS4136TableThead">
     <tr class="styDepTblHdr">
      <th style="width:3mm;height:4mm;border-right-width:0px;" class="styDepTblCell"></th>
      <th class="styDepTblCell" style="width:77mm;border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="width:16mm;"><b>(a) Type of use</b> </th>
        <th class="styDepTblCell" style="width:13mm;"><b>(b) Rate</b></th>
      <th class="styDepTblCell" style="width:32mm;border-right-width:0px;"><b>(c) Gallons</b></th>
      <th class="styDepTblCell" style="border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="width:32mm;"><b>(d) Amount of credit</b></th>
      <th class="styDepTblCell" style="width:9mm;"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 8A -->
      <xsl:variable name="Line8bcount" select="count($IRS4136Data/OtherNontaxUseAviationGrade)" />
    <tr class="styDepTblRow1">
    
     <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>a</b></td>
      <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;">Use in commercial aviation (other than foreign trade)</td>
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        $ .175
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC" style="text-align:right;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseCommercialAviationKerosene" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD" style="text-align:left;">
          <xsl:if test="$IRS4136Data/AviationFuelCredit">
            <xsl:attribute name="style">text-align:right;</xsl:attribute>
          </xsl:if>  
       $
           <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$IRS4136Data/UseInCommercialAviationCredit" />
            </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        355
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 8B OTHER NONTAXABLE USE  -->
       <xsl:variable name="UseRowCount" select="count($IRS4136Data/OtherNontaxUseAviationGrade)"></xsl:variable>
       <xsl:for-each select="$IRS4136Data/OtherNontaxUseAviationGrade">
          <xsl:variable name="RowCount" select="count(OtherNontaxUseAviationGrade)"/>
            <tr>
                <xsl:attribute name="class">
                  <xsl:choose>
                     <xsl:when test="position() mod 2 = 1">styDepTblRow2</xsl:when>
                     <xsl:otherwise>styDepTblRow1</xsl:otherwise>
                  </xsl:choose>
                </xsl:attribute>
              <xsl:if  test="position()=1">
              
               <td class="styDepTblCell" style="text-align:left;border-right-width:0px;">
                        <xsl:attribute name="rowspan">
                          <xsl:value-of select="$UseRowCount"></xsl:value-of>
                        </xsl:attribute>
                  <b>b</b>
               </td>
                    <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;">
                  <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount"></xsl:value-of></xsl:attribute>
                  Other nontaxable use
                </td>
              </xsl:if>
                <td class="styIRS4136TableCellA">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="TypeOfUse" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="MaxSize" select="9" />
                    <xsl:with-param name="TargetNode" select="Gallons" />
                  </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <xsl:if test="position()=1">
                  <td class="styIRS4136Braces" style="vertical-align:top;">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount + 2"></xsl:value-of></xsl:attribute>
                    <img src="{$ImagePath}/4136_Bracket_L6.gif" alt="bracket"/>
                  </td>
                  <td class="styIRS4136TableCellD" style="vertical-align:top;">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount + 2"></xsl:value-of></xsl:attribute>
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationCredit" />
                    </xsl:call-template>
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                  <td class="styIRS4136TableCellE" style="vertical-align:top;">
                    <xsl:attribute name="rowspan"><xsl:value-of select="$UseRowCount + 2"></xsl:value-of></xsl:attribute>
                    369
                    <span class="styIRS4136TableCellPad"></span>
                  </td>
                </xsl:if> 
              </tr> 
          </xsl:for-each>
      <!--  END LOOP  -->
      
     <!--  Row 8C  -->  
              <tr class="styDepTblRow1">
                <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>c</b></td>
                <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;">Use on a farm for farming purposes
                  <!-- Form to Form Link -->
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesAviationGallons"/>            
                  </xsl:call-template>
                </td>
                <td class="styIRS4136TableCellA" style="background-color: lightgrey"><span class="styIRS4136TableCellPad"></span></td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="MaxSize" select="9" />
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/FarmingPurposesAviationGallons" />
                    </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
              </tr>  

     <!--  Row 8D -->  
              <tr class="styDepTblRow2">
               <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>d</b></td>
               <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;">Use by a state or local government
                  <!-- Form to Form Link -->
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationGallons"/> 
                  </xsl:call-template>               
               </td>
                <td class="styIRS4136TableCellA" style="background-color: lightgrey"><span class="styIRS4136TableCellPad"></span></td>
                <td class="styIRS4136TableCellB">
                  <span style="width: 11px"> </span> .219
                  <span class="styIRS4136TableCellPad"></span>
                </td>
                <td class="styIRS4136TableCellC" >
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="MaxSize" select="9" />
                      <xsl:with-param name="TargetNode" select="$IRS4136Data/StateLocalGovtAviationGallons" />
                    </xsl:call-template>
                  <span class="styIRS4136TableCellPad"></span>
                </td>
              </tr>  
    </tbody>
  </table>
</div>
<br />
</xsl:if>
  
  <xsl:if test="(count($IRS4136Data/OtherNontaxableUse) &gt;1) and ($Print = $Separated)">
  <span class="styRepeatingDataTitle">Form 4136, Line 11 - Nontaxable Use of Liquefied Petroleum Gas (LPG)</span>

<div style="width:187mm;">
  <table class="styDepTbl" cellspacing="0"  style="font-size:7pt;">
    <thead class="styIRS4136TableThead">
    <tr class="styDepTblHdr">
      <th style="width:3mm;height:4mm;border-right-width:0px;" class="styDepTblCell"></th>
      <th class="styDepTblCell" style="border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="text-align: center"><b>(a) Type of use</b> </th>
      <th class="styDepTblCell" style="text-align: center"><b>(b) Rate</b></th>
      <th class="styDepTblCell" style="text-align: center;border-right-width:0px;"><b>(c) Gallons</b></th>
      <th class="styDepTblCell" style="border-left-width:0px;"><span class="styIRS4136TableCellPad"></span></th>
      <th class="styDepTblCell" style="text-align: center"><b>(d) Amount of credit</b></th>
      <th class="styDepTblCell" style="text-align: center"><b>(e) CRN</b></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody>
      <!--  Row 11A USE IN CERTAIN INTERCITY AND LOCAL BUSES -->
    <tr class="styDepTblRow1">
         <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>a</b></td>
    <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;">Use in certain intercity and local buses</td>
    
      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        $ .062
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="9" />
            <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfLPGInBusesGallons" />
          </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD">
        $
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/UseOfLPGInBusesCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        352
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 11B USE IN QUALIFIED LOCAL AND SCHOOL BUSES  -->
    <tr class="styDepTblRow2">
         <td class="styDepTblCell" style="text-align:left;border-right-width:0px;"><b>b</b></td>
         <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;">Use in qualified local buses or school buses</td>

      <td class="styIRS4136TableCellA" style="background-color: lightgrey">
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellB">
        <span style="width: 10px"> </span> .136
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellC">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="9" />
          <xsl:with-param name="TargetNode" select="$IRS4136Data/QualifiedUseLPGInBusesGallons" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
      <td class="styIRS4136TableCellD">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$IRS4136Data/QualifiedUseLPGInBusesCredit" />
        </xsl:call-template>
        <span class="styIRS4136TableCellPad"></span>
      </td>
      <td class="styIRS4136TableCellE">
        361
        <span class="styIRS4136TableCellPad"></span>
      </td>
      </tr>

    <!--  Row 11C  -->
      <xsl:for-each select="$IRS4136Data/OtherNontaxableUse">
        <tr>
                <xsl:attribute name="class">
                  <xsl:choose>
                     <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                     <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                  </xsl:choose>
                </xsl:attribute>        
          <xsl:if  test="position()=1">
               <td class="styDepTblCell" style="text-align:left;border-right-width:0px;vertical-align:top;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>
              <b>c</b>
            </td>
             <td class="styDepTblCell" style="width:77mm;text-align:left;border-left-width:0px;vertical-align:top;">
          
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>
              Other nontaxable use
            </td>
          </xsl:if>        
          <td class="styIRS4136TableCellA">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TypeOfUse" />
            </xsl:call-template>          
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellB">
            <span style="width: 10px"> </span> .136
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136TableCellC">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="MaxSize" select="9" />
              <xsl:with-param name="TargetNode" select="Gallons" />
            </xsl:call-template>
            <span class="styIRS4136TableCellPad"></span>
          </td>
          <td class="styIRS4136Braces"><span class="styIRS4136TableCellPad"></span></td>
          <xsl:if test="position()=1">          
            <td class="styIRS4136TableCellD" style="vertical-align:top;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>            
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$IRS4136Data/OtherNontaxableUseLPGCredit" />
              </xsl:call-template>
              <span class="styIRS4136TableCellPad"></span>
            </td>
            <td class="styIRS4136TableCellE" style="vertical-align:top;">
              <xsl:attribute name="rowspan"><xsl:value-of select="$RowCount11C"></xsl:value-of></xsl:attribute>            
              361
              <span class="styIRS4136TableCellPad"></span>
            </td>
          </xsl:if>
        </tr>
      </xsl:for-each>
    </tbody>  
  </table>
</div>
</xsl:if>
  
</form>
</body>
</html>

</xsl:template>
</xsl:stylesheet>