<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" >
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddHeader.xsl"/>
  <xsl:include href="AddOnTable.xsl"/>
  <xsl:include href="IRS5712AStyle.xsl"/>
  <xsl:output method="html" indent="yes" />
  <xsl:strip-space elements="*" />
  <xsl:param name="Form5712AData" select="$RtnDoc/IRS5712A" />
  <xsl:template match="/">
    <html>
      <head>
        <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form5712AData)"></xsl:with-param></xsl:call-template></title>
        <!-- No Browser Caching -->
        <meta http-equiv="Pragma" content="no-cache" />
        <meta http-equiv="Cache-Control" content="no-cache" />
        <meta http-equiv="Expires" content="0" />
        <!-- No Proxy Caching -->
        <meta http-equiv="Cache-Control" content="private" />
        <!-- Define Character Set -->
        <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
        <meta name="Description" content="Form IRS5712A" />        
        <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
        <xsl:call-template name="InitJS"></xsl:call-template>
        <style type="text/css">    
          <xsl:if test="not($Print) or $Print=''">
            <xsl:call-template name="IRS5712AStyle"></xsl:call-template>
            <xsl:call-template name="AddOnStyle"></xsl:call-template>        
          </xsl:if>
        </style>
        <xsl:call-template name="GlobalStylesForm"/>
      </head>
      <body class="styBodyClass">
        <form name="Form5712A">
          <xsl:call-template name="DocumentHeader"  />  
          <div style="width:186mm;height:18mm;" class="styTBB">
            <div style="width:36mm;height:20mm;" class="styFNBox">
              <div style="height:13mm;">Form<span class="styFormNumber" style="font-family:arial;">  5712-A</span>
                <br />(Rev. December 2003)
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="$Form5712AData" />
                  <xsl:with-param name="TabOrder" select="2"/>
                </xsl:call-template>
              </div>
              <div style="height:7mm">
                <span class="styAgency">Department of the Treasury</span>
                <br />
                <span class="styAgency">Internal Revenue Service</span>
              </div>
            </div>
            <div style="width:120mm;height:20mm;" class="styFTBox">
              <div style="height:12mm;padding-top:1mm;" class="styMainTitle">
                Election and Verification of the Cost Sharing or
				<br />
                Profit Split Method Under Section 936(h)(5)
              </div>
              <div style="height:8mm;font-size:7pt;padding-top:4mm;" class="styFST">
                <img src="{$ImagePath}/5712-A_Bullet.gif" alt="Bullet Image" />
                Attach to Schedule P (Form 5735)
              </div>
            </div>
            <div style="width:30mm;height:20mm;" class="styTYBox">
              <div style="height:19mm;padding-top:7mm;border-bottom-width:0px;" class="styOMB">
                OMB No. 1545-0215
              </div>
            </div>
          </div>
          <div style="width:186mm;height:4mm;" class="styBB">
            The corporation named below elects under section 936(h)(5) to use the cost sharing or profit split method for income tax purposes.
          </div>
          <div style="width:186mm;" class="styBB">
            <div style="width:140mm;height:8mm;font-size:7pt;font-weight:normal;" class="styNameBox">
              Name of corporation<br />
              <xsl:choose>
                <xsl:when test="$Form5712AData/NameofCorporation">
                  <span>
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="$Form5712AData/NameofCorporation/BusinessNameLine1" />
                    </xsl:call-template><br />
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="$Form5712AData/NameofCorporation/BusinessNameLine2" />
                    </xsl:call-template>  
                  </span>            
                </xsl:when>
                <xsl:otherwise >
                  <span>
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
                  </span>            
                </xsl:otherwise>
              </xsl:choose>
            </div>
            <div style="width:46mm;height:4mm;padding-left:2mm;font-size:7pt;" class="styEINBox">
              Employer identification number<br />
              <br />
              <span style="font-weight:normal;">
                <xsl:choose>
                  <xsl:when test="$Form5712AData/EmployerIdentificationNumber">
                    <xsl:call-template name="PopulateEIN">
                      <xsl:with-param name="TargetNode" select="$Form5712AData/EmployerIdentificationNumber" />
                    </xsl:call-template>  
                  </xsl:when>
                  <xsl:otherwise>
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>          
                  </xsl:otherwise>
                </xsl:choose>
              </span>      
            </div>
          </div>
          <div style="width:187mm;font-size:8pt;" class="styBB">
            <div style="width:140mm;height:4mm;font-size:8pt;" class="styNameBox">
              Enter the possession product to which this form relates<span style="width:4px;"></span>  <img src="{$ImagePath}/5712-A_Bullet.gif" alt="Bullet Image" />
              <span style="width:4px;"></span>    
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form5712AData/PossessionProduct" />
              </xsl:call-template>  
            </div>
            <div style="width:46mm;height:4mm;padding-left:2mm;font-size:8pt;font-weight:normal;" class="styEINBox">
              SIC code <img src="{$ImagePath}/5712-A_Bullet.gif" alt="Bullet Image" /><span style="width:4px;"></span>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form5712AData/PossessionProductNaicsCode" />
              </xsl:call-template>  
            </div>
          </div>
          <div style="width:186mm;" class="styBB">
            <div style="width:186mm;height:4mm;font-weight:bold;text-align:center;font-size:8pt;" class="styGenericDiv">
              Significant Business Presence Tests
            </div>
            <div style="width:186mm;height:7mm;" class="styGenericDiv">
              <span class="styBoldText">Note:</span><span class="styItalicText"> Corporations engaged in start-up operations in a possession may be able to reduce the percentages               computed on lines 3 and 8 below. See the instructions for start-up operations.</span>
            </div>
          </div>
          <!--begin Part I -->
          <div style="width:186mm;" class="styBB">
            <div class="styPartName" style="width:13mm;">Part I</div>
            <div class="styPartDesc" style="padding-left:3mm;">
              Tests Used To Qualify for Cost Sharing or Profit Split Method <br />
              <span class="styNormalText"><span style="width:5px;"></span>Complete the column and lines that apply for the method you elected and the test you meet.</span>
            </div>
          </div>
          <!-- Beginning Direct labor test -->
          <div style="width:186mm;" class="styBB">
            <div style="width:186mm;font-weight:bold;">
              <div style="width:122mm;" class="styLNDesc">
                Direct Labor Test
              </div>
              <div class="styLNAmountBox" style="text-align:center;">Cost Sharing</div>
              <div class="styLNAmountBox" style="text-align:center;">Profit Split</div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBoxSD">1</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Possessions corporation's direct labor costs
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">.............</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/PossCorpDirectLaborCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/PossCorpDirectLaborPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBoxSD">2</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Total direct labor costs of affiliated group
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">...............</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/TotAffiliatedGroupLaborCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/TotAffiliatedGrpLaborPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBoxSD">3</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Divide line 1 by line 2
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">....................</span>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/DirectLaborTestPercentCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/DirectLaborTestPercentPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox"></div>
              <div style="width:114mm;height:17mm;" class="styLNDesc">
                If line 3 is at least 65% (see the instructions for start-up operations for exceptions), you meet the
                <span class="styBoldText">direct labor test</span> and you qualify to use the <span class="styBoldText">
                cost sharing method.</span> To see if you qualify for the <span class="styBoldText">profit
                split method,</span> answer the question on line 18. If line 3 is less than 65%, you do not meet the direct
                labor test. Complete lines 4 through 8 to see if you qualify under the value added test.
              </div>
              <div class="styLNAmountBoxNBB" style="text-align:center;height:17mm;background-color:lightgrey;"></div>
              <div class="styLNAmountBoxNBB" style="text-align:center;height:17mm;background-color:lightgrey;"></div>
            </div>
          </div>
          <!-- Beginning Value added Test -->
          <div style="width:186mm;" class="styBB">
            <div style="width:186mm;font-weight:bold;">
              <div style="width:122mm;" class="styLNDesc">
                Value Added Test
              </div>
              <div class="styLNAmountBoxNBB" style="border-left-width:1px;">
              </div>
              <div class="styLNAmountBoxNBB" style="border-left-width:1px;">
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBoxSD">4</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Production costs of possessions corporation
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">.............</span>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/ProductionCostsOfPossCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/ProductionCostsOfPossPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm">        
              <div class="styLNLeftNumBoxSD">5</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Gross receipts on sales or dispositions of possession product by the affiliated group                
              </div>
              <div style="float:right;">
                <div class="styLNAmountBoxNBB"></div>
                <div class="styLNAmountBoxNBB">
                </div>
              </div>        
            </div>
            <div style="width:186mm">  
              <div class="styLNLeftNumBox"></div>
              <div style="float:left;">
                to unrelated parties
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:0mm;">  
                  .....................    
                </span>
                <div class="styLNAmountBox" style="height:4mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/GrossReceiptsOnSalesCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox" style="height:4mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/GrossReceiptsOnSalesPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>    
            </div>        
            <div style="width:186mm">        
              <div class="styLNLeftNumBoxSD">6</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Cost of direct material purchased from unrelated suppliers used in the production                
              </div>
              <div style="float:right;">
                <div class="styLNAmountBoxNBB"></div>
                <div class="styLNAmountBoxNBB">
                </div>
              </div>        
            </div>
            <div style="width:186mm">  
              <div class="styLNLeftNumBox"></div>
              <div style="float:left;">
                of the possession product
              </div>
              <div style="float:right">
                <span class="styDotLn">  
                  ...................    
                </span>
                <div class="styLNAmountBox" style="height:4mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/CostsOfMtrlPurchasedCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox" style="height:4mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/CostsOfMtrlPurchasedPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>    
            </div>  
            <div style="width:186mm;">
              <div class="styLNLeftNumBoxSD">7</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Subtract line 6 from line 5
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">....................</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/DiffOfCostsAndReceiptsCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/DiffOfCostsAndReceiptsPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBoxSD">8</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Divide line 4 by line 7
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">....................</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/ValueAddedTestPercentCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/ValueAddedTestPercentPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox"></div>
              <div style="width:114mm;height:17mm;" class="styLNDesc">
                If line 8 is at least 25% (see the instructions for start-up operations for exceptions), you meet the
                <span class="styBoldText">value added test</span> and you qualify to use the <span class="styBoldText">
                cost sharing method.</span> To see if you qualify for the
                <span class="styBoldText">profit split method,</span> answer the question on line 18. If line 8 is less than 25%, you do not meet the
                value added test. Complete lines 9 through 15 to see if you qualify under the alternative test.
              </div>
              <div class="styLNAmountBoxNBB" style="text-align:center;height:17mm;background-color:lightgrey;"></div>
              <div class="styLNAmountBoxNBB" style="text-align:center;height:17mm;background-color:lightgrey;"></div>
            </div>
          </div>
          <!-- Beginning part II -->
          <!-- Begin part ii title -->
          <div style="width:186mm;" class="styBB">
            <div class="styPartName" style="width:13mm;">Part II</div>
            <div class="styPartDesc" style="padding-left:3mm;">
              Alternative Test Used To Qualify for Cost Sharing or Profit Split Method
            </div>
          </div>
          <!-- Beginning Direct labor test -->
          <div style="width:186mm;" class="styBB">
            <div style="width:186mm;">
              <div class="styLNLeftNumBoxSD">9</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Direct labor costs of possessions corporation
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">............</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/LaborCostOfPossessionsCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/LaborCostOfPossessionsPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">10</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Direct labor costs of affiliated group
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">................</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/LaborCostOfAffiliatedCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/LaborCostOfAffiliatedPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">11</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Divide line 9 by line 10
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">....................</span>
                <div class="styLNAmountBox">      
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/PctAffltGrpToPossCorpCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/PctAffltGrpToPossCorpPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox"></div>
              <div style="width:114mm;height:4mm;" class="styLNDesc">
                If line 11 is at least 50%, go to line 12. If line 11 is less than 50%, you do not meet the alternative test.
              </div>
              <div class="styLNAmountBoxNBB" style="background-color:lightgrey;height:8mm;"></div>
              <div class="styLNAmountBoxNBB" style="background-color:lightgrey;height:8mm;"></div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">12</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Base period construction costs
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">.................</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/BasePeriodConstructionCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/BasePeriodConstructionPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">13</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Add lines 9 and 12
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">......................</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/PossLaborAndConstrCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/PossLaborAndConstrPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">14</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Add lines 10 and 12
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">.....................</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/AffltLaborAndConstrCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/AffltLaborAndConstrPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">15</div>
              <div style="float:left;padding-top:0.5mm;padding-bottom:.5mm;">
                Divide line 13 by line 14
              </div>
              <div style="float:right">
                <span class="styDotLn" style="padding-right:2mm;">....................</span>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/AlternativeTestPercentCostShr" />
                  </xsl:call-template>  
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/AlternativeTestPercentPrftSplt" />
                  </xsl:call-template>  
                </div>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox"></div>
              <div style="width:114mm;height:11mm;" class="styLNDesc">
                If line 15 is at least 70%, you meet the alternative test and you qualify to use the
                <span class="styBoldText">cost sharing method.</span> To see if you qualify for the <span class="styBoldText">
                profit split method,</span> answer the
                question on line 18. If line 15 is less than 70%, you do not meet the alternative test.
              </div>
              <div class="styLNAmountBoxNBB" style="text-align:center;height:11mm;background-color:lightgrey;"></div>
              <div class="styLNAmountBoxNBB" style="text-align:center;height:11mm;background-color:lightgrey;"></div>
            </div>
          </div>

          <!-- Beginning part III -->
          <!-- Begin part III title -->
          <div style="width:186mm;" class="styBB">
            <div class="styPartName" style="width:15mm;">Part III</div>
            <div class="styPartDesc" style="padding-left:3mm;width:131mm;">
              Start-up Operations <span class="styNormalText">(see instructions)</span>
            </div>
          </div>
          <!-- Beginning Direct labor test -->
          <div style="width:186mm;" class="styBB">
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">16</div>
              <div style="width:178mm;height:4mm;" class="styLNDesc">
                <label>
                  <xsl:call-template name="PopulateLabel">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/StartUpOperations" />
                  </xsl:call-template>
                  If the corporation is engaged in start-up operations, check this box
                  <span style="letter-spacing:4mm;font-weight:bold;">.................</span>
                </label>
                <span style="width:4px;"></span>
                <img src="{$ImagePath}/5712-A_Bullet.gif" alt="Bullet Image" />
                <span style="width:4px;"></span>
                <input type="checkbox" class="styCkbox" onclick="return false;" >
                  <xsl:call-template name="PopulateCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form5712AData/StartUpOperations" />                    
                  </xsl:call-template>
                </input>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">17</div>
              <div style="width:178mm;height:4mm;" class="styLNDesc">
                Enter the beginning date of the tax year the possessions corporation began producing the product in
                the possession
                <span style="letter-spacing:4mm;font-weight:bold;">..........................</span>
                <span style="width:7px;"></span>
                <img src="{$ImagePath}/5712-A_Bullet.gif" alt="Bullet Image" />
                <span style="width:7px;"></span>
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form5712AData/ProductionBegngDateOfTaxYear" />
                </xsl:call-template>  
              </div>
            </div>
          </div>
      
          <!-- Beginning part IV -->
          <!-- Begin part IV title -->
          <div style="width:186mm;" class="styBB">
            <div class="styPartName" style="width:15mm;">Part IV</div>
            <div class="styPartDesc" style="padding-left:3mm;width:131mm;">
              Other Information
            </div>
          </div>
          <div style="width:186mm;" class="styTBB">
            <div style="width:186mm;">
              <div class="styLNLeftNumBox">18</div>
              <div style="width:178mm;height:4mm;" class="styLNDesc">
                If you are claiming the profit split method: Is the possession product manufactured (as defined in Regulations
                section 1.954-3(a)(4)) in the possession?
                <span style="letter-spacing:4mm;font-weight:bold;">............................</span>
                <span style="width:5px;"></span>
                <span>
                <xsl:call-template name="PopulateSpan">
                  <xsl:with-param name="TargetNode" select="$Form5712AData/IsProdManufacturedInPossession" />
                </xsl:call-template>
                  <input type="checkbox" class="styCkbox">
                    <xsl:call-template name="PopulateYesCheckbox">
                      <xsl:with-param name="TargetNode" select="$Form5712AData/IsProdManufacturedInPossession" />
                    </xsl:call-template>
                  </input>
                </span>
                  <label style="font-weight:bold;">
                    <xsl:call-template name="PopulateLabelYes">
                      <xsl:with-param name="TargetNode" select="$Form5712AData/IsProdManufacturedInPossession" />
                    </xsl:call-template>
                    Yes
                  </label>
                  <span style="width:5px;"></span>
                <span>
                <xsl:call-template name="PopulateSpan">
                  <xsl:with-param name="TargetNode" select="$Form5712AData/IsProdManufacturedInPossession" />
                </xsl:call-template>
                  <input type="checkbox" class="styCkbox">
                    <xsl:call-template name="PopulateNoCheckbox">
                      <xsl:with-param name="TargetNode" select="$Form5712AData/IsProdManufacturedInPossession" />
                    </xsl:call-template>
                  </input>
                </span>
                  <label style="font-weight:bold;">
                    <xsl:call-template name="PopulateLabelNo">
                      <xsl:with-param name="TargetNode" select="$Form5712AData/IsProdManufacturedInPossession" />
                    </xsl:call-template>
                    No
                  </label>
              </div>
            </div>
            <div style="width:186mm;">
              <div class="styLNLeftNumBox"></div>
              <div style="width:178mm;height:4mm;" class="styLNDesc">
                If "No," you do not qualify to use the profit split method of computing taxable income.
                <br />
                <span class="styBoldText">Note:</span><span class="styItalicText"> Affiliated group members must attach a list showing name, address, and employer identification                 number   of all members of the group.</span>
              </div>
            </div>
          </div>

          <!-- the signature part was removed to match the updated PDF -->
          <div style="width:186mm;clear:both;padding-top:1mm;">
            <div style="width:90mm;font-weight:bold;" class="styGenericDiv">For Paperwork Reduction Act Notice, see instructions on back.</div>
            <div style="width:55mm;text-align:center;" class="styGenericDiv">Cat. No. 61166D</div>
            <div style = "float:right;" class="styGenericDiv">Form <span class="styBoldText">5712-A</span> (Rev. 12-2003)</div>
          </div>    
          <p class="pageend"></p>      
          <!-- Begininning of write-in data -->
          <div class="styLeftOverTitleLine" id="LeftoverData">
            <div class="styLeftOverTitle">
              Additional Data        
            </div>
            <div class="styLeftOverButtonContainer">
              <input class="styLeftoverTableBtn" tabindex="1" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
            </div>      
          </div>
          <table class="styLeftOverTbl">
            <xsl:call-template name="PopulateCommonLeftover">
              <xsl:with-param name="TargetNode" select="$Form5712AData" />
              <xsl:with-param name="DescWidth" select="100"/>
            </xsl:call-template>
          </table>

        </form>
      </body>  
    </html>
  </xsl:template>
</xsl:stylesheet>
