<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS5735Style.xsl"/>

<xsl:output method="html" indent="yes" encoding="iso-8859-1"/>

<xsl:strip-space elements="*" />
<xsl:param name="FormData" select="$RtnDoc/IRS5735" />

<xsl:template match="/">
<html>
<head>  
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache"/>
  <meta http-equiv="Cache-Control" content="no-cache"/>
  <meta http-equiv="Expires" content="0"/>
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private"/>  
  <meta name="Description" content="Form IRS 5735"/>
  <meta name="GENERATOR" content="IBM WebSphere Studio"/>
   <xsl:call-template name="GlobalStylesForm"/>
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>  
  <style type="text/css">    
    <xsl:if test="not($Print) or $Print=''">
      <xsl:call-template name="IRS5735Style"></xsl:call-template>    
      <xsl:call-template name="AddOnStyle"></xsl:call-template>  
    </xsl:if>
  </style>      
  
</head>

<body class="styBodyClass">
  <form name="Form5735">    
    <xsl:call-template name="DocumentHeader"></xsl:call-template>  
    
  <!--Title of Form -->    
  <div class="styBB" style="width:187mm;height: 19mm">
    <div class="styFNBox" style="width:31mm;font-size: 7pt; height: 19mm">
      Form <span class="styFormNumber" style="font-size: 16pt">5735
      <span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$FormData"/>
        </xsl:call-template>  
      </span>  
      </span>      
      <br/>
      (Rev. April 2003)

      <br/>
      <div class="styAgency" style="padding-top: 2mm">Department of the Treasury</div><div class="styAgency">Internal Revenue Service</div>
    </div>
    <div class="styFTBox" style="width:125mm">
      <div class="styMainTitle" style="height:8mm;">Possessions Corporation Tax Credit <br/> <span style="font-size:11pt">(Under Sections 936 and 30A)</span></div>
      <div class="styFST" style="height:4mm;font-size:7pt;margin-left:3mm;font-weight:bold">
        <div style="padding-top: .5mm">
          <img src="{$ImagePath}/5735_Bullet_Sm.gif" alt="SmallBullet"/> 
          See separate instructions.
        </div>
        <div style="padding-top: .5mm">
          <img src="{$ImagePath}/5735_Bullet_Sm.gif" alt="SmallBullet"/> 
          Attach to the corporation's tax return.
        </div>
      </div>
    </div>
    <div class="styTYBox" style="width:31mm; height: 19mm">        
      <div style="padding-top:8mm; font-size:7pt">OMB No. 1545-0217</div>
    </div>
  </div>
  <!--  End title of Form  -->
  
  <!--  For calendar year line  -->
  <div class="styBB" style="width: 187mm">
    <div class="styBoldText">For calendar year
      <span style="width: 8mm">
	   <xsl:if test="normalize-space($FormData/CalendarYear) != ''">
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CalendarYear" />
          </xsl:call-template>
        </xsl:if>   
      </span>, or other tax year beginning
        <span style="width: 17mm">
	   <xsl:if test="normalize-space($FormData/TaxPeriodBeginDate) != ''">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="$FormData/TaxPeriodBeginDate" />
            </xsl:call-template>
          </xsl:if>
        </span>and ending 
        <span style="width: 17mm">
	   <xsl:if test="normalize-space($FormData/TaxPeriodEndDate) != ''">
            <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/TaxPeriodEndDate" />
            </xsl:call-template>
          </xsl:if>
        </span>
    </div>
  </div>
  <!--  End For calendar year line  -->
    
  <!--  Name and Employer identification number  -->
  <div class="styBB" style="width:187mm">
          <div class="styNameBox" style="width:141mm;font-size:7pt;">
      Name<br/>
          <div>
        <xsl:choose>
          <xsl:when test="normalize-space($FormData/Name) != ''">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$FormData/Name/BusinessNameLine1" /></xsl:call-template>
            <xsl:if test="normalize-space($FormData/Name/BusinessNameLine2)!=''">
              <br /><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$FormData/Name/BusinessNameLine2" /></xsl:call-template>
            </xsl:if>            
          </xsl:when>  
          <xsl:otherwise>
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </div>
    </div>
    <div class="styEINBox" style=" padding-left:2mm;font-size:7pt;"><span class="BoldText">Employer identification number</span>
      <div style="text-align:left; padding-top:3mm;font-weight:normal;">    
        <xsl:choose>
          <xsl:when test="normalize-space($FormData/EmployerIdentificationNumber) != ''">
            <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" select="$FormData/EmployerIdentificationNumber" /></xsl:call-template>
          </xsl:when>  
          <xsl:otherwise>  
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </div>    
    </div>
  </div>  
  <!--  End Name and Employer indentification number  -->
  
  <!--  Part I -->
  <div class="styBB" style="width: 187mm;  float: none; clear:none">
    <div class="styPartName" style="width: 15mm; height: 3.75mm">Part I</div>
    <div class="styPartDesc" style="width: 120mm">Gross Income in Applicable Period  <span class="styNormalText">(See instructions.)</span></div>
    <!-- button display logic -->
    <div style="float:right; clear: none; width: 4mm">
       <xsl:call-template name="SetDynamicTableToggleButton">
        <xsl:with-param name="TargetNode" select="$FormData/GrossIncomeInApplcblPeriod"/>
        <xsl:with-param name="containerHeight" select="3"/>
        <xsl:with-param name="headerHeight" select="2"/>
        <xsl:with-param name="containerID" select=" 'APctn' "/>
      </xsl:call-template>
       <!-- end button display logic -->
     </div>
  </div>
  <!--  End Part I -->  
  
  <div class="styIRS5735TableContainer" id="APctn">
    <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
    <!-- end -->  
   <table class="styTable" cellspacing="0">
     <thead class="styTableThead" style="border-color:black">
    <tr>
      <th class="styTableCellHeader" colspan="2" style="width: 60mm"><span class="styNormalText" >Tax year (Use a separate line for each tax year<br/>ending with or within your applicable period. Start<br/>with the earliest such tax year.)</span></th>
      <th class="styTableCellHeader" rowspan="2" style="width: 67mm"><b>(c)</b><br/><span class="styNormalText" style="font-size:7pt">Name of U.S. possession in which trade or<br/>business was actively conducted</span></th>
      <th class="styTableCellHeader" colspan="2" style="width: 60mm; border-right-width: 0px"><span class="styNormalText">Periods in which trade or business was actively<br/>conducted in a U.S. possession (Dates are<br/>inclusive)</span></th>
      </tr>
    <tr>
      <th class="styTableCellHeader"><b>(a)</b><br/><span class="styNormalText" style="font-size:7pt">Beginning</span></th>
      <th class="styTableCellHeader" style="width: 33mm"><b>(b)</b><br/><span class="styNormalText" style="font-size:7pt">Ending</span></th>
      <th class="styTableCellHeader"><b>(d)</b><br/><span class="styNormalText" style="font-size:7pt">From</span></th>
      <th class="styTableCellHeader" style="border-right-width: 0px"><b>(e)</b><br/><span class="styNormalText" style="font-size:7pt">To</span></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody style="border-color:black">
      <xsl:if test="count($FormData/GrossIncomeInApplcblPeriod) != 0">
      <xsl:for-each select="$FormData/GrossIncomeInApplcblPeriod">
       <xsl:if test="($Print != $Separated) or (count($FormData/GrossIncomeInApplcblPeriod) &lt;=3)">
          <tr>
            <td class="styTableCell" style="text-align: center;font-size:7pt">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="TaxYearBeginning" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell" style="text-align: center;font-size:7pt">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="TaxYearEnding" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell" style="text-align: left;font-size:7pt">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="NameOfUSPossession" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell" style="text-align: center;font-size:7pt">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="PeriodsTradeWasConductedFrom" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell" style="border-right-width: 0px; text-align: center;font-size:7pt">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="PeriodsTradeWasConductedTo" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
          </tr>
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="(count($FormData/GrossIncomeInApplcblPeriod) &lt; 1) or (($Print = $Separated) and (count($FormData/GrossIncomeInApplcblPeriod) &gt; 3))">
        <tr>
        <xsl:choose>
        	<xsl:when test="count($FormData/GrossIncomeInApplcblPeriod) &lt; 1">
	          <td class="styTableCell"><span class="styTableCellPad"></span></td>
	          <td class="styTableCell"><span class="styTableCellPad"></span></td>
	          <td class="styTableCell"><span class="styTableCellPad"></span></td>
	          <td class="styTableCell"><span class="styTableCellPad"></span></td>
	          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>
	       </xsl:when>
	       <xsl:otherwise>
	          <td class="styTableCell">
	          	<xsl:call-template name="PopulateAdditionalDataTableMessage">
	          		<xsl:with-param name="TargetNode" select="$FormData/GrossIncomeInApplcblPeriod/TaxYearBeginning"/>
	          	</xsl:call-template>
	          </td>
	          <td class="styTableCell"><span class="styTableCellPad"></span></td>
	          <td class="styTableCell"><span class="styTableCellPad"></span></td>
	          <td class="styTableCell"><span class="styTableCellPad"></span></td>
	          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>	       
	       </xsl:otherwise>
	</xsl:choose>
        </tr>        
       </xsl:if>
       
      <xsl:if test="(count($FormData/GrossIncomeInApplcblPeriod) &lt; 2) or (($Print = $Separated) and (count($FormData/GrossIncomeInApplcblPeriod) &gt; 3))">      
        <tr>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      
      <xsl:if test="(count($FormData/GrossIncomeInApplcblPeriod) &lt; 3) or (($Print = $Separated) and (count($FormData/GrossIncomeInApplcblPeriod) &gt; 3))">
        <tr>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      
    </tbody>
  </table>
  </div>
  <!-- Set Initial Height of Above Table -->
  <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$FormData/GrossIncomeInApplcblPeriod"/>
    <xsl:with-param name="containerHeight" select="3"/>
      <xsl:with-param name="headerHeight" select="2"/>
    <xsl:with-param name="containerID" select=" 'APctn' "/>
  </xsl:call-template>
  <!-- End Set Initial Height of Above Table -->
  
  <div class="styBB" style="width: 187mm; text-align: center">
    <div class="styBoldText" style="width:183mm;float:left;clear:none;">Gross income during periods shown in columns (d) and (e)</div>
      <!-- button display logic -->
    <div style="float:right; clear: none">
       <xsl:call-template name="SetDynamicTableToggleButton">
        <xsl:with-param name="TargetNode" select="$FormData/GrossIncmDuringPrdInColmDAndE"/>
        <xsl:with-param name="containerHeight" select="4"/>
        <xsl:with-param name="headerHeight" select="2"/>
        <xsl:with-param name="containerID" select=" 'GIctn' "/>
      </xsl:call-template>
       <!-- end button display logic -->
     </div>
  </div>
  <!--  End Part I -->  
  
  <div class="styIRS5735TableContainer" style="border-bottom-width: 0px" id="GIctn">
    <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
    <!-- end -->    
     <table class="styTable" cellspacing="0">
     <thead class="styTableThead" style="border-color:black">
    <tr>
      <th class="styTableCellHeader" colspan="4" style="width: 92mm; text-align: left"><span class="styNormalText">Gross income from the active conduct of a trade or business in a U.S. possession</span></th>
      <th class="styTableCellHeader" rowspan="2" style="width: 32mm"><b>(i)</b><br/><span class="styNormalText">Gross qualified<br/>possession source<br/>investment income<br/>(QPSII) (see instructions)</span></th>
      <th class="styTableCellHeader" colspan="3" style="width: 63mm; border-right-width: 0px"><span class="styNormalText">All other gross income</span></th>
      </tr>
    <tr>
      <th class="styTableCellHeader" colspan="2"><b>(f)</b><br/><span class="styNormalText">From sources in U.S. possessions</span></th>
      <th class="styTableCellHeader"><b>(g)</b><br/><span class="styNormalText">From all other sources outside the U.S.</span></th>
      <th class="styTableCellHeader"><b>(h)</b><br/><span class="styNormalText">From sources in the U.S.</span></th>
      <th class="styTableCellHeader"><b>(j)</b><br/><span class="styNormalText">From sources in U.S. possessions</span></th>
      <th class="styTableCellHeader"><b>(k)</b><br/><span class="styNormalText">From all other sources outside the U.S.</span></th>
      <th class="styTableCellHeader" style="border-right-width: 0px"><b>(l)</b><br/><span class="styNormalText">From sources in the U.S.</span></th>
    </tr>
    </thead>
    <tfoot/>
    <tbody style="border-color:black">
      <xsl:if test="count($FormData/GrossIncmDuringPrdInColmDAndE) != 0">
        <xsl:for-each select="$FormData/GrossIncmDuringPrdInColmDAndE">
        <xsl:if test="($Print != $Separated) or (count($FormData/GrossIncmDuringPrdInColmDAndE) &lt;=3)">
          <tr>
            <td class="styTableCell" colspan="2">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="GrossIncomeFromSourcesInUSPoss" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="GrossIncmOtherSourcesOutsideUS" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="GrossIncomeFromSourcesInUS" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="GrossQlfyPossSourceInvstIncome" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="AllOtherGroIncmFromSrcsUSPoss" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="AllOthGroIncmAllOthSrcsOutsdUS" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
            <td class="styTableCell" style="border-right-width: 0px">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="AllOthGrossIncmFromSourcesInUS" />
              </xsl:call-template>
              <span class="styTableCellPad"></span>
            </td>
          </tr>
         </xsl:if>
        </xsl:for-each>
      </xsl:if>  
      <xsl:if test="(count($FormData/GrossIncmDuringPrdInColmDAndE) &lt; 1) or (($Print = $Separated) and (count($FormData/GrossIncmDuringPrdInColmDAndE) &gt; 3))">
        <tr>
	       <xsl:choose>
	        	<xsl:when test="count($FormData/GrossIncmDuringPrdInColmDAndE) &lt; 1">
		          <td class="styTableCell" colspan="2"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>
		       </xsl:when>
		       <xsl:otherwise>
		          <td class="styTableCell" colspan="2">
		          	<xsl:call-template name="PopulateAdditionalDataTableMessage">
		          		<xsl:with-param name="TargetNode" select="$FormData/GrossIncmDuringPrdInColmDAndE/GrossIncomeFromSourcesInUSPoss"/>
		          	</xsl:call-template>
		          </td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell"><span class="styTableCellPad"></span></td>
		          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>
       
		       </xsl:otherwise>
		</xsl:choose>
        </tr>
      </xsl:if>

      <xsl:if test="(count($FormData/GrossIncmDuringPrdInColmDAndE) &lt; 2) or (($Print = $Separated) and (count($FormData/GrossIncmDuringPrdInColmDAndE) &gt; 3))">      
        <tr>
          <td class="styTableCell" colspan="2"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>

      <xsl:if test="(count($FormData/GrossIncmDuringPrdInColmDAndE) &lt; 3) or (($Print = $Separated) and (count($FormData/GrossIncmDuringPrdInColmDAndE) &gt; 3))">         
        <tr>
          <td class="styTableCell" colspan="2"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="border-right-width: 0px"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>

	<xsl:choose>
		<xsl:when test="($Print != $Separated) or (count($FormData/GrossIncmDuringPrdInColmDAndE) &lt;=3)">
	        <tr>
	          <td class="styTableCell" style="width: 2mm; border-right-width: 1px"><img src="{$ImagePath}/5735_Totals.gif" alt="SmallBullet"/></td>
	          <td class="styTableCell" style="padding-top: 4mm">          
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGroIncmFromSourcesInUSPoss" />
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 31mm; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGroIncmOthSourcesOutsideUS" />
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 31mm; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGrossIncomeFromSourcesInUS" />
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 32mm; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGroQlfyPossSourceInvstIncm" />
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotAllOthGroIncmFromSrcsUSPoss" />
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotAllOthGroIncmOthSrcsOutsdUS" />
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="border-right-width: 0px; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotAllOthGrossIncmFromSrcsInUS" />
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	        </tr>
	      </xsl:when>
	      <xsl:otherwise>
		<tr>
	          <td class="styTableCell" style="width: 2mm; border-right-width: 1px"><img src="{$ImagePath}/5735_Totals.gif" alt="SmallBullet"/></td>
	          <td class="styTableCell" style="padding-top: 4mm">          
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 31mm; padding-top: 4mm">
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 31mm; padding-top: 4mm">
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 32mm; padding-top: 4mm">
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="padding-top: 4mm">
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="padding-top: 4mm">
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="border-right-width: 0px; padding-top: 4mm">
	            <span class="styTableCellPad"></span>
	          </td>
	        </tr>	      
	      </xsl:otherwise>
       </xsl:choose>
    </tbody>
  </table>
  <!-- Set Initial Height of Above Table -->
  <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$FormData/GrossIncmDuringPrdInColmDAndE"/>
    <xsl:with-param name="containerHeight" select="4"/>
      <xsl:with-param name="headerHeight" select="2"/>
    <xsl:with-param name="containerID" select=" 'GIctn' "/>
  </xsl:call-template>
  <!-- End Set Initial Height of Above Table -->
</div>  
  
  <!--  Line 1  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">1</div>
    <div class="styLNDesc">
      Total gross income in applicable period (add totals of columns (f) through (l))
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">1</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotGrossIncomeInApplcblPeriod" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 1  -->
  
  <!--  Line 2  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">2</div>
    <div class="styLNDesc">Gross income in applicable period from sources in U.S. possessions (add total of columns (f), (i), and (j))</div>
    <div class="styLNRightNumBox">2</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GroIncmApplcblPeriodSrcsUSPoss" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 2  -->
  
  <!--  Line 3 -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">3</div>
    <div class="styLNDesc">
      Divide line 2 by line 1. If less than 80%, <b>stop here.</b> The possessions tax credit is not allowed
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">3</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulatePercent">
        <xsl:with-param name="TargetNode" select="$FormData/GrossIncomeSourcesUSPossRatio" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 3  -->
  
  <!--  Line 4 -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">4</div>
    <div class="styLNDesc">
      Gross income from the active conduct of a trade or business in a U.S. possession (total of columns (f), (g), and (h))
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height: 8mm;padding-top: 4mm">4</div>
    <div class="styLNAmountBox" style="height: 8mm;padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GroIncmActiveConductTrdUSPoss" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 4  -->
  
  <!--  Line 5  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBoxBB">5</div>
    <div class="styIRS5735LNDescBB">Divide line 4 by line 1. If less than 75%, <b>stop here.</b> The possessions tax credit is not allowed</div>
    <div class="styLNRightNumBox">5</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulatePercent">
        <xsl:with-param name="TargetNode" select="$FormData/GroIncomeActiveTrdUSPossRatio" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 5  -->
  
  <!--  Part II -->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part II</div>
    <div class="styPartDesc">Taxable Income From Possession Sources <span class="styNormalText">(See instructions.)<br/>When completing Part II, do not take into account any deduction for possession income taxes.</span></div>
  </div>
  <!--  End Part II -->

  <!--  Heading -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox" style="padding-top: 6mm">6</div>
    <div class="styLNDesc" style="padding-top: 6mm; width: 114.75mm">Qualified gross income in current year:</div>
    <div class="styLNAmountBox" style="text-align: center"><b>A</b><br/>Active Business<br/>Income</div>
    <div class="styLNAmountBox" style="text-align: center"><b>B</b><br/>Gross QPSII<br/>(see instructions)</div>
  </div>
  <!--  Heading-->

  <!--  Line 6a  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">a</div>
    <div class="styLNDesc" style="width: 114.75mm">From sources outside the U.S. from the active conduct of a trade or business in a U.S. possession
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox" style="height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QlfyGroIncmOutsdActConductTrd" />
      </xsl:call-template>
    </div>
    <div class="styShadingCell" style="height: 8mm"></div>
  </div>
  <!--  Line 6a -->

  <!--  Line 6b  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">b</div>
    <div class="styLNDesc" style="width: 114.75mm">From sources outside the U.S. from the sale or exchange of substantially all assets used in a possessions trade or business
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox" style="height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QlfyGroIncmOutsdFromSale" />
      </xsl:call-template>
    </div>
    <div class="styShadingCell" style="height: 8mm"></div>
  </div>
  <!--  Line 6b -->
  
  <!--  Line 6c  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">c</div>
    <div class="styLNDesc" style="width: 114.75mm">Total active business income. Add lines 6a and 6b
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QlfyGroTotActiveBusIncm" />
      </xsl:call-template>
    </div>
    <div class="styShadingCell" style="height: 4.5mm"></div>
  </div>
  <!--  Line 6c -->
  
  <!--  Line 6d  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">d</div>
    <div class="styLNDesc" style="width: 114.75mm">Enter gross qualified possession source investment income
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styShadingCell" style="height: 4.5mm"></div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GroQlfyPossSrceInvestmentIncm" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 6d -->
  
  <!-- LIne 7a -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox" style="padding-top: 4.5mm">7a</div>
    <div class="styLNDesc" style="padding-top: 4.5mm; width: 114.75mm">Amounts received in the U.S.
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox" style="height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AmountsReceivedInUS/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox" style="height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AmountsReceivedInUS/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--Line 7a-->

  <!--  Line 7b  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">b</div>
    <div class="styLNDesc" style="width: 114.75mm">Intangible property income (section 936(h)(2))
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/IntangiblePropertyIncome" />
      </xsl:call-template>
    </div>
    <div class="styShadingCell" style="height: 4.5mm"></div>
  </div>
  <!--  Line 7b -->
  
  <!--  Line 7c  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">c</div>
    <div class="styLNDesc" style="width: 114.75mm">Other intangible property income
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OtherIntangiblePropertyIncome" />
      </xsl:call-template>
    </div>
    <div class="styShadingCell" style="height: 4.5mm"></div>
  </div>
  <!--  Line 7c -->
    
  <!--  Line 7d  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">d</div>
    <div class="styLNDesc" style="width: 114.75mm">Add lines 7a, 7b, and 7c
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AmountRcvdUSAndIntngblPropIncm/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AmountRcvdUSAndIntngblPropIncm/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 7d -->
  
  <!--  Line 7e -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">e</div>
    <div style="float: left; padding-top:.5mm">Subtract line 7d, column A from line 6c, column A.<br/>Subtract line 7d, column B from line 6d, column B.</div>
    <div style="float: left">
      <span style="width: 2mm"></span>
      <img src="{$ImagePath}/5735_Bracket_Sm.gif" alt="Bracket"/>
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div style="float: right">
      <div class="styLNAmountBox">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/AmountsAfterSubtraction/ActiveBusinessIncome" />
        </xsl:call-template>
      </div>
      <div class="styLNAmountBox" style="width: 32.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/AmountsAfterSubtraction/GrossQPSII" />
        </xsl:call-template>
      </div>
    </div>
    <br/>
    <div style="float:right">
      <div class="styShadingCell" style="height: 6mm"></div>
      <div class="styShadingCell" style="height: 6mm; width: 32.25mm"></div>
    </div>
  </div>
  <!--  Line 7e -->
  
  <!-- Line 8  -->
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">8</div>
    <div class="styLNDesc" style="width: 114.75mm">Applicable deductions</div>
    <div class="styShadingCell" style="border-top-width: 0mm; height: 4.5mm"></div>
    <div class="styShadingCell" style="border-top-width: 0mm; height: 4.5mm"></div>
  </div>
  <!--  Line 8 -->

  <!--  Line 8a  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">a</div>
    <div class="styLNDesc" style="width: 114.75mm">Cost sharing amount
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ApplcblDedCostSharingAmount" />
      </xsl:call-template>
    </div>
    <div class="styShadingCell" style="height: 4.5mm"></div>
  </div>
  <!--  Line 8a -->
  
  <!--  Line 8b  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">b</div>
    <div class="styLNDesc" style="width: 114.75mm">Definitely allocable deductions
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ApplcblDedDefinitelyAllocable/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ApplcblDedDefinitelyAllocable/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 8b -->
  
  <!--  Line 8c  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">c</div>
    <div class="styLNDesc" style="width: 114.75mm">Ratable part of other deductions not definitely allocable
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ApplcblDedNotDefinitelyAllcbl/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ApplcblDedNotDefinitelyAllcbl/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 8c -->
    
  <!--  Line 8d  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">d</div>
    <div class="styLNDesc" style="width: 114.75mm">Add lines 8a, 8b, and 8c
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalsOfApplicableDeductions/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalsOfApplicableDeductions/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 8d -->

  <!--  Line 9  -->
  <div style="width: 187mm; border-style: solid; border-color: black; border-left-width: 0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width:2px">
    <div class="styLNLeftNumBox" style="padding-top: 4.5mm">9</div>
    <div class="styLNDesc" style="width: 114.75mm; padding-top: 4.5mm">Qualified taxable income before adjustments. Subtract line 8d from line 7e
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QlfyTaxableIncomeBeforeAdj/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QlfyTaxableIncomeBeforeAdj/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 9 -->
  <!--  Begin Footer  -->
  <div style="width:187mm">
    <div style="float: left; clear: none;"><span class="styBoldText">For Paperwork Reduction Act Notice, see separate instructions.</span></div>        
    <div style="float:right">
      Cat. No. 12090G 
      <span style="width:35px"></span>
      Form <b style="font-size:8pt;">5735</b> (Rev. 4-2003)
    </div>      
  </div>     
  <div class="pageEnd"></div>
  <!--  End footer  -->
  
  <!--  page header  -->
  <div class="styBB" style="width:187mm">
    <div style="float: left; clear: none">Form 5735 (Rev. 4-2003)</div>        
    <div style="float:right">
      Page <span class="styBoldText" style="font-size: 8pt">2</span>
    </div>      
  </div> 
  <!--  end page header  -->
  
  <!--  Part II (continued)-->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part II</div>
    <div class="styPartDesc">Taxable Income From Possession Sources <span class="styNormalText"><span class="styItalicText">(continued)</span></span></div>
  </div>
  <!--  End Part II -->

  <!--  Line 10-->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox" style="padding-top: 6mm">10</div>
    <div class="styLNDesc" style="padding-top: 6mm; width: 114.75mm">Adjustments</div>
    <div class="styLNAmountBox" style="text-align: center"><b>A</b><br/>Active Business<br/>Income</div>
    <div class="styLNAmountBox" style="text-align: center"><b>B</b><br/>Gross QPSII<br/>(see instructions)</div>
  </div>
  <!--  Line 10-->

  <!--  Line 10a  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">a</div>
    <div class="styLNDesc" style="width: 114.75mm">Current year losses from nonqualified sources
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AdjCyLossesNonqualifiedSources/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AdjCyLossesNonqualifiedSources/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 10a -->

  <!--  Line 10b  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">b</div>
    <div class="styLNDesc" style="width: 114.75mm">Recapture of prior year overall foreign losses
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AdjRcptrPyOverallForeignLosses/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AdjRcptrPyOverallForeignLosses/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 10b -->
  
  <!--  Line 10c  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">c</div>
    <div class="styLNDesc" style="width: 114.75mm">Income against which foreign tax credit is claimed
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AdjIncomeWhichFrgnTxCrClaimed/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AdjIncomeWhichFrgnTxCrClaimed/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 10c -->
  
  <!--  Line 10d  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">d</div>
    <div class="styLNDesc" style="width: 114.75mm">Add lines 10a through 10c
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalsOfAdjustments/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalsOfAdjustments/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 10d -->

  <!--  Line 11-->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">11</div>
    <div class="styLNDesc" style="width: 114.75mm"><span class="styBoldText">Qualified taxable income. </span> Subtract line 10d from line 9. <span class="styBoldText"> Caution: </span><span class="styItalicText">Do not enter
      more than the corporation’s adjusted base period income in column A (see instructions)</span>
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
       
      </span>
    </div>
    <div class="styLNAmountBox" style="height: 6.5mm; padding-top: 6mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedTaxableIncome/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox" style="height: 6.5mm; padding-top:6mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedTaxableIncome/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 11-->
  
  <!--  Line 12-->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">12</div>
    <div class="styLNDesc" style="width: 114.75mm">Total taxable income from all sources (enter taxable income from the corporation’s tax return)
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
      <img src="{$ImagePath}/5735_Bullet_Md.gif" alt="MediumBullet"/><span style="width: 4px"></span>
      <span style="width: 30mm; font-size: 7pt; border-style: solid; border-color: black; border-top-width: 0px; border-bottom-width: 1px; border-right-width: 0px; border-left-width: 0px">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/TotalTaxableIncomeFromAllSrcs" />
        </xsl:call-template>
      </span>
    </div>
    <div class="styShadingCell" style="height: 8mm"></div>
    <div class="styShadingCell" style="height: 8mm"></div>
  </div>
  <!--  Line 12-->
  
  <!--  Line 13-->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">13</div>
    <div class="styLNDesc" style="width: 114.75mm">For each column, divide line 11 by line 12. Enter result as a decimal
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedTaxableIncomeRatios/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedTaxableIncomeRatios/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 13-->

  <!--  Line 14-->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">14</div>
    <div class="styLNDesc" style="width: 114.75mm;font-size:6pt;">Total U.S. income tax against which possessions credit is allowed
      <img src="{$ImagePath}/5735_Bullet_Md.gif" alt="MediumBullet"/><span style="width: 4px"></span>
      <span style="width: 30mm; font-size: 7pt; border-style: solid; border-color: black; border-top-width: 0px; border-bottom-width: 1px; border-right-width: 0px; border-left-width: 0px">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/TotalUSIncmTaxPossCrIsAllowed" />
        </xsl:call-template>
      </span>
    </div>
    <div class="styShadingCell" style="height: 4.5mm"></div>
    <div class="styShadingCell" style="height: 4.5mm"></div>
  </div>
  <!--  Line 14-->
  
  <!--  Line 15-->  
  <div style="width: 187mm; border-style: solid; border-color: black; border-left-width: 0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width:1px">
    <div class="styLNLeftNumBox">15</div>
    <div class="styLNDesc" style="width: 114.75mm">For each column, multiply line 14 by line 13
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/PossessionsCreditOnTotUsIncome/ActiveBusinessIncome" />
      </xsl:call-template>
    </div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/PossessionsCreditOnTotUsIncome/GrossQPSII" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 15-->
  
  <!--  Part III -->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part III</div>
    <div class="styPartDesc">Possessions Credit Using the Percentage Limitation Method <span class="styNormalText">(See instructions.)</span></div>
  </div>
  <div class="styBB" style="width: 187mm; padding-top:4px; padding-bottom:4px">
    <div class="styLNDesc" style="width: 187mm">
    <label>
        <xsl:call-template name="PopulateLabel">
          <xsl:with-param name="TargetNode" select="$FormData/ElectionUnderSection936a4B" />
          <xsl:with-param name="BackupName" select="ElectionUnderSection936a4B" />
        </xsl:call-template>
        If the corporation elects to claim a reduced credit under section 936(a)(4)(B), check here and complete Part     III. Skip Part IV and<br/>go to Part V, line 28
    </label>
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
      <img src="{$ImagePath}/5735_Bullet_Md.gif" alt="MediumBullet"/><span style="width: 4px"></span>
      <input type="checkbox" class="styCkbox" name="CategoryOfFiler1">
        <xsl:call-template name="PopulateCheckbox">
          <xsl:with-param name="TargetNode" select="$FormData/ElectionUnderSection936a4B" />
          <xsl:with-param name="BackupName" select="ElectionUnderSection936a4B" />
        </xsl:call-template>
      </input>
    </div>
  </div>
  <!--  End Part III -->
  
  <!--  Line 16  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">16</div>
    <div class="styLNDesc">Multiply line 15, column A, by 40%
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">16</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/FrctnTotUSIncomeTxPossCr40Pct" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 16  -->
  
  <!--  Line 17  -->  
  <div style="width: 187mm; border-style: solid; border-color: black; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px">
    <div class="styLNLeftNumBox">17</div>
    <div class="styLNDesc">Possessions credit. Add line 15, column B, and line 16. Enter here and on Form 1120,<br/>Schedule J, line 6b, or the appropriate line of other returns
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; padding-top: 4mm; height: 8mm">17</div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/PossessionsCrUsingPctLmtMethod" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 17  -->
  
  <!-- Part IV -->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part IV</div>
    <div class="styPartDesc">Possessions Credit Using the Economic-Activity Limitation Method <span class="styNormalText">(See instructions.)</span></div>
  </div>
  <!--  End Part IV -->
  
  <!--  Line 18  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">18</div>
    <div class="styLNDesc">Enter 60% of qualified compensation
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">18</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/Percent60OfQlfyCompensation" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 18  -->
  
  <!--  Line 19  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">19</div>
    <div class="styLNDesc">Enter applicable portion of depreciation deductions
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 2px">19</div>
    <div class="styLNAmountBox" style="border-bottom-width: 2px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ApplicableDeprecDeductions" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 19  -->
  
  <!--  Line 20  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">20</div>
    <div class="styLNDesc">Add lines 18 and 19
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">20</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/PctQlfyCompPortionDeprecDed" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 20  -->
  
  <!--  Line 21  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">21</div>
    <div class="styLNDesc">Subtract line 20 from line 15, Column A
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">21</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/RedPctQlfyCompPrtnDeprecDed" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 21  -->
  
  <!--  Line 22  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">22</div>
    <div class="styLNDesc">Divide line 21 by line 14. Enter the result as a decimal
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">22</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/RedPctQlfyCompDeprecDedRatio" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 22  -->
  
  <!--  Note  -->  
  <div style="width: 187mm">
    <div class="styIRS5735NoteHdr"><span class="styBoldText">Note: </span>
      <span class="styItalicText"> If the corporation used the profit split method, skip lines 23 and 24. Enter the amount from line
          20 on line 25. Complete the rest of Part IV and go to Part V, line 32. If the corporation did not use the
          profit split method, complete lines 23 through 27; skip Part V and go to Part VI.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; height: 10mm; background-color: lightgrey"></div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 10mm"></div>
  </div>
  <!--  Note  -->
  
  <!--  Line 23  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">23</div>
    <div class="styLNDesc">Enter possession income taxes (but not more than 9% of taxable income)
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">23</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/PossessionIncomeTaxes" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 23  -->
  
  <!--  Line 24  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">24</div>
    <div class="styLNDesc">Possession taxes allocable to nonsheltered income. Multiply line 23 by line 22
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 2px">24</div>
    <div class="styLNAmountBox" style="border-bottom-width: 2px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/PossTxsAllcblNonshelteredIncm" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 24  -->
  
  <!--  Line 25  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">25</div>
    <div class="styLNDesc">Add lines 20 and 24
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">25</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QlfyCompDeprecDedPossTx" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 25  -->
  
  <!--  Line 26  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">26</div>
    <div class="styLNDesc">Economic-activity limitation. Enter the smaller of line 15, column A, or line 25
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">26</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/EconomicActivityLimitation" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 26  -->

  <!--  Line 27  -->  
  <div style="width: 187mm; border-style: solid; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width: 1px">
    <div class="styLNLeftNumBox">27</div>
    <div class="styLNDesc">Possessions credit. Add line 15, column B, and line 26. Enter the result here and on Form 1120, Schedule J, line 6b, or the appropriate line of other returns
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; height: 8mm; padding-top: 4mm">27</div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/PossessionsCrUsingEconomicActy" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 27  -->
  
  <!-- Part V -->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part V</div>
    <div class="styPartDesc">Deduction For Possession Income Taxes <span class="styNormalText">(See instructions.)</span></div>
  </div>
  <!--  End Part V -->
  
  <!--  Note  -->  
  <div style="width: 187mm">
    <div class="styIRS5735NoteHdr"><span class="styBoldText">Note: </span>
      <span class="styItalicText"> Complete Part V only if the corporation is electing the percentage limitation (reduced credit), or<br/>the corporation is using the economic-activity limitation and the profit split method.<br/></span>
      <div class="styBoldText" style="padding-top: 1.5mm">Corporations Using Percentage Limitation (Reduced Credit)</div>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; height: 12mm; background-color: lightgrey"></div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 12mm"></div>
  </div>
  <!--  Note  -->
  
  <!--  Line 28  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">28</div>
    <div class="styLNDesc">Subtract line 16 from line 15, Column A
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">28</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/USIncmTaxPossCrMinus40Percent" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 28  -->
  
  <!--  Line 29  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">29</div>
    <div class="styLNDesc">Divide line 28 by line 14. Enter the result as a decimal
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 2px">29</div>
    <div class="styLNAmountBox" style="border-bottom-width: 2px">
      <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/RedPossCrTotUSIncmAllwRatio" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 29 -->
  
  <!--  Line 30  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">30</div>
    <div class="styLNDesc">Enter possession income taxes
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">30</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CorpUsingPctLmtPossIncomeTaxes" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 30  -->

  <!--  Line 31  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">31</div>
    <div class="styLNDesc">Deduction for possession income taxes. Multiply line 30 by line 29. Include the result on Form 1120, page 1, line 17, or the applicable line of other returns
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height: 8mm; padding-top: 4mm">31</div>
    <div class="styLNAmountBox" style="height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CorpUsingPctLmtDedPossIncmTxs" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 31  -->
  
  <div style="width: 187mm">
    <div class="styIRS5735NoteHdr">
      <span class="styBoldText">Corporations Using the Economic-Activity Limitation and the Profit Split Method</span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; background-color: lightgrey"></div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
  </div>
  <!--  Note  -->
  
  <!--  Line 32  -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">32</div>
    <div class="styLNDesc">Enter possession income taxes
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">32</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CorpUsingEconomicPossIncmTaxes" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 32  -->

  <!--  Line 33  -->  
  <div style="width: 187mm; border-style: solid; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width: 1px">
    <div class="styLNLeftNumBox">33</div>
    <div class="styLNDesc">Deduction for possession income taxes. Multiply line 32 by line 22. Include the result on Form 1120, page 1, line 17, or the applicable line of other returns
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; height: 8mm; padding-top: 4mm">33</div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px; height: 8mm; padding-top: 4mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CorpUsingEconomicDedPossIncmTx" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 33  -->
  
  <!-- Part VI -->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part VI</div>
    <div class="styPartDesc">Summary From Schedule P (Form 5735) <span class="styNormalText">(See instructions.)</span></div>
  </div>
  <!--  End Part VI -->
  
  <!--  Line 34 -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">34</div>
    <div class="styLNDesc">Enter the total sales of possession products to which each income method applies:</div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; background-color: lightgrey; height: 4.5mm"></div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
  </div>
  <!--  Line 34  -->
    
  <!--  Line 34a  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">a</div>
    <div class="styLNDesc">Cost sharing method
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">34a</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotSalesPossProdCostShrMethod" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 34a -->
  
  <!--  Line 34b  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">b</div>
    <div class="styLNDesc">Profit split method
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">34b</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotSalesPossProdPrftSplitMthd" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 34b -->
  
  <!--  Line 35 -->  
  <div style="width: 187mm">
    <div class="styLNLeftNumBox">35</div>
    <div class="styLNDesc">Enter the total sales of possession products that qualify under each business presence test:</div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px; background-color: lightgrey; height: 4.5mm"></div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>
  </div>
  <!--  Line 35  -->
    
  <!--  Line 35a  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">a</div>
    <div class="styLNDesc">Direct labor test
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">35a</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotSalesPossProdDirectLbrTest" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 35a -->
  
  <!--  Line 35b  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">b</div>
    <div class="styLNDesc">Value-added test
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">35b</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotSalesPossProdVlAddedTest" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 35b -->
  
  <!--  Line 35c  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">c</div>
    <div class="styLNDesc">Alternative test
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">35c</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalSalesPossProductsAltTest" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 35c -->
  
  <!--  Line 35d  -->  
  <div style="width: 187mm">
    <div class="styLNLeftLtrBox">d</div>
    <div class="styLNDesc">Start-up test
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox">35d</div>
    <div class="styLNAmountBox">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotSalesPossProdStartupTest" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 35d -->
  
  <!--  Line 35e  -->  
  <div style="width: 187mm; border-style: solid; border-color: black; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 2px">
    <div class="styLNLeftLtrBox">e</div>
    <div class="styLNDesc">None of the above
      <span class="styBoldText">
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
        <span class="styNBSP"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="border-bottom-width: 0px">35e</div>
    <div class="styLNAmountBox" style="border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalSalesPossProductsOther" />
      </xsl:call-template>
    </div>
  </div>
  <!--  Line 35e -->
      <div class="pageEnd"></div>
      
      <div class="styLeftOverTitleLine" id="LeftoverData" style="padding-top: 4mm">
        <div class="styLeftOverTitle">
          Additional Data        
        </div>
        <div class="styLeftOverButtonContainer">
          <input class="styLeftoverTableBtn" TabIndex="1" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
        </div>      
      </div>
      
      <table class="styLeftOverTbl">
        <xsl:call-template name="PopulateCommonLeftover">
          <xsl:with-param name="TargetNode" select="$FormData" />
          <xsl:with-param name="DescWidth" select="100"/>
        </xsl:call-template>
      </table>    
      
    <!-- Separated Data Table for columns A - E -->
    <xsl:if test="($Print = $Separated) and (count($FormData/GrossIncomeInApplcblPeriod) &gt; 3)">
    <br/><br/>
	<span class="styRepeatingDataTitle">Form 5735 - Part I, Gross Income in Applicable Period (See instructions.):</span>
    
		    <table class="styDepTbl" style="font-size:7pt;" cellspacing="0">
		     <thead class="styTableThead" style="border-color:black">
		    <tr class="styDepTblHdr">
		      <th class="styDepTblCell" colspan="2" style="width: 60mm"><span class="styNormalText" >Tax year (Use a separate line for each tax year ending 	with or within your applicable period. Start with the earliest such tax year.)</span></th>
		      <th class="styDepTblCell" rowspan="2" style="width: 67mm"><br/><b>(c)</b><br/><span class="styNormalText" style="font-size:7pt">Name of U.S. 		possession in which trade or<br/>business was actively conducted</span></th>
		      <th class="styDepTblCell" colspan="2" style="width: 60mm; border-right-width: 0px"><span class="styNormalText">Periods in which trade or 	business was actively conducted in a U.S. possession (Dates are inclusive)</span></th>
		      </tr>
		    <tr class="styDepTblHdr">
		      <th class="styDepTblCell"><b>(a)</b><br/><span class="styNormalText" style="font-size:7pt">Beginning</span></th>
		      <th class="styDepTblCell" style="width: 33mm"><b>(b)</b><br/><span class="styNormalText" style="font-size:7pt">Ending</span></th>
		      <th class="styDepTblCell"><b>(d)</b><br/><span class="styNormalText" style="font-size:7pt">From</span></th>
		      <th class="styDepTblCell" style="border-right-width: 0px"><b>(e)</b><br/><span class="styNormalText" style="font-size:7pt">To</span></th>
		    </tr>
		    </thead>
		    <tfoot/>
		    <tbody style="border-color:black">
		      <xsl:for-each select="$FormData/GrossIncomeInApplcblPeriod">
		          <tr>
           			<!-- Define background colors to the rows -->
	              	<xsl:attribute name="class">
	                        <xsl:choose>
	                          <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                          <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                        </xsl:choose>
	                   </xsl:attribute>		          
		            <td class="styTableCell" style="text-align: center;font-size:7pt">
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="TaxYearBeginning" />
		              </xsl:call-template>
		              <span class="styTableCellPad"></span>
		            </td>
		            <td class="styTableCell" style="text-align: center;font-size:7pt">
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="TaxYearEnding" />
		              </xsl:call-template>
		              <span class="styTableCellPad"></span>
		            </td>
		            <td class="styTableCell" style="text-align: left;font-size:7pt">
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="NameOfUSPossession" />
		              </xsl:call-template>
		              <span class="styTableCellPad"></span>
		            </td>
		            <td class="styTableCell" style="text-align: center;font-size:7pt">
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="PeriodsTradeWasConductedFrom" />
		              </xsl:call-template>
		              <span class="styTableCellPad"></span>
		            </td>
		            <td class="styTableCell" style="border-right-width: 0px; text-align: center;font-size:7pt">
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="PeriodsTradeWasConductedTo" />
		              </xsl:call-template>
		              <span class="styTableCellPad"></span>
		            </td>
		          </tr>
		        </xsl:for-each>   		        
		       <thead class="styTableThead" style="border-color:black"> 	
		        <tr class="styDepTblHdr" style="border-bottom-width: 0px">
				<th class="styDepTblCell" colspan="5" style="border-bottom-width: 0px">		
					<div  style="width: 187mm; text-align: center">
						<div class="styBoldText">Gross income during periods shown in columns (d) and (e)</div>
					</div>
				</th>
			</tr>	          
			</thead>			
		    </tbody>
		  </table>
    </xsl:if>
    <!-- /Separated Data Table for columns A - E -->
    
    <!-- Separated Data Table for columns F - L -->
    <xsl:if test="($Print = $Separated) and (count($FormData/GrossIncmDuringPrdInColmDAndE) &gt; 3)">
	     <table class="styDepTbl" style="font-size:7pt; width: 191.25mm" cellspacing="0">
	     <thead class="styTableThead" style="border-color:black">
	    <tr class="styDepTblHdr">
	      <th class="styDepTblCell" colspan="4" style="width: 92mm; text-align: center"><span class="styNormalText">Gross income from the active conduct of a 	trade or business in a U.S. possession</span></th>
	      <th class="styDepTblCell" rowspan="2" style="width: 32mm"><b>(i)</b><br/><span class="styNormalText">Gross qualified<br/>possession source<br/>	investment income<br/>(QPSII) (see instructions)</span></th>
	      <th class="styDepTblCell" colspan="3" style="width: 63mm; border-right-width: 0px; text-align: center"><span class="styNormalText">All other gross income</span></th>
	      </tr>
	    <tr class="styDepTblHdr">
	      <th class="styDepTblCell" colspan="2" style="width:22mm"><b>(f)</b><br/><span class="styNormalText">From sources in U.S. possessions</span></th>
	      <th class="styDepTblCell"><b>(g)</b><br/><span class="styNormalText">From all other sources outside the U.S.</span></th>
	      <th class="styDepTblCell"><b>(h)</b><br/><span class="styNormalText">From sources in the U.S.</span></th>
	      <th class="styDepTblCell"><b>(j)</b><br/><span class="styNormalText">From sources in U.S. possessions</span></th>
	      <th class="styDepTblCell"><b>(k)</b><br/><span class="styNormalText">From all other sources outside the U.S.</span></th>
	      <th class="styDepTblCell" style="border-right-width: 0px"><b>(l)</b><br/><span class="styNormalText">From sources in the U.S.</span></th>
	    </tr>
	    </thead>
	    <tfoot/>
	    <tbody style="border-color:black;">
	        <xsl:for-each select="$FormData/GrossIncmDuringPrdInColmDAndE">
	          <tr style="font-size:6pt;">
	                   <!-- Define background colors to the rows -->
	              	<xsl:attribute name="class">
	                        <xsl:choose>
	                          <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                          <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                        </xsl:choose>
	                   </xsl:attribute>	
	            <td class="styTableCell" colspan="2" style="width:26mm">
	              <xsl:call-template name="PopulateAmount">
	                <xsl:with-param name="TargetNode" select="GrossIncomeFromSourcesInUSPoss" />
	              </xsl:call-template>
	              <span class="styTableCellPad"></span>
	            </td>
	            <td class="styTableCell">
	              <xsl:call-template name="PopulateAmount">
	                <xsl:with-param name="TargetNode" select="GrossIncmOtherSourcesOutsideUS" />
	              </xsl:call-template>
	              <span class="styTableCellPad"></span>
	            </td>
	            <td class="styTableCell">
	              <xsl:call-template name="PopulateAmount">
	                <xsl:with-param name="TargetNode" select="GrossIncomeFromSourcesInUS" />
	              </xsl:call-template>
	              <span class="styTableCellPad"></span>
	            </td>
	            <td class="styTableCell">
	              <xsl:call-template name="PopulateAmount">
	                <xsl:with-param name="TargetNode" select="GrossQlfyPossSourceInvstIncome" />
	              </xsl:call-template>
	              <span class="styTableCellPad"></span>
	            </td>
	            <td class="styTableCell">
	              <xsl:call-template name="PopulateAmount">
	                <xsl:with-param name="TargetNode" select="AllOtherGroIncmFromSrcsUSPoss" />
	              </xsl:call-template>
	              <span class="styTableCellPad"></span>
	            </td>
	            <td class="styTableCell">
	              <xsl:call-template name="PopulateAmount">
	                <xsl:with-param name="TargetNode" select="AllOthGroIncmAllOthSrcsOutsdUS" />
	              </xsl:call-template>
	              <span class="styTableCellPad"></span>
	            </td>
	            <td class="styTableCell" style="border-right-width: 0px">
	              <xsl:call-template name="PopulateAmount">
	                <xsl:with-param name="TargetNode" select="AllOthGrossIncmFromSourcesInUS" />
	              </xsl:call-template>
	              <span class="styTableCellPad"></span>
	            </td>
	          </tr>
	        </xsl:for-each>
	        
	      <thead class="styTableThead" style="border-color:black"> 	
		   <tr class="styDepTblHdr" style="border-bottom-width: 0px;font-size:6pt;">
	          <td class="styTableCell" style="width: 2mm; border-right-width: 1px"><img src="{$ImagePath}/5735_Totals.gif" alt="SmallBullet"/></td>
	          <td class="styTableCell" style="width: 24mm; padding-top: 4mm">          
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGroIncmFromSourcesInUSPoss" />
			<xsl:with-param name="WhiteFont">true</xsl:with-param>	              
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          
	          <td class="styTableCell" style="width: 31mm; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGroIncmOthSourcesOutsideUS" />
			<xsl:with-param name="WhiteFont">true</xsl:with-param>	              
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 31mm; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGrossIncomeFromSourcesInUS" />
			<xsl:with-param name="WhiteFont">true</xsl:with-param>	              
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="width: 32mm; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotGroQlfyPossSourceInvstIncm" />
			<xsl:with-param name="WhiteFont">true</xsl:with-param>	              
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotAllOthGroIncmFromSrcsUSPoss" />
			<xsl:with-param name="WhiteFont">true</xsl:with-param>	              
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotAllOthGroIncmOthSrcsOutsdUS" />
			<xsl:with-param name="WhiteFont">true</xsl:with-param>	              
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	          <td class="styTableCell" style="border-right-width: 0px; padding-top: 4mm">
	            <xsl:call-template name="PopulateAmount">
	              <xsl:with-param name="TargetNode" select="$FormData/TotGroIncmDuringPrdInColmDandE/TotAllOthGrossIncmFromSrcsInUS" />
			<xsl:with-param name="WhiteFont">true</xsl:with-param>	              
	            </xsl:call-template>
	            <span class="styTableCellPad"></span>
	          </td>
	        </tr>

</thead>
	
	    </tbody>
	  </table>	
	  
	  
    </xsl:if>
    <!-- /Separated Data Table for columns F - L -->

  </form>  
</body>
</html>
</xsl:template>    

</xsl:stylesheet>