<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS5884Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form5884Data" select="$RtnDoc/IRS5884" />


<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form5884Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 5884" />
      
      
      
      <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
      <xsl:call-template name="InitJS"></xsl:call-template>

    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 5884 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS5884Style"></xsl:call-template>
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>  
    </style>
  <xsl:call-template name="GlobalStylesForm"/>
</head>

  <body class="styBodyClass">
    <form name="Form5884">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>

      <!-- Begin Form Number and Name -->
      <div class="styBB" style="width:187mm;">
      
        <div class="styFNBox" style="width:31mm;height:22.5mm;">
          Form <span class="styFormNumber">&#160;5884</span>
        
          <br/><br/><br/>
          <span class="styAgency">Department of the Treasury</span>
          <br/>
          <span class="styAgency">Internal Revenue Service</span>
        </div>
      <div class="styFTBox" style="width:125mm;height:13mm;">
        <span style="height: 1mm;"></span>
        <div class="styMainTitle" style="height:8mm;">
          Work Opportunity Credit          
        </div>
        <br/>
        <br/>
        <div class="styFST" style="height:5mm;font-size:7pt;">
          <img src="{$ImagePath}/5884_Bullet.gif" width="4" height="7"  alt="Bullet Image"/>
          Attach to your tax return.
        </div>
      </div>
      <div class="styTYBox" style="width:30mm;height:14mm;">
        <div class="styOMB" style="height:2mm;">
          OMB No. 1545-0219
        </div>
        <div class="styTY" style="height:11.85mm;">
          20<span class="styTYColor">05</span>
        </div>
        <div><span style="padding-right:6mm">Attachment</span><br/> Sequence No. <span class="styBoldText">77</span></div>
      </div>
    </div>
    
    <!-- End Form Number and Name section -->
    <!-- Begin Names and Identifying number section -->

    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:148mm;height:8mm;font-size:7pt;">
        Name(s) shown on return<br/>
        <span>          
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
        </span>
      </div>
      <div class="styEINBox" style="width:35mm;height:4mm;padding-left:2mm;font-size:7pt;">
        Identifying number<br/>
        <span style="width:34mm; text-align:left;font-weight:normal;">
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>          
        </span>          
      </div>
    </div>
    
    <!-- End Names and Identifying number section -->
    <!-- Start Part I Current Year Credit -->
    
    <div class="styBB" style="width:187mm;padding-top:1mm;padding-bottom:1mm;">
      <div class="styPartName">Part I</div>
      <div class="styPartDesc"><span style="width:16px;"></span>Current Year Credit <span class="styNormalText">(Members of a controlled group, see instructions.)</span>
      </div>
    </div>
    <!--Line 1 Begin-->
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">
          1
        </div>
        <div class="styLNDesc" style="height:4mm;">        
          Enter the total qualified first-year wages paid or incurred during the tax year, and multiply by
           the percentage shown, for services of employees who began work for you before the applicable
           date in the instructions, are certified (if required) as members of a targeted group, and:           
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4mm;border-right-width:1px;padding-top:6.75mm;">
        </div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">a</div>
        <div class="styLNDesc" style="width:81.25mm;height:4mm;">
          Worked for you at least 120 hours but fewer than 400 hours
          <!--Dotted Line-->
          
        </div>
        <div class="styBB"  style ="width:3mm;float:left;clear:none;">
          $   
        </div>
        <div class="styBB"  style ="width:32mm;text-align:right;float:left;clear:none;">        
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/WagesBetween120And399Hours"/>
          </xsl:call-template>
        </div>
        <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 25% (.25)</div>
        <div style="width:4mm;float:left;Clear:none;"></div>
        <div class="styLNRightNumBox">
          1a
        </div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/TotalWagesBetween120And399Hrs"/>
          </xsl:call-template>        
        </div>
      </div>
      <div style= "width:187mm;">
        <div class="styLNDesc" style="width:146mm;height:1mm;float:left;Clear:none;">
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:1mm;border-right-width:1px;padding-top:1mm;">
        </div>      
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">b</div>
        <div class="styLNDesc" style="width:81.25mm;height:4mm;">
          Worked for you at least 400 hours
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.                  
          </span>
        </div>
        
        <div class="styBB"  style ="width:3mm;float:left;clear:none;">
          $   
        </div>
        <div class="styBB"  style ="width:32mm;text-align:right;float:left;clear:none;">  
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/WagesFor400HoursOrMore"/>
          </xsl:call-template>
        </div>
        <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 40% (.40)</div>
        <div style="width:4mm;float:left;Clear:none;"></div>
        <div class="styLNRightNumBox">          
          1b
        </div>
        <div class="styLNAmountBox" >
        <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/CreditForWagesOf400OrMoreHours"/>
          </xsl:call-template>
        </div>
      </div>
      <!--Line 1 End-->
      
	 <!--Line 2 Begin-->

      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">2</div>
        <div class="styLNDesc" style="height:4mm;">
          Add lines 1a and 1b.  You <span class="styBoldText">must</span> subtract this amount from your deduction for salaries and wages
          <!--Dotted Line-->
           <span style="width:2px;"></span>  
          <!-- Form to Form Link -->
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$Form5884Data/TotalWages"/>
          </xsl:call-template>
        </div>        
        <div class="styLNRightNumBox" style="height:4mm;">
          2
        </div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/TotalWages"/>
          </xsl:call-template>
        </div>
      </div>
       <!--Line 2 End-->
       
       <!--Line 3 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">3</div>
        <div class="styLNDesc" style="width:18mm; height:4mm;">
          <div style = "width:18mm;">Work opportunity credits from pass-through entities:</div>
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;"> </div>
        <div class="styLNDesc" style="width:115mm; height:4mm;">
          <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Table for Work Opportunity Credit">
             <tr>
                <th class="styForm5884TBTable" scope="col">                
                  If you are a&#151;
              
                </th>
                <th class="styForm5884TBTable" scope="col" style="border-right:none;padding-left:1mm;">
                  Then enter the total of the current year credits from&#151;
                </th>
             </tr>
             <tr>
                <td height="50mm"  scope="row" style="font-size: 7pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt;padding:0mm">
                <span class="styBoldText">a</span> Shareholder      
                <br/>
                  <span class="styBoldText">b</span> Partner  
                  <span class="styBoldText">                  
                  <span style="width:16px;"></span>.  
                </span>
                <br/>
                  <span class="styBoldText">c</span> Beneficiary          
                <br/>
                  <span class="styBoldText">d</span> Patron
                  <span class="styBoldText">
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                </span>
                </td>
                <td style="font-size:7pt;font-family:verdana;font-style: normal;font-weight:normal;border:none;padding-left:1.5mm;">
                  Schedule K-1 (Form 1120S), box 13, code F, G, or J  
                  <br/>
                  Schedule K-1 (Form 1065), box 15, code F, G, or J
                  <br/>
                  Schedule K-1 (Form 1041), box 13, code F
                  <span class="styBoldText">
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                </span>
                <br/>
                  Written statement from cooperative
                  <span class="styBoldText">
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                </span>
                </td>
              <td >
                <div class="styLNDesc" style="width:5mm; height:4mm;">
                  <img src="{$ImagePath}/5884_Bracket_L3.gif" height="50mm"  alt="Curly Bracket Image"/>
                                    
                </div>
                <div class="styLNDesc" style="width:11mm; height:4mm;">                  
                  <span class="styBoldText" style="width:11mm;height:4mm;padding-bottom:0mm;padding-top:3mm;font-size:7pt;">
                    <span style="width:8px;"></span>.    
                    <span style="width:8px;"></span>.                                                        
                  </span>                  
                </div>

              </td>
             </tr>
            
          </table>
          
        </div>
        <div class="styLNRightNumBox" style="height:12mm;padding-top:0mm;">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;height:8mm;">
          </div>
          3          
        </div>        
        <div class="styLNAmountBox" style="height:12mm;">
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/PassThruWorkOpportunityCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:8mm;border-right-width:1px;"></div>
      </div>
      <!--Line 3 End-->

	<!--Line 4 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">4</div>
        <div class="styLNDesc" style="height:4mm;">
          <span class="styBoldText">
            Current year credit.
          </span>
          Add lines 2 and 3. (S corporations, partnerships, estates, trusts, cooperatives, regulated investment
          companies, and real estate investment trusts, see instructions.)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.                              
          </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:8mm;">
        <br/>
        4
        </div>
        <div class="styLNAmountBoxNBB" style="height:8mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/CYWorkOpportunityCredit"/>
          </xsl:call-template>        
        </div>
      </div>
    </div>
	<!--Line 4 End-->

    <!-- End Part II Current Year Credit -->


    <!-- Begin Allowable credit section-->
    <div class="styBB" style="width:187mm;padding-top:1mm; padding-bottom:1mm;">
      <div class="styPartName">Part II</div>
      <div class = "styPartDesc"><span style="width:16px;"></span>Allowable Credit<span class="styNormalText"> (See</span> Who must file Form
        3800<span class="styNormalText">  to find out if you complete Part II or file Form 3800.)</span>
      </div>
    </div>
    
    <!--Line 5 Begin-->
    <div class="styBB" style="width:187mm;">
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">5</div>
      <div class="styLNDesc" style="width:123mm;height:4mm;">
        Regular tax before credits:          
          <li style="padding-top: .75mm;position:relative;left:-4.25mm;">Individuals. Enter the amount from Form 1040, line 44
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              .........
            </span>  
          </li>
          <li style="padding-top: .75mm;position:relative;left:-4.25mm;">Corporations. Enter the amount from Form 1120, Schedule J, line 3; Form 1120-A,<br/>
            <span style="width:14px;float:left;"></span>Part I, line 1; or the amount from the applicable line of your return
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              ......
            </span>  
          </li>
          <li style="padding-top: .75mm;position:relative;left:-4.25mm;">Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G, lines 1a<br/>
            <span style="width:14px;float:left;"></span> and 1b, or the amount from the applicable line of your return
             <!--Dotted Line-->
             <span style="letter-spacing:4mm; font-weight:bold">  
              ........
            </span>  
          </li>                  
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:2.75mm;">
          <img src="{$ImagePath}/8830_Bracket_Lg.gif" height="66mm" alt="Curly Bracket Image" style="position: relative; top: 2mm;" />      
        </div>
        <div class="styLNDesc" style="width:10mm; height:14mm;">    
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold; float:left;width:10mm; height:14mm;padding-bottom:0mm;padding-top:9mm;">  
            ..
          </span>                                
        </div>

        <div class="styLNRightNumBox" style="width:7.75mm;padding-top=0mm;height:11mm;">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;height:7.25mm;">
          </div>
          5
        </div>
        <div class="styLNAmountBox" style="height:11mm;">
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/RegularTaxBeforeCredit"/>
          </xsl:call-template>                    
        </div>
        
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:11.25mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>
       <!--Line 5 End-->

	 <!--Line 6 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">6</div>
        <div class="styLNDesc" style="width:105mm;height:4mm;">
          Alternative minimum tax:          
            <li style="padding-top: .75mm;position:relative;left:-4.25mm;">Individuals. Enter the amount from Form 6251, line 35
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold">  
                .....
              </span>  
            </li>
            <li style="padding-top: .75mm;position:relative;left:-4.25mm;">Corporations. Enter the amount from Form 4626, line 14
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold">  
                .....
              </span>  
            </li>             
            <li style="padding-top: .75mm;position:relative;left:-4.25mm;">Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56
            </li>                 
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:2mm;">
          <img src="{$ImagePath}/5884_Bracket_L6.gif" height="46mm" alt="Curly Bracket Image" style="position: relative; top: 2mm;"/>        
        </div>
        <div class="styLNDesc" style="width:28mm; height:4mm;">                  
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold; float:left;width:10mm; height:14mm;padding-bottom:0mm;padding-top:6.5mm;">  
            .....
          </span>                  
        </div>

        <div class="styLNRightNumBox" style="width:7.75mm;height:8.25mm;padding-top=0mm;">
        <div class="styLNRightNumBoxNBB" style="width:7.75mm;padding-top=0.5mm;border-left-width:0px;background-color:lightgrey;">
        </div>
        6
        </div>
        <div class="styLNAmountBox" style="height:8.25mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/AlternativeMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:8.75mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>
      <!--Line 6 End-->

	<!--Line 7 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">7</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 5 and 6
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
            </span>
        </div>
        <div class="styLNRightNumBox" style="width:8mm;height:5mm;padding-top=0mm;">    
        7
        </div>
        <div class="styLNAmountBox" style="height:5mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/RegularTaxPlusAltMinimumTax"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">8a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Foreign tax credit
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <!--Line 7 End-->

	   <!--Line 8 Begin-->
        <div class="styLNRightNumBox" style="height:4mm;">8a</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Credits from Form 1040, lines 48 through 54
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8b</div>
        <div class="styLNAmountBox" style="height:4mm;">
    <!--      <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/ForeignTaxCredit"/>
          </xsl:call-template>
    -->
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Possessions tax credit
          (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.            
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8c</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/PossessionsTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Nonconventional source fuel credit (Form 8907, line 23)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8d</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/NonconventionalFuelSourceCr"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">e</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Other specified credits (see instructions)
              <span class="styBoldText">
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>. 
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.                      
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8e</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/OtherSpecifiedCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">f</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 8a through 8e
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8f
        </div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/TotalTaxCredits"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="padding-left:2mm; height:4mm;">9</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Net income tax.  Subtract line 8f from line 7.  If zero,
          skip lines 10 through 13 and enter -0- on line 14
          <!--Dotted Line-->
         <!--Line 8 End-->

		<!--Line 9 Begin-->
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">9
        </div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>
      <!--Line 9 End-->
      
      <!--Line 10 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">10</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Net regular tax.  Subtract line 8f from line 5.  If zero
          or less, enter -0-
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/NetRegularTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!--Line 10 End-->

	<!--Line 11 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">11</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <span class="stySmallText">
            Enter 25% (.25) of the excess, if any, of line 10 over
            $25,000 (see instructions)
          </span>          
        </div>
        <div class="styLNRightNumBox" style="height:4mm;padding-top:0.5mm">11</div>
        <div class="styLNAmountBox" style="height:4mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/ExcessNetRegularTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;padding-top:0.5mm;border-right-width:1px;"></div>
      </div>
      <!--Line 11 End-->

	<!--Line 12 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">12</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Tentative minimum tax
          (see instructions)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.              
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">12</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/TentativeMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!--Line 12 End-->

	<!--Line 13 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">13</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Enter the greater of line 11 or line 12
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">13</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/GreaterOfTentMinOrAdjNetRegTax"/>
          </xsl:call-template>
        </div>
      </div>
      <!--Line 13 End-->

	<!--Line 14 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">14</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Subtract line 13 from line 9.  If zero or less, enter -0-
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">14</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/AdjustedNetIncomeTax"/>
          </xsl:call-template>
        </div>        
      </div>
     <!--Line 14 End-->
 
	<!--Line 15 Begin-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">15</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <span class="styBoldText">Credit allowed for the current year.</span>
          Enter the <span class="styBoldText">smaller</span> of line 4 or line 14 here and
          on Form 1040, line 55; Form 1120, Schedule J, line 6d;
          Form 1120-A, Part I, line 2; Form 1041,
          Schedule G, line 2c; or the applicable line of your return.
          If line 14 is smaller than line 4, see instructions
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
                      
          </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:11mm;padding-top:0mm">
        <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">        <br/><br/>
        </div>
        15
        </div>
        <div class="styLNAmountBoxNBB" style="height:11mm;">
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884Data/CYWorkOpportunityCreditAllowed"/>
          </xsl:call-template>
        </div>
      </div>
    </div>
	<!--Line 15 End-->

	<!--End of form-->

    <div style="width:187mm;">
    <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions. </span> 
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      
      Cat. No. 13570D 
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
  
      Form <span class="styBoldText">5884</span> (2005)
  </div>

        <br/>
        <br class="pageEnd"/>
        
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form5884Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
        <!-- END Left Over Table -->    
            

      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
