<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS6252Style.xsl"/>



<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />
<xsl:param name="Form6252Data" select="$RtnDoc/IRS6252" />

<xsl:template match="/">

<html lang="EN-US">
<head>
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form6252Data)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache" />
  <meta http-equiv="Cache-Control" content="no-cache" />
  <meta http-equiv="Expires" content="0" />
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private" />
  <!-- Define Character Set -->
  <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
  <meta name="Description" content="IRS Form 6252" />
    
    
    
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>

  <style type="text/css">  
    <!--xsl:if test="not($Print) or $Print=''">-->
      <!-- Form 6252 CSS Styles are located in the template called below -->
      <xsl:call-template name="IRS6252Style"></xsl:call-template>
      <xsl:call-template name="AddOnStyle"></xsl:call-template>
  <!--/xsl:if>-->
  </style>  
<xsl:call-template name="GlobalStylesForm"/>
</head>


<body class="styBodyClass" >

  <form name="Form6252">
    <!-- WARNING LINE -->
    <xsl:call-template name="DocumentHeader"></xsl:call-template>
  
    <!-- Begin Form Number and Name -->
    <div class="styTBB" style="width:187mm;height:23.5mm;">
        <div class="styFNBox" style="width:31mm;height:23.5mm;">
          <!--div style="padding-top:1mm;">-->
            Form<span class="styFormNumber">6252</span>
            <br/>
            <div class="styAgency" style="width:22mm;">
            </div>
            <br/>
            <span class="styAgency">Department of the Treasury</span>
            <br/>
            <span class="styAgency">Internal Revenue Service</span>
          <!--/div>-->
        </div>
        <div class="styFTBox" style="width:125mm;height:23.5mm;">
          <div class="styMainTitle" style="padding-top:1mm;">Installment Sale Income</div>
          <br/>
          <div class="styFST" style="font-size:7pt;">
            <img src="{$ImagePath}/6252_Bullet.gif" alt="Bullet Image"/> Attach to your tax return.
            </div>
            <div class="styFST" style="font-size:7pt;">
            <img src="{$ImagePath}/6252_Bullet.gif" alt="Bullet Image"/> Use a separate form for each sale or other disposition of 
            <br/> property on the installment method.<br/>
          </div>
        </div>
        
        <div class="styTYBox" style="width:30mm;height:23.5mm;">
          <div class="styOMB" style="height:2mm;">OMB No. 1545-0228</div>
          <div class="styTY" style="height:11mm">
            20<span class="styTyColor">05</span>
          </div>
          <div class="styOMB" style="height:3mm;border-bottom-width:0px;text-align:left;padding-left: 1mm;">
            Attachment<br/>Sequence No. <span class="styBoldText">79</span>
          </div>
        </div>
      </div>
      <!-- End Form Number and Name section -->

      <div class="styBB" style="width:187mm;">
        <div class="styNameBox" style="width:140mm;height:8mm;font-size:7pt;">
          Name(s) shown on return<br/>
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>                
        </div>        
        <div class="styForm6252INBox" style="width:45mm;height:8mm;font-size:7pt;padding-left:2mm;">
          Identifying number<br/><br />
          <span style="font-weight:normal;">  
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
          </span>  
        </div>
      </div>
      
    <div class="styBB" style="width:187mm;">                
      <div  style="width:187mm;">         
        <div class="styLNLeftNumBox" style="height:4mm;">1</div>
        <div class="styLNDesc" style="width:35mm;height:4mm;">            
          Description of property <img src="{$ImagePath}/6252_Bullet.gif" alt="Bullet Image"/><br/>                
        </div>
         <div class="styForm6252UnderlineText" style="width:144mm;height:4mm;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form6252Data/PropertyDescription" />
          </xsl:call-template>    
         </div>       
      </div> 
      
      <div  style="width:187mm;">      
        <div class="styLNLeftNumBox" style="height:4mm;">2a</div>
        <div class="styLNDesc" style="width:52mm;height:4mm;">            
          Date acquired (month, day, year)
           <img src="{$ImagePath}/6252_Bullet.gif" alt="Bullet Image"/><br/>
                  
        </div>
        <div class="styLNAmountBox" style="border-bottom-width:1px;border-right-width:1px;height:4mm;text-align:left;">
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form6252Data/DateAcquired" />
          </xsl:call-template>  
        </div>
                        
        <div class="styLNDesc" style="width:62.75mm;height:4mm;padding-left:14mm;">
          <span class="styBoldText">b</span> Date sold (month, day, year) 
          <img src="{$ImagePath}/6252_Bullet.gif" alt="Bullet Image"/><br/>
          
        </div>
        <div class="styLNAmountBox" style="border-bottom-width:1px; border-right-width:1px;height:4mm;text-align:left;">
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form6252Data/DateSold" />
          </xsl:call-template>
        </div>
                          
      </div>
            
      <div style= "width:187mm;" >        
        <div class="styLNLeftNumBox" style="height:4mm;">3</div>
        <div class="styLNDesc" style="width:148mm;height:4.5mm;padding-top:1.5mm;">
          Was the property sold to a related party (see instructions) after May 14, 1980? If "No," skip line 4
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNDesc" style="width:15mm;height:4.5mm;text-align:right;">
        <span>
            <xsl:call-template name="PopulateSpan">
              <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldToRelatedParty" />
            </xsl:call-template>  
            <input type="checkbox" class="styCkbox" name="Checkbox"> 
              <xsl:call-template name="PopulateYesCheckbox">
                <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldToRelatedParty" />
              </xsl:call-template>
            </input>
            </span>
            <span style="width:8px"></span>
             <label>
               <xsl:call-template name="PopulateLabelYes">
                 <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldToRelatedParty" />
               </xsl:call-template>          
                 Yes           
            </label>                 
          </div>
      
          <div class="styLNDesc" style="width:15mm;height:4.5mm;text-align:right;">
          <span>
            <xsl:call-template name="PopulateSpan">
              <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldToRelatedParty" />
            </xsl:call-template>
            <input type="checkbox" class="styCkbox" name="Checkbox"> 
              <xsl:call-template name="PopulateNoCheckbox">
                <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldToRelatedParty" />
              </xsl:call-template>
            </input> 
            </span>
            <span style="width:8px"></span>
             <label>
               <xsl:call-template name="PopulateLabelNo">
                 <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldToRelatedParty" />
               </xsl:call-template>            
                 No            
            </label>          
          </div>
      </div>
    <div style= "width:187mm;">        
      <div class="styLNLeftNumBox" style="height:4mm;">4</div>
      <div class="styLNDesc" style="width:148mm;height:4.5mm;padding-top:1.5mm;">
      Was the property you sold to a related party a marketable security? If "Yes", complete Part III.  If "No,"  complete Part III for the year of sale and the 2 years after the year of sale
      <!--Dotted Line-->
        <span class="styBoldText">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.            
        </span>        
      </div>
        <div class="styLNDesc" style="width:15mm;height:4.5mm;text-align:right; padding-top:3.5mm;">
      <span>
          <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form6252Data/PropSoldRltdPartyMarketableSec" />
          </xsl:call-template>        
        <input type="checkbox" class="styCkbox" name="Checkbox"> 
          <xsl:call-template name="PopulateYesCheckbox">
            <xsl:with-param name="TargetNode" select="$Form6252Data/PropSoldRltdPartyMarketableSec" />
          </xsl:call-template>
        </input> 
        </span>
        <span style="width:8px"></span>
         <label>
           <xsl:call-template name="PopulateLabelYes">
             <xsl:with-param name="TargetNode" select="$Form6252Data/PropSoldRltdPartyMarketableSec" />
           </xsl:call-template>            
             Yes            
        </label>
        
      </div>
      <div class="styLNDesc" style="width:15mm;height:4.5mm;text-align:right;padding-top:3.5mm;">
       <span>
          <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form6252Data/PropSoldRltdPartyMarketableSec" />
          </xsl:call-template>
        <input type="checkbox" class="styCkbox" name="Checkbox">
          <xsl:call-template name="PopulateNoCheckbox">
            <xsl:with-param name="TargetNode" select="$Form6252Data/PropSoldRltdPartyMarketableSec" />
          </xsl:call-template>
        </input>
        </span>
        <span style="width:8px"></span>
         <label>
           <xsl:call-template name="PopulateLabelNo">
             <xsl:with-param name="TargetNode" select="$Form6252Data/PropSoldRltdPartyMarketableSec" />
           </xsl:call-template>            
             No            
        </label>          
      </div>   
    </div>      
  </div>
  
      <!-- BEGIN Part I Title -->
      <div class="styBB" style="width:187mm;">
        <div class="styPartName">Part I</div>
        <div class="styPartDesc">Gross Profit and Contract Price.
          <span class="styNormalText"> Complete this part for the year of sale only.</span>
        </div>
      </div>
      <!-- END Part I Title -->
    <div class="styBB" style="width:187mm;">    
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">5</div>
        <div class="styLNDesc" style="width:139mm;height:4mm;">
          Selling price including mortgages and other debts. 
          <span class="styBoldText">Do not</span> include interest whether stated or unstated
          <span style="width:2px;"></span>  
          <!-- Form to Form Link -->
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$Form6252Data/SellingPriceIncludingMortgage "/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">5</div>
        <div class="styLNAmountBox" style="height:4mm;">                
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6252Data/SellingPriceIncludingMortgage " />
          </xsl:call-template>          
        </div>         
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">6</div>
        <div class="styLNDesc" style="width:99mm;height:4mm;">
          Mortgages, debts, and other liabilities the buyer assumed or took
          the property subject to (see instructions)      
        <!--Dotted Line-->
        <span class="styBoldText">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
        </span>
      </div>
      <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3.5mm;">6</div>
      <div class="styLNAmountBox" style="height:7.5mm;padding-top:3.5mm;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$Form6252Data/MortgageIndebtedness" />
        </xsl:call-template>      
      </div>  
      
      <div class="styLNRightNumBoxNBB" style="width=8.25mm;background-color:lightgrey;height:7.5mm;border-right-width:1px;padding-top:3.5mm;">
      </div>
            
    </div>

  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">7</div>
    <div class="styLNDesc" style="width:99mm;height:4;">Subtract line 6 from line 5
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">7</div>
    <div class="styLNAmountBox" style="border-bottom-width:1px;height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/SellingPriceLessMortgageIndbt" />
      </xsl:call-template>
    
    </div>    
    <div class="styLNRightNumBoxNBB" style="width=8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;">
    </div>
        
  </div>
  
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">8</div>
    <div class="styLNDesc" style="width:99mm;height:4mm;">Cost or other basis of property sold
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">8</div>
    <div class="styLNAmountBox" style="border-bottom-width:1px;height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/CostOrOtherBasisofPropertySold" />
      </xsl:call-template>    
    </div>    
    <div class="styLNRightNumBoxNBB" style="width=8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;">
    </div>
    
  </div>    
      
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">9</div>
    <div class="styLNDesc" style="width:99mm;height:4mm;">Depreciation allowed or allowable
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">9</div>
    <div class="styLNAmountBox" style="border-bottom-width:1px;height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/DepreciationAllowedOrAllowable" />
      </xsl:call-template>    
    </div>    
    <div class="styLNRightNumBoxNBB" style="width=8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;">
    </div>    
  </div>    
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">10</div>
    <div class="styLNDesc" style="width:99mm;height:4mm;">Adjusted basis. Subtract line 9 from line 8
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">10</div>
    <div class="styLNAmountBox" style="border-bottom-width:1px;height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/AdjustedBasis" />
      </xsl:call-template>    
    </div>    
    <div class="styLNRightNumBoxNBB" style="width=8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;">
    </div>  
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">11</div>
    <div class="styLNDesc" style="width:99mm;height:4mm;">Commissions and other expenses of sale
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">11</div>
    <div class="styLNAmountBox" style="border-bottom-width:1px;height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/CommissionsOtherExpensesOfSale" />
      </xsl:call-template>    
    </div>    
    <div class="styLNRightNumBoxNBB" style="width=8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;">
    </div>
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">12</div>
    <div class="styLNDesc" style="width:99mm;height:4mm;">Income recapture from Form 4797, Part III (see instructions)
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.            
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">12</div>
    <div class="styLNAmountBox" style="width:32mm;border-bottom-width:1px;height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/IncomeRecaptureFromForm4797" />
      </xsl:call-template>    
    </div>    
    <div class="styLNRightNumBoxNBB" style="width=8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>    
  </div>        
      
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">13</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">Add lines 10, 11, and 12
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">13</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/SumOfAdjBasisCommIncomeRcptr" />
      </xsl:call-template>    
    </div>    
  </div>    
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">14</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">Subtract line 13 from line 5. If zero or less, <span class="styBoldText">do not</span> complete the rest of this form (see instructions)
      <!--Dotted Line-->
      
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">14</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/SumLessAdjBasisCommIncmRcptr" />
      </xsl:call-template>
    </div>    
  </div>    
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:7mm;">15</div>
    <div class="styLNDesc" style="width:139mm;height:7mm;">If the property described on line 1 above was your main home, enter the amount of your excluded gain (see instructions).  Otherwise, enter -0-
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>      
    </div>
    <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3.5mm;">15</div>
    <div class="styLNAmountBox" style="height:7.5mm;padding-top:3.5mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/ExcludedGainAmount" />
      </xsl:call-template>    
    </div>    
  </div>        
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">16</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"><span class="styBoldText">Gross profit.</span> Subtract line 15 from line 14
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.

      </span>  
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">16</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/GrossProfit" />
      </xsl:call-template>    
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">17</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">Subtract line 13 from line 6. If zero or less, enter -0-
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.

      </span>
      
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">17</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/MortgLessAdjBasisCommIncmRcptr" />
      </xsl:call-template>    
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">18</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"><span class="styBoldText">Contract price.</span> Add line 7 and line 17
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBoxNBB" style="height:4mm;">18</div>
    <div class="styLNAmountBoxNBB" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/ContractPrice" />
      </xsl:call-template>    
    </div>    
  </div>
  
</div>
  <!-- BEGIN Part II Title -->
  <div class="styBB" style="width:187mm;">
    <div class="styPartName">Part II</div>
    <div class="styPartDesc">Installment Sale Income.<span class="styNormalText"> Complete this part for the year of sale  <span class="styBoldText">and</span> any year you receive a payment or 
     have certain debts you must treat as a payment on installment obligations. </span></div>
  </div>
  <!-- END Part II Title -->
<div class="styBB" style="width:187mm;">       
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">19</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"> Gross profit percentage. Divide line 16 by line 18.  For years after the year of sale, see instructions

    </div>
    <div class="styLNRightNumBox" style="height:4mm;">19</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulatePercent">
        <xsl:with-param name="TargetNode" select="$Form6252Data/GrossProfitPercentage" />
      </xsl:call-template>
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">20</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"> If this is the year of sale, enter the amount from line 17. Otherwise, enter -0-
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">20</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/IfYearOfSaleAmount" />
      </xsl:call-template>    
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">21</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"> Payments received during year (see instructions). <span class="styBoldText">Do not</span> include interest, whether stated or unstated
    <!--Dotted Line-->
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">21</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/PaymentsReceivedDuringYear" />
      </xsl:call-template>    
    </div>
    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">22</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"> Add lines 20 and 21
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">22</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/YearOfSaleAmountPaymentsRcvd" />
      </xsl:call-template>    
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">23</div>
    <div class="styLNDesc" style="width:99mm;height:4mm;">Payments received in prior years (see instructions).  <span class="styBoldText">Do not</span> include
     interest, whether stated or unstated      
    <!--Dotted Line-->
    <span class="styBoldText">
      <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
    </span>
    </div>
    <div class="styLNRightNumBox" style="height:7.5mm;padding-top=3.5mm;">23</div>
    <div class="styLNAmountBox" style="height:7.5mm;padding-top=3.5mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/PaymentsReceivedPriorYear" />
      </xsl:call-template>    
    </div>    
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:7.5mm;padding-top=3.5mm;border-right-width:1px;">
    </div>        
  </div>  
  
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">24</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"> <span class="styBoldText">Installment sale income.</span> Multiply line 22 by line 19    
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.

      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">24</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/InstallmentSaleIncome" />
      </xsl:call-template>    
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">25</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"> Enter the part of line 24 that is ordinary income under the recapture rules (see instructions)
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">25</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/OrdinaryIncomePart" />
      </xsl:call-template>    
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">26</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;"> Subtract line 25 from line 24. Enter here and on Schedule D or Form 4797 (see instructions)
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
      </span>  
    </div>
    <div class="styLNRightNumBoxNBB" style="height:4mm;">26</div>
    <div class="styLNAmountBoxNBB" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/InstalSaleIncmLessOrdnryIncm" />
      </xsl:call-template>    
    </div>    
  </div>
 </div>
  <!-- BEGIN Part III Title -->
  <div class="styBB" style="width:187mm;">
    <div class="styPartName">Part III</div>
    <div class="styPartDesc">Related Party Installment Sale Income. Do not<span class="styNormalText"> complete if you received the final payment this tax year. </span></div>
  </div>
  <!-- END Part III Title -->
  <div  style="width:187mm;">         
    <div class="styLNLeftNumBox" style="height:4mm;">27</div>
    
    <!--Showing empty rows when there is no element added Ravi Venigalla 04/27/04 -->
    <xsl:if test="(count($Form6252Data/RelatedParty) &lt; 1) or (($Print=$Separated) and (count($Form6252Data/RelatedParty) &gt;1))">
      <div class="styLNDesc" style="width:85mm;height:4mm;">            
        Name, address, and taxpayer identifying number of related party
      </div>
      <div class="styFixedUnderline" style ="width:89mm;text-align:left;float:right;" >
              <xsl:call-template name="PopulateAdditionalDataTableMessage">
                  <xsl:with-param name="TargetNode" select="$Form6252Data/RelatedParty/RelatedPartyName/BusinessNameLine1"/>
              </xsl:call-template> </div>
    
      <div class="styGenericDiv" style="height:2mm;">                
           <div class="styBB" style="width:180mm;height:4.5mm; text-decoration:underline;float:right;"><br/></div>                
           </div>  
    </xsl:if>
    <!--End show empty row code-->
    
    <xsl:if test = "(not ( count($Form6252Data/RelatedParty) &lt; 1) and ($Print!=$Separated)) or (($Print=$Separated) and (count($Form6252Data/RelatedParty)=1))">
    <div class="styLNDesc" style="width:179mm;height:4mm;">            
      <span style="float:left;clear:none;">Name, address, and taxpayer identifying number of related party</span><span style="width:93mm;float:right;clear:none;border-bottom:1px solid black;"></span>
    </div>
    
    <div class="GenericDiv" id="STPctn" style="padding-left: 8mm;">
      <xsl:for-each select="$Form6252Data/RelatedParty">      
        <div class="styForm6252UnderlineText" style="width:179mm;height:4mm;">
               
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyName/BusinessNameLine1"/>
        </xsl:call-template> 
        <span style="width:16px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyName/BusinessNameLine2"/>
        </xsl:call-template> 
        <span style="width:8px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/AddressLine1"/>
        </xsl:call-template> 
        <span style="width:16px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/AddressLine2"/>
        </xsl:call-template> 
        <span style="width:8px;">,</span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/City"/>
        </xsl:call-template> 
        <span style="width:8px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/State"/>
        </xsl:call-template> 
        <span style="width:8px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/ZIPCode"/>
        </xsl:call-template> 
        
           <xsl:if test="RelatedPartySSN != ''">
                <span style="width:8px;">,</span>
                 <xsl:call-template name="PopulateSSN">
                 <xsl:with-param name="TargetNode" select="RelatedPartySSN"/>
                  </xsl:call-template>
            </xsl:if>
            <xsl:if test="RelatedPartyEIN != ''">
                 <span style="width:8px;">,</span>
                  <xsl:call-template name="PopulateEIN">
                  <xsl:with-param name="TargetNode" select="RelatedPartyEIN"/>
                  </xsl:call-template>
           </xsl:if>
        
        </div>  
      </xsl:for-each>  
    </div>          
    </xsl:if>        
  </div>     
  
  <div style= "width:187mm;" >        
    <div class="styLNLeftNumBox" style="height:4mm;padding-top:1.5mm;">28</div>
    <div class="styLNDesc" style="width:148mm;height:4.5mm;padding-top:1.5mm;">Did the related party resell or dispose of the property ("second disposition") during this tax year?
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.

      </span>
    </div>
    <div class="styLNDesc" style="width:15mm;height:4.5mm;text-align:right;">
    <span>
        <xsl:call-template name="PopulateSpan">
          <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldOrDisposed" />
        </xsl:call-template>
      <input type="checkbox" class="styCkbox"  name="Checkbox"> 
        <xsl:call-template name="PopulateYesCheckbox">
          <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldOrDisposed" />
        </xsl:call-template>
      </input> 
      </span>
      <span style="width:8px"></span>
       <label>
         <xsl:call-template name="PopulateLabelYes">
           <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldOrDisposed" />
         </xsl:call-template>            
           Yes            
      </label>            
    </div>
    
    <div class="styLNDesc" style="width:15mm;height:4.5mm;text-align:right;">
    <span>
        <xsl:call-template name="PopulateSpan">
          <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldOrDisposed" />
        </xsl:call-template>
      <input type="checkbox" class="styCkbox"  name="Checkbox">
        <xsl:call-template name="PopulateNoCheckbox">
          <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldOrDisposed" />
        </xsl:call-template>
      </input> 
      </span>
      <span style="width:8px"></span>
       <label>
         <xsl:call-template name="PopulateLabelNo">
           <xsl:with-param name="TargetNode" select="$Form6252Data/PropertySoldOrDisposed" />
         </xsl:call-template>            
           No            
      </label>       
    </div>
  </div>
  <div style="width:187mm;">
  <div class="styLNLeftNumBox" style="height:4.5mm;padding-top:1.5mm;">29</div>
  <div class="styLNDesc" style="width:178mm;height:4.5mm;"><span class="styBoldText"> If the answer to question 28 is "Yes," complete lines 30 through 37 below unless one of the following conditions is 
   met. Check the box that applies.</span>    
  </div>
</div>
<div style="width:187mm;">
  <div class="styLNLeftLtrBox" style="height:4.5mm;">a</div>
  <div class="styLNDesc" style="width:146mm;height:4.5mm;">
     <input type="checkbox"  class="styCkbox"  name="Checkbox">
       <xsl:call-template name="PopulateCheckbox">
         <xsl:with-param name="TargetNode" select="$Form6252Data/SecondDisposMore2YrsThanFirst" />
       </xsl:call-template>
     </input>
     <label>
       <xsl:call-template name="PopulateLabel">
         <xsl:with-param name="TargetNode" select="$Form6252Data/SecondDisposMore2YrsThanFirst" />
       </xsl:call-template>            
        The second disposition was more than 2 years after the first disposition (other than dispositions of
        <span style="float:left;width:12px;"></span>marketable securities).  If this box is checked, enter the date of disposition (month, day, year)     
      <img src="{$ImagePath}/6252_Bullet.gif" alt="Bullet Image"/> 
    </label>
  </div>
  <div class="styLNAmountBox" style="width:32mm;border-bottom-width:1px; border-right-width:1px;height:4mm;padding-top:4mm;text-align:left;">
    <xsl:call-template name="PopulateMonthDayYear">
      <xsl:with-param name="TargetNode" select="$Form6252Data/DateOfDisposition" />
    </xsl:call-template>
  </div>
</div>

<div style="width:187mm;">
  <div class="styLNLeftLtrBox" style="height:4.5mm;">b</div>
  <div class="styLNDesc" style="width:158mm;height:4.5mm;">
    <input type="checkbox"  class="styCkbox"  name="Checkbox">
      <xsl:call-template name="PopulateCheckbox">
         <xsl:with-param name="TargetNode" select="$Form6252Data/FirstDisposSaleExchange" />
       </xsl:call-template>
     </input>
     <label>
       <xsl:call-template name="PopulateLabel">
         <xsl:with-param name="TargetNode" select="$Form6252Data/FirstDisposSaleExchange" />
       </xsl:call-template> 
       The first disposition was a sale or exchange of stock to the issuing corporation.
    </label>    
  </div>  
</div>
<div style="width:187mm;">
  <div class="styLNLeftLtrBox" style="height:4.5mm;">c</div>
  <div class="styLNDesc" style="width:178mm;height:4.5mm;">
    <input type="checkbox"  class="styCkbox"  name="Checkbox">
      <xsl:call-template name="PopulateCheckbox">
         <xsl:with-param name="TargetNode" select="$Form6252Data/SecondDisposInvoluntaryCnvrt" />
       </xsl:call-template>
     </input>
     <label>
       <xsl:call-template name="PopulateLabel">
         <xsl:with-param name="TargetNode" select="$Form6252Data/SecondDisposInvoluntaryCnvrt" />
       </xsl:call-template>             
       The second disposition was an involuntary conversion and the threat of conversion occurred after the first disposition.  
     </label>  
  </div>  
</div>

<div style="width:187mm;">
  <div class="styLNLeftLtrBox" style="height:4.5mm;">d</div>
  <div class="styLNDesc" style="width:158mm;height:4.5mm;">
    <input type="checkbox"  class="styCkbox"  name="Checkbox">
      <xsl:call-template name="PopulateCheckbox">
         <xsl:with-param name="TargetNode" select="$Form6252Data/SecondDisposAfterDeathSeller" />
       </xsl:call-template>
     </input>
     <label>
       <xsl:call-template name="PopulateLabel">
         <xsl:with-param name="TargetNode" select="$Form6252Data/SecondDisposAfterDeathSeller" />
       </xsl:call-template>           
       The second disposition occurred after the death of the original seller or buyer.  
      </label>  
  </div>  
</div>

<div style="width:187mm;">
  <div class="styLNLeftLtrBox" style="height:4.5mm;">e</div>
  <div class="styLNDesc" style="width:178mm;height:4.5mm;">
    <input type="checkbox"  class="styCkbox"  name="Checkbox">
      <xsl:call-template name="PopulateCheckbox">
         <xsl:with-param name="TargetNode" select="$Form6252Data/DispositionNotToAvoidTax" />
       </xsl:call-template>
     </input>
      <label>
       <xsl:call-template name="PopulateLabel">
         <xsl:with-param name="TargetNode" select="$Form6252Data/DispositionNotToAvoidTax" />
       </xsl:call-template>  
       It can be established to the satisfaction of the Internal Revenue Service that tax avoidance was not a principal purpose for either of
       <span style="float:left;width:12px;"></span> the dispositions.  If this box is checked, attach an explanation (see instructions).                
      </label>
      <span style="width:2px;"></span>  
    <!-- Form to Form Link -->
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$Form6252Data/DispositionNotToAvoidTax"/>
    </xsl:call-template>            
  </div>  
</div>

<div class="styBB" style="width:187mm;">
  
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">30</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Selling price of property sold by related party (see instructions)
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.

      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">30</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/SellingPriceByRelatedParty" />
      </xsl:call-template>    
    </div>    
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">31</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Enter contract price from line 18 for year of first sale
      <!--Dotted Line-->
      <span class="styBoldText">
        
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>
    <div class="styLNRightNumBox" style="height:4mm;">31</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/ContractPriceYearOfFirstSale" />
      </xsl:call-template>    
    </div>
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">32</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Enter the <span class="styBoldText">smaller</span> of line 30 or line 31      
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>

    <div class="styLNRightNumBox" style="height:4mm;">32</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/SmallerSellPriceContractPrice" />
      </xsl:call-template>    
    </div>
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">33</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Total payments received by the end of your 2005 tax year (see instructions)    
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        
      </span>
    </div>

    <div class="styLNRightNumBox" style="height:4mm;">33</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/TotalPaymentsReceived" />
      </xsl:call-template>    
    </div>
  </div>   
    
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">34</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Subtract line 33 from line 32. If zero or less, enter -0-    
      <!--Dotted Line-->
      <span class="styBoldText">        
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      
      </span>
    </div>

    <div class="styLNRightNumBox" style="height:4mm;">34</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/TotalPaymentsReceivedLessPrice" />
      </xsl:call-template>  
    </div>
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">35</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Multiply line 34 by the gross profit percentage on line 19 for year of first sale    
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>
    </div>

    <div class="styLNRightNumBox" style="height:4mm;">35</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/TotPymtPrcMultipliedGroPrftPct" />
      </xsl:call-template>  
    </div>
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">36</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Enter the part of line 35 that is ordinary income under the recapture rules (see instructions)  
      <!--Dotted Line-->
      <span class="styBoldText">        
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.        
      </span>
    </div>

    <div class="styLNRightNumBox" style="height:4mm;">36</div>
    <div class="styLNAmountBox" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/OrdinaryIncmUnderRecaptureRls" />
      </xsl:call-template>  
    </div>
  </div>
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">37</div>
    <div class="styLNDesc" style="width:139mm;height:4mm;">
      Subtract line 36 from line 35. Enter here and on Schedule D or Form 4797 (see instructions)  
      <!--Dotted Line-->
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        
      </span>
    </div>
    <div class="styLNRightNumBoxNBB" style="height:4mm;">37</div>
    <div class="styLNAmountBoxNBB" style="height:4mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6252Data/PaymentPriceLessOrdinaryIncome" />
      </xsl:call-template>  
    </div>
  </div>
  
</div>
      <div style="width:187mm;">
        <span class="styBoldText">For Paperwork Reduction Act Notice, see page 4. </span> 
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>    
          
          Cat. No. 13601R 
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          <span style="width:16px;"></span>
          
        Form <span class="styBoldText">6252</span> (2005)
      </div>
    
      <br /><br class="pageEnd"/>
      <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form6252Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
      <!-- END Left Over Table -->      
      
 <xsl:if test="($Print = $Separated) and (count($Form6252Data/RelatedParty) &gt;1)">
<br/>
<span class="styRepeatingDataTitle">Form 6252 Line 27 - Name, address, and taxpayer identifying number of related party </span>			
<table class="styDepTbl" style="font-size: 7pt">  
      <xsl:for-each select="$Form6252Data/RelatedParty"> 
      <tr>
          <xsl:attribute name="class">
		  <xsl:choose>
                  <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                        <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
          </xsl:attribute>     
        <td class="styDepTblCell" style="text-align: left">               
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyName/BusinessNameLine1"/>
        </xsl:call-template> 
        <span style="width:16px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyName/BusinessNameLine2"/>
        </xsl:call-template> 
        <span style="width:8px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/AddressLine1"/>
        </xsl:call-template> 
        <span style="width:16px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/AddressLine2"/>
        </xsl:call-template> 
        <span style="width:8px;">,</span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/City"/>
        </xsl:call-template> 
        <span style="width:8px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/State"/>
        </xsl:call-template> 
        <span style="width:8px;"></span>
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="RelatedPartyAddress/ZIPCode"/>
        </xsl:call-template> 
        
         <xsl:if test="RelatedPartySSN != ''">
             <span style="width:8px;">,</span>
             <xsl:call-template name="PopulateSSN">
              <xsl:with-param name="TargetNode" select="RelatedPartySSN"/>
              </xsl:call-template>
         </xsl:if>
         <xsl:if test="RelatedPartyEIN != ''">
              <span style="width:8px;">,</span>
               <xsl:call-template name="PopulateEIN">
               <xsl:with-param name="TargetNode" select="RelatedPartyEIN"/>
               </xsl:call-template>
          </xsl:if>
        </td>  
        </tr>
      </xsl:for-each> 
      </table>
    </xsl:if>  
    </form>
  </body>
</html>
</xsl:template>
</xsl:stylesheet>

  
