<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS6478Style.xsl"/>



<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form6478Data" select="$RtnDoc/IRS6478" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" 
    select="local-name($Form6478Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Author" content="Ravi Venigalla" />
    <meta name="Description" content="TY 2005 IRS Form 6478" />
    
    
    
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>
    
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 6478 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS6478Style"></xsl:call-template>  
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>
    </style>    
  <xsl:call-template name="GlobalStylesForm"/>
</head>
  

  <body class="styBodyClass">
    <form name="Form6478">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>
      
      <!-- Begin Form6478 Number and Name -->
      <div class="styBB" style="width:187mm;">
      <div class="styFNBox" style="width:31mm;height:22.5mm;">
        Form <span class="styFormNumber">6478</span>
         
          <br/>
         <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form6478Data"/>
            </xsl:call-template>
          <br/><br/>
            
        <span class="styAgency">Department of the Treasury</span>
        <br/>
        <span class="styAgency">Internal Revenue Service</span>
      </div>
      <div class="styFTBox" style="width:123mm;height:11mm;">
        <span style="height: 1mm;" />
        <div class="styMainTitle" style="height:8mm;">
          Credit for Alcohol Used as Fuel
        </div>
        <br/>
        <div class="styFST" style="height:5mm;font-size:7pt;">
          <img src="{$ImagePath}/6478_Bullet.gif" width="4" height="7" alt="Bullet Image"/>
          Attach to your tax return.
        </div>
      </div>
      <div class="styTYBox" style="width:32mm;height:12mm;">
        <div class="styOMB" style="height:2mm;">
          OMB No. 1545-0231
        </div>
        <div class="styTY" style="height:13mm;">
          20<span class="styTYColor">05</span>
        </div>
        <div>Attachment<br/> Sequence No.<span class="styBoldText"><span style="width:4px;"></span>83</span></div>
      </div>
    </div>
    
<!-- End Form Number and Name section -->
    
<!-- Begin Name and Identifying number section -->

    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:130mm;height:8mm;font-size:7pt;">
        Name(s) shown on return
        <br/>
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
      </div>
      <div class="styEINBox" style="width:50mm;height:4mm;font-size:7pt;padding-left:2mm;">
        Identifying number<br/><br/>
        <span style="font-weight:normal;">
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
        </span>
      </div>
    </div>
    
<!-- Start Caution -->
     
<div style="width:187mm;" class="styBB">
  <div  style="width:15mm;font-weight:bold;">Caution:<br/></div>
  <div class="styGenericDiv" style="padding-left:3mm;">
       <li style="padding-top:.75mm;"><span style="width:.5mm;"></span> 
       See What's New<span style="font-style:italic"> on page 2 for important changes to this credit.</span></li>
     <li  style="padding-top: .75mm;"><span style="width:.5mm"></span>  
       You cannot claim any amounts on Form 6478 that you claimed (or  will claim)
        on Schedule C (Form 720), Form 8849, or Form 4136.</li>

  </div>
</div>
<!-- End Caution -->     

<!-- Start part I -->
<div style="width:187mm;"></div>
     
<div style="width:187mm;height:6mm" class="styBB">

  <div class="styPartName" style="width:15mm;padding-top:.25mm;">Part I</div>
  <div class="styPartDesc" style="padding-left:3mm;padding-top:.25mm;">
    Current Year Credit 
    
    <xsl:call-template name="LinkToLeftoverDataTableInline">
        <xsl:with-param name="Desc">Schema 2005v1.0 - Line 4a Alcohol fuel mixtures containing ethanol (in gallons)</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form6478Data/GallonsOfAlcoholFuelMixEthanol"/>
        <xsl:with-param name="Style">padding-left:3mm;</xsl:with-param>
      </xsl:call-template >
 
 <xsl:call-template name="LinkToLeftoverDataTableInline">
        <xsl:with-param name="Desc">Schema 2005v1.0 - Line 4b - Alcohol fuel mixtures containing ethanol rate</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form6478Data/RateForAlcoholFuelMixEthanol"/>
        <xsl:with-param name="Style">padding-left:6mm;</xsl:with-param>
      </xsl:call-template >
     

 <xsl:call-template name="LinkToLeftoverDataTableInline">
        <xsl:with-param name="Desc">Schema 2005v1.0 - Line 4c - Alcohol fuel mixtures containing ethanol credit (Column (a) x Column (b))</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholFuelMixEthanolCredit"/>
        <xsl:with-param name="Style">padding-left:6mm;</xsl:with-param>
      </xsl:call-template >
     


  </div>
</div>
<!-- End part I -->     



    <!-- End Names and Identifying number section -->
    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" align="center" style="width:101.75mm;height:9mm; padding-top:3mm;font-size:7pt;">
        Type of Alcohol Fuel
      </div>
      
      <div class="styNameBox" align="center" style="width:28mm;height:9mm;">
        <span class="styBoldText">(a)</span><br/>Number of Gallons of <br/>Alcohol  Sold or Used
      </div>
      
      <div class="styNameBox" align="center" style="width:25mm;height:9mm;">
        <span class="styBoldText">(b)</span><br/>Rate*      
      </div>
      <div align="center" ><span class="styBoldText" style="font-size:6pt;">(c)</span><br/>Column(a) x Column(b)</div>

    </div>
<!--  Start line 1 -->        
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          1
        </div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">Qualified ethanol fuel production (in gallons)</span>
        </div>      
        <div class="styLNAmountBox" style="border-bottom-width:0px;width:5mm;padding-right:2mm;"></div>

        <div class="styLNAmountBox" style="width:28mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:25mm;text-align:center;border-bottom-width:0px;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0px;">
          
        </div>
    </div>
<!-- End line 1 -->
    
<!-- start line 1 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">(see instructions for election)</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:right;padding-right:1mm">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>. 
            
        </span>
     </div>      
     <div class="styLNAmountBox" style="width:5mm;padding-right:2mm;">1</div>
        <div class="styLNAmountBox" style="width:28mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="8"/>          
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            QualifiedEthanolFuelProduction"/>
          </xsl:call-template>
        </div>
         <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:25mm;text-align:center;">
          $
          <xsl:if test="$Form6478Data/QualifiedEthanolFuelProdRate">
            <xsl:call-template name="PopulateText">
               <xsl:with-param name="TargetNode"
                select="$Form6478Data/QualifiedEthanolFuelProdRate"/>
            </xsl:call-template>
          </xsl:if>
          <!--xsl:if test="not($Form6478Data/QualifiedEthanolFuelProdRate) or ($Form6478Data/QualifiedEthanolFuelProdRate='')" -->
          <xsl:if test="not($Form6478Data/QualifiedEthanolFuelProdRate)">
            .10
          </xsl:if>
        </div>

        
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            QualifiedEthanolFuelCredit"/>
          </xsl:call-template>        
        </div>
    </div>
    
<!-- End line 1 extention -->
 
 <!--  Start line 2 -->        
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          2
        </div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">Alcohol 190 proof or greater</span>
          <span style="font-weight:bold"> and </span>
          <span style="font-weight:normal">alcohol 190 proof or greater</span>
        </div>      
        <div class="styLNAmountBox" style="border-bottom-width:0px;width:5mm;padding-right:2mm;"></div>

        <div class="styLNAmountBox" style="width:28mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:25mm;text-align:center;border-bottom-width:0px;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0px;">
          
        </div>
    </div>
<!-- End line 2 -->
    
<!-- start line 2 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">in fuel mixtures</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:right;padding-right:1mm">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.

        </span>
     </div>      
     <div class="styLNAmountBox" style="width:5mm;padding-right:2mm;">2</div>
        <div class="styLNAmountBox" style="width:28mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="8"/>          
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            Alcohol190ProofOrHigherPrf"/>
          </xsl:call-template>
        </div>
        
  <div class="styLNAmountBox" style="width:25mm;text-align:center;">  
          $   
          <xsl:if test="$Form6478Data/RateFor190OrHigherPrfAlcohol">
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            RateFor190OrHigherPrfAlcohol"/>
          </xsl:call-template> 
          </xsl:if>                      
           <xsl:if test="not($Form6478Data/RateFor190OrHigherPrfAlcohol)">.51
          </xsl:if>                      
       </div>
        
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            Alcohol190ProofOrGreaterCredit"/>
          </xsl:call-template>        
        </div>
    </div>
    
<!-- End line 2 extention -->

 
 <!--  Start line 3 -->        
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          3
        </div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
        <span style="float:left">Alcohol less than 190 proof but at least 150 proof </span>
        <span style="font-weight:bold"> and </span><span style="font-weight:normal">alcohol</span>
        </div>      
        <div class="styLNAmountBox" style="border-bottom-width:0px;width:5mm;padding-right:2mm;"></div>

        <div class="styLNAmountBox" style="width:28mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:25mm;text-align:center;border-bottom-width:0px;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0px;">
          
        </div>
    </div>
<!-- End line 3 -->
    
<!-- start line 3 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">less than 190 proof but at least 150 proof in fuel mixtures</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:right;padding-right:1mm">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
           </span>
     </div>      
     <div class="styLNAmountBox" style="width:5mm;padding-right:2mm;">3</div>
        <div class="styLNAmountBox" style="width:28mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="8"/>          
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            GallonsOf150To189ProofAlcohol"/>
          </xsl:call-template>
        </div>
        
        <div class="styLNAmountBox" style="width:25mm;text-align:center;">  
          $     
          <xsl:if test="$Form6478Data/RateFor150To189ProofAlcohol">
                <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            RateFor150To189ProofAlcohol"/>
          </xsl:call-template> 
          </xsl:if>
           <xsl:if test="not($Form6478Data/RateFor150To189ProofAlcohol)">
           <span style="font-size:6pt;">.3778</span>         
           </xsl:if>                      
         </div>

        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            Alcohol150To189ProofCredit"/>
          </xsl:call-template>        
        </div>
    </div>
    
<!-- End line 3 extention -->
 
 <!-- Start line 4 -->
 
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:7mm;padding-top:3.5mm;">
          4
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:7mm;padding-top:3.5mm;">
          <span style="float:left">Alcohol fuel credit(s) from a partnership
          , S corporation, estate, trust or cooperative (see instructions)</span>
          
        </div>                
        <div class="styLNRightNumBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm">4
        </div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            AlcoholFuelCreditFromPrtshp"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- start line 5 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:7mm;padding-top:3.5mm;">
          5
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:7mm;padding-top:3.5mm;" >
          <span style="float:left">Add lines 1 through 4, column (c)</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
         </span>      
        </div>                
        <div class="styLNRightNumBox" style="height:7mm;padding-top:3.5mm;
        padding-bottom:0mm">5
        </div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholFuelCredit"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 5 -->

<!-- start line 6 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:7mm;padding-top:3.5mm;">
          6
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:7mm;padding-top:3.5mm;" >
          <span style="float:left">Alcohol fuel credit included on line 5 from passive activities (see instructions)</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
           <span style="width:16px;"></span>.
           </span>      
        </div>                
        <div class="styLNRightNumBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm">6
        </div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholCreditFromPassiveActy"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 6 -->


<!-- start line 7 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:7mm;padding-top:3.5mm;">
          7
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:7mm;padding-top:3.5mm;" >
          <span style="float:left">Subtract line 6 from line 5</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
           <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
       </span>      
        </div>                
        <div class="styLNRightNumBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm">7
        </div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetAlcoholCredits"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 7 -->

<!-- start line 8 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:7mm;padding-top:3.5mm;">
          8
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:7mm;padding-top:3.5mm;" >
          <span style="float:left">Alcohol fuel credit allowed for 2005 from a passive activity (see instructions)</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
         </span>      
        </div>                
        <div class="styLNRightNumBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm">8
        </div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholPassiveCreditAllowed"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 8 -->


<!-- start line 9 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:7mm;padding-top:3.5mm;">
          9
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:7mm;padding-top:3.5mm;" >
          <span style="float:left">Carryback of alcohol fuel credit from 2006 (see instructions)</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          </span>      
        </div>                
        <div class="styLNRightNumBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm">9
        </div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
           AlcoholFuelCreditCarryback"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 9 -->


<!-- start line 10 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:7mm;padding-top:3.5mm;">
          10
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:7mm;padding-top:3.5mm;" >
          <span style="float:left"><span class="styBoldText">Current year credit.</span> Add lines 7 through 9</span>

          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
         </span>      
        </div>                
        <div class="styLNRightNumBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm;border-bottom-width:0px">10
        </div>
        <div class="styLNAmountBox" style="height:7mm;padding-top:3.5mm;padding-bottom:0mm;border-bottom-width:0px"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            TotalCYCreditForAlcoholAsFuel"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 10 -->

  <div class="styBB" style="width:187mm;border-top-width:1px">
    <div class="styLNDesc" style="width:187mm;">  
    <span style="width:16px;"></span>
   * Only the rate for ethanol is shown. See instructions for lines 2 and 3 for rates
     for alcohol other than ethanol.
    <br />
    </div>
  </div>
  
  <!-- Start PartII -->
  
<div style="width:187mm;" class="styBB">
  <div class="styPartName" style="width:15mm;">Part II</div>
  <div class="styPartDesc" style="padding-left:3mm;">
    Allowable Credit<span style="width:3mm;"></span>
    <span class="styNormalText"><span class="styBoldText">Caution: </span>
    If you have both an alcohol fuel credit and a credit from section B of
Form 8835, do not complete Part II below. Instead, go to Form 8835 (see instructions).
    <span class="styBoldText"></span></span>

  </div>
</div>
  
<!-- End PartII -->

<!-- Start line 11 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          11
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
            Regular tax before credits (see instructions)
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          11          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            RegularTaxBeforeCredits"/>
          </xsl:call-template>    
        </div>                
    </div>
  


<!-- End line 11 --> 
  

<!-- Start line 12 -->

    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          12
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
        
            Alternative minimum tax (see instructions)
     
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          12          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            AlternativeMinimumTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 12 --> 

<!-- Start line 13 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          13
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
    
          Add lines 11 and 12
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox">
          13          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            RegularTaxPlusAltMinimumTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 13 --> 

<!-- Start line 14 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          14a
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Foreign tax credit</span>
           <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
          </span>
          
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">14a</div>      
        <div class="styLNAmountBox" style="padding-right:1mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>          
    </div>

    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;">
          b
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Credit from Form 1040, lines 48 through 54</span>
          <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:3px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>. 
       </span>
       </div>
        <div class="styLNRightNumBox" style="height:4mm;">14b</div>      
        <div class="styLNAmountBox" >
    <!--      
    	   <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/"/>
          </xsl:call-template>
    -->
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;padding-right:1mm;"></div>
       </div>
    
    <div style="width:187mm">                        
    <div class="styLNLeftLtrBox" style="height:4mm;">
          c
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Possessions tax credit (Form 5735, line 17 or 27)</span>
          <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>. 
           </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">14c</div>
        <div class="styLNAmountBox" style="padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/PossessionsTaxCredit"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
                  
    </div><div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;">
          d
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Nonconventional source fuel credit (Form 8907, line 23)</span>
          <span class="styBoldText" style="float:right;padding-right:1.5mm">
            <span style="width:1px;"></span>.          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.                                            
          </span>

        </div>
        <div class="styLNRightNumBox" style="height:4mm;">14d</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            CreditForFuelFromNnconvSource"/>
          </xsl:call-template>    
        </div>
          <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
        </div>

    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;">
          e
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Other specified credits (see instructions)</span>
          <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 

          </span>          
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">14e</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            OtherSpecifiedCredits"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>        
          
    </div>
    
    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;">
        f
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">Add lines 14a through 14e</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.                                        
          </span>
       </div>
      
        <div class="styLNRightNumBox">14f
        </div>
          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/TaxCreditTotal"/>
          </xsl:call-template>    
        </div>
    </div>



<!-- End line 14 -->

<!-- Start line 15 -->

    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          15
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            <span class="stySmallText;">
           Net income tax. Subtract line 14f from line 13. If zero, skip lines 16 through 19 and enter -0- on line 20
            </span>
          </span>
         
        </div>      
        <div class="styLNRightNumBox">
          15          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetIncomeTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 15 --> 

<!-- Start line 16 -->


   <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:1mm">
          16
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Net regular tax. Subtract line 14f from line 11. If zero or less, enter -0-</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">16</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetRegularTax"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
    </div>

<!-- End line 16 -->

<!-- Start line 17 -->

  <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          17
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
           Enter 25% (.25) of the excess, if any, of line 16 over $25,000 (see instructions)
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox">
          17          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetRegularTax25PctOfExcess"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 17 -->    

<!-- Start line 18 -->

    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          18
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
            Subtract line 17 from line 15. If zero or less, enter -0-
       
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox">
          18          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            NetIncomeTaxLessExcess"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 18 --> 

<!-- Start line 19 -->
   
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          19
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            
            General business credit (see instructions)
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          19          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/GeneralBusinessCredit"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 19 --> 

<!-- Start line 20 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          20
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
         
               Subtract line 19 from line 18. If zero or less, enter -0-
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          20          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            AdjustedNetIncomeTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 20 --> 

<!-- Start line 21 -->
  
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          21
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span class="styBoldText">Credit allowed for the current year.</span> Enter the <span class="styBoldText">smaller</span> of line 10 or line 20 here and on Form 1040, line   
        </div>
        
        <div class="styShadingCell" style="width:8mm;height:4.5mm;padding-top: 1.0mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;" ></div>
            
    </div>
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          55; Form 1120, Schedule J, line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule G, line 2c; or  
        </div>        
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;" ></div>        
    
      </div>
        <div style="width:187mm">
          <div class="styLNLeftNumBox" style="height:4mm;">        
          </div>
          <div class="styLNDesc" style="width:138.75mm;height:4mm;">
            <span style="float:left">the applicable line of your return. If line 20 is smaller than line 10, see instructions</span> 
            <span class="styBoldText" style="float:right;padding-right:1mm">          
              <span style="width:4px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
    
          </div>      
          <div class="styLNRightNumBoxNBB">21          
          </div>          
          <div class="styLNAmountBoxNBB" style="height:4.5mm;" >
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form6478Data/
              CYCreditForAlcoholAsFuel"/>
            </xsl:call-template>    
          </div>                
        </div>    
<!-- End line 21 -->      
  <!-- END Part II Line Items -->  
  
      <div class="styFooter" style="width:187mm; font-size:7pt; border-top:2 solid black; padding-top:1mm;">    
        <div style="float:left; font-size:8.5pt">
          <b>For Paperwork Reduction Act Notice, see page 4.</b>
        </div>    
        <div style="float:right;font-size:6pt">
          Cat. No. 13605J
          <span style="width:35mm"></span>
          Form <b style="font-size:9pt">6478<span  style="font-size:6pt"> (2005)</span></b>
        </div>      
      </div>        
      
      <p style="page-break-before:always" />      

<!-- BEGIN Left Over Table -->  
<!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form6478Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template> 
          
              
    <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Schema 2005v1.0 - Line 4a - Alcohol fuel mixtures containing ethanol (in gallons)</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form6478Data/GallonsOfAlcoholFuelMixEthanol"/>
        <xsl:with-param name="Style">padding-left:3mm;</xsl:with-param>
      </xsl:call-template >
 
 <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Schema 2005v1.0 - Line 4b - Alcohol fuel mixtures containing ethanol rate</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form6478Data/RateForAlcoholFuelMixEthanol"/>
        <xsl:with-param name="Style">padding-left:6mm;</xsl:with-param>
      </xsl:call-template >
     

 <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Schema 2005v1.0 - Line 4c - Alcohol fuel mixtures containing ethanol credit (Column (a) x Column (b))</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholFuelMixEthanolCredit"/>
        <xsl:with-param name="Style">padding-left:6mm;</xsl:with-param>
      </xsl:call-template >
     


                   
        </table>
        <!-- END Left Over Table -->  
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
