<?xml version="1.0" encoding="UTF-8" ?>
<!DOCTYPE xsl:stylesheet [
    <!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS6765Style.xsl"/>



<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form6765Data" select="$RtnDoc/IRS6765" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form6765Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 6765" />
    
      <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
      <xsl:call-template name="InitJS"></xsl:call-template>
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 6765 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS6765Style"></xsl:call-template>
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>
    </style>  
  <xsl:call-template name="GlobalStylesForm"/>
</head>
 
  <body class="styBodyClass">
    <form name="Form6765">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>      
      
      <!-- Begin Form Number and Name -->
      <div class="styBB" style="width:187mm;">
      <div class="styFNBox" style="width:31mm;height:22mm;">
        Form <span class="styFormNumber">6765</span>
        <br/><br/><br/>
        <span class="styAgency">Department of the Treasury</span>
        <br/>
        <span class="styAgency">Internal Revenue Service</span>
      </div>
      <div class="styFTBox" style="width:123mm;height:13mm;">
        <div class="styMainTitle" style="height:8mm;">
          Credit for Increasing Research Activities
        </div>
        <br/>      
        <div class="styFST" style="height:5mm;font-size:7pt;">
          <img src="{$ImagePath}/6765_Bullet.gif"  alt="Bullet Image"/>
          Attach to your tax return.
        </div>
      </div>
      <div class="styTYBox" style="width:32mm;height:13.5mm;">
        <div class="styOMB" style="height:2mm;">
          OMB No. 1545-0619
        </div>
        <div class="styTY" style="height:11.5mm;">
           20<span class="styTYColor">05</span>             
        </div>
        <div>Attachment<br/> Sequence No.<span class="styBoldText"><span style="width:4px;"></span>81</span></div>
      </div>
    </div>    
    <!-- End Form Number and Name section -->
    <!-- Begin Names and Identifying number section -->

    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:147mm;height:8mm;font-weight:normal;font-size:7pt;">
        Name(s) shown on return<br/>
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
      </div>
      <div class="styEINBox" style="width:39mm;height:4mm;padding-left:2mm;font-size:7pt;">
        Identifying number<br/><br />
        <span style="font-weight:normal;">  
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
        </span>  
      </div>
    </div>
    
    <!-- End Names and Identifying number section -->
    <!-- BEGIN Part I Title -->
    <div class="styBB" style="width:187mm;">
      <div class="styPartName">Part I</div>
      <div class="styPartDesc">Current Year Credit
        <span class="styNormalText">(Members of controlled groups or businesses under common control, see instructions.)
        </span>
      </div>
    </div>
    <!-- END Part | Title -->
    <!--Begin Section A-->
    <div class="styBB" style="width:187mm;font-size:7pt;">    
      <div class="styPartDesc" style="width:183mm;font-size:7pt;padding-left:0mm;">Section A&#151;Regular Credit.
        <span class="styNormalText"> Skip this section and go to Section B if you are electing or previously elected the alternative incremental credit.
        </span>
      </div>
    </div> 
    <!-- line 1 -->       
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
     1
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          Certain amounts paid or incurred to energy consortia after August 8, 2005 (see instructions)        
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>          
        </div> 
         <div class="styLNRightNumBox" style="width:8.25mm;height:4mm;border-right-width:1px;">1</div>
         <div class="styLNAmountBox" style="height:4mm;border-right-width:0px;border-left-width:0px;">
           <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/EnergyConsortiaAmount"/>
          </xsl:call-template>
         </div>
       </div>  
<!-- line 2 -->
<div style="width:187mm">
  <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
     2
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          Basic research payments paid or incurred to qualified organizations (see instructions)        
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>          
        </div>        
        <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm;">
       2        
        </div>
        <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/BasicResearchPayment"/>
          </xsl:call-template>
        </div>
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:7.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:7.5mm;border-right-width:0px;border-left-width:0px;"></div>
   
    </div>
      
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
         3
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          Qualified organization base period amount (see instructions)       
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.         
         </span>        
        </div>          
        
        <div class="styLNRightNumBox" style="height:4mm;">
         3          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/BasePeriodAmount"/>
          </xsl:call-template>
        </div>
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
    </div> 
     
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
        4
        </div>
             <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        
            Subtract line 3 from line 2. If zero or less, enter -0-          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>     
            </span>          
          </div>              
     
        <div class="styLNRightNumBox" style="height:4mm;">
         4          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/ResearchPymtMinusBasePeriodAmt"/>
          </xsl:call-template>
        </div>
       
          
    </div>
    
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
          5
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Wages for qualified services (do not include wages used in figuring the work opportunity credit)          
             <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            
          </span>          
         </div>              
 
        <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm;">
         5          
        </div>
        <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;padding-right:1mm;" >
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/WagesForQualifiedServices"/>
          </xsl:call-template>
        </div>
          <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:7.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:7.5mm;border-right-width:0px;border-left-width:0px;"></div>

      
    </div>
    
    <!-- line 6 -->
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
         6
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Cost of supplies          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
                            
            </span>
                
          </div>              
       
        <div class="styLNRightNumBox" style="height:4mm;">
       6          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/CostOfSupplies"/>
          </xsl:call-template>
        </div>
        
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
        
    </div>
    
    <!-- line 7 -->
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
     7
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Rental or lease costs of computers (see instructions)          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
         7          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/RentalOrLeaseCostsOfComputers"/>
          </xsl:call-template>
        </div> 
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
       
    </div>
    
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
         8
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Enter the applicable percentage of contract research expenses (see instructions)          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm;">
       8          
        </div>
        <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;padding-right:1mm;" >        
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/PctOfContractResearchExpenses"/>
          </xsl:call-template>          
        </div> 
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:7.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:7.5mm;border-right-width:0px;border-left-width:0px;"></div>

          
    </div>
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.5mm;">
          9
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Total qualified research expenses. Add lines 5 through 8          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
                   
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
          9         
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/TotalQualifedResearchExpenses"/>
          </xsl:call-template>
        </div>
       <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

        
    </div>
    
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
       10
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Enter fixed-base percentage, but not more than 16% (see instructions)  
             <!--
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              </span>
              -->
        </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
        10          
        </div>
        <div class="styLNAmountBox" style="height:4mm;" >
        <xsl:choose>
           <xsl:when test="$Form6765Data/FixedBasePercentage=''">
               <td class="styTableCell" style="width:17mm;height:5mm;text-align:right;font-size:7pt;border-color:black;">
              <span style="width:2px;">%</span>
            </td>           
          </xsl:when>
            <xsl:otherwise>
            <td class="styTableCell" style="width:17mm;height:5mm;text-align:right;font-size:7pt;border-color:black;padding-right:1mm;">
              <xsl:call-template name="PopulatePercent"><xsl:with-param name="TargetNode" select="$Form6765Data/FixedBasePercentage"/></xsl:call-template>
            </td>            
          </xsl:otherwise>
        </xsl:choose>
         </div>
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

       </div>
    
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          11
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Enter average annual gross receipts (see instructions)          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
                                     
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
          11          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/AverageAnnualGrossReceipts"/>
          </xsl:call-template>
        </div>
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

    </div>
    
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          12
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Multiply line 11 by the percentage on line 10          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
                                 
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
          12          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/FixedBasePctTimesGrossReceipts"/>
          </xsl:call-template>
        </div>
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

    </div>
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          13
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Subtract line 12 from line 9. If zero or less, enter -0-          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
          13          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/AdjTotQualifedResearchExpenses"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

      </div>
      
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          14
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Multiply line 9 by 50% (.50)          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
          14          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/HalfAdjTotQlfyResearchExpenses"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

    </div>
    
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          15
        </div>
          <div class="styLNDesc" style="width:98.75mm;height:4mm;">
            Enter the <span class="styBoldText">smaller</span> of line 13 or line 14          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
                                                 
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" style="height:4mm;">
          15          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/SmallestQlfyResearchExpenses"/>
          </xsl:call-template>
        </div>
         <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

     </div>
     
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          16
        </div>
          <div class="styLNDesc" style="width:138.75mm;height:4mm;">
            Add lines 1, 4,  and 15          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
            </span>          
          </div>              
        
        <div class="styLNRightNumBox">
          16          
        </div>
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/RsrchExpensesPlusRrchPayments"/>
          </xsl:call-template>
        </div>        
    </div>      
    
    <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;">
        17
      </div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        <span class="styBoldText">Regular credit.</span> If you are not electing the reduced credit under section 280C(c), multiply line 16
      </div>
      <div class="styLNRightNumBoxNBB"></div>  
      <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
    </div>
    <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;"></div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        by 20% (.20), enter the result, and see the instructions for the schedule that must be attached.
      </div>
      <div class="styLNRightNumBoxNBB"></div>  
      <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
    </div>
    <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;"></div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        If you are electing the reduced credit, multiply line 16 by 13% (.13) and enter the result. Also,
      </div>
      <div class="styLNRightNumBoxNBB"></div>  
      <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
    </div>          
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          write "Sec. 280C" on the dotted line to the left of the entry space. Go to Section C
          <!-- Adding pen image -->
          <span style="width:2px;"></span>
          <xsl:call-template name="LinkToLeftoverDataTableInline">
            <xsl:with-param name="Desc">Line 16 - Reduced Credit Indicator</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form6765Data/RegularCredit/@reducedCreditIndicator"/>
          </xsl:call-template>
        
           <span style="width:10px;"></span>  
          <!-- Form to Form Link -->
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$Form6765Data/RegularCredit"/>
          </xsl:call-template>
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
                      
          </span>          
        </div>        
        <div class="styLNRightNumBoxNBB" style="height:5.5mm;" >
          17          
        </div>
        <div class="styLNAmountBoxNBB" style="height:5.5mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/RegularCredit"/>
          </xsl:call-template>
        </div>
      </div>        
    </div>  
  
  <!--End of Section A-->
  <!-- Begin Section B-->
  <div class="styBB" style="width:187mm;">    
    <div class="styPartDesc" style="font-size:7pt;">Section B&#151;Alternative Incremental Credit.
      <span class="styNormalText"> Skip this section if you completed Section A.
      </span>
    </div>
  </div>
  
   <div style="width:187mm;" >
    <div class="styLNLeftNumBox" style="height:4mm;">
      18
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">Certain amounts paid or incurred to energy consortia after August 8,
2005 (see the line 1 instructions)
    </div>
      <div class="styLNRightNumBox" style="width:8.25mm;height:4mm;border-right-width:1px;">18</div>
         <div class="styLNAmountBox" style="height:4mm;border-right-width:0px;border-left-width:0px;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form6765Data/EnergyConsortiaAmountSectB"/>
            </xsl:call-template>
         </div>
             
  </div>

  
  <!-- line 19 -->
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      19
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Basic research payments paid or incurred to qualified organizations (see the line 2 instructions)
       <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
     
       </span>               
    </div>        
    <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm;">
      19          
    </div>
    <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/BasicResearchPaymentSectB"/>
      </xsl:call-template>
    </div> 
       <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:7.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:7.5mm;border-right-width:0px;border-left-width:0px;"></div>
          
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      20
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Qualified organization base period amount (see the line 3 instructions)          
    
    </div>              
        
    <div class="styLNRightNumBox" style="height:4mm;">
      20          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/BasePeriodAmountSectB"/>
      </xsl:call-template>
    </div> 
   <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

   </div>
    
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      21
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      Subtract line 20 from line 19. If zero or less, enter -0-          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.                                                
      </span>          
    </div>        
    <div class="styLNRightNumBox">
      21          
    </div>
    <div class="styLNAmountBox" style="height:4mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/RsrchPymtMinusBasePrdAmtSectB"/>
      </xsl:call-template>
    </div>        
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      22
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      Multiply line 21 by 20% (.20)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.    
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.                                  
      </span>          
    </div>        
    <div class="styLNRightNumBox">
      22          
    </div>
    <div class="styLNAmountBox" style="height:4mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/FifthOfRsrchPymtMinusBasePrd"/>
      </xsl:call-template>
    </div>        
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      23
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Wages for qualified services (do not include wages used in figuring the work opportunity credit)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
         <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
       <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
     </span>
    </div>              
    <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm;">
      23         
    </div>
    <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/WagesForQualifiedServicesSectB"/>
      </xsl:call-template>
    </div> 
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:7.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:7.5mm;border-right-width:0px;border-left-width:0px;"></div>

               
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      24
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Cost of supplies
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
       </span>          
    </div>        
    <div class="styLNRightNumBox" style="height:4mm;">
      24          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/CostOfSuppliesSectB"/>
      </xsl:call-template>
    </div> 
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

    </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      25
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Rental or lease costs of computers (see the line 7 instructions)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
       
      </span>          
    </div>              
        
    <div class="styLNRightNumBox" style="height:4mm;">
      25          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/RntlOrLsCostsOfComputersSectB"/>
      </xsl:call-template>
    </div>
  <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>

  </div>
    
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      26
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Enter the applicable percentage of contract research expenses (see the line 8 instructions)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
       </span>          
    </div>        
    <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3mm;">
      26          
    </div>
    <div class="styLNAmountBox" style="height:7.5mm;padding-top:3mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/PctOfCntrctRsrchExpensesSectB"/>
      </xsl:call-template>      
    </div>
      <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:7.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:7.5mm;border-right-width:0px;border-left-width:0px;"></div>

                
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      27
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Total qualified research expenses. Add lines 23 through 26          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.

       </span>          
    </div>        
    <div class="styLNRightNumBox" style="height:4mm;">
      27          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/TotQualifedRsrchExpensesSectB"/>
      </xsl:call-template>
    </div>
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
    </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      28
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Enter average annual gross receipts (see the line 11 instructions)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
      </span>
    </div>              
    <div class="styLNRightNumBox" style="height:4mm;">
      28          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/AvgAnnualGrossReceiptsSectB"/>
      </xsl:call-template>
    </div>
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
   </div>
   
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      29
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Multiply line 28 by 1% (.01)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
      </span>
    </div>        
    <div class="styLNRightNumBox" style="height:4mm;">
      29          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/OnePctOfAvgAnnualGrossReceipts"/>
      </xsl:call-template>
    </div>
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
    </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      30
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Subtract line 29 from line 27. If zero or less, enter -0-          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>          
    </div>              
        
    <div class="styLNRightNumBox" style="height:4mm;">
      30          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/AdjustedTotalResearchExpenses"/>
      </xsl:call-template>
    </div>
   <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
    </div>
    
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      31
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Multiply line 28 by 1.5% (.015)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
      </span>          
    </div>        
    <div class="styLNRightNumBox" style="height:4mm;">
      31          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/PctOfAnnualGrossReceipts"/>
      </xsl:call-template>
    </div>
   <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      32
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Subtract line 31 from line 27 If zero or less, enter -0-          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      </span>          
    </div>        
    <div class="styLNRightNumBox" style="height:4mm;">
      32          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/RsrchExpnsMinusPctOfGroRcpts"/>
      </xsl:call-template>
    </div>
   <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
    </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      33
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Subtract line 32 from line 30          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
       </span>
    </div>              
    <div class="styLNRightNumBox" style="height:4mm;">
      33          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/RsrchMinusAdjResearchExpenses"/>
      </xsl:call-template>
    </div>
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
    </div>
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      34
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Multiply line 28 by 2% (.02)
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
      </span>
    </div>        
    <div class="styLNRightNumBox" style="height:4mm;">
      34          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/TwoPctOfAvgAnnualGrossReceipts"/>
      </xsl:call-template>
    </div>
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
     </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      35
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Subtract line 34 from line 27. If zero or less, enter -0-          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
       </span>          
    </div>              
        
    <div class="styLNRightNumBox" style="height:4mm;">
      35          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/ResearchMinus2PctOfReceipts"/>
      </xsl:call-template>
    </div>
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
    </div>
    
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      36
    </div>
    <div class="styLNDesc" style="width:98.75mm;height:4mm;">
      Subtract line 35 from line 32.          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
      </span>          
    </div>        
    <div class="styLNRightNumBox" style="height:4mm;">
      36          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/ResearchMinusPctOfReceiptsDiff"/>
      </xsl:call-template>
    </div> 
   <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:4.5mm;border-right-width:1px;"></div>
         <div class="styLNAmountBoxNBB" style="height:4.5mm;border-right-width:0px;border-left-width:0px;"></div>
   </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      37
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      Multiply line 33 by 2.65% (.0265)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.                                                
      </span>          
    </div>        
    <div class="styLNRightNumBox">
      37          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/PctOfResearchMinusAdjResearch"/>
      </xsl:call-template>
    </div>        
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      38
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      Multiply line 36 by 3.2% (.032)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.                                          
      </span>
    </div>              
    <div class="styLNRightNumBox">
      38          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/PctOfResearchMinusReceiptsDiff"/>
      </xsl:call-template>
    </div>        
  </div>
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      39
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      Multiply line 35 by 3.75% (.0375)          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.                                                
      </span>          
    </div>        
    <div class="styLNRightNumBox">
      39          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/PctOfResearchMinus2PctOfRcpts"/>
      </xsl:call-template>
    </div>        
  </div>
  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      40
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      Add lines 18, 22, 37, 38, and 39          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.  
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
                           
      </span>
    </div>              
    <div class="styLNRightNumBox">
      40          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/PctOfResearchExpensesTotal"/>
      </xsl:call-template>
    </div>        
  </div>
    <div style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      41
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      <span class="styBoldText">Alternative incremental credit.</span> If you are not electing the reduced credit under section 280C(c),
    </div>
    <div class="styLNRightNumBoxNBB"></div>  
    <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
    </div>
    <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;"></div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        enter the amount from line 40, and see the line 17 instructions for the schedule that must be
      </div>
      <div class="styLNRightNumBoxNBB"></div>  
      <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
    </div>
    <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;"></div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        attached. If you are electing the reduced credit, multiply line 40 by 65% (.65) and enter the result.
      </div>
      <div class="styLNRightNumBoxNBB"></div>  
      <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
    </div>          
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          Also, write "Sec. 280C" on the dotted line to the left of the entry space. 
          <!-- Adding pen image -->
          <span style="width:2px;"></span>
          <xsl:call-template name="LinkToLeftoverDataTableInline">
            <xsl:with-param name="Desc">Line 39 - Reduced Credit Indicator</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form6765Data/AlternateIncrementalCredit/@reducedCreditIndicator"/>
          </xsl:call-template>
          
           <span style="width:10px;"></span>  
          <!-- Form to Form Link -->
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$Form6765Data/AlternateIncrementalCredit "/>
          </xsl:call-template>

          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
                 
          </span>          
        </div>        
        <div class="styLNRightNumBoxNBB" style="height:5.5mm;">
          41          
        </div>
        <div class="styLNAmountBoxNBB" style="height:5.5mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/AlternateIncrementalCredit "/>
          </xsl:call-template>
        </div>
      </div>        
    </div>
  <!--End of Section B-->
  
    
  <!-- Page Break-->
  <!-- Footer-->
  
  <div class="pageEnd" style="width:187mm;padding-top:1mm;">  
    <div style="float:left;">
      <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions. </span> 
    
      <span style="width:110px;"></span>                        
      Cat. No. 13700H 
    </div>
      
    <div style="float:right;">
      <span style="width:80px;"></span>  
      Form <span class="styBoldText">6765</span> (2005)
    </div>    
  </div>
  
  
  <!-- Header -->
    
  <div class="styBB" style="width:187mm;padding-top:.5mm;">  
    <div style="float:left;">Form 6765 (2005)<span style="width:148mm;"></span></div>
    <div style="float:right;">Page <span style="font-weight:bold;font-size:8pt;">2</span></div>  
  </div>  
  
  <!--Begin Page 2 --> 
  

  
  <!-- Begin Section C-->
  <div class="styBB" style="width:187mm;float:none; clear:none;">    
    <div class="styGenericDiv" style="font-size:7pt;font-weight:bold;">Section C&#151;Current Year Credit for Increasing Research Activities      
    </div>    
  </div>  
  
  <div class="styBB" style="width:187mm;">

  <div  style="width:187mm">
    <div class="styLNLeftNumBox" style="height:4mm;">
      42
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      Pass-through research credit(s) from a partnership, S corporation, estate, or trust          
      <span class="styBoldText">
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.                                    
      </span>          
    </div>              
        
    <div class="styLNRightNumBox">
      42          
    </div>
    <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/PassThroughCreditsFromPrtshp"/>
      </xsl:call-template>
    </div>        
  </div>
      
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">
      43
    </div>
    <div class="styLNDesc" style="width:138.75mm;height:4mm;">
      <span class="styBoldText">Current year credit.</span>
      Add line 17
      <span class="styBoldText">or</span>
      line 41 to line 42, and 
      <span class="styBoldText">go to Part II</span>
            
      <span class="styBoldText">
            <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
      <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.
        <span style="width:16px;"></span>.                                                        
      </span>          
    </div>        
    <div class="styLNRightNumBoxNBB" >
      43          
    </div>
    <div class="styLNAmountBoxNBB" style="height:4mm;padding-right:1mm;" >
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form6765Data/CurrentYearCredit"/>
      </xsl:call-template>
    </div>        
  </div>  
   </div>  
 
  
  
  <!-- BEGIN Part II Title -->
  <div class="styBB" style="width:187mm;height:8mm;padding-top:2mm;">
    <div class="styPartName">Part II</div>
    <div class="styPartDesc">Allowable Credit <span class="styNormalText">(See</span> Who must file Form 3800 
       <span class="styNormalText">to find out if you complete Part II or file Form 3800.) </span>
    </div>
  </div>
  <!-- END Part II Title -->
  
  <!-- Begin Allowable Credit-->
  
  <div class="styBB" style="width:187mm;">
      <div style="width:187mm;">
        <div class="styLNLeftNumBox">44</div>
        <div class="styLNDesc">
          Regular tax (see instructions)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.                                    
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.                                    
             </span> 
           </div>
      <div class="styLNRightNumBox" style="width:7.75mm;height:4.5mm;padding-top:0mm;">
         44
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;">
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/RegularTaxBeforeCredits"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox">45</div>
        <div class="styLNDesc">
          Alternative minimum tax (see instructions)
                    <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.            
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span> 
         </div>
       <div class="styLNRightNumBox" style="width:7.75mm;">
          45
        </div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
           <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/AlternativeMinimumTax"/>
          </xsl:call-template>
        </div>
   </div>
         <!-- line 46 -->  
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">46</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 44 and 45
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <div class="styLNRightNumBox" style="width:7.75mm;">    
        46
        </div>
        <div class="styLNAmountBox" style="padding-right:1mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/TaxBeforeCreditsPlusAltMinTax"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">47a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Foreign tax credit
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">47a</div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.5mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Credits from Form 1040, lines 48 through 54
            <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">47b</div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;">
        <!--
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/"/>
          </xsl:call-template>
       -->
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.5mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Possessions tax credit
          (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">47c</div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/PossessionsTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.5mm;">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
        Nonconventional source fuel credit (Form 8907, line 23)
          
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">47d</div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/CreditForNonconventionalFuel"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!--line 47e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.5mm;">e</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
        Other specified credits (see instructions)
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.              
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">47e</div>
        <div class="styLNAmountBox" style="height:4mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/OtherSpecifiedCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
      <!-- line 47f -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.5mm;">f</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add  lines 47a through 47e
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">47f
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/TotalTaxCredit"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">48</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Net income tax.  Subtract line 47f from line 46.  If zero,
          skip lines 49 through 52 and enter -0- on
        </div>
        <div class="styLNRightNumBoxNBB"></div>  
        <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          line 53
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>          
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">48
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">49</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Net regular tax. Subtract line 47f from line 44.  If zero
          or less, enter -0-
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">49</div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/NetRegularTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">50</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Enter 25% (.25) of the excess, if any, of line 49 over
          $25,000 (see instructions)
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:8mm;padding-top:3.5mm">50</div>
        <div class="styLNAmountBox" style="height:8mm;padding-right:1mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/TwentyFivePercentOfExcess"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:8mm;padding-top:3.5mm;border-right-width:1px;"></div>
      </div>
      
            
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">51</div>
        <div class="styLNDesc" style="width:98.25mm;">
          Tentative minimum tax (see instructions)
        
            <!--Dotted Line-->
           
             <span class="styBoldText">            
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
           </span>
        </div>
     
        <div class="styLNRightNumBox">51</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/TentativeMinimumTax"/>
          </xsl:call-template>
        </div>
       <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
     </div>

      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">52</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Enter the greater of line 50 or line 51
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">52</div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/GreaterOfTentMinOrExcessTax"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">53</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Subtract line 52 from line 48.  If zero or less, enter -0-
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.            
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">53</div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/AdjustedNetIncomeTax"/>
          </xsl:call-template>
        </div>        
      </div>      
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">54</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <span class="styBoldText">Credit allowed for the current year. Individuals, estates, and trusts: </span>
          Enter the <span class="styBoldText">smallest</span> of 
          line 43, line 53, or the amount from the formula in the instructions for line 54 here and on Form
          1040, line 55; or Form 1041, Schedule G, line 2c. <span class="styBoldText">Corporations:</span> Enter the <span class="styBoldText">smaller</span> of line 43 or 
          line 53 here and on Form 1120, Schedule J, line 6d; Form 1120-A, Part I, line 2; or the applicable
          line of other returns. If line 54 is smaller than line 43, see instructions
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.                      
          </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:17.5mm;padding-top:0mm">
        <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
          <br/><br/><br/><br/>
        </div>
          54
        </div>
        <div class="styLNAmountBoxNBB" style="height:17.5mm;padding-right:1mm;">
          <br/><br/><br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6765Data/CYTotalCreditAllowed"/>
          </xsl:call-template>
        </div>
      </div>
    </div>

<!-- END Part II  -->

      <!--Footer-->
  
      <div style="width:187mm; text-align:right;padding-top:1mm;">        
        Form <span class="styBoldText">6765</span> (2005)
      </div>

      
      <br class="pageEnd"/>
        
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form6765Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
          <xsl:call-template name="PopulateLeftoverRow">
            <xsl:with-param name="Desc">Line 16 - Reduced Credit Indicator</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form6765Data/RegularCredit/@reducedCreditIndicator"/>
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>
          <xsl:call-template name="PopulateLeftoverRow">
            <xsl:with-param name="Desc">Line 39 - Reduced Credit Indicator</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form6765Data/AlternateIncrementalCredit/@reducedCreditIndicator"/>
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>
        </table>
      <!-- END Left Over Table -->  
        
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
