<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" >
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8271Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8271Data" select="$RtnDoc/IRS8271" />

<xsl:template match="/">

<html xmlns="http://www.irs.gov/efile" xmlns:efile="http://www.irs.gov/efile">
<head>
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8271Data)"></xsl:with-param></xsl:call-template></title>
  <meta http-equiv="Pragma" content="no-cache"/>
  <meta http-equiv="Cache-Control" content="no-cache"/>
  <meta http-equiv="Expires" content="0"/>
  <meta http-equiv="Cache-Control" content="private"/>
  <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
  <meta name="Description" content="IRS Form 8271"/>
  <META name="GENERATOR" content="IBM WebSphere Studio"/>  
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>
  <style type="text/css">
    <xsl:if test="not($Print) or $Print=''">
      <xsl:call-template name="IRS8271Style"></xsl:call-template>    
      <xsl:call-template name="AddOnStyle"></xsl:call-template>    
    </xsl:if>
  </style>
<xsl:call-template name="GlobalStylesForm"/>
</head>

<!-- Added table header tags <thead>, <tfoot> and <tbody> tags to table on Jan 29, 2004-->

<body class="styBodyClass">
<form name="Form8271">
<xsl:call-template name="DocumentHeader"></xsl:call-template>

<div style="width:187mm;">
  <div class="styFNBox" style="width:27mm;height:20mm;">
      <span>
        Form </span>
     <!-- <span style="width:18.5mm;font-weight:bold;font-size:15pt;">8271</span>-->
     
     <span class="styFormNumber">8271</span> 
     
      <span style="width:26mm;padding-top:0.2mm;padding-bottom:1mm;font-size:6pt">(Rev. December 2005)</span>
      <span class="styAgency" style="text-align:left;width:25mm;">Department of the Treasury</span>
      <span class="styAgency" style="width:24mm;">Internal Revenue Service</span>
  </div>
  <div class="styFTBox" style="width:127mm;">
<!--    <span style="font-size: 11pt;"><b>Investor Reporting of Tax Shelter Registration Number</b></span>    -->

	<span class="styMainTitle">Investor Reporting of Tax Shelter Registration Number </span>
	<br/>
    <span class="styFBT" style="padding-bottom:1mm;"><img src="{$ImagePath}/8271_Bullet.gif" alt="Right pointing large arrowhead image" width="8"/> Attach to your tax return.</span>
    <br/><br/>
    <span style="width:127mm;height:3mm;"></span>
      <span class="styFBT" style="margin-top:none;">
      <img src="{$ImagePath}/8271_Bullet.gif" alt="Right pointing large arrowhead image" width="8"/>
        If you received this form from a partnership, S corporation, or trust, see the instructions.
    </span>
  </div>
  <div class="styTYBox" style="width:32mm;text-align:left;height:20mm;">
      <span class="styBB" style="width:30mm;padding-top:3mm;padding-bottom:2mm;font-size:7pt;">
        <span style="margin-left:1mm;">OMB No. 1545-0881</span>
      </span><br/>
        <span style="width:30mm;padding-top:1mm;margin-left:1mm;">Attachment</span>
          <span style="width:30mm;margin-left:1mm;">Sequence No. 
        <span style="font-weight:bold;font-size:8pt;">71</span>
      </span>
  </div>
</div>
<div class="styBB" style="width:187mm;border-top-width:1px;">
  <div class="styNameBox" style="font-size:7pt;width:110mm;height:10.5mm;">
      <span style="font-size:7pt;">Investor's name(s) shown on return</span><br/>
    <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
    <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
  </div>
  <div class="styNameBox" style="font-size:7pt;width:44.25mm;height:10.5mm;padding-left:1.5mm">
    <span style="font-size:7pt;">Investor's identifying number</span><br/><br/>
    <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
  </div>
  <div class="styEINBox" style="font-size:7pt;text-align:center;font-weight:normal;width:30mm;height:10.5mm;padding-left:1.5mm">
    <span style="font-size:6pt;">Investor's tax year ended</span><br/><br/>
    <span style="width:30mm;text-align:center">
      <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$Form8271Data/InvestorsTaxYearEnded" />
      </xsl:call-template>
    </span>
  </div>
</div>

<div class="styBB" style="width:187mm;clear:both;float:none;">
<!-- Table expand/collapse button -->
  <span class="styGenericDiv" style="float:right;clear:none;width:7mm;text-align:right;">
     <xsl:call-template name="SetDynamicTableToggleButton">
      <xsl:with-param name="TargetNode" select="$Form8271Data/InvestorReportingInfo"/>
        <xsl:with-param name="containerHeight" select="10"/>
        <xsl:with-param name="headerHeight" select="1"/>
      <xsl:with-param name="containerID" select=" 'TPctn' "/>
     </xsl:call-template>       
  </span>
</div>

<div class="styTableContainerNBB" id="TPctn">
<!-- Show table in expanded form-->
<xsl:call-template name="SetInitialState"/>
<!-- end -->  
  <table cellspacing="0" summary="Investor Reporting of Tax Shelter Registration Number" style="border-bottom: 0px;">
  <thead class="styTableThead">
    <tr>
      <th colspan="2" class="styTableCell" style="width: 110mm; height:8mm;text-align:center;font-size:7pt;font-weight:normal;border-color:black;">
        <span style="width: 90mm;"><span style="font-weight:bold;">(a)</span> Tax Shelter Name</span>
      </th>
      <th class="styTableCell" style="width: 44mm; height:8mm;text-align:center;font-size:7pt;font-weight:normal;border-color:black;">
          <span style="font-weight:bold;">(b)</span> Tax Shelter Registration<br/> Number (11-digit number)
      </th>
      <th class="styTableCell" style="width: 33mm; height:8mm;text-align:center;font-size:7pt;font-weight:normal;border-color:black;border-right:none;">
        <!--<span style="width:35mm;text-align:center;">-->
            <span style="font-weight:bold;">(c)</span> Tax Shelter<br/>Identifying Number
         <!--</span>-->
      </th>
    </tr>
  </thead>
  <tfoot></tfoot>
  <tbody>
<xsl:if test="($Print != $Separated) or (count($Form8271Data/InvestorReportingInfo) &lt;= 10) "> 
  <xsl:for-each select="$Form8271Data/InvestorReportingInfo">
    <tr>
      <td class="styTableCell" style="width: 7mm; text-align:center;font-size:7pt;border-color:black;">
        <span style="float:center;font-weight:bold;">
          <xsl:if test="position() &lt;=10">
            <xsl:number value="position()" format="1" />
          </xsl:if>
        </span><span class="styTableCellPad"></span>          
      </td>
      <td class="styTableCell" style="width: 103mm; text-align:left;font-size:7pt;border-color:black;padding-left:1mm;">
        <span style="float:left;">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TaxShelterName/BusinessNameLine1" />
            </xsl:call-template>
          <xsl:if test="TaxShelterName/BusinessNameLine2">
            <br/>
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TaxShelterName/BusinessNameLine2" />
            </xsl:call-template>  
          </xsl:if>
        </span>          
      </td>        
      <td class="styTableCell" style="width: 39mm; text-align:left;font-size:7pt;border-color:black;padding-left:1mm;">
        <span style="width:10mm;"/>
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="TaxShelterRegistrationNumber" />
          </xsl:call-template><br/>
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfPersonWhoApplied/BusinessNameLine1" />
            </xsl:call-template>
          <xsl:if test="NameOfPersonWhoApplied/BusinessNameLine2">
            <br/>
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfPersonWhoApplied/BusinessNameLine2" />
            </xsl:call-template>  
          </xsl:if>
      </td>
      <td class="styTableCell" style="width: 37mm; text-align:center;font-size:7pt;border-color:black;border-right:none;">
        <xsl:choose>
          <xsl:when test="TaxShelterSSN">
            <xsl:call-template name="PopulateSSN">
              <xsl:with-param name="TargetNode" select="TaxShelterSSN" />
            </xsl:call-template>          
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name="PopulateEIN">
              <xsl:with-param name="TargetNode" select="TaxShelterEIN" />
            </xsl:call-template>        
          </xsl:otherwise>      
        </xsl:choose>
      </td>
    </tr>
    </xsl:for-each>
  </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 1 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr rowheight="5">
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">1<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;font-size:7pt;text-align:left;">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form8271Data/InvestorReportingInfo"/>                      
                  </xsl:call-template>
      <span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 2 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">2<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 3 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">3<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 4 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">4<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 5 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">5<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>  
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 6 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">6<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>  
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 7 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">7<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 8 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">8<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 9 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">9<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form8271Data/InvestorReportingInfo) &lt; 10 or ((count($Form8271Data/InvestorReportingInfo) &gt; 10) and ($Print = $Separated))">
    <tr>
      <td class="styTableCell" style="height:10mm;width:7mm;text-align:center;font-weight:bold;font-size:7pt;border-color:black;">10<span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:103mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:40mm;border-color:black;"><span class="styTableCellPad"></span></td>
      <td class="styTableCell" style="width:37mm;border-color:black;border-right:none;"><span class="styTableCellPad"></span></td>
    </tr>
    </xsl:if>
    </tbody>                                                        
  </table>
  </div>  
   <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$Form8271Data/InvestorReportingInfo"/>
      <xsl:with-param name="containerHeight" select="10"/>
        <xsl:with-param name="headerHeight" select="1"/>
    <xsl:with-param name="containerID" select=" 'TPctn' "/>
   </xsl:call-template>

<div style="width:187mm;clear:both;">
	<div style="width:100mm;font-weight:bold;" class="styGenericDiv">For Paperwork Reduction Act Notice, see page 2</div>
	<div style="width:45mm;text-align:center;" class="styGenericDiv">Cat. No. 61924F</div>
	<div style = "float:right;" class="styGenericDiv">Form <span class="styBoldText">8271</span> (Rev. 12-2005)</div>
</div>
<!-- Left over data -->
  <br/>
  <br class="pageEnd"/>
  
  <!-- BEGIN Left Over Table -->  
    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" TabIndex="1" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>  

    <!-- Additional Data Table -->
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form8271Data" />
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
    </table>
      <!-- END Left Over Table -->  
    <!-- Begin Separated Repeating Data Table -->
    <xsl:if test="($Print = $Separated) and (count($Form8271Data/InvestorReportingInfo) &gt; 10)">
      <span class="styRepeatingDataTitle">Form 8271 - Investor Reporting of Tax Shelter Registration Number Information:</span>
      <table cellspacing="0" summary="Investor Reporting of Tax Shelter Registration Number" style="font-size:7pt;" class="styDepTbl">
  <thead class="styTableThead">
    <tr class="styDepTblHdr">
      <th colspan="2" class="styDepTblCell" style="width: 110mm; height:8mm;">
        <span style="width: 90mm;"><span style="font-weight:bold;">(a)</span> Tax Shelter Name</span>
      </th>
      <th class="styDepTblCell" style="width: 44mm; height:8mm;">
          <span style="font-weight:bold;">(b)</span> Tax Shelter Registration<br/> Number (11-digit number)
      </th>
      <th class="styDepTblCell" style="width: 33mm; height:8mm;">
            <span style="font-weight:bold;">(c)</span> Tax Shelter<br/>Identifying Number
      </th>
    </tr>
  </thead>
  <tfoot></tfoot>
  <tbody>
  <xsl:for-each select="$Form8271Data/InvestorReportingInfo">
    <tr>
      <xsl:attribute name="class">
        <xsl:choose>
           <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
           <xsl:otherwise>styDepTblRow2</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <td class="styDepTblCell" style="width: 7mm; ">
        <span style="float:center;font-weight:bold;">
          <xsl:number value="position()" format="1" />
        </span><span class="styTableCellPad"></span>          
      </td>
      <td class="styDepTblCell" style="width: 103mm; text-align:left;">
        <span style="float:left;">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TaxShelterName/BusinessNameLine1" />
            </xsl:call-template>
          <xsl:if test="TaxShelterName/BusinessNameLine2">
            <br/>
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="TaxShelterName/BusinessNameLine2" />
            </xsl:call-template>  
          </xsl:if>
        </span>          
      </td>        
      <td class="styDepTblCell" style="width: 39mm; text-align:center;">
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="TaxShelterRegistrationNumber" />
          </xsl:call-template>
      </td>
      <td class="styTableCell" style="width: 37mm; text-align:center;font-size:7pt;border-color:black;border-right:none;">
        <xsl:choose>
          <xsl:when test="TaxShelterSSN">
            <xsl:call-template name="PopulateSSN">
              <xsl:with-param name="TargetNode" select="TaxShelterSSN" />
            </xsl:call-template>          
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name="PopulateEIN">
              <xsl:with-param name="TargetNode" select="TaxShelterEIN" />
            </xsl:call-template>        
          </xsl:otherwise>      
        </xsl:choose>
      </td>
    </tr>
    </xsl:for-each>
    </tbody>                                                        
  </table>
</xsl:if>
  </form>
</body>
</html>
  </xsl:template>
</xsl:stylesheet>
