<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8832Style.xsl"/>



<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8832Data" select="$RtnDoc/IRS8832" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8832Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 8832" />
      
      
      
      <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
      <xsl:call-template name="InitJS"></xsl:call-template>
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 8832 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS8832Style"></xsl:call-template>  
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>
    </style>
  <xsl:call-template name="GlobalStylesForm"/>
</head>
  <body class="styBodyClass">
    <form name="Form8832">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>
      
      <!-- Begin Form Number and Name -->
      <div class="styTBB" style="width:187mm;height:20mm;">
        <div class="styFNBox" style="width:32mm;height:20mm;">
          <div style="height:13mm;">
            Form<span class="styFormNumber" >8832</span><br/>
            (Rev. January 2006)
          </div>
          <div style="height:7mm" >
            <span class="styAgency">Department of the Treasury</span><br/>
            <span class="styAgency">Internal Revenue Service</span>
          </div>        
        </div>    
        <div class="styFTBox" style="width:125mm;height:20mm;padding-top:9mm;">
          <div class="styMainTitle">Entity Classification Election </div>          
        </div>
        <div class="styTYBox" style="width:30mm;height:20mm;padding-top:9mm;">        
            OMB No. 1545-1516        
        </div>
      </div>
      
<!-- End Form Number and Name section -->
      
      
      <div class="styBB" style="width:187mm;">
        <div class="styUseLbl" style="width:10mm;height:32mm; text-align:center;padding-top:9.5mm;font-size:7pt;">Type or Print</div>
        <div class="styNameAddr" style="width:132mm;height:9.7mm;font-size:7pt;">
          Name of entity<br/>
          
<!--<span class = "stysmalltext"> -->
          <div style="font-family:verdana;font-size:6pt;height:6.25mm">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="$Form8832Data/EntityName/BusinessNameLine1" />
            </xsl:call-template><br/>  
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="$Form8832Data/EntityName/BusinessNameLine2" />
            </xsl:call-template>
          <!--</span> -->   
           </div>         
        </div>        
        
        <div class="styLNAmountBox" style="width:45mm;height: 9.7mm;font-size:7pt; text-align:left; padding-top: 1.8mm;">
          <span style="width: 1mm;" /><b>EIN</b><span style="width: 1mm;" /><img src="{$ImagePath}/8832_Bullet_Sm.gif" alt="Bullet Image" />          
          <span style="width:25mm; text-align: center;">
            <!-- If EntityEIN -->
            <xsl:if test="not($Form8832Data/EntityEIN='' or not($Form8832Data/EntityEIN))">
              <xsl:call-template name="PopulateEIN">
                <xsl:with-param name="TargetNode" select="$Form8832Data/EntityEIN" />
              </xsl:call-template>
            </xsl:if>
            <!-- Else EntityEINMissingReason -->
            <xsl:if test="not($Form8832Data/EntityEINMissingReason='' or not($Form8832Data/EntityEINMissingReason))">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form8832Data/EntityEINMissingReason" />
              </xsl:call-template>
            </xsl:if>
          </span>                
        </div>      
                    
        <div class="styNameAddr" style="width:177mm;height:8mm;font-size:7pt;">
          Number, street, and room or suite no. If a P.O. box, see instructions.<br/>
          <xsl:choose> 
                       <xsl:when test="$Form8832Data/EntityForeignAddress"> 
              <!--<span class = "stysmalltext"> -->
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityForeignAddress/AddressLine1" />
                </xsl:call-template><br/>
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityForeignAddress/AddressLine2" />
                </xsl:call-template>
              <!--</span> -->
            </xsl:when>         
                    <xsl:otherwise> 
                <!--<span class = "stysmalltext"> -->
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityDomesticAddress/AddressLine1" />
                </xsl:call-template><br/>
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityDomesticAddress/AddressLine2" />
                </xsl:call-template>
                <!--</span> -->
                    </xsl:otherwise> 
                  </xsl:choose>                               
        </div>
                      
        <div class="styNumberBox" style="height:8mm;font-size:7pt;">
          City or town,<span style="width:2px;"></span> state,<span style="width:2px;"></span> and<span style="width:2px;"></span> ZIP code.<span style="width:2px;"></span> If a
          foreign address, enter city, province or state, postal code and country.
          <br/>                    
          <xsl:choose> 
          <xsl:when test="$Form8832Data/EntityForeignAddress">               
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityForeignAddress/City" />
                </xsl:call-template>
                <xsl:if test="$Form8832Data/EntityForeignAddress/City != '' and $Form8832Data/EntityForeignAddress/ProvinceOrState != ''">,
                  <span style="width:2px;"></span>
                </xsl:if>                            
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityForeignAddress/ProvinceOrState" />
                </xsl:call-template>
                <span style="width:7px"></span>                
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityForeignAddress/PostalCode" />
                </xsl:call-template><br/>                
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityForeignAddress/Country" />
                </xsl:call-template>
                
          </xsl:when>         
          <xsl:otherwise> 
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityDomesticAddress/City" />
                </xsl:call-template>
                <xsl:if test="$Form8832Data/EntityDomesticAddress/City != '' and $Form8832Data/EntityDomesticAddress/State != ''">,
                  <span style="width:2px;"></span>
                </xsl:if>
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityDomesticAddress/State" />
                </xsl:call-template>
                <span style="width:7px"></span> 
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/EntityDomesticAddress/ZIPCode" />
                </xsl:call-template>
          </xsl:otherwise> 
          </xsl:choose> 

        </div>      
      </div>
      <div style="width:187mm;"> </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">1</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <span class="styBoldText">Type of election</span> (see instructions):    
        </div>
      </div>
      
<!-- start line 1a -->        
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">a</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
           <input type="checkbox" class="styCkbox" name="Checkbox">
             <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/InitialClassification" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/InitialClassification" />
             </xsl:call-template> 
             Initial classification by a newly-formed entity. 
           </label>       
        </div>
      </div>

<!-- end line 1a -->

<!-- start line 1b -->

      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">b</div>
        <div class="styLNDesc" style="width:158mm;height:4.5mm;">
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               ChangeInCurrentClassification" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               ChangeInCurrentClassification" />
             </xsl:call-template> 
             Change in current classification.
           </label>
        </div>  
      </div>

<!-- end line 1b --> 

<!-- start line 2a -->

      <div style="width:187mm;"> </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">2</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <span class="styBoldText">Form of entity</span> (see instructions):    
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">a</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               DomAssocTaxableAsACorporation" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               DomAssocTaxableAsACorporation" />
             </xsl:call-template> 
             A domestic eligible entity electing to be classified as an association taxable as a corporation.
           </label>
        </div>  
      </div>
      
<!-- end line 2a -->

<!-- start line 2b --> 

      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">b</div>
        <div class="styLNDesc" style="width:158mm;height:4.5mm;">
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               DomesticEntityAsAPartnership" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               DomesticEntityAsAPartnership" />
             </xsl:call-template> 
             A domestic eligible entity electing to be classified as a partnership.
           </label>
        </div>  
      </div>

<!-- end line 2b -->

<!-- start line 2c -->

      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">c</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               DomSnglOwnerDisregardedSepEnt" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               DomSnglOwnerDisregardedSepEnt" />
             </xsl:call-template> 
             A domestic eligible entity with a single owner electing to be disregarded as a separate entity.
           </label>
        </div>  
      </div>
      
<!-- end line 2c -->

<!-- start line 2d -->
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">d</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               FrgnAssocTaxableAsACorporation" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               FrgnAssocTaxableAsACorporation" />
             </xsl:call-template> 
             A foreign eligible entity electing to be classified as an association taxable as a corporation.
           </label>
              
        </div>  
      </div>
      
<!-- end line 2d -->

<!-- start line 2e -->
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">e</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               ForeignEntityAsAPartnership" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               ForeignEntityAsAPartnership" />
             </xsl:call-template> 
             A foreign eligible entity electing to be classified as a partnership.
           </label>
        </div>  
      </div>
      
<!-- end line 2e --> 

<!-- start line 2f -->
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">f</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateCheckbox">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               FrgnSnglOwnerDisregardedSepEnt" />
             </xsl:call-template>
           </input>
           <span style="width:8px"></span>
           <label>
             <xsl:call-template name="PopulateLabel">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               FrgnSnglOwnerDisregardedSepEnt" />
             </xsl:call-template> 
             A foreign eligible entity with a single owner electing to be disregarded as a separate entity.
           </label>
        </div>  
      </div>
      
<!-- end line 2f -->

<!-- start line 3 -->      
      
      <div style="width:187mm;"> </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">3</div>
        <div class="styLNDesc" style="width:178mm;height:4.5mm;">
          <span class="styBoldText">Disregarded entity information</span> (see instructions):    
        </div>
      </div>

<!-- end line 3 -->

<!-- start line 3a -->      
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">a</div>
        <div class="styLNDesc" style="width:30mm;height:4.5mm;">
          Name of owner <img src="{$ImagePath}/8832_Bullet_Lg.gif"  alt="Bullet Image"/>              
        </div>        
        <div class="styFixedUnderline" style ="width:120mm;">        
          <div style="font-family:verdana;font-size:6pt;">        
             <xsl:call-template name="PopulateText">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               NameOfOwner/BusinessNameLine1" />
            </xsl:call-template>
            <span style="width:16px;"></span>
            <xsl:call-template name="PopulateText">
               <xsl:with-param name="TargetNode" select="$Form8832Data/
               NameOfOwner/BusinessNameLine2" />
            </xsl:call-template>  
          </div>                    
        </div>        
      </div>

<!-- end line 3a -->

<!-- start line 3b -->      
      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">b</div>
        <div class="styLNDesc" style="width:40mm;height:4.5mm;">
          Identifying number of owner <img src="{$ImagePath}/8832_Bullet_Lg.gif" alt="Bullet Image"/>              
        </div>        
        <span class="styFixedUnderline" style ="width:110mm; height: 4.5mm;">
          
          <xsl:choose> 
              <xsl:when test="$Form8832Data/OwnerEIN"> 
                  <xsl:call-template name="PopulateEIN">
                  <xsl:with-param name="TargetNode" select="$Form8832Data/OwnerEIN"/>
                  </xsl:call-template>
             </xsl:when> 
             <xsl:when test="$Form8832Data/OwnerSSN"> 
                <xsl:call-template name="PopulateSSN">
                <xsl:with-param name="TargetNode" select="$Form8832Data/OwnerSSN"/>
                </xsl:call-template>
              </xsl:when> 
              <xsl:when test="$Form8832Data/OwnerNONE"> 
                <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form8832Data/OwnerNONE"/>
                </xsl:call-template>
              </xsl:when> 
           </xsl:choose>      
 
         
      
        </span>        
      </div>
      
<!-- end line 3b -->

<!-- start line 3c --> 
     
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">c</div>
        <div class="styLNDesc" style="width:100mm;height:4.5mm;">
          Country of organization of entity electing to be disregarded (if foreign) <img src="{$ImagePath}/8832_Bullet_Lg.gif"  alt="Bullet Image"/>              
        </div>        
        <div class="styFixedUnderline" style ="width:60mm;">
          
        <!--  <xsl:if test="$Form8832Data/EntityForeignAddress"> -->
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="$Form8832Data/
              CountryOfOrgToBeDisregarded" />
            </xsl:call-template>
      <!--    </xsl:if> -->
      
        </div>        
      </div>
      
<!-- end line 3c -->

<!-- start line 4 -->
      
      <div style="width:187mm;"> </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">4</div>
        <div class="styLNDesc" style="width:148mm;height:4.5mm;">          
          Election is to be effective beginning (month, day, year) (see instructions)
          <!--Dotted Line-->
          <span class="styBoldText" style="width:180px;">
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>
            <span style="width:16px;">.</span>      
            <span style="width:16px;">.</span>            
          </span>      
          
          <img src="{$ImagePath}/8832_Bullet_Lg.gif" alt="Bullet Image"/>
        </div>
        <div class="styFixedUnderline" style ="width:30mm;text-align:center;">
          <xsl:call-template name="PopulateMonthDayYear">
            <xsl:with-param name="TargetNode" select="$Form8832Data/ElectionEffectiveDate" />
          </xsl:call-template>
        </div>
        <div style="width:4mm;float:left;Clear:none;"></div>        
      </div>      

<!-- end line 4 -->

<!-- start line 5 -->
      
      <div class="styTBB"  style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">5</div>        
        <div class="styLNDesc" style="width:108mm;height:7mm;font-size:7pt;">
          Name and title of person whom the IRS may call for more information
          <br/><br/>  
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form8832Data/
            PersonNameIRSMayCallForInfo" />
          </xsl:call-template>  
          <span style="width:8px;"></span> 
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form8832Data/
            PersonTitleIRSMayCallForInfo" />
          </xsl:call-template>        
        </div>        
<!-- end line 5 -->

<!-- start line 6 -->
        
        <div class="styLNAmountBox" style="border-bottom:0px;width:70mm;height:8mm;font-size:6pt; text-align:left;">
          <div class="styLNLeftNumBox" style="width:50mm;height:4.5mm;">
          <span class="styBoldText">6</span>
          <span style="font-size:7pt; font-weight:normal; ">                  
            <span style="width:8px;"></span>That  person's telephone number
            <br/><br/>
            <span style="width:50mm; text-align:left;">
              <span style="width:15px;"></span>
              <xsl:choose>
                <xsl:when test="$Form8832Data/PhoneOfPersonIRSMayCallForInfo">
                  <xsl:call-template name="PopulatePhoneNumber">
                    <xsl:with-param name="TargetNode" select="$Form8832Data/
                    PhoneOfPersonIRSMayCallForInfo" />
                  </xsl:call-template>  
                </xsl:when>
                <xsl:otherwise>
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="$Form8832Data/
                    ForeignPhoneOfPersonIRSMayCall" />
                  </xsl:call-template>  
                </xsl:otherwise>
              </xsl:choose>
            </span>              
          </span>
          </div>
        </div>
      </div>

<!-- end line 6 -->
      
<!-- Begin signature part -->
          
      <div class="styBB" style="width:187mm;">
        <div class="styLNDesc" style="width:187mm;height:4.5mm;text-align:center;font-size:9pt;">
          <br/>
          <span class="styBoldText">
            Consent Statement and Signature(s) (see instructions)                      
          </span>
          <div style="width:187mm;"><br/> </div>                        
        </div>        
      </div>
      
      <div class="styForm8832SignatureText" style="width:187mm">
        <br/>
        Under penalties of perjury, I (we) declare that I (we) consent to the election of the 
        above-named entity to be classified as indicated above, and that I (we) have examined this
        consent statement, and to the best of my (our) knowledge and belief, it is true, correct, and 
        complete.  If I am an officer, manager, or member signing for all members of the entity, I 
        further declare that I am authorized to execute this consent statement on their behalf.        
      </div>      
      <div style="width:187mm;"><br/> </div>
      <div style="width:187mm;"><br/> </div>
      <div style="width:187mm;">
        <span class="styBoldText" style="width:260px; text-align:center">          
          Signature(s)        
        </span>
        <span class="styBoldText" style="width:160px;text-align:center">
          Date        
        </span>
        <span class="styBoldText" style="width:260px;text-align:center">
          Title        
        </span>        
      </div>
      <div class="styBB" style="width:187mm;border-top-width:1px;border-bottom-width:0px;">
        <div style="width:187mm;">
          <table cellspacing="0"  class="TableContainer" style="width:187mm;" summary="Table for Signatures">          
            <tr>
              <td class="styTableCell" scope="row" style="width:72mm;text-align:left;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:43mm;text-align:center;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:72mm;text-align:center;font-weight:bold;border-color:black;border-right:none;"><div style="width:20mm;"> </div></td>
            </tr>
            <tr>
              <td class="styTableCell" scope="row" style="width:72mm;text-align:left;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:43mm;text-align:center;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:72mm;text-align:center;font-weight:bold;border-color:black;border-right:none;"><div style="width:20mm;"> </div></td>
            </tr>
            <tr>
              <td class="styTableCell" scope="row" style="width:72mm;text-align:left;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:43mm;text-align:center;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:72mm;text-align:center;font-weight:bold;border-color:black;border-right:none;"><div style="width:20mm;"> </div></td>
            </tr>
            <tr>
              <td class="styTableCell" scope="row" style="width:72mm;text-align:left;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:43mm;text-align:center;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:72mm;text-align:center;font-weight:bold;border-color:black;border-right:none;"><div style="width:20mm;"> </div></td>
            </tr>
            <tr>
              <td class="styTableCell" scope="row" style="width:72mm;text-align:left;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:43mm;text-align:center;font-weight:bold;border-color:black;"><div style="width:20mm;"> </div></td>
              <td class="styTableCell" style="width:72mm;text-align:center;font-weight:bold;border-color:black;border-right:none;"><div style="width:20mm;"> </div></td>
            </tr>            
          </table>
        </div>
      </div>            
      
      <!-- End signature part -->

      <div style="width:187mm;">
        <span class="styBoldText">For Paperwork Reduction Act Notice, see page 4. </span>         
        <span style="width:144px;"></span>        
        Cat. No. 22598R 
        <span style="width:88px;"></span>        
        Form <span class="styBoldText">8832</span> (Rev. 1-2006)
      </div>
            
      <!-- End signature part -->
      
        <br/>
        <br class="pageEnd"/>
        
<!-- BEGIN Left Over Table -->  
<!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form8832Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
<!-- END Left Over Table -->              
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
