<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="IRS8834Style.xsl"/>
<xsl:include href="AddOnTable.xsl"/>

<xsl:output method="html" indent="yes" encoding="iso-8859-1"/>

<xsl:strip-space elements="*" />
<xsl:param name="FormData" select="$RtnDoc/IRS8834" />


<xsl:template match="/">
<html>
<head>  
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache"/>
  <meta http-equiv="Cache-Control" content="no-cache"/>
  <meta http-equiv="Expires" content="0"/>
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private"/>  
  <meta name="Description" content="Form IRS 8834"/>
  <meta name="GENERATOR" content="IBM WebSphere Studio"/>
   <xsl:call-template name="GlobalStylesForm"/>
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>  
  <style type="text/css">  

    <xsl:if test="not($Print) or $Print=''"> 

      <xsl:call-template name="IRS8834Style"></xsl:call-template>
      <xsl:call-template name="AddOnStyle"></xsl:call-template>  

    </xsl:if>

  </style>      
  
</head>

<body class="styBodyClass">
  <form name="Form8834">    
    <xsl:call-template name="DocumentHeader"></xsl:call-template>  
    
  <!--Title of Form -->    
  <div class="styBB" style="width:187mm;height: 20mm">
    <div class="styFNBox" style="width:31mm;font-size: 7pt;height: 22mm">
      Form <span class="styFormNumber">8834</span>      
      <br/>
      <br/>
      <br/>
      <span class="styAgency">Department of the Treasury</span><br /><span class="styAgency">Internal Revenue Service</span>
    </div>
    <div class="styFTBox" style="height: 22mm;width:125mm">
      <div class="styMainTitle" style="height: 8mm">Qualified Electric Vehicle Credit</div>
      <div class="styFST" style="font-size:7pt;margin-left:3mm;font-weight:bold"><br/>
        <div style="margin-left: 1.5mm; padding-top:1mm">
          <img src="{$ImagePath}/8834_Bullet.gif" alt="MediumBullet"/>  
          Attach to your tax return.
        </div>
        <div style="padding-top:1.5mm">
          <img src="{$ImagePath}/8834_Bullet.gif" alt="MediumBullet"/>  
          See instructions on back.
        </div>
      </div>
    </div>
    <div class="styTYBox" style="width:30mm;height:22mm; border-left-width: 1px">
      <div class="styOMB" style="height:2mm;">OMB No. 1545-1374</div>
      <div class="styTY" style="height:10mm">20<span class="styTYColor">05</span></div>
      <div class="stySequence">Attachment<br/>Sequence No. <b>111</b></div>
    </div>
  </div>
  <!--  End title of Form  -->
    
  <!--  Name and Employer identification number  -->
  <div class="styBB" style="width:187mm">
    <div class="styNameBox" style="width:141mm;font-size:7pt;">
      Name(s) shown on return<br/>
     <div style="font-family:verdana;font-size:6pt;height:6mm">
       <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
       <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
     </div>
    </div>
    
    <div class="styEINBox" style=" padding-left:2mm; font-size:7pt;"><span class="BoldText">Identifying number</span>
      <div style="text-align:left;font-weight:normal; ">
      <br/>  
        <xsl:choose>
          <xsl:when test="normalize-space($FormData/IdentifyingNumber) != ''">
            <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" select="$FormData/IdentifyingNumber" /></xsl:call-template>
          </xsl:when>  
          <xsl:otherwise>  
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>  
          </xsl:otherwise>
        </xsl:choose>
      </div>    
    </div>
  </div>  
  <!--  End Name and Employer indentification number  -->
  
  <!--  Part I -->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part I</div>
    <div class="styPartDesc">Tentative Credit</div>
  </div>
  <!--  End Part I -->
  <xsl:if test="($Print != $Separated) or (count($FormData/TentativeCredit) &lt;= 3)">
 <xsl:for-each select="$FormData/TentativeCredit">
  <xsl:variable name="pos" select="position()"/>
 <xsl:if test="(position() mod 3)=1">
 <div class="styIRS8834TableContainer" id="Spcctn">
   <!--print logic-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
   <table class="styTable" cellspacing="0" style="font-size: 7pt">
     <thead class="styTableThead">
    <tr style="height: 8mm">

    <th style="width:6mm;"></th>
      <th class="styTableCell" colspan="2" style="width: 83mm; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px; text-align: left">        
        <span class="styNormalText" style="font-size:6pt;">
          Use a separate column for each vehicle. If you need more columns, use<br/>additional Forms 8834 and include the total on line 8.
        </span>
      </th>
        <th class="styTableCell" style="width: 32mm;border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:0px; text-align: center">(<xsl:number value="($pos)" format="a"/>)</th>
        <th class="styTableCell" style="width: 32mm;border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:0px; text-align: center">(<xsl:number value="($pos + 1)" format="a"/>)</th>
        <th class="styTableCell" style="width: 32mm;border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px; text-align: center">(<xsl:number value="($pos + 2)" format="a"/>)</th>
      </tr>
    </thead>
    <tfoot/>
    <tbody>

      <!--  Line 1   -->
      <tr>
      <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">1
      </td>
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
 Enter date vehicle placed in service (MM/DD/YYYY)
        </td>
        <td class="styLNRightNumBox" style="border-top-width: 1px">1</td>
        <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 1px; border-bottom-width:1px; text-align: center">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateMonthDayYear">
            <xsl:with-param name="TargetNode" select="DateVehiclePlacedInService"/>
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 1px; border-bottom-width:1px; text-align: center">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateMonthDayYear">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/DateVehiclePlacedInService" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 1px; border-bottom-width:1px; text-align: center">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateMonthDayYear">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/DateVehiclePlacedInService" />
          </xsl:call-template>
        </td>
        </tr>
        
           <!-- Line 2  -->
      <tr style="font-size: 7pt">
      <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">2
      </td> 
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
    Cost of vehicle
  <b>
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
               <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
    </b>
  
         </td>
         <td class="styLNRightNumBox">2</td>
        <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: right">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="CostOfVehicle" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: right">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/CostOfVehicle" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px; text-align: right">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/CostOfVehicle" />
          </xsl:call-template>
        </td>
        </tr>
        
        <!-- Line 3  -->
     <tr>
         <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">3
        </td> 
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
                Section 179 expense deduction (see instructions)
              <b>
                <span class="styNBSP"></span>.
              </b>
             
         </td>
         <td class="styLNRightNumBox" style="border-bottom-width: 1px">3</td>
        <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="Section179ExpenseDeduction" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/Section179ExpenseDeduction" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px;">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/Section179ExpenseDeduction" />
          </xsl:call-template>
        </td>
        </tr>
      <!--  Line 4   -->
      <tr>
       <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">4
      </td> 
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
        
          Subtract line 3 from line 2
            <b>
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
               <span class="styNBSP"></span>.
            </b>
        </td>
        <td class="styLNRightNumBox">4</td>
        <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="CostOfVehicleMinusSect179Expns" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/CostOfVehicleMinusSect179Expns" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/CostOfVehicleMinusSect179Expns" />
          </xsl:call-template>
        </td>
        </tr>
         <!-- Line 5  -->
        <tr>
      <td  class="styBoldText" style="padding-left: 2mm;width:6mm;" valign="top">5</td>
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
          For a vehicle placed in service before 2006, multiply <br/>
          line 4 by 10% (.10). For a vehicle placed in service <br/>
          in 2006, multiply line 4 by 2.5% (.025) (see instructions).
        </td>
         <td class="styLNRightNumBox">5</td>
        <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;" valign="bottom">
          <span class="styTableCellPad"></span>
	            <xsl:call-template name="PopulateAmount">
		            <xsl:with-param name="TargetNode" select="MultiplyCostByAppropriatePct" />
		          </xsl:call-template>      
       </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;" valign="bottom">
          <span class="styTableCellPad"></span>
	               <xsl:call-template name="PopulateAmount">
		            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/MultiplyCostByAppropriatePct" />
		          </xsl:call-template>      
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px" valign="bottom">
          <span class="styTableCellPad"></span>
			    <xsl:call-template name="PopulateAmount">
		            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/MultiplyCostByAppropriatePct" />
		          </xsl:call-template>      
        </td>
        </tr> 
       
       <!-- Line 6  -->
      <tr>
      <td  class="styBoldText" style="padding-left: 2mm;width:6mm;" valign="top">6</td>
        <td class="styTableCell" style="width:75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px;">
        Maximum credit per vehicle. For a vehicle placed in <br/>
        service before 2006, enter $4,000. For a vehicle placed 
        in service in 2006, enter $1,000 (see instructions).
        </td>
         <td class="styLNRightNumBox">6</td>
        <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;" valign="bottom">
     
        <span class="styTableCellPad"  ></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="MaximumCreditPerVehicle" />
          </xsl:call-template>
        </td>
         <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;"  valign="bottom">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/MaximumCreditPerVehicle" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px;"  valign="bottom">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/MaximumCreditPerVehicle" />
          </xsl:call-template>
        </td>

        </tr>  
        
       <!-- Line 7  -->
      <tr>
      <td  class="styBoldText" style="padding-left: 2mm;width:6mm;">7</td>
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
          Enter the <span class="styBoldText">smaller</span> of line 5 or line 6
            <b>
            <span class="styNBSP"></span>.
            <span class="styNBSP"></span>.
            <span class="styNBSP"></span>.
            <span class="styNBSP"></span>.
          </b>
         </td>
         <td class="styLNRightNumBox" style="border-bottom-width:1px">7</td>
        <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="SmallerVehicleCredit" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/SmallerVehicleCredit" />
          </xsl:call-template>
        </td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px">
          <span class="styTableCellPad"></span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/SmallerVehicleCredit" />
          </xsl:call-template>
        </td>
        </tr>
      </tbody>
    </table>
  </div>
  </xsl:if>
  </xsl:for-each>
  </xsl:if>
 <!-- Display if there are no data elements, or Print is set to separated and there are more than 3 elements.  Be sure to test by commenting 
 out "if separated" statements in 3 places: at top of form, on transmissionXML.xml print paramter and in the populateTemplate globalStylesForm -->
 <xsl:if test="(count($FormData/TentativeCredit)=0) or (($Print = $Separated) and (count($FormData/TentativeCredit) &gt; 3))">
 <div class="styIRS8834TableContainer" id="Spcctn" >
   <!--print logic for the table that remains empty if separated (repeating) data appears at the bottom of form-->
  <xsl:call-template name="SetInitialState"/>
  <!--end-->
   <table class="styTable" cellspacing="0" style="font-size: 7pt">
     <thead class="styTableThead">
    <tr style="height: 8mm">
      <th style="width:6mm;"></th>
      <th class="styTableCell" colspan="2" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px; text-align:left;">        
        <span class="styNormalText" style="font-size:6pt;">
          Use a separate column for each vehicle. If you need more columns, use<br/> additional Forms 8834 and include the total on line 8.
        </span>
      </th>
      
      <th class="styTableCell" style="width: 32mm;border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:0px; text-align: center">(a)</th>
      <th class="styTableCell" style="width: 32mm;border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:0px; text-align: center">(b)</th>
      <th class="styTableCell" style="width: 32mm;border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px; text-align: center">(c)</th>
      </tr>
    </thead>
    <tfoot/>
    <tbody>
    
    
      <!--  Line 1   -->
      <tr>
      <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">1
      </td>
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
 Enter date vehicle placed in service (MM/DD/YYYY)
        </td>
        <td class="styLNRightNumBox" style="border-top-width: 1px">1</td>
      
        
         <xsl:choose>
          <!-- Display "Additional Data" message if Print is set to separated and there are more than 3 elements -->
          <xsl:when test="(($Print = $Separated) and (count($FormData/TentativeCredit) &gt; 3))">
            <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 1px; border-bottom-width:1px; text-align: center">
              <xsl:call-template name="PopulateAdditionalDataTableMessage">
                <xsl:with-param name="ShortMessage">true</xsl:with-param>
                <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit/DateVehiclePlacedInService"/>
              </xsl:call-template>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 1px; border-bottom-width:1px; text-align: center"><span class="styTableCellPad"></span></td>
          </xsl:otherwise>
        </xsl:choose>
        
         <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 1px; border-bottom-width:1px; text-align: center"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 1px; border-bottom-width:1px; text-align: center"><span class="styTableCellPad"></span></td>
        </tr>
        
           <!-- Line 2  -->
      <tr style="font-size: 7pt">
      <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">2
      </td> 
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
    Cost of vehicle
  <b>
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
               <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
    </b>
  
         </td>
         <td class="styLNRightNumBox">2</td>
         
         <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: right"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: right"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px; text-align: right"><span class="styTableCellPad"></span></td>
       </tr>
        
        <!-- Line 3  -->
     <tr>
         <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">3
        </td> 
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
                Section 179 expense deduction (see instructions)
              <b>
                <span class="styNBSP"></span>.
              </b>
             
         </td>
         <td class="styLNRightNumBox" style="border-bottom-width: 1px">3</td>
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px;"><span class="styTableCellPad"></span></td>
         
         
       
        </tr>
      <!--  Line 4   -->
      <tr>
       <td class="styBoldText" style="font-size: 7pt; padding-left: 2mm;width:6mm;">4
      </td> 
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
        
          Subtract line 3 from line 2
            <b>
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
              <span class="styNBSP"></span>.
               <span class="styNBSP"></span>.
            </b>
        </td>
        <td class="styLNRightNumBox">4</td>
       
               <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
       
        </tr>
         <!-- Line 5  -->
        <tr>
      <td  class="styBoldText" style="padding-left: 2mm;width:6mm;" valign="top">5</td>
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
          For a vehicle placed in service before 2006, multiply <br/>
          line 4 by 10% (.10). For a vehicle placed in service <br/>
          in 2006, multiply line 4 by 2.5% (.025) (see instructions).
        </td>
         <td class="styLNRightNumBox">5</td>
      
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
      
        </tr> 
       
       <!-- Line 6  -->
      <tr>
      <td  class="styBoldText" style="padding-left: 2mm;width:6mm;" valign="top">6</td>
        <td class="styTableCell" style="width:75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px;">
        Maximum credit per vehicle. For a vehicle placed in <br/>
        service before 2006, enter $4,000. For a vehicle placed 
        in service in 2006, enter $1,000 (see instructions).
        </td>
         <td class="styLNRightNumBox">6</td>
       
           <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>

        </tr>  
        
       <!-- Line 7  -->
      <tr>
      <td  class="styBoldText" style="padding-left: 2mm;width:6mm;">7</td>
        <td class="styTableCell" style="width: 75mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
          Enter the <span class="styBoldText">smaller</span> of line 5 or line 6
            <b>
            <span class="styNBSP"></span>.
            <span class="styNBSP"></span>.
            <span class="styNBSP"></span>.
            <span class="styNBSP"></span>.
          </b>
         </td>
         <td class="styLNRightNumBox" style="border-bottom-width:1px">7</td>
       
               <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
        <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px"><span class="styTableCellPad"></span></td>
       
        </tr>

    
    
      </tbody>
    </table>
  </div>
  </xsl:if>

  <!--  Line 8 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">8</div>
    <div style="float:left;padding-top:.5mm;">
      Add columns (a) through (c) on line 7
    </div>    
    <div style="float:right;">    
      <span style="letter-spacing:4mm;padding-top:.5mm; font-weight:bold; float:left">  
        ..................
      </span>        
      <div class="styLNRightNumBox" style="border-bottom-width: 1px">8</div>
      <div class="styLNAmountBox" style="border-bottom-width: 1px">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/ElectricVehicleCredit"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 8 -->
  
  <!--  Line 9  -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">9</div>
    <div style="float:left">
      Qualified electric vehicle credits from pass-through entities:
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="border-bottom-width: 0px"></div>          
    </div>
  </div>
  <div style="width:187mm;padding-left:4mm">
    <div class="styLNDesc" style="width:143.25mm; height:4mm; padding-left: 4mm">
      <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Qualified electric vehicle credits from pass-through entities:">
         <tr>
            <th class="styTableCell" scope="col" style="border-color: black; border-top-width: 1px; font-size: 7pt; width: 20mm; text-align:left">                
              If you are a:              
            </th>
            <th class="styTableCell" colspan="3" scope="col" style="text-align: left; border-color: black; border-right-width:0px; border-top-width:1px; font-size: 7pt; width: 92mm;padding-left: 2mm">
              Then enter the total electric vehicle credits from:
            </th>
            <th class="styTableCell" scope="col" style="border-bottom-width: 0px;width:35mm">
            <span class="styTableCellPad"></span>
            </th>
         </tr>
         <tr>
            <td scope="row" style="width: 20mm; font-size: 6pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt">
            Shareholder      
            <br/>
              Partner  
              </td>
            <td scope="row" style="width: 69mm; font-size:6pt;font-family:verdana;font-style: normal;font-weight:normal;border:none;padding:0mm;padding-left:2mm">
              Schedule K-1 (Form 1120S), box 13, code F, G, or U  
              <br/>
              Schedule K-1 (Form 1065), box 15, code F, G, or U
            </td>
          <td scope="row" style="width: 4mm">
            <div class="styLNDesc" style="width:4mm; text-align: left">
              <img src="{$ImagePath}/8834_Bracket_Sm.gif" alt="Curly Bracket Image"/>                
            </div>
          </td>
          <td scope="row" style="width: 18mm">
            <div class="styLNDesc" style="width:18mm;letter-spacing:4mm; font-weight: bold; float:left; font-size: 7pt">                  
                ....              
            </div>
          </td>
          <td scope="row" style="width: 34mm">
            <div class="styLNDesc" style="width:34mm;letter-spacing:4mm; font-weight: bold; float:left; font-size: 7pt">                  
                .......              
            </div>
          </td>
         </tr>            
      </table>          
    </div>
    <div class="styLNRightNumBox" style="height:5mm;padding-top:0mm;">
      <div class="styLNRightNumBoxN" style="width:7.75mm;background-color:lightgrey;height:7mm"></div>
          9          
    </div>        
    <div class="styLNAmountBox" style="height: 10.5mm; width: 31.75mm; padding-top: 7mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QlfyCrFromPassThroughEntities"/>
      </xsl:call-template>
    </div>
    <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color: lightgrey;border-right-width:1px;"></div>

  </div>      
    
   
  <!--  Line 10 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">10</div>
    <div style="float:left">
      Add lines 8 and 9
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        .......................
      </span>        
      <div class="styLNRightNumBox" style="border-bottom-width: 1px">10</div>
      <div class="styLNAmountBox" style="border-bottom-width: 1px">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/TotalCurrentYearCredit"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 10 -->
  
  <!--  Line 11 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">11</div>
    <div style="float:left">
      Passive activity credits included on line 10 (see instructions)
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        ...........
      </span>        
      <div class="styLNRightNumBox">11</div>
      <div class="styLNAmountBox">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveActivityCredits"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 11 -->
  
  <!--  Line 12 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">12</div>
    <div style="float:left">
      Subtract line 11 from line 10
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        .....................
      </span>        
      <div class="styLNRightNumBox" style="border-bottom-width: 1px">12</div>
      <div class="styLNAmountBox" style="border-bottom-width: 1px">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/TotalCurrYrCreditMinusPassive"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 12 -->
  
  <!--  Line 13 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">13</div>
    <div style="float:left">
      Passive activity credits allowed for 2005 (see instructions)
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        ............
      </span>        
      <div class="styLNRightNumBox" style="border-bottom-width: 1px">13</div>
      <div class="styLNAmountBox" style="border-bottom-width: 1px">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveActivityCreditsAllowed"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 13 -->
  
  <!--  Line 14 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">14</div>
    <div style="float:left">
      <span class="styBoldText">Tentative qualified electric vehicle credit.</span> Add lines 12 and 13
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        ..........
        <img src="{$ImagePath}/8834_Bullet.gif" alt="Curly Bracket Image"/>
      </span>              
      <div class="styLNRightNumBox" style="border-bottom-width: 0px">14</div>
      <div class="styLNAmountBox" style="border-bottom-width: 0px">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/TentQlfyElectricVehicleCredit"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 14 -->
  
  <!--  Part II -->
  <div class="styBB" style="width: 187mm; border-top-width: 1px">
    <div class="styPartName" style="width: 15mm">Part II</div>
    <div class="styPartDesc" style="width: 172mm">Allowable Credit</div>
  </div>
  <!--  End Part II -->
    
  <!--  Line 15 -->  
  <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">15</div>
        <div class="styLNDesc" style="width:100mm;height:4mm;">
          Regular tax before credits.          
        <li style="height: 4mm; padding-top: .75mm">Individuals. Enter the amount from Form 1040, line 44.</li>
        <li style="height: 4mm; padding-top: .75mm">Corporations. Enter the amount from Form 1120, Schedule J, line 3.</li>
        <li style="height: 4mm; padding-top: .75mm">Other filers. Enter the regular tax before credits from your return.</li>                     
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:4.5mm;">
          <img src="{$ImagePath}/8834_Bracket_Md.gif" alt="Curly Bracket Image"/>        
        </div>
        <div class="styLNDesc" style="width:33mm; height:4mm;">                  
          <span class="styBoldText" style="width:33mm; height:4mm;padding-bottom:0mm;padding-top:7mm;">
            <span style="width:8px;"></span>.    
            <span style="width:8px;"></span>.  
            <span style="width:8px;"></span>.    
            <span style="width:8px;"></span>.
            <span style="width:8px;"></span>.    
            <span style="width:8px;"></span>.
            <span style="width:8px;"></span>.    
            <span style="width:8px;"></span>.                                                      
          </span>                  
        </div>

        <div class="styLNRightNumBox" style="width:7.75mm;height:8.25mm;padding-top=0mm;">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;padding-top=0.5mm;border-left-width:0px;background-color:lightgrey;">
        </div>
        15
        </div>
        <div class="styLNAmountBox" style="height:8.25mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/RegularTaxBeforeCredits"/>
        </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:8.25mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>
          <!-- End Line 15 -->
          
  <div class="styBB" style="width:187mm;">      
      <!-- Line 16a-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">16</div>
        <div class="styLNDesc" style="width:138mm;height:4mm">
          Credits that reduce regular tax before the qualified electric vehicle credit:
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey; border-bottom-width: 0px"></div>
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px">
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm">
          Foreign tax credit
          <span style="letter-spacing:4mm; font-weight:bold">  
            ...............
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16a</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/ForeignTaxCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 16a-->
      
      <!-- Line 16b-->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Credits from Form 1040, lines 48 through 54
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold">  
            .......
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16b</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
        <!--
          NO SCHEMA ELEMENT FOR THIS FIELD
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/PossessionsTaxCredits"/>
          </xsl:call-template>
        -->
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 16b-->
      
      <!-- Line 16c -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Possessions tax credit (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              ......
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/PossessionsTaxCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 16c -->
      
      <!-- Line 16d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Nonconventional source fuel credit (Form 8907, line 23)
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              ....
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/CreditOfFuelFromNnconvSource"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
   
      
      <!-- Line 16e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">e</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 16a through 16d
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              .....................
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16e</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/SumOfForeignAndFuelCredit"/>
          </xsl:call-template>
        </div>
      </div>
      <!-- Line 16e -->
      
      <!-- Line 17  -->      
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">17</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Net regular tax. Subtract line 16e from line 15. If zero or less, <span class="styBoldText">do not</span> file this form; you cannot 
        </div>
        <div class="styLNRightNumBoxNBB"></div>  
        <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          claim this credit
          <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              ........................
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">17  </div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NetRegularTax"/>
          </xsl:call-template>
        </div>
      </div>
      
      <!--  Line 18  -->    
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">18</div>
        <div class="styLNDesc" style="width:105mm;height:4mm;">
          Tentative minimum tax (see instructions).            
        <li style="height:4mm; padding-top: .75mm">Individuals. Enter the amount from Form 6251, line 33.</li>
        <li style="height: 4mm; padding-top: .75mm">Corporations. Enter the amount from Form 4626, line 12.</li>
        <li style="height: 4mm; padding-top: .75mm">Estates and trusts. Enter the amount from Form 1041, Schedule I, line 54.</li>                   
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:4.5mm;">
          <img src="{$ImagePath}/8834_Bracket_Md.gif" style="padding-top:2mm" alt="Curly Bracket Image"/>        
        </div>
        <div class="styLNDesc" style="width:28mm; height:4mm;">                  
          <span class="styBoldText" style="width:28mm; height:4mm;padding-bottom:0mm;padding-top:7mm;">
            <span style="width:8px;"></span>.    
            <span style="width:8px;"></span>.  
            <span style="width:8px;"></span>.    
            <span style="width:8px;"></span>.
            <span style="width:8px;"></span>.    
            <span style="width:8px;"></span>.                                                      
          </span>                  
        </div>

        <div class="styLNRightNumBox" style="width:7.75mm;height:8.5mm;padding-top=0mm;border-bottom-width: 1px">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;padding-top=0.5mm;border-left-width:0px;background-color:lightgrey;">
        </div>
        18
        </div>
        <div class="styLNAmountBox" style="height:8.55mm; border-bottom-width: 1px">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TentativeMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:8mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>
      <!--  Line 18  -->
  
      <!--  Line 19  -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">19</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Subtract line 18 from line 17. If zero or less, <span class="styBoldText">do not</span> file this form; you cannot claim this credit
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">19</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/ExcessOfNetOverTentativeTax"/>
          </xsl:call-template>
        </div>
      </div>
      
      <!--  Line 20  -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">20</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <span class="styBoldText">Qualified electric vehicle credit.</span> Enter the <span class="styBoldText">smaller</span> of line 14 or 19 here and on Form 1040,
          line 55; Form 1120, Schedule J, line 6c; Form 1041, Schedule G, line 2b; or the appropriate line
          of your return. If line 19 is smaller than line 14, see instructions
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold">  
            .............
            <img src="{$ImagePath}/8834_Bullet.gif" alt="Curly Bracket Image"/>
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:10.5mm;padding-top: 6mm; border-bottom-width: 0px">20</div>
        <div class="styLNAmountBox" style="height:10.5mm; padding-top: 6mm; border-bottom-width: 0px">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/AllowableQlfyElectricVehicleCr"/>
          </xsl:call-template>
        </div>        
      </div>      
    </div>

        <div style="width:187mm;">
          <span class="styBoldText">For Paperwork Reduction Act Notice, see back of form. </span> 
          <span style="width:120px;"></span>                      
          Cat. No. 14953G 
          <span style="width:80px;"></span>  
          Form <span class="styBoldText">8834</span> (2005)
        </div>
        <br/>
        <br class="pageEnd"/>
        
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$FormData" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
      <!-- END Left Over Table -->     
       
       
       
       
  <!-- Additional Data Table for Separated Data from Part I; displayed if more than 3 elements and Print is set to separated-->
  <xsl:if test="($Print = $Separated) and (count($FormData/TentativeCredit) &gt; 3)">            
    <br />
    <br />
    <span class="styRepeatingDataTitle">Form IRS8834, Part I - Tentative Credit:</span>
    <xsl:for-each select="$FormData/TentativeCredit">
      <xsl:variable name="pos" select="position()"/>
      <xsl:if test="(position() mod 3)=1">
        <table class="styDepTbl" cellspacing="0" style="font-size: 7pt">
          <thead class="styTableThead">
            <tr style="height: 8mm" class="styDepTblHdr">
              <td class="styDepTblCell" colspan="2" style="width: 91mm; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px; text-align: left">        
                <span class="styNormalText" style="padding-left: 5mm">
                  Use a separate column for each vehicle. If you need more<br/><span style="width: 5mm"></span>
                  columns, use additional Forms 8834 and include the total on<br/><span style="width: 5mm"></span>line 8.
                </span>
              </td>
              <td class="styDepTblCell" style="width: 30mm;border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: center">(<xsl:number value="($pos)" format="a"/>)</td>
              <td class="styDepTblCell" style="width: 30mm;border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: center">(<xsl:number value="($pos + 1)" format="a"/>)</td>
              <td class="styDepTblCell" style="width: 30mm;border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px; text-align: center">(<xsl:number value="($pos + 2)" format="a"/>)</td>
            </tr>
          </thead>
          <tfoot/>
          <tbody>
            <!--  Line 1   -->
            <tr class="styDepTblRow1" style="height: 8mm">
              <td class="styTableCell" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 1px; border-bottom-width:0px">
              <span class="styBoldText" style="font-size: 7pt; padding-left: 2mm">1</span><span style="width: 1mm"></span>
                <span>Enter date vehicle placed in service (MM/DD/YYYY)</span>
              </td>
              <td class="styLNRightNumBox" style="border-top-width: 1px">1</td>
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 1px; border-bottom-width:1px; text-align: center">
                <xsl:call-template name="PopulateMonthDayYear">
                  <xsl:with-param name="TargetNode" select="DateVehiclePlacedInService"/>
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 1px; border-bottom-width:1px; text-align: center">
                <xsl:call-template name="PopulateMonthDayYear">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/DateVehiclePlacedInService" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 1px; border-bottom-width:1px; text-align: center">
                <xsl:call-template name="PopulateMonthDayYear">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/DateVehiclePlacedInService" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              </tr>

            <!-- Line 2  -->
            <tr class="styDepTblRow2" style="height: 8mm; font-size: 7pt">
              <td class="styTableCell" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
              <span class="styBoldText" style="font-size: 7pt; padding-left: 2mm">2</span><span style="width: 1mm"></span>
                <span>Cost of vehicle</span>
              </td>
              <td class="styLNRightNumBox">2</td>
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: right">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="CostOfVehicle" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px; text-align: right">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/CostOfVehicle" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px; text-align: right">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/CostOfVehicle" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
            </tr>

          <!-- Line 3  -->
            <tr class="styDepTblRow1" style="height: 8mm">
              <td class="styTableCell" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
                <span class="styBoldText" style="font-size: 7pt; padding-left: 2mm">3</span><span style="width: 1mm"></span>
                  <span>Section 179 expense deduction (see instructions)
                  </span>
               </td>
               <td class="styLNRightNumBox" style="border-bottom-width: 1px">3</td>
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="Section179ExpenseDeduction" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/Section179ExpenseDeduction" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/Section179ExpenseDeduction" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              </tr>
            <!--  Line 4   -->
            <tr class="styDepTblRow2" style="height: 8mm">
              <td class="styTableCell" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
              <span class="styBoldText" style="font-size: 7pt; padding-left: 2mm">4</span><span style="width: 1mm"></span>
                <span>Subtract line 3 from line 2</span>
              </td>
              <td class="styLNRightNumBox">4</td>
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="CostOfVehicleMinusSect179Expns" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/CostOfVehicleMinusSect179Expns" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/CostOfVehicleMinusSect179Expns" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              </tr>

            <!-- Line 5  -->
            <tr class="styDepTblRow1" style="height: 8mm">
              <td class="styTableCell" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
              <span class="styBoldText" style="font-size: 7pt; padding-left: 2mm">5</span><span style="width: 1mm"></span>For a vehicle placed in service before 2006, multiply <br/><span style="width:5mm;"></span>   line 4 by 10% (.10). For a vehicle placed in service in<br/><span style="width:5mm;"></span> 2006, multiply line 4 by 2.5% (.025) (see instructions).
               </td>
               <td class="styLNRightNumBox" style="height:10.5mm;padding-top: 8.5mm;">5</td>
	
              <td class="styTableCell" style="height:10.5mm;padding-top: 8.5mm;border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="MultiplyCostByAppropriatePct" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/MultiplyCostBy10Percent" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/MultiplyCostBy10Percent" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
             </tr>
      
          <!-- Line 6  -->
            <tr class="styDepTblRow2" style="height: 8mm">
              <td class="styTableCell" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
              <span class="styBoldText" style="padding-left: 2mm">6</span><span style="width: 1mm"></span>
                <span style="font-size: 7pt">Maximum credit per vehicle. For a vehicle placed in<br/><span style="width:5mm;"></span>
service before 2006, enter $4,000. For a vehicle placed<br/><span style="width:5mm;"></span>
in service in 2006, enter $1,000 (see instructions).</span>
               </td>
               <td class="styLNRightNumBox">6</td>
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="MaximumCreditPerVehicle" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:1px;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/MaximumCreditPerVehicle" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:1px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/MaximumCreditPerVehicle" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              </tr>

          <!-- Line 7  -->
            <tr class="styDepTblRow1" style="height: 8mm">
              <td class="styTableCell" style="width: 83mm; text-align: left; border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:0px">
                <span class="styBoldText" style="font-size: 7pt; padding-left: 2mm">7</span><span style="width: 1mm"></span>
                  <span style="font-size: 7pt">Enter the <span class="styBoldText">smaller</span> of line 5 or line 6</span>
               </td>
               <td class="styLNRightNumBox" style="border-bottom-width: 2px">7</td>
              <td class="styTableCell" style="border-color: black; border-left-width: 1px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:2px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="SmallerVehicleCredit" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 1px; border-top-width: 0px; border-bottom-width:2px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 1]/SmallerVehicleCredit" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCell" style="border-color: black; border-left-width: 0px; border-right-width: 0px; border-top-width: 0px; border-bottom-width:2px">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$FormData/TentativeCredit[$pos + 2]/SmallerVehicleCredit" />
                </xsl:call-template>
                <span class="styTableCellPad"></span>
              </td>
              </tr>
            </tbody>
          </table>
          <br/>
        </xsl:if>
      </xsl:for-each>
    </xsl:if>
  </form>  
</body>
</html>
</xsl:template>    

</xsl:stylesheet>