<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="IRS8835Style.xsl"/>
<xsl:include href="AddOnTable.xsl"/>

<xsl:output method="html" indent="yes" encoding="iso-8859-1"/>

<xsl:strip-space elements="*" />
<xsl:param name="FormData" select="$RtnDoc/IRS8835" />


<xsl:template match="/">
  	<html>
<head>  
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache"/>
  <meta http-equiv="Cache-Control" content="no-cache"/>
  <meta http-equiv="Expires" content="0"/>
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private"/>  
  <meta name="Author" content="Michelle Hayden - haydem@us.ibm.com" />
  <meta name="Description" content="Form IRS 8835"/>
  <meta name="GENERATOR" content="IBM WebSphere Studio"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/header.css"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/body.css"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/general.css"/>
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>  
  <style type="text/css">    
  <xsl:if test="not($Print) or $Print=''">  
      <xsl:call-template name="IRS8835Style"></xsl:call-template>
      <xsl:call-template name="AddOnStyle"></xsl:call-template>  
 </xsl:if>   
  </style>      
  
</head>

<body class="styBodyClass">
  <form name="Form8835">    
    <xsl:call-template name="DocumentHeader"></xsl:call-template>  
    
  <!--Title of Form -->    
  <div class="styBB" style="width:187mm;height: 20mm">
    <div class="styFNBox" style="width:31mm;font-size: 7pt;height: 20mm">
      Form <span class="styFormNumber">8835</span>      
      <br/>
      <xsl:call-template name="LinkToLeftoverDataTableInline">
        <xsl:with-param name="Desc">Fiscal Year Taxpayer Indicator</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$FormData/@fiscalYearTaxpayerIndicator"/>
        <xsl:with-param name="Style">padding-left:3mm;</xsl:with-param>
      </xsl:call-template>
      <br/>
      <div class="styAgency" style="padding-top: 1.5mm">Department of the Treasury</div><span class="styAgency">Internal Revenue Service</span>
    </div>
    <div class="styFTBox" style="height: 20mm;width:125mm">
      <div class="styMainTitle" style="height: 8mm; padding-top: 1.5mm">Renewable Electricity, Refined Coal,<br />and Indian Coal Production Credit</div>
      <div class="styFST" style="font-size:7pt;margin-left:3mm;font-weight:bold; padding-top: 5mm">
        <img src="{$ImagePath}/8835_Bullet.gif" alt="MediumBullet"/>  
        Attach to your tax return.
      </div>
    </div>
    <div class="styTYBox" style="width:30mm;height:20mm; border-left-width: 1px">
      <div class="styOMB" style="height:2mm;">OMB No. 1545-1362</div>
      <div class="styTaxYear" style="height:10mm">20<span class="styTYColor">05</span></div>
      <div class="stySequence">Attachment<br/>Sequence No. <b>95</b></div>
    </div>
  </div>
  <!--  End title of Form  -->
   
  <!--  Name and Employer identification number  -->
  <div class="styBB" style="width:187mm">
    <div class="styNameBox" style="width:141mm;font-size:7pt;">
      Name(s) shown on return<br/>
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
    </div>
    <div class="styEINBox" style=" padding-left:2mm;font-size:7pt;"><span class="BoldText">Identifying number</span>
      <div style="text-align:left;font-weight:normal;">    
        <br/>
        <xsl:choose>
          <xsl:when test="normalize-space($FormData/IdentifyingNumber) != ''">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$FormData/IdentifyingNumber" /></xsl:call-template>
          </xsl:when>  
          <xsl:otherwise>  
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>  
          </xsl:otherwise>
        </xsl:choose>
      </div>    
    </div>
  </div>  
  <!--  End Name and Employer indentification number  -->
 <div class="styBB" style="width: 187mm">
       <div class="styBoldText" style="padding-bottom:0mm;"><span style="font-size: 10pt">Section A. </span><span style="width: 1mm" /><span style="font-size: 9pt"> Electricity produced at qualified facilities placed in service prior to October 23, 2004</span></div>
       <br/>
 </div>  
  <!--  Part I Title-->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part I</div>
    <div class="styPartDesc">Current Year Credit</div>
  </div>
  <!--  End Part I Title-->

  <!--  Line 1 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">1</div>
    <span class="styLNDesc" style="width: 137mm">
      Kilowatt-hours produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ..
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/NumKwHrsProducedAndSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>0.019</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">1</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalKwHrsProducedAndSoldCr"/>
          </xsl:call-template>
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalKwHrsProducedAndSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 1 -->
  
  <!--  Line 2 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">2</div>
    <span class="styLNDesc" style="width: 137mm">
      Phaseout adjustment (see instructions)  
      <span style="width: 26.5mm">
        <span class="styDotLn" style="float: none">  
          .......
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 34mm">$
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditBeforePhaseoutAdjustment"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span><span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 10mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/PhaseoutAdjustmentRate"/>
        </xsl:call-template>
        </span>
      </span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">2</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalPhaseoutAdjustment"/>
          </xsl:call-template>
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalPhaseoutAdjustment"/>
        </xsl:call-template>
      </span>          
  </div>
  <!--  Line 2 -->
  
  <!--  Line 3 -->  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="padding-left: 2mm; height:4mm;">3</div>
    <div style="float: left; padding-top: .5mm">
      Credit before reduction. Subtract line 2 from line 1     
    </div>   
     <div style="float: right"> 
      <!--Dotted Line-->
        <div class="styDotLn" style="padding-top: .5mm">  
          .................
        </div>
    <div class="styLNRightNumBox" style="height:4.5mm">3
    </div>
    <div class="styLNAmountBox" style="height:4.5mm; width: 34mm">
      <xsl:call-template name="PopulateAmount">     
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditBeforeReduction"/>
      </xsl:call-template>
    </div>
    </div>
  </div>

  <!--  Line 3 -->

  <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        Reduction for government grants, subsidized financing, and other credits:
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>
  
  <!--  Line 4 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">4</div>
    <div style="float: left; padding-top: .5mm">
      Total of government grants, proceeds of tax-exempt government obligations, subsidized energy
    </div>
    <div style="float: right">
      <span class="styLNRightNumBox" style="background-color: lightgrey; border-bottom-width: 0px" />
      <span class="styLNAmountBox" style="width: 34mm; background-color: lilghtgrey; border-bottom-width: 0px" />        
    </div>
  </div>
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox"/>
    <div style="float: left; padding-top: .5mm">
      financing, and any other credits allowed for the project for this and all prior tax years
    </div>
    <div style="float: right">    
        <span class="styDotLn" style="padding-top: .5mm">  
          ...... 
      </span>
      <span class="styLNRightNumBox" style="height: 5mm">4</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalOfGovernmentGrants"/>
        </xsl:call-template>
      </span>        
    </div>
  </div>
  <!--  Line 4 -->
  
  <!--  Line 5 -->  
    <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">5</div>
    <div style="float: left; padding-top: .5mm">
     Total of additions to the capital account for the project for this and all prior tax years
     </div>
   <div style="float: right">
        <span class="styDotLn" style="padding-top: .5mm">  
          ...... 
      </span>
      <span class="styLNRightNumBox" style="height: 5mm">5</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
       
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalOfCapitalAccountAdditions"/>
        </xsl:call-template>
      </span> 
    </div>       
  </div>
  <!--  Line 5 -->
  
  <!--  Line 6 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">6</div>
    <div style="float:left; padding-top: .5mm">
      Divide line 4 by line 5. Show as a decimal carried to at least 4 places  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ...........
      </span>        
      <div class="styLNRightNumBox">6</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditReductionPercentage"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 6 -->
  
  <!--  Line 7 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">7</div>
    <div style="float:left; padding-top: .5mm">
      Multiply line 3 by line 6  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ..........................
      </span>        
      <div class="styLNRightNumBox">7</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 7  -->
  
  <!--  Line 8 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">8</div>
    <div style="float:left; padding-top: .5mm">
      Subtract line 7 from line 3  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        .........................
      </span>        
      <div class="styLNRightNumBox">8</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/AdjustedCreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 8  -->
  
  <!--  Line 9  -->
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm; padding-left: 2mm">9</div>
    <div class="styLNDesc" style="width:28mm; height:4mm">
      <div style = "width:29mm;">Section A credits from pass-through entities:</div>
    </div>
    <div class="styLNDesc" style="width:1.75mm; height:4mm"> </div>
    <div class="styLNDesc" style="width:106mm; height:4mm">
      <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Table for Work Opportunity Credit">
         <tr>
            <th class="styTableCell" scope="col" style="border-color: black; border-top-width: 1px; font-weight: bold; font-size: 6pt; width: 30mm; padding-left: 2mm; text-align: left">                
              If you are a—              
            </th>
            <th class="styTableCell" scope="col" style="border-color: black; font-weight: bold; border-right-width:0px; border-top-width:1px; font-size: 6pt; width: 68mm;padding-left: 2mm; text-align: left">
              Then enter the credit(s) from—
            </th>
         </tr>
         <tr>
            <td scope="row" style="width: 30mm; font-size: 6pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt">
            <span class="styBoldText" style="padding-left: 2mm">a</span> Shareholder<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">..</span>      
            <br/>
              <span class="styBoldText" style="padding-left: 2mm">b</span> Partner<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">...</span> 
              <br/> 
              <span class="styBoldText" style="padding-left: 2mm">c</span> Beneficiary<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">..</span>
               <br/> 
              <span class="styBoldText" style="padding-left: 2mm">d</span> Patron<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">....</span>
             
              </td>
            <td style="font-size:6pt;font-style: normal;font-weight:normal;border:none;padding-left: 2mm">
              Schedule K-1 (Form 1120S), box 13, code F, G, or U
              <span class="styDotLn" style="float: none; font-size: 7pt">.</span>
              <br/>
              Schedule K-1 (Form 1065), box 15, code F, G, or U
              <span class="styDotLn" style="float: none; font-size: 7pt">.</span>
              <br/>
              Schedule K-1 (Form 1041), box 13, code J
                <span class="styDotLn" style="float: none; font-size: 7pt">....</span>
              <br/>
              Written statement from cooperative
                <span class="styDotLn" style="float: none; font-size: 7pt">......</span>
                
            </td>
          <td style="width:4mm">
            <div class="styLNDesc" style="width:4mm">
              <img src="{$ImagePath}/8835_Bracket_Md.gif"  alt="Curly Bracket Image" />                                    
            </div>            
          </td>
          <td class="styDotLn" style="width: 8mm; font-size: 7pt; padding-bottom: 4mm">
          ..
          </td>
         </tr>            
      </table>          
    </div>
    <div class="styLNRightNumBox" style="height:9mm;padding-top:0mm;">
      <div class="styLNRightNumBoxN" style="width:7.75mm;background-color:lightgrey;height:5mm;"></div>
          9         
    </div>        
    <div class="styLNAmountBox" style="height: 9mm; width: 34mm; padding-top: 5mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditsFromPassThroughEntities"/>
      </xsl:call-template>
    </div>  
    <div style="float:right">          
      <div class="styLNRightNumBoxNBB" style="height:8mm;background-color: lightgrey;"></div>
      <div class="styLNAmountBoxNBB" style="height: 8mm;width: 34.25mm"></div>          
  </div>
  </div>      
    

  <!--  Line 10 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">10</div>
    <div style="float:left">
      <span class="styBoldText">Current year credit. </span> Add lines 8 and 9
    </div>    
    <div style="float:right">    
      <span class="styDotLn">  
        .....................
      </span>        
      <div class="styLNRightNumBoxNBB">10</div>
      <div class="styLNAmountBoxNBB" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalCurrentYearCredit"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 10 -->
  
  <!--  Part II Title-->
  <div class="styBB" style="width: 187mm; border-top-width: 1px">
    <div class="styPartName" style="width: 15mm">Part II</div>
    <div class="styPartDesc" style="width: 172mm">Allowable Credit <span class="styNormalText">(See</span> Who must file Form 3800 <span class="styNormalText">to find out if you complete Part II or file Form 3800.)</span></div>
  </div>
  <!--  End Part II Title-->
    
  <!--  Line 11 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">11</div>
      <div style="float: left; padding-top: .5mm">
        Regular tax before credits (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ...................
          </span>        
      <div class="styLNRightNumBox">11</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/RegularTaxBeforeCredits"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 11 -->
    
    <!-- Line 12 -->
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">12</div>
      <div style="float: left; padding-top: .5mm">
        Alternative minimum tax (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ....................
          </span>        
      <div class="styLNRightNumBox">12</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/AlternativeMinimumTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 12 -->    
      
      <!-- Line 13-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">13</div>
        <div style="float: left; padding-top: .5mm">
          Add lines 11 and 12
        </div>
          <!--Dotted Line-->
        <div style="float: right">
          <span class="styDotLn" style="padding-top: .5mm">  
            ...........................
          </span>  
        <div class="styLNRightNumBox" style="width:8mm;height:5mm;padding-top=1mm;">13</div>
        <div class="styLNAmountBox" style="height:5mm;width: 34.25mm">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/RegularTaxPlusAltMinimumTax"/>
          </xsl:call-template>
        </div>
      </div>
      </div>
      <!-- Line 13-->
      
      <!-- Line 14a-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">14a</div>
        <div class="styLNDesc" style="width:97mm;height:4mm">
          Foreign tax credit
          <span class="styDotLn" style="float: none">  
            ..................
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">14a</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 14a-->
      
      <!-- Line 14b-->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">b</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
         Credits from Form 1040, lines 48 through 54
          <!--Dotted Line-->
          <span class="styDotLn" style="float: none">  
            .........
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">14b</div>
        <div class="styLNAmountBox" style="height:4.5mm;">  </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 14b-->
      
     
      <!-- Line 14c -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">c</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Possessions tax credit (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              .......
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">14c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/PossessionsTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 14c -->
      
      <!-- Line 14d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">d</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Nonconventional source fuel credit (Form 8907, line 23)
            <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              .....
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">14d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/NonconventionalSourceFuelCr"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 14d -->
      
      <!-- Line 14e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">e</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Other specified credits (see instructions)
            <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              ..........
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">14e</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/OtherSpecifiedCredits"/>
          </xsl:call-template>
          </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 14e -->
      
      <!-- Line 14f -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">f</div>
        <div style="float: left">
          Add lines 14a through 14e
        </div>
        <div style="float:right">
          <!--Dotted Line-->
            <span class="styDotLn">  
              .........................
            </span>  
        <div class="styLNRightNumBox" style="height:4.5mm;">14f</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalTaxCredits"/>
          </xsl:call-template>
        </div>
      </div>
      </div>
      <!-- Line 14f  -->
      
      <!--  Line 15  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">15</div>
        <div style="float:left; padding-top: .5mm">
          Net income tax. Subtract line 14f from line 13. If zero, skip lines 16 through 19 and enter -0-
        </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
         on line 20
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ..............................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">15</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/NetIncomeTax"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 15  -->
      
      <!--  Line 16  -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">16</div>
        <div style="float: left; padding-top: .5mm">
         Net regular tax. Subtract line 14f from line 11. If zero or less,
        </div>
        <div style="float: right">
        <div class="styLNRightNumBox" style="height:4.5mm;background-color: lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm"/>
        </div>
      </div>
        
        <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          enter -0-
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm; font-weight:bold">  
              ...................
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16</div>
        <div class="styLNAmountBox" style="height:4.5mm">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/NetRegularTax"/>
          </xsl:call-template>
          </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;" />
      </div>
      <!--  Line 16  -->
      
      <!--  Line 17  -->        
        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">17</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Enter 25% (.25) of the excess, if any, of line 16 over $25,000
        </div>
        <div class="styLNRightNumBoxNBB" style="height:4.5mm" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px" />
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;" />
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          (see instructions)
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm; font-weight:bold">  
              .................
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">17</div>
        <div class="styLNAmountBox" style="height:4.5mm">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/Pct25OfExcessNetRegularTax"/>
          </xsl:call-template>
          </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;" />
      </div>
      <!--  Line 17  -->
      
      <!-- Line 18-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">18</div>
        <div class="styLNDesc" style="width:97mm;height:4mm">
          Tentative minimum tax (see instructions)
          <span class="styDotLn" style="float: none">  
            ..........
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">18</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TentativeMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 18-->
      
      <!-- Line 19 -->
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">19</div>
      <div style="float: left; padding-top: .5mm">
        Enter the greater of line 17 or line 18 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            .....................
          </span>        
      <div class="styLNRightNumBox">19</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/GrtrOfTentMinTxOr25PctOfExcess"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 19 -->
  
  <!-- Line 20 -->
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">20</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 19 from line 15. If zero or less, enter -0- 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ................
          </span>        
      <div class="styLNRightNumBox">20</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/AdjustedNetIncomeTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 20 -->
  
   <!--  Line 21  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">21</div>
        <div style="float:left; padding-top: .5mm">
          <span class="styBoldText">Credit allowed for the current year. </span> Enter the <span class="styBoldText">smaller </span>of line 10 or line 20. Report the total of </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
          this amount and the amount from Section B, line 41, on Form 1040, line 55; Form 1120, Schedule</div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
           J, line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule G, line 2c; or the applicable line of</div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div class="styBB"  style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
         your return. If line 20 is smaller than line 10, see instructions
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              .............
            </span>          
        <div class="styLNRightNumBoxNBB" style="height:4.5mm;">21</div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CurrentYearCreditAllowed"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 21  -->
      
 <!--Section B -->
  <div class="styBB" style="width: 187mm">
       <div class="styBoldText"><span style="font-size: 10pt">Section B.</span><span style="width: 1mm" /><span style="font-size: 8pt"> Electricity and refined coal produced at qualified facilities placed in service after <br /><span style="width: 21.5mm" /> October 22, 2004
       and Indian coal produced at facilities placed in service after August 8, 2005</span></div>
 </div>   
  <!--  Part I Title-->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="width: 15mm">Part I</div>
    <div class="styPartDesc">Current Year Credit</div>
  </div>
  <!--  End Part I Title-->
 <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left; padding-top: .5mm">
          <span class="styBoldText">Electricity produced at qualified facilities using wind, closed-loop biomass not modified</span>
        </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
          <span class="styBoldText">for co-fire purposes, geothermal, and solar</span>
        </div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>

  <!--  Line 1 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">1</div>
    <span class="styLNDesc" style="width: 137mm">
      Kilowatt-hours produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ..
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NumClosedLoopKwHrsPrdcdAndSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>0.019</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">1</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotClosedLoopKwHrsPrdcdSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 1 -->
   <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left; padding-top: .5mm">
          <span class="styBoldText">Electricity produced at qualified facilities using open-loop biomass, small irrigation power,</span>
        </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;">
         <span class="styBoldText">landfill gas, trash combustion, and hydropower</span>
        </div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div> 
    <!-- Line 2  -->
       <div style="width:187mm">
        <div class="styLNLeftNumBox" style="padding-left: 2mm;height:4mm;">2</div>
        <div style="float:left; padding-top: .5mm">
          Kilowatt-hours produced and sold after December 31, 2004</div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
        <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm"></div>
    <span class="styLNDesc" style="width: 137mm">
      (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          .............
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NumOpenLoopPrdcdSoldAfter1231"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>.009</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">2</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotOpenLoopPrdcdSoldAfter1231"/>
        </xsl:call-template>
      </span>        
  </div>
<!-- Line 2 -->


<!--  Line 3 -->   
<!-- Added page break to this div ini order to avoid repeating line 4 -->
  <div class="pageEnd" style="width:187mm; ">
      <div class="styLNLeftNumBox" style="padding-left: 2mm;height:4mm;">3</div>
      <div style="float: left; padding-top: .5mm">
        Add lines 1 and 2 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ...........................
          </span>        
      <div class="styLNRightNumBox">3</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">								     
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotClosedOpenKwHrsPrdcdSoldCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 3 -->

 

  <!--  Line 4 -->    
  <div style="width: 187mm" >  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">4</div>
    <span class="styLNDesc" style="width:137mm;">
      Phaseout adjustment (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ......
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">$
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopCrBfrPhaseoutAdj"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span><span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 10mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopPhaseoutAdjRate"/>
        </xsl:call-template>
        </span>
      </span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">4</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopTotalPhaseoutAdj"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 4 -->
 
 <!--  Line 5 -->  
  <div class="styBB" style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;padding-left: 2mm">5</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 4 from line 3 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            .........................
          </span>        
      <div class="styLNRightNumBoxNBB">5</div>
      <div class="styLNAmountBoxNBB" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopKwHrsCrMinusAdj"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 5 -->

<!--  FOOTER-->
        <div style="width:187mm;">
          <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions.</span> 
          <span style="width:20mm;"></span>                      
          Cat. No. 14954R 
          <span style="width:170px"></span>  
          Form <span class="styBoldText">8835</span> (2005)
        </div>
        <div class="pageEnd" />      
<!--END FOOTER-->

<!--BEGIN HEADER-->
<div class="styBB" style="width:187mm">
	<div style="float: left; clear: none">Form 8835 (2005)</div>				
	<div style="float:right">
		Page <span class="styBoldText" style="font-size: 8pt">2</span>
	</div>			
</div> 
<!--END HEADER-->
 
   <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        Refined coal produced at a qualified refined coal production facility
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>
  
  <!--  Line 6 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">6</div>
    <span class="styLNDesc" style="width: 137mm">
      Tons produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          .....
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NumRefinedCoalTonsPrdcdAndSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>$5.481</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">6</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotRefinedCoalTonsPrdcdSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 6 -->
  
   <!--  Line 7 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">7</div>
    <span class="styLNDesc" style="width: 137mm">
      Phaseout adjustment (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ......
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">$
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalCrBeforePhaseoutAdj"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span><span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 10mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalPhaseoutAdjRate"/>
        </xsl:call-template>
        </span>
      </span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">7</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalTotalPhaseoutAdj"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 7 -->
  
   <!--  Line 8 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;padding-left: 2mm">8</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 7 from line 6 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            .........................
          </span>        
      <div class="styLNRightNumBox">8</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalTonsCreditMinusAdj"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 8 -->
    
    
    <!-- Begin of line 9 -->
    
      <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        Indian Coal produced at a qualified Indian coal production facility
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style=" height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>

          
    
     <!--  Line 9 -->  
     
     
       <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">9</div>
    <span class="styLNDesc" style="width: 137mm">
      Tons produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          .....
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
    <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/
          IndianCoalProducedAndSold"/>
        </xsl:call-template> 
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>$1.50</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">9</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/
          TotIndianCoalProducedAndSoldCr"/>
        </xsl:call-template>  
      </span>        
  </div>

     
     
<!--     
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="padding-left: 2mm;height:4mm">9</div>
      <div style="float: left; padding-top: .5mm">
        Credit before reduction. Add lines 5 and 8 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ....................
          </span>        
      <div class="styLNRightNumBox">9</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalCrBeforeReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>             -->
    <!-- End Line 9 -->
    
    
            <!--  Line 10 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;padding-left: 2mm">10</div>
      <div style="float: left; padding-top: .5mm">
      Credit before reduction. Add lines 5, 8 and 9 
       </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ...................
          </span>        
      <div class="styLNRightNumBox">10</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalCrBeforeReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 10 -->
  
  <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        Reduction for government grants, subsidized financing, and other credits:
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>
 
 <!--  Line 11  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">11</div>
        <div style="float:left; padding-top: .5mm">
          Total of government grants, proceeds of tax-exempt government obligations, subsidized energy </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
         financing, and any other credits allowed for the project for this and all prior tax years
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ......
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">11</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalOfGovernmentGrants"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 11  -->
  
   <!--  Line 12 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">12</div>
      <div style="float: left; padding-top: .5mm">
        Total of additions to the capital account for the project for this and all prior tax years 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ......
          </span>        
      <div class="styLNRightNumBox">12</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalOfCapitalAccountAdditions"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 12 -->
    
    <!--  Line 13 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">13</div>
      <div style="float: left; padding-top: .5mm">
        Divide line 11 by line 12. Show as a decimal carried to at least 4 places 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ..........
          </span>        
      <div class="styLNRightNumBox">13</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CreditReductionPercentage"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 13 -->
    
    <!--  Line 14 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">14</div>
      <div style="float: left; padding-top: .5mm">
        Multiply line 10 by the lesser of 1⁄2 or line 13 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ...................
          </span>        
      <div class="styLNRightNumBox">14</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 14-->    
    
    <!--  Line 15 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">15</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 14 from line 10 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ........................
          </span>        
      <div class="styLNRightNumBox">15</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjustedCreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 15 -->
    
     <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        Electricity produced at qualified closed-loop biomass facilities modified to co-fire with
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>
   <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        coal, other biomass, or both
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>
    
    <!--  Line 16 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">16</div>
      <div style="float: left; padding-top: .5mm">
        Thermal content of closed-loop biomass used in the facilities 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ..............
          </span>        
      <div class="styLNRightNumBox">16</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ModifiedBiomassThermalContent"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 16 -->
    
    <!--  Line 17 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">17</div>
      <div style="float: left; padding-top: .5mm">
        Thermal content of all fuels used in the facilities 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ..................
          </span>        
      <div class="styLNRightNumBox">17</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ModifiedFuelThermalContent"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 17 -->
    
    <!--  Line 18 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">18</div>
      <div style="float: left; padding-top: .5mm">
        Divide line 16 by line 17. Show as a decimal carried to at least two places 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            .........
          </span>        
      <div class="styLNRightNumBox">18</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ModifFuelThermalCrReductionPct"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 18 -->
 
  <!--  Line 19 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">19</div>
    <span class="styLNDesc" style="width: 137mm">
      Kilowatt-hours produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ..
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ModifiedBiomassKwHrsPrdcdSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>0.019</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">19</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotModifBmssKwHrsPrdcdSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 19 -->
  
  <!--  Line 20 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">20</div>
      <div style="float: left; padding-top: .5mm">
        Multiply line 19 by line 18 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            .........................
          </span>        
      <div class="styLNRightNumBox">20</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotModifBiomassPrdcdSoldCrRed"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 20 -->

<!--  Line 21 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox">21</div>
    <span class="styLNDesc" style="width: 137mm">
      Phaseout adjustment (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ......
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">$
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ModifBiomassCrBfrPhaseoutAdj"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span><span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 10mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ModifBiomassPhaseoutAdjRate"/>
        </xsl:call-template>
        </span>
      </span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">21</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ModifBiomassTotPhaseoutAdj"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 21 -->

    <!--  Line 22 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">22</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 21 from line 20 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ........................
          </span>        
      <div class="styLNRightNumBox">22</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjModifBiomassCreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 22 -->
      
      <!--  Line 23  -->
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm">23</div>
    <div class="styLNDesc" style="width:28mm; height:4mm">
      <div style = "width:29mm;">Section B credits from pass-through entities:</div>
    </div>
    <div class="styLNDesc" style="width:1.75mm; height:4mm"> </div>
    <div class="styLNDesc" style="width:106mm; height:4mm">
      <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Table for Work Opportunity Credit">
         <tr>
            <th class="styTableCell" scope="col" style="border-color: black; border-top-width: 1px; font-weight: bold; font-size: 6pt; width: 30mm; padding-left: 2mm; text-align: left">                
              If you are a—              
            </th>
            <th class="styTableCell" scope="col" style="border-color: black; font-weight: bold; border-right-width:0px; border-top-width:1px; font-size: 6pt; width: 68mm;padding-left: 2mm; text-align: left">
              Then enter the credit(s) from—
            </th>
         </tr>
         <tr>
            <td scope="row" style="width: 30mm; font-size: 6pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt">
            <span class="styBoldText" style="padding-left: 2mm">a</span> Shareholder<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">..</span>      
            <br/>
              <span class="styBoldText" style="padding-left: 2mm">b</span> Partner<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">...</span> 
              <br/> 
              <span class="styBoldText" style="padding-left: 2mm">c</span> Beneficiary<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">..</span>
              <br/> 
              <span class="styBoldText" style="padding-left: 2mm">d</span> Patron<span class="styDotLn" style="float: none; font-size: 7pt; padding-left: 2mm">....</span>
              </td>
            <td style="font-size:6pt;font-style: normal;font-weight:normal;border:none;padding-left: 2mm">
              Schedule K-1 (Form 1120S), box 13, code F, G, or U
              <span class="styDotLn" style="float: none; font-size: 7pt">.</span>
              <br/>
              Schedule K-1 (Form 1065), box 15, code F, G, or U
              <span class="styDotLn" style="float: none; font-size: 7pt">.</span>
              <br/>
              Schedule K-1 (Form 1041), box 13, code J
                <span class="styDotLn" style="float: none; font-size: 7pt">....</span>
               <br/>
              Written statement from cooperative
                <span class="styDotLn" style="float: none; font-size: 7pt">......</span>
            </td>
          <td style="width:4mm">
            <div class="styLNDesc" style="width:4mm">
              <img src="{$ImagePath}/8835_Bracket_Md.gif" alt="Curly Bracket Image"/>                                    
            </div>            
          </td>
          <td class="styDotLn" style="width: 8mm; font-size: 7pt; padding-bottom: 4mm">
          ..
          </td>
         </tr>            
      </table>          
    </div>
    <div class="styLNRightNumBox" style="height:7mm;padding-top:0mm;">
      <div class="styLNRightNumBoxN" style="width:7.75mm;background-color:lightgrey;height:7mm"></div>
          23          
    </div>        
    <div class="styLNAmountBox" style="height: 10.9mm; width: 34mm; padding-top: 7mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CreditsFromPassThroughEntities"/>
      </xsl:call-template>
    </div>  
    <div style="float:right">          
      <div class="styLNRightNumBoxNBB" style="height: 6mm;background-color: lightgrey"></div>
      <div class="styLNAmountBoxNBB" style="height: 6mm;width: 34.25mm"></div>          
  </div>
  </div>      
  
  <!--  Line 24 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">24</div>
      <div style="float: left; padding-top: .5mm">
        Add lines 15, 22, and 23 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ..........................
          </span>        
      <div class="styLNRightNumBox">24</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/GovtGrantsAndModifBiomassCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 24 -->
  
  <!--  Line 25  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">25</div>
        <div style="float:left; padding-top: .5mm">
          Renewable electricity, refined coal, and Indian coal production credit included on line 24 from </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;" />
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
         passive activities (see instructions)
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ......................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">25</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RenewableElecRefinedCoalProdCr"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 25  -->  
    
     <!--  Line 26 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">26</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 25 from line 24 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ........................
          </span>        
      <div class="styLNRightNumBox">26</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjGovtGrantsAndModifBiomassCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 26 -->
    
    <!--  Line 27  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">27</div>
        <div style="float:left; padding-top: .5mm">
         Renewable electricity, refined coal, and Indian coal production credit allowed for 2005 from a</div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
        passive activity (see instructions)
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ......................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">27</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RnwblElecRefinedCoalCrAllwCY"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 27  -->
    
    <!--  Line 28 -->  
    
    
         <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">28</div>
        <div style="float:left; padding-top: .5mm">
          Carryforward of renewable electricity and refined coal production credit to 2005</div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
        (see instructions)
	          <xsl:call-template name="LinkToLeftoverDataTableInline">
	       	     <xsl:with-param name="Desc">Line 28 - Form 8884 Indicator</xsl:with-param>
		     	<xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CfwdRnwblElecRefinedCoalNextYr/@form8884Indicator"/>
		     </xsl:call-template>
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ...........................
                          </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">28</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CfwdRnwblElecRefinedCoalNextYr"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
 
    
    
    <!--  Line 29 -->  
    
         <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">29</div>
        <div style="float:left; padding-top: .5mm">
         Carryback of renewable electricity, refined coal, and Indian coal production credit from 2006</div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
        (see instructions)
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ............................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">29</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CybkRnwblElecRefinedCoalNextYr"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
 
    <!-- End Line 29 -->

 <!--  Line 30  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">30</div>
        <div style="float:left; padding-top: .5mm">
          <span class="styBoldText">Current year credit. </span> Add lines 26 through 29 (<b>Caution.</b> if you also have a credit from Form 6478,
	   </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
          (see instructions)
	          <xsl:call-template name="LinkToLeftoverDataTableInline">
	       	     <xsl:with-param name="Desc">Line 30 - Form 6478 Indicator</xsl:with-param>
		     	<xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalCurrentYearCredit/@form6478Indicator"/>
		     </xsl:call-template>
          
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ..........................
            </span>          
        <div class="styLNRightNumBoxNBB" style="height:4.5mm;">30</div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalCurrentYearCredit"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 30  -->
 
  <!--  Part II Title-->
  <div class="styBB" style="width: 187mm; border-top-width: 1px">
    <div class="styPartName" style="width: 15mm">Part II</div>
    <div class="styPartDesc" style="width: 172mm">Allowable Credit</div>
  </div>
  <!--  End Part II Title-->
   
   <!--  Line 31 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">31</div>
      <div style="float: left; padding-top: .5mm">
        Regular tax before credits (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ...................
          </span>        
      <div class="styLNRightNumBox">31</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RegularTaxBeforeCredits"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 31 -->
    
    <!--  Line 32 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">32</div>
      <div style="float: left; padding-top: .5mm">
        Alternative minimum tax (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ....................
          </span>        
      <div class="styLNRightNumBox">32</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AlternativeMinimumTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 32 -->
    
    <!--  Line 33 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">33</div>
      <div style="float: left; padding-top: .5mm">
        Add lines 31 and 32 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ...........................
          </span>        
      <div class="styLNRightNumBox">33</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RegularTaxPlusAltMinimumTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 33 -->
    
     <!-- Line 34a-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">34a</div>
        <div class="styLNDesc" style="width:97mm;height:4mm">
          Foreign tax credit
          <span class="styDotLn" style="float: none">  
            ..................
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34a</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34a-->
      
      <!-- Line 34b-->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">b</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
         Credits from Form 1040, lines 48 through 54
          <!--Dotted Line-->
          <span class="styDotLn" style="float: none">  
            .........
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34b</div>
        <div class="styLNAmountBox" style="height:4.5mm;">  </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34b-->
      
     
      <!-- Line 34c -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">c</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Possessions tax credit (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              .......
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/PossessionsTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34c -->
      
      <!-- Line 34d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">d</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
         Nonconventional source fuel credit (Form 8907, line 23)
            <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              .....
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NonconventionalSourceFuelCr"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34d -->
      
      <!-- Line 34e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">e</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Other specified credits (see instructions)
            <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              ..........
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34e</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/OtherSpecifiedCredits"/>
          </xsl:call-template>
          </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34e -->
      
      <!-- Line 34f -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">f</div>
        <div style="float: left">
          Add lines 34a through 34e
        </div>
        <div style="float:right">
          <!--Dotted Line-->
            <span class="styDotLn">  
              .........................
            </span>  
        <div class="styLNRightNumBox" style="height:4.5mm;">34f</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalTaxCredits"/>
          </xsl:call-template>
        </div>
      </div>
      </div>
      <!-- Line 34f  -->
       
       <!--  Line 35  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">35</div>
        <div style="float:left; padding-top: .5mm">
          Net income tax. Subtract line 34f from line 33. If zero, skip lines 36 through 39 and enter </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
         -0- on line 40
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              .............................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">35</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NetIncomeTax"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 35  -->

      <!--  Line 36 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">36</div>
      <div style="float: left; padding-top: .5mm">
        Net regular tax. Subtract line 34f from line 31. If zero or less, enter -0- 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ..........
          </span>        
      <div class="styLNRightNumBox">36</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NetRegularTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 36 -->
    
    <!--  Line 37 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">37</div>
      <div style="float: left; padding-top: .5mm">
        Enter 25% (.25) of the excess, if any, of line 36 over $25,000 (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            .......
          </span>        
      <div class="styLNRightNumBox">37</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/Pct25OfExcessNetRegularTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 37 -->
    
    <!--  Line 38 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">38</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 37 from line 35. If zero or less, enter -0- 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ................
          </span>        
      <div class="styLNRightNumBox">38</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjustedNetIncomeTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 37 -->
    
    <!--  Line 39 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">39</div>
      <div style="float: left; padding-top: .5mm">
        General business credit (see instructions)
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ....................
          </span>        
      <div class="styLNRightNumBox">39</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/GeneralBusinessCredit"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 39 -->
    
    <!--  Line 40 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm">40</div>
      <div style="float: left; padding-top: .5mm">
        Subtract line 39 from line 38. If zero or less, enter -0- 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ................
          </span>        
      <div class="styLNRightNumBox">40</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjNetIncomeTaxMinusGenBusCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 40 -->
   
   
   <!--  Line 41  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">41</div>
        <div style="float:left; padding-top: .5mm">
          <span class="styBoldText">Credit allowed for the current year. </span> Enter the <span class="styBoldText">smaller </span>of line 30 or line 40. Report this amount </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
         and the amount from Section A, line 21 (if any) on Form 1040, line 55; Form 1120, Schedule J,</div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
           line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule G, line 2c; or the applicable line of</div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div class="styBB"  style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
         your return. If line 40 is smaller than line 30, see instructions
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              .............
            </span>          
        <div class="styLNRightNumBoxNBB" style="height:4.5mm;">41</div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CurrentYearCreditAllowed"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 40  -->
      
      
      
      
      
      
      
      
      
      <!--  FOOTER-->
        <div style="width:187mm">
        <span style="float: right">
          Form <span class="styBoldText">8835</span> (2005)
        </span>
        </div>

        <br class="pageEnd"/>
        <br/><br/>

<!--END FOOTER-->
          
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$FormData" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>  
          
          <xsl:call-template name="PopulateLeftoverRow">
            <xsl:with-param name="Desc">Fiscal Year Taxpayer Indicator</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$FormData/@fiscalYearTaxpayerIndicator"/>
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>        
        </table>
      <!-- END Left Over Table -->      
  </form>  
</body>
</html>

</xsl:template>    

</xsl:stylesheet>
