<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="AddHeader.xsl"/>
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddOnTable.xsl"/>
  <xsl:include href="IRS8844Style.xsl"/>
  <xsl:output method="html" indent="yes" />
  <xsl:strip-space elements="*" />  
  <xsl:param name="Form8844Data" select="$RtnDoc/IRS8844" />  
  <xsl:template match="/">
    <html lang="EN-US">
      <head>
        <title>
          <xsl:call-template name="FormTitle">
            <xsl:with-param name="RootElement" select="local-name($Form8844Data)">
            </xsl:with-param>
          </xsl:call-template>
        </title>
        <!-- No Browser Caching -->
        <meta http-equiv="Pragma" content="no-cache" />
        <meta http-equiv="Cache-Control" content="no-cache" />
        <meta http-equiv="Expires" content="0" />
        <!-- No Proxy Caching -->
        <meta http-equiv="Cache-Control" content="private" />
        <!-- Define Character Set -->
        <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
        <meta name="Description" content="IRS Form 8844" />
        <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
        <xsl:call-template name="InitJS"></xsl:call-template>
        <style type="text/css">
          <xsl:if test="not($Print) or $Print=''">
            <xsl:call-template name="IRS8844Style"></xsl:call-template>
            <xsl:call-template name="AddOnStyle"></xsl:call-template>
          </xsl:if>  
        </style>
        <xsl:call-template name="GlobalStylesForm"/>
      </head>
      <body class="styBodyClass">
        <form id="Form8844">
          <xsl:call-template name="DocumentHeader"></xsl:call-template>
          <div class="styTBB" style="width:187mm;">
            <div class="styFNBox" style="width:30mm;height:16mm;">
              <div style="height:9mm;">Form<span class="styFormNumber">  8844</span>
              <br />
              </div>
              <div style="height:6mm;padding-top:5mm;">
                <span class="styAgency">Department of the Treasury</span>
                <br />
                <span class="styAgency">Internal Revenue Service</span>
              </div>
            </div>
            <div class="styFTBox" style="width:125mm;height:16mm;">
              <div class="styMainTitle" style="height:12mm;font-size:13pt;padding-top:1mm;">
                Empowerment Zone and Renewal <br />Community Employment Credit
              </div>
              <div class="styFMT" style="height:4mm;font-size:7pt;padding-top:5mm;">
                <img src="{$ImagePath}/8844_Bullet.gif" alt="Bullet Image" />
                Attach to your tax return.
              </div>
            </div>
            <div class="styTYBox" style="width:32mm;height:12mm;">
              <div class="styOMB" style="height:3mm;padding-top:0mm;">
                OMB No. 1545-1444
              </div>
              <div class="styTY" style="height:3mm;font-size:21pt;padding-top:0mm;padding-bottom:0mm;">
                    20<span class="stytycolor">05</span>
              </div>
              <div class="styOMB" style="height:3.5m;text-align:left;padding-left:5mm;border-bottom-width:0px;">
                    Attachment <br />Sequence No. <span class="styBoldText">99</span>
              </div>
            </div>
          </div>    
          <!-- End Form Number and Name section -->
          <!-- Begin Names and Identifying number section -->
          <div style="width:187mm;" class="styBB">
            <div style="width:138mm;height:8mm;font-weight:normal;font-size:7pt;" class="styNameBox">
              Name(s) shown on return<br />
             <div style="font-family:verdana;font-size:6pt;height:6.25mm">      
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
             <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
             </div>            
            </div>
            
            <div style="width:49mm;height:4mm;padding-left:2mm;font-size:7pt;" class="styEINBox">
              Identifying number<br /><br />
              <span style="font-weight:normal;">  
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
              </span>      
            </div>
          </div>    
          <!-- End Names and Identifying number section -->
          <!-- Start Part I Current Year Credit -->    
          <div style="width:187mm;" class="styBB">
            <div class="styPartName" style="width:15mm;">Part I</div>
            <div class="styPartDesc" style="padding-left:3mm;">
              Current Year Credit  
            </div>
          </div>
          <!-- Part I, line 1 -->          
          <div class="styBB" style="width:187mm;">
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">
                  1
                </div>
                <div class="styLNDesc" style="height:4mm;">        
                  Enter the total qualified wages paid or incurred during <span class="styBoldText">calendar year 2005</span> only (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm;border-right-width:1px;border-right-width:0px;">
                </div>
                <div class="styLNAmountBoxNBB">
                </div>
              </div>
            </div>      
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;">a</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Qualified empowerment zone wages
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ......
                </div>
                <div style ="width:3mm;float:left;clear:none;">
                  $   
                </div>
                <div class="styBB"  style ="width:32mm;text-align:right;float:left;clear:none;">
                  <xsl:if test="not($Form8844Data/QualifiedEmpowermentZoneWages) or $Form8844Data/QualifiedEmpowermentZoneWages = ''">
                    <span style="width:1px;"></span>
                  </xsl:if>
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/QualifiedEmpowermentZoneWages"/>
                  </xsl:call-template>
                </div>
                <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 20% (.20)</div>
                <div style="width:12mm;float:left;Clear:none;"></div>
                <div class="styLNRightNumBox">
                  1a
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalQualifiedEmpwrZoneWages"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>            
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;">b</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Qualified renewal community wages
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ......
                </div>
                <div style ="width:3mm;float:left;clear:none;">
                  $   
                </div>
                <div class="styBB"  style ="width:32mm;text-align:right;float:left;clear:none;">
                  <xsl:if test="not($Form8844Data/QualifiedRenewalCommunityWages) or $Form8844Data/QualifiedRenewalCommunityWages = ''">
                    <span style="width:1px;"></span>
                  </xsl:if>
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/QualifiedRenewalCommunityWages"/>
                  </xsl:call-template>
                </div>
                <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 15% (.15)</div>
                <div style="width:12mm;float:left;Clear:none;"></div>
                <div class="styLNRightNumBox">
                  1b
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalQlfyRnwlCommunityWages"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>
            <!-- Part I, line 2 -->            
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">2</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Add lines 1a and 1b. You <span class="styBoldText">must</span> subtract this amount from your deduction for salaries and wages
                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBox">
                  2
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CurrentYearCredit1"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 3 -->            
            <div style="width:187mm;">
              <div style="float:left">
                <div class="styLNLeftNumBox" style="height:4mm;">3</div>
                <div class="styLNDesc" style="width:18mm; height:4mm;">
                    Form 8844 credits from pass-through entities:
                </div>
                <div class="styLNDesc" style="width:5mm; height:4mm;"> </div>
                <div class="styLNDesc" style="width:116mm; height:4mm;">
                  <table summary="Table for Work Opportunity Credit" id="wkOpCrd" style="width:116mm;font-size:7pt;" cellpadding="0" cellspacing="0" border="0" class="stytable">
                    <tr>
                      <th scope="col" class="styForm8844TBTable" style="width:29mm;text-align:center;" >
                          If you are a-
                        </th>
                       <th style="border-right:none;padding-left:2mm;width:73mm;text-align:left;" scope="col" class="styForm8844TBTable">
                          Then enter the total of the current year credits from-
                        </th>
                        <th style="padding-left:2mm;" scope="col"><span style="width:2px;"></span></th>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                         <span style="float:left;">
                           <span class="styBoldText">a</span> Shareholder
                         </span>
                         <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >..</span>
                         </span>
                       </td>
                       <td style="padding-left:2mm;">
                             <span style="float:left;">
                        Schedule K-1 (Form 1120S), box 13, code F, G, or M
                          </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >.</span>
                         </span>
                      </td>
                       <td rowspan="4">
                         <span style="float:left;">
                          <img alt="Bullet Image" src="{$ImagePath}/8844_Bracket_Sm.gif" />
                        </span>
                        <span style="float:right;letter-spacing:3.2mm;padding-right:3mm;font-weight:bold;padding-top:4.5mm;padding-left:1mm;">..</span>
                       </td>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                          <span style="float:left;">
                          <span class="styBoldText">b</span> Partner
                        </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >...</span>
                         </span>              
                       </td>
                       <td style="padding-left:2mm;">
                            <span style="float:left;">
                        Schedule K-1 (Form 1065), box 15, code F, G or M
                         </span>
                           <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >.</span>
                         </span>              
                       </td>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                           <span style="float:left;">
                          <span class="styBoldText">c</span> Beneficiary
                         </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >..</span>
                         </span>
                      </td>
                       <td style="padding-left:2mm;">
                            <span style="float:left;">
                          Schedule K-1 (Form 1041), Box 13, code K            
                          </span>
                            <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >....</span>
                         </span>              
                      </td>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                           <span style="float:left;">
                          <span class="styBoldText">d</span> Patron
                         </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >....</span>
                         </span>
                      </td>
                       <td style="padding-left:2mm;">
                            <span style="float:left;">
                          Written statement from cooperative
                         </span>
                           <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >......</span>
                         </span>              
                       </td>
                    </tr>
                  </table>
                </div>
              </div>
              <div style="float:right;">
                <div style="height:9mm;background-color:lightgrey;" class="styLNRightNumBoxNBB"></div>
                <div style="height:9mm;" class="styLNAmountBoxNBB"></div>
                <div style="height:4mm;" class="styLNRightNumBox">3</div>
                <div style="height:4.5mm;" class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditsFromFlowthruEntities"/>
                  </xsl:call-template>        
                </div>
                <div style="height:4.5mm;" class="styLNRightNumBoxNBB"></div>
                <div style="height:4.5mm;" class="styLNAmountBoxNBB"></div>
              </div>
            </div>    
            <!-- Part I, line 4 -->                
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">4</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Add lines 2 and 3
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ............................
                </div>
                <div class="styLNRightNumBox">
                  4
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalCurrentYearEZRCECredit"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 5 -->            
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">5</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Empowerment zone and renewal community employment credit included on line 4 from passive
                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBoxNBB">
                </div>
                <div class="styLNAmountBoxNBB" >
                </div>
              </div>
            </div>  
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;"></div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  activities (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ........................
                </div>
                <div class="styLNRightNumBox">
                  5
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/EZRCECreditFromPassiveActy"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 6 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">6</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Subtract line 5 from line 4
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  .........................
                </div>
                <div class="styLNRightNumBox">
                  6
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditWithoutPssvActyForPY"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 7 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">7</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Passive activity credit allowed for 2005 (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  .............
                </div>
                <div class="styLNRightNumBox">
                  7
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/PssvActivityCreditAllowedForPY"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 8 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">8</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Carryforward of empowerment zone and renewal community employment credit to 2005
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ....
                </div>
                <div class="styLNRightNumBox">
                  8
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CarryForwardOfEZECrToPY"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 9 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">9</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Carryback of empowerment zone and renewal community employment credit from 2006 (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBox">
                  9
                </div>
                <div class="styLNAmountBox" >
                  <!--xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CarryForwardOfEZECrToPY"/>
                  </xsl:call-template-->        
                </div>
              </div>
            </div>  
            <!-- Part I, line 10 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">10</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  <span class="styBoldtext">Current year credit.</span> Add lines 6 through 9. (S corporations, partnerships, estates, trusts, and
                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBoxNBB">
                </div>
                <div class="styLNAmountBoxNBB" >
                </div>
              </div>
            </div>  
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;"></div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  cooperatives, see instructions.)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  .......................
                </div>
                <div class="styLNRightNumBoxNBB">
                  10
                </div>
                <div class="styLNAmountBoxNBB" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CurrentYearCredit2"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>
          </div>  
          <!-- End PartII Current Year Credit -->    
    
          <!-- Begin Allowable credit section-->
          <!-- Begin part II -->
          <div class="styBB" style="width:187mm;">
            <div class="styPartName">Part II</div>
            <div class="styPartDesc" style="padding-left:3mm;">
              Allowable Credit
            </div>
          </div>
          <div class="styBB" style="width:187mm;">
            <div style="width:187mm">  
              <div class="styLNLeftNumBox">11</div>
              <div style="float:left;padding-top:.5mm;">
                Regular tax before credits:                
              </div>
              <div style="float:right">  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <!-- Part II, line 11 -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Individuals. Enter the amount from Form 1040, line 44                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ..........
                </span>
                <div class="styLNLeftNumBox" style="position:relative;width:25mm;">
                    <!-- bracket -->
                      <span style="position:absolute;top:0mm;left:-3mm;">
                        <img src="{$ImagePath}/8844_Bracket_Lger.gif" alt="bracket" border="0"/>
                      </span>
                    <!-- end bracket -->
                </div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Corporations. Enter the amount from Form 1120, Schedule J, line 3; Form 1120-A,            
              </div>
              <div style="float:right">  
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"></div>
              <div style="float:left;padding-top:.5mm;">
                Part I, line 1; or the applicable line of your return                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ..........
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;">
	                <span class="styDotLn">      
	                  ......
	                </span>
                </div>  
                <div class="styLNRightNumBox" style="height:4.5mm;">11</div>  
                <div class="styLNAmountBox" style="height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/RegularTaxBeforeCredits"/>
                  </xsl:call-template>
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G,             
              </div>
              <div style="float:right">  
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"></div>
              <div style="float:left">
                lines 1a and 1b, or the amount from the applicable line of your return                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ....
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>            
            <!-- Part II, line 12 -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox">12</div>
              <div style="float:left;padding-top:.5mm;">
                Alternative minimum tax:
              </div>
              <div style="float:right">
	              <div class="styLNLeftNumBox" style="position:relative;width:25mm;">
	                 <!-- bracket -->
	                   <span style="position:absolute;top:0mm;left:-3mm;">
	                     <img src="{$ImagePath}/8844_Bracket_Lg.gif" alt="bracket" border="0"/>
	                   </span>
	                 <!-- end bracket -->
	              </div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <!-- First bullet point -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Individuals. Enter the amount from Form 6251, line 35                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ..........
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;"></div>
                <div class="styLNRightNumBox" style="border-bottom-width:1px;height:4.5mm;">12</div>  
                <div class="styLNAmountBox" style="border-bottom-width:1px;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/AlternativeMinimumTax"/>
                  </xsl:call-template>
                </div>    
              </div>
            </div>
            <!-- Second bullet point -->    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Corporations. Enter the amount from Form 4626, line 14            
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  .........
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;">
	                <span class="styDotLn" style="position:relative;top:-4mm;">      
	                  ......
	                </span>
                </div>  
                <div class="styLNRightNumBox" style="border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <!-- Third bullet point -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56             
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ....
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>   
	          <!-- End Part II, line 12 -->
				  <!-- Part II, line 13 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">13</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Add lines 11 and 12    
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ...........................
                </div>
                <div class="styLNRightNumBox">
                  13
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SumOfRegularAndAltMinmumTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 14a -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">14a</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Foreign tax credit    
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ..................
                </div>
                <div class="styLNRightNumBox">
                  14a
                </div>
                <div class="styLNAmountBox"  style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/ForeignTaxCredit"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 14b -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">b</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Credits from Form 1040, lines 48 through 54   
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  .........
                </div>
                <div class="styLNRightNumBox">
                  14b
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <!--xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalCurrentYearEZRCECredit"/>
                  </xsl:call-template-->
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 14c -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">c</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Possessions tax credit (Form 5735, line 17 or 27)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">.......
                </div>
                <div class="styLNRightNumBox">
                  14c
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/PossessionsTaxCredit"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 14d -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">d</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Nonconventional source fuel credit (Form 8907, line 23)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">......
                </div>
                <div class="styLNRightNumBox">
                  14d
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditForFuelFromNnconvSource"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 14e -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">e</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Other specified credits (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">..........
                </div>
                <div class="styLNRightNumBox">
                  14e
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/OtherSpecifiedCredits"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>   
            <!-- Part II, line 14f -->       
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">f</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Add lines 14a through 14e
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">.........................
                </div>
                <div class="styLNRightNumBox">
                  14f
                </div>
                <div class="styLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalCredits"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 15 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">15</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Net income tax. Subtract line 14f from line 13. If zero, skip lines 16 through 22 and enter -0- on line 23
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  15
                </div>
                <div class="styLNAmountBox" style="height:4.5mm;" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/NetIncomeTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>   
            <!-- Part II, line 16 -->       
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">16</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Net regular tax. Subtract line 14f from line 11. If zero or less, enter -0-
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBox">
                  16
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/NetRegularTax"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 17 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">17</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Tentative minimum tax (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">..........
                </div>
                <div class="styLNRightNumBox">
                  17
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TentativeMinimumTax"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 18 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">18</div>
                <div class="styForm8844LnDesc" style="height:4mm;font-size:6pt;">
                  Enter 25% (.25) of the excess, if any, of line 16 over $25,000 (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">.
                </div>
                <div class="styLNRightNumBox">
                  18
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TwentyFivePercentOfExcess"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 19 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">19</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Multiply line 17 by 75% (.75)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">..............
                </div>
                <div class="styLNRightNumBox">
                  19
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SeventyFivePercentOfTentMinTax"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 20 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">20</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Enter the greater of line 18 or line 19
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">.....................
                </div>
                <div class="styLNRightNumBox">
                  20
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/GreaterOfTentMinTaxOrExcess"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 21 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">21</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Subtract line 20 from line 15. If zero or less, enter -0-
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">................
                </div>
                <div class="styLNRightNumBox">
                  21
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SubtractGreaterFromNetIncTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 22 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">22</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  General business credit (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                ....................
                </div>
                <div class="styLNRightNumBox">
                  22
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/GeneralBusinessCredit"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>    
            <!-- Part II, line 23 -->  
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">23</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Subtract line 22 from line 21
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">........................
                </div>
                <div class="styLNRightNumBox">
                  23
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SubtractGenBusCreditFromTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 24 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">24</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  <span class="styBoldText">Credit allowed for the current year.</span> Enter the smaller of line 10 or line 23 here and on Form 1040,
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;">
                </div>
                <div class="styLNAmountBoxNBB">
                </div>
              </div>
            </div>
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;"></div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                   line 55; Form 1120, Schedule J, line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule G, line 2c;
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;">
                </div>
                <div class="styLNAmountBoxNBB">
                </div>
              </div>
            </div>
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;"></div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  or the applicable line of your return. If line 23 is smaller than line 10, see instructions
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBoxNBB">24
                </div>
                <div class="styLNAmountBoxNBB">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditAllowedForCY"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
          </div>
          <div style="width:186mm;clear:both;padding-top:1mm;">
            <div style="width:90mm;font-weight:bold;" class="styGenericDiv">For Paperwork Reduction Act Notice, see page 4.</div>
            <div style="width:55mm;text-align:center;" class="styGenericDiv">Cat. No. 16145S</div>
            <div style = "float:right;" class="styGenericDiv">Form <span class="styBoldText">8844</span> (2005)</div>
          </div>    
          <p class="pageend"></p>        
          <!-- BEGIN Left Over Table -->  
          <!-- Additonal Data Title Bar and Button -->
          <div class="styLeftOverTitleLine" id="LeftoverData">
            <div class="styLeftOverTitle">
              Additional Data        
            </div>
            <div class="styLeftOverButtonContainer">
              <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
            </div>      
          </div>
          <!-- Additional Data Table -->
          <table class="styLeftOverTbl">
            <xsl:call-template name="PopulateCommonLeftover">
              <xsl:with-param name="TargetNode" select="$Form8844Data" />
              <xsl:with-param name="DescWidth" select="100"/>
            </xsl:call-template>          
          </table>
          <!-- END Left Over Table -->  
        </form>
      </body>
    </html>
  </xsl:template>
</xsl:stylesheet>
