<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8845Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8845Data" select="$RtnDoc/IRS8845" />


<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8845Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 8845" />
      
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>

    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 8845 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS8845Style"></xsl:call-template>
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>  
    </style>
  
    <xsl:call-template name="GlobalStylesForm"/>
  </head>

  <body class="styBodyClass">
    <form name="Form8845">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>

      <!-- Begin Form Number and Name -->
      <div class="styBB" style="width:187mm;">
      
        <div class="styFNBox" style="width:31mm;height:20mm;">
          Form <span class="styFormNumber">8845</span>
        
          <br/><br/>
          <div style="padding-top:1mm;">
            <span class="styAgency">Department of the Treasury</span>
            <br/>
            <span class="styAgency">Internal Revenue Service</span>
          </div>
        </div>
      <div class="styFTBox" style="width:125mm;height:13mm;">
        <div class="styMainTitle" style="height:8mm;padding-top: 2mm">
          Indian Employment Credit          
        </div>
        <br/>
        <br/>
        <div class="styFST" style="height:5mm;font-size:7pt;padding-top:1.5mm;">
          <img src="{$ImagePath}/8845_Bullet.gif" width="4" height="7"  alt="Bullet Image"/>
          Attach to your tax return.
        </div>
      </div>
      <div class="styTYBox" style="width:30mm;height:20mm;">
        <div class="styOMB" style="height:2mm;">
          OMB No. 1545-1417
        </div>
        <div class="styTaxYear" style="height:7.5mm">
          20<span class="styTYColor">05</span>
        </div>
        Attachment<span style="width:20px;"></span><br/> 
        <span style="width:12px;"></span>Sequence No.<span style="width:4px;"></span><span class="styBoldText">113</span>
      </div>
    </div>
    
    <!-- End Form Number and Name section -->
    <!-- Begin Names and Identifying number section -->

    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:156mm;height:8mm;font-size:7pt;">
        Name(s) as shown on return<br/>
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>        
      </div>
      <div class="styEINBox" style="width:30mm;height:4mm;padding-left:2mm;font-size:7pt;">
        Identifying number<br/><br/>
        <span style="font-weight:normal;">  
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
        </span>          
      </div>
    </div>
    
    <!-- End Names and Identifying number section -->
    <!-- Start Part I Current Year Credit -->
    
    <div class="styBB" style="width:187mm;">
      <div class="styPartName">Part I</div>
      <div class="styPartDesc">Current Year Credit</div>
    </div>
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm;">
        <div class="styLNLeftNumBoxSD" style="height:7.5mm;">1</div>
        <div class="styLNDesc" style="height:7.5mm;">
          Total of qualified wages and qualified employee health insurance costs paid or incurred during the tax year
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..............................</span>  
        </div>        
        <div class="styLNRightNumBox" style="height:7.5mm;padding-top: 3.5mm">1</div>
        <div class="styLNAmountBox" style="height:7.5mm;padding-top:3.5mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/TotalOfQualifiedWages"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBoxSD" style="height:7.5mm;">2</div>
        <div class="styLNDesc" style="height:7.5mm;padding-right:1mm;">
          Calendar year 1993 qualified wages and qualified employee health insurance costs (see instructions). If none, enter -0-
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..........................</span>  
        </div>        
        <div class="styLNRightNumBox" style="height:7.5mm;padding-top: 3.5mm">2</div>
        <div class="styLNAmountBox" style="height:7.5mm;padding-top: 3.5mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/CalendarYear1993QualifiedWages"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBoxSD" style="height:7mm;padding-top: 2.5mm">3</div>
        <div class="styLNDesc" style="height:7mm;padding-right:1mm;padding-top: 2.5mm">
          Incremental increase. Subtract line 2 from line 1
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">................</span>  
        </div>        
        <div class="styLNRightNumBox" style="height:7mm;padding-top: 3mm">3</div>
        <div class="styLNAmountBox" style="height:7mm;padding-top: 3mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/IncrementalIncrease"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBoxSD" style="height:7mm;padding-top: 2mm">4</div>
        <div class="styLNDesc" style="height:7mm;padding-right:1mm;padding-top: 2mm">
          Multiply line 3 by 20% (.20) (see instructions)
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">................</span>  
        </div>        
        <div class="styLNRightNumBox" style="height:7mm;padding-top: 3mm">4</div>
        <div class="styLNAmountBox" style="height:7mm;padding-top: 3mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/CurrentYearCredit"/>
          </xsl:call-template>
        </div>
      </div>
      
<!-- Line 5 -->      
<div style="width:187mm;">
        <div style="float:left">
          <div class="styLNLeftNumBoxSD" style="height:4mm;">5</div>
          <div class="styLNDesc" style="width:18mm; height:4mm;">
              Indian employment credits from pass-through entities:
          </div>
          <div class="styLNDesc" style="width:5mm; height:4mm;"> </div>
          <div class="styLNDesc" style="width:115mm; height:4mm;">
            <table summary="Table for Work Opportunity Credit" id="wkOppCrd" style="width:115mm;font-size:7pt;" cellpadding="0" cellspacing="0" border="0" class="stytable">
              <tr>
                <th scope="col" class="styForm8845TBTable" style="width:29mm;text-align:center;" >
                    If you are a—
                  </th>
                 <th style="border-right:none;padding-left:2mm;width:73mm;text-align:left;" scope="col" class="styForm8845TBTable">
                    Then enter the total of the current year credit(s) from—
                  </th>
                  <th style="padding-left:2mm;" scope="col"><span style="width:2px;"></span></th>
              </tr>
              <tr>
                 <td style="border-right:solid black .75pt;">
                   <span style="float:left;">
                     <span class="styBoldText">a</span> Shareholder
                   </span>
                   <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >..</span>
                   </span>
                 </td>
                 <td style="padding-left:2mm;">
                       <span style="float:left;">
                  Schedule K-1 (Form 1120S), box 13, code F, G, or U
                    </span>
                    <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >.</span>
                   </span>
                </td>
                 <td rowspan="4">
                   <span style="float:left;">
                    <img alt="Bullet Image" src="{$ImagePath}/8845_Bracket_Md.gif" />
                  </span>
                  <span style="float:right;letter-spacing:3.2mm;padding-right:3mm;font-weight:bold;padding-top:4.5mm;padding-left:1mm;">..</span>
                 </td>
              </tr>
              <tr>
                 <td style="border-right:solid black .75pt;">
                    <span style="float:left;">
                    <span class="styBoldText">b</span> Partner
                  </span>
                    <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >...</span>
                   </span>              
                 </td>
                 <td style="padding-left:2mm;">
                      <span style="float:left;">
                  Schedule K-1 (Form 1065), box 15, code F, G, or U
                   </span>
                     <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >.</span>
                   </span>              
                 </td>
              </tr>
              <tr>
                 <td style="border-right:solid black .75pt;">
                     <span style="float:left;">
                    <span class="styBoldText">c</span> Beneficiary
                   </span>
                    <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >..</span>
                   </span>
                </td>
                 <td style="padding-left:2mm;">
                      <span style="float:left;">
                    Schedule K-1 (Form 1041), box 13, code L            
                    </span>
                      <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >....</span>
                   </span>              
                </td>
              </tr>
              <tr>
                 <td style="border-right:solid black .75pt;">
                     <span style="float:left;">
                    <span class="styBoldText">d</span> Patron
                   </span>
                    <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >....</span>
                   </span>
                </td>
                 <td style="padding-left:2mm;">
                      <span style="float:left;">
                    Written statement from cooperative
                   </span>
                     <span style="float:right;padding-right:1.5mm;">
                     <span class = "styDotLn" >......</span>
                   </span>              
                 </td>
              </tr>
            </table>
          </div>
        </div>
        <div style="height:9mm;" class="styLNRightNumBoxNBB"></div>
        <div style="height:9mm;" class="styLNAmountBoxNBB"></div>
        <div style="height:5mm;" class="styLNRightNumBox">5</div>
        <div style="height:5mm;" class="styLNAmountBox">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/IndianEmplmnCrFromPassThruEnt"/>
          </xsl:call-template>        
        </div>
        <div style="height:7mm;" class="styLNRightNumBoxNBB"></div>
        <div style="height:7mm;" class="styLNAmountBoxNBB"></div>
      </div>        

      <div style="width:187mm;">
        <div class="styLNLeftNumBoxSD" style="height:4mm;">6</div>
        <div class="styLNDesc" style="height:4mm;">
          <span class="styBoldText">Current year credit.</span>
          Add lines 4 and 5. (S corporations, partnerships, estates, trusts, and cooperatives, see instructions.)
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.........................</span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:8mm;padding-top:4mm;">6</div>
        <div class="styLNAmountBoxNBB" style="height:8mm;padding-top:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/TotalCurrentYearCredit"/>
          </xsl:call-template>        
        </div>
      </div>
    </div>

    <!-- End Part II Current Year Credit -->


    <!-- Begin Allowable credit section-->
    <div class="styBB" style="width:187mm;">
      <div class="styPartName">Part II</div>
      <div style="font-weight:normal;" class="styPartDesc">
        <span style ="font-weight: bold;">Allowable Credit</span>
        (See <span style ="font-weight: bold;">Who must file Form 3800</span>
         to find out if you complete Part II or file Form 3800.)
      </div>
    </div>
<!-- Line 7 -->    
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm">  
        <div class="styLNLeftNumBoxSD">7</div>
        <div style="float:left;padding-top:.5mm;">
          Regular tax before credits:                
        </div>
        <div style="float:right">  
          <div class="styIRS8845LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8845LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8845_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Individuals. Enter the amount from Form 1040, line 44                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ..........
          </span>
          <div class="styIRS8845LNLeftNumBox" style="position:relative;width:25mm;">
              <!-- floating bracket -->
                <span style="position:absolute;top:0mm;left:-3mm;">
                  <img src="{$ImagePath}/8845_Bracket_Lg.gif" alt="bracket" border="0"/>
                </span>
              <!-- end bracket -->
          </div>  
          <div class="styIRS8845LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8845LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8845_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Corporations. Enter the amount from Form 1120, Schedule J, line 3; Form 1120-A,            
        </div>
        <div style="float:right">  
          <div class="styIRS8845LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8845LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8845LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBox"></div>
        <div style="float:left">
          Part I, line 1; or the applicable line of your return                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ..........
          </span>
          <div class="styIRS8845LNLeftNumBox" style="width:25mm;">
          <span class="styDotLn">      
            ......
          </span>
          </div>  
          <div class="styIRS8845LNRightNumBox" style="height:4.5mm;padding-top:.5mm;">7</div>  
          <div class="styIRS8845LNAmountBox" style="height:4.5mm;padding-top:.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8845Data/RegularTaxBeforeCredits"/>
            </xsl:call-template>
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8845_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G,             
        </div>
        <div style="float:right">  
          <div class="styIRS8845LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8845LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8845LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styIRS8845LNLeftNumBox"></div>
        <div style="float:left">
          lines 1a and 1b, or the amount from the applicable line of your return                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ....
          </span>
          <div class="styIRS8845LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8845LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8845LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
<!-- line 8 -->            
      <div style="width:187mm">      
        <div class="styLNLeftNumBoxSD" style="padding-top:0mm;padding-bottom:0mm;">8</div>
        <div style="float:left">
          Alternative minimum tax:
        </div>
        <div style="float:right">  
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey"></div>
          <div class="styLNAmountBoxNBB" style="width:33mm;"></div>  
        </div>      
      </div>    
      
      <div style="width:187mm">      
        <div class="styLNLeftLtrBoxDD" style="padding-top:0mm;padding-bottom:0mm;"><img src="{$ImagePath}/8845_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Individuals. Enter the amount from Form 6251, line 35          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            ......        
          </span>
          <div class="styIRS8845LNLeftNumBox" style="position:relative;width:35mm;">
            <!-- floating bracket -->
              <span style="position:absolute;top:0mm;left:-3mm;">
                <img src="{$ImagePath}/8845_Bracket_Sm.gif" alt="bracket" border="0"/>
              </span>
            <!-- end bracket -->
          </div>  
          <div class="styIRS8845LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8845LNAmountBox" style="border-bottom:0;">
          </div>        
        </div>    
      </div>    
          
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD" style="padding-top:0mm;padding-bottom:0mm;"><img src="{$ImagePath}/8845_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Corporations. Enter the amount from Form 4626, line 14          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            .......    
          </span>
          <div class="styIRS8845LNLeftNumBox" style="width:35mm;">
          <span class="styDotLn">  
            ........   
          </span>
          </div>  
          <div class="styIRS8845LNRightNumBox" style="height:4.5mm;padding-top:.5mm;">8</div>
          <div class="styIRS8845LNAmountBox" style="height:4.5mm;padding-top:.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8845Data/AlternativeMinimumTax"/>
            </xsl:call-template>
          </div>  
        </div>
      </div>          
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD" style="padding-top:0mm;padding-bottom:0mm;"><img src="{$ImagePath}/8845_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            
          </span>
          <div class="styIRS8845LNLeftNumBox" style="width:35mm;"></div>  
          <div class="styIRS8845LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8845LNAmountBox" style="border-bottom:0;">
          </div>      
        </div>
      </div>       
      <!-- line 9 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBoxSD" style="height:4mm;">9</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 7 and 8
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..........................</span>
        </div>
        <div class="styLNRightNumBox" style="width:8mm;height:0.5mm;padding-top=1mm;">    
        9
        </div>
        <div class="styLNAmountBox" style="height:5mm;padding-top:1mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/RegularTaxPlusAltMinimumTax"/>
          </xsl:call-template>
        </div>
      </div>
      <!-- line 10 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">10a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Foreign tax credit
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.................</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10a</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Credits from Form 1040, lines 48 through 54
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">........</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10b</div>
        <div class="styLNAmountBox" style="height:4mm;"></div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
     
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Possessions tax credit
          (Form 5735, line 17 or 27)
            <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">......</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10c</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/PossessionsTaxCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Nonconventional source fuel credit (Form 8907, line 23)
        <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.....</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10d</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/CreditForFuelFromNnconvSource"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">e</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Other specified credits (see instructions)
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.........</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10e</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/OtherSpecifiedCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">f</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 10a through 10e                   
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.......................</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10f
        </div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/TotalCredits"/>
          </xsl:call-template>
        </div>
      </div>      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">11</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Net income tax. Subtract line 10f from line 9. If zero, skip lines 12 through 15 and enter -0- on line 16
          <!--Dotted Line-->
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">11
        </div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">12</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Net regular tax. Subtract line 10f from line 7. If zero or less, enter -0-
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">12</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/NetRegularTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">13</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <span class="stySmallText">
            Enter 25% (.25) of the excess, if any, of line 12 over $25,000 (see instructions)
          </span>          
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;padding-top:0.5mm">13</div>
        <div class="styLNAmountBox" style="height:4.5mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/TwentyFivePercentOfExcess"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;padding-top:0.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div style="width:8mm;padding-top:.5mm;padding-bottom:.5mm;font-weight:bold;float:left; clear: none;height:4mm;">
          <div style="width:8mm;padding-left:1mm;font-weight:bold;">14</div>
          <div style="width:8mm;padding-left:3.75mm;"><li/></div>
          <div style="width:8mm;padding-left:3.75mm;"><li/></div>
          <div style="width:8mm;padding-left:3.75mm;"><li/></div>
        </div>
        <div class="styLNDesc" style="width:93.25mm;height:4mm;">
          Tentative minimum tax (see instructions):
          <br/>Individuals. Enter the amount from Form 6251, line 33
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">....</span>
          <br/>Corporations. Enter the amount from Form 4626, line 12             
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...</span>
          Estates and trusts. Enter the amount from Form 1041,<br/>Schedule I, line 54
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
         </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:1mm;">
          <img src="{$ImagePath}/8845_Bracket_Md.gif" alt="Curly Bracket Image"/>        
        </div>
        <div class="styLNRightNumBox" style="height:12mm;padding-top:8mm;">14</div>
        <div class="styLNAmountBox" style="height:12mm;padding-top:8mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/TentativeMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:18.25mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">15</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Enter the greater of line 13 or line 14
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">....................</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">15</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/GreaterOfTentMinTaxOrExcess"/>
          </xsl:call-template>
        </div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">16</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Subtract line 15 from line 11. If zero or less, enter -0-
          <!--Dotted Line-->
          <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">16</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/SubtractGreaterFromNetIncmTax"/>
          </xsl:call-template>
        </div>        
      </div>
      
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">17</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <span class="styBoldText">Credit allowed for the current year.</span>
          Enter the <span class="styBoldText">smaller</span> of line 6 or line 16 here and
          on Form 1040, line 55; Form 1120, Schedule J, line 6d;
          Form 1120-A, Part I, line 2; Form 1041,
          Schedule G, line 2c; or the applicable line of your return.
          If line 16 is smaller than line 6, see instructions
        </div>
        <div class="styLNRightNumBoxNBB" style="height:11mm;padding-top:0mm">
        <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">        <br/><br/>
        </div>
        17
        </div>
        <div class="styLNAmountBoxNBB" style="height:11mm;padding-top:7.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8845Data/IndianEmplmnCreditAllowedForCY"/>
          </xsl:call-template>
        </div>
      </div>
    </div>

    <div style="width:187mm;">
    <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions. </span> 
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      
      Cat. No. 16146D 
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
  
      Form <span class="styBoldText">8845</span>(2005)
  </div>

        <br/>
        <br class="pageEnd"/>
        
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form8845Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
        <!-- END Left Over Table -->    
            

      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
