<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:include href="PopulateTemplate.xsl" />
  <xsl:include href="AddHeader.xsl" />
  <xsl:include href="CommonPathRef.xsl" />
  <xsl:include href="AddOnTable.xsl" />
  <xsl:include href="IRS8846Style.xsl" />
  <xsl:output method="html" indent="yes" />
  <xsl:strip-space elements="*" />
  <xsl:param name="Form8846Data" select="$RtnDoc/IRS8846" />
  <xsl:template match="/">
    <html lang="EN-US">
      <head>
        <title>
          <xsl:call-template name="FormTitle">
            <xsl:with-param name="RootElement" select="local-name($Form8846Data)" />
          </xsl:call-template>
        </title>
        <!-- No Browser Caching -->
        <meta http-equiv="Pragma" content="no-cache" />
        <meta http-equiv="Cache-Control" content="no-cache" />
        <meta http-equiv="Expires" content="0" />
        <!-- No Proxy Caching -->
        <meta http-equiv="Cache-Control" content="private" />
        <!-- Define Character Set -->
        <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
        <meta name="Description" content="IRS Form 8846" />
        <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript" />
        <xsl:call-template name="InitJS" />
        <style type="text/css">
          <xsl:if test="not($Print) or $Print=''">
            <!-- Form 8846 CSS Styles are located in the template called below -->
            <xsl:call-template name="IRS8846Style" />
            <xsl:call-template name="AddOnStyle" />
          </xsl:if>
        </style>
        <xsl:call-template name="GlobalStylesForm" />
      </head>
      <body class="styBodyClass">
        <form name="Form8846" id="Form8846">
          <xsl:call-template name="DocumentHeader" />
          <!-- Begin Form Number and Name -->
          <div class="styBB" style="width:187mm;">
            <div class="styFNBox" style="width:31mm;height:20.5mm;">
          Form <span class="styFormNumber">8846</span>
              <br />
              <br />
              <div style="padding-top:2mm;">
                <span class="styAgency">Department of the Treasury</span>
                <br />
                <span class="styAgency">Internal Revenue Service</span>
              </div>
            </div>
            <div class="styFTBox" style="width:125mm;height:13mm;">
              <div class="styMainTitle">
          Credit for Employer Social Security and Medicare Taxes<br />
          Paid on Certain Employee Tips      
              </div>
              <br />
              <div class="styFST" style="height:5mm;font-size:7pt;padding-top:4mm;">
                <img src="{$ImagePath}/8846_Bullet_Md.gif" width="4" height="7" alt="Bullet Image" />
          Attach to your tax return.
        </div>
            </div>
            <div class="styTYBox" style="width:30mm;height:20.5mm;">
              <div class="styOMB" style="height:2mm;">
          OMB No. 1545-1414
        </div>
              <div class="styTY" style="height:7.5mm;font-size:24pt;">
          20<span class="styTYColor">05</span>
              </div>
              <div class="stySequence">Attachment<br/>Sequence No. <b>98</b></div>
            </div>
          </div>
          <!-- End Form Number and Name section -->
          <!-- Begin Names and Identifying number section -->
          <div class="styBB" style="width:187mm;">
            <div class="styNameBox" style="width:156mm;height:8mm;font-weight:normal;font-size:7pt;">
        Name(s) shown on return<br />
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
            </div>
            <div class="styEINBox" style="width:30mm;height:4mm; padding-left:2mm;font-size:7pt;">
              Identifying number<br /><br />
              <span style="font-weight:normal;">  
                <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
              </span>
            </div>
          </div>
          <div class="styBB" style="width:187mm;padding-top:1mm;padding-bottom:1mm;">
          <b>Note.</b> <i> Claim this credit <b>only</b> for social security and Medicare taxes paid by a food or beverage establishment where tipping is customary for providing food or beverages. See the instructions for line 1.</i>
          </div>
          <!-- End Names and Identifying number section -->
          <!-- Start Part I Current Year Credit -->
          <div class="styBB" style="width:187mm;height: 8mm">
            <div class="styPartName" style="height: 4mm; margin-top: 2mm">Part I</div>
            <div class="styPartDesc" style="padding-top: 2mm">Current Year Credit</div>
          </div>
          <div class="styBB" style="width:187mm;">
            <div style="width:187mm;">
              <div class="styLNLeftNumBox" style="height:8mm; padding-left:3mm">1</div>
              <div class="styLNDesc" style="height:8mm;">
          Tips received by employees for services on which you paid or incurred employer social security and Medicare taxes during the tax year (see instructions)          <!--Dotted Line-->
                <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
              </div>
              <div class="styLNRightNumBox" style="height:8mm;">
                <br />1</div>
              <div class="styLNAmountBox" style="height:8mm;">
                <br />
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form8846Data/TipsRcvdByEmployeesForServices" />
                </xsl:call-template>
              </div>
            </div>
            <div style="width:187mm;">
              <div class="styLNLeftNumBox" style="height:4mm; padding-left:3mm">2</div>
              <div class="styLNDesc" style="height:4mm;padding-right:1mm;">
          Tips not subject to the credit provisions (see instructions)
          <!--Dotted Line-->
                <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.............</span>
              </div>
              <div class="styLNRightNumBox" style="height:4mm;">  2</div>
              <div class="styLNAmountBox" style="height:4mm;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form8846Data/TipsNotSubjectToTheCreditPrvsn" />
                </xsl:call-template>
              </div>
            </div>
            <div style="width:187mm;">
              <div class="styLNLeftNumBox" style="height:4mm; padding-left:3mm">3</div>
              <div class="styLNDesc" style="height:4mm;padding-right:1mm;">
          Creditable tips. Subtract line 2 from line 1
          <!--Dotted Line-->
                <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..................</span>
              </div>
              <div class="styLNRightNumBox" style="height:4mm;">  3</div>
              <div class="styLNAmountBox" style="height:4mm;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form8846Data/CreditableTips" />
                </xsl:call-template>
              </div>
            </div>
            <div style="width:187mm;">
              <div class="styLNLeftNumBox" style="height:8mm; padding-left:3mm">4</div>
              <div class="styLNDesc" style="height:8mm;padding-right:1mm;">
                <label>   
				          <xsl:call-template name="PopulateLabel">
				            <xsl:with-param name="TargetNode" select="$Form8846Data/EmpWagesExceededMaxAmt" />
				            <xsl:with-param name="BackupName">IRS8846EmpWagesExceededMaxAmt</xsl:with-param>
				          </xsl:call-template>
                   Multiply line 3 by 7.65% (.0765). If you had any tipped employees whose wages (including tips) exceeded $90,000, see instructions and check here  
		              <xsl:call-template name="SetFormLinkInline">
		                  <xsl:with-param name="TargetNode" select="$Form8846Data/EmpWagesExceededMaxAmt" />
		              </xsl:call-template>
                </label>
              
                <!--Dotted Line-->
                <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.............</span>
                <img src="{$ImagePath}/8846_Bullet_Md.gif" width="4" height="7" alt="Bullet Image" /><span style="width:1mm;" />
                <input type="checkbox" class="styCkbox">
                  <xsl:call-template name="PopulateCheckbox">
                  <xsl:with-param name="TargetNode" select="$Form8846Data/EmpWagesExceededMaxAmt" />
                  <xsl:with-param name="BackupName">IRS8846EmpWagesExceededMaxAmt</xsl:with-param>
                  </xsl:call-template>
                </input>
              </div>
              <div class="styLNRightNumBox" style="height:8mm;">
                <div style="height:3.5mm;" />4</div>
              <div class="styLNAmountBox" style="height:8mm;">
                <div style="height:3.5mm;" />
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form8846Data/CurrentYearCredit" />
                </xsl:call-template>
              </div>
            </div>
            <div style="width:187mm;">
              <div class="styLNLeftNumBox" style="height:4mm; padding-left:3mm">5</div>
              <div class="styLNDesc" style="width:33mm; height:4mm;">
                <div style="width:33mm;font-size:7pt;">Form 8846 credits from pass-through entities:</div>
              </div>
              <div class="styLNDesc" style="width:1mm; height:4mm;"> </div>
              <div class="styLNDesc" style="width:104mm;height:4mm;">
                <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Table for Work Opportunity Credit">
                  <tr>
                    <th class="styForm8846TBTable" scope="col">                
                      If you are a—
                      </th>
                    <th class="styForm8846TBTable" colspan="2" scope="col" style="border-right:none;">
                      Then enter the Form 8846 credits from—
                      </th>
                  </tr>
                  <tr>
                    <td scope="row" style="vertical-align:top;line-height:4mm;font-size: 7pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt;padding:1mm">
                      <div><span class="styBoldText">a</span> Shareholder</div>
                      <div><span class="styBoldText">b</span> Partner</div>
                       </td>
                    <td style="vertical-align:top;line-height:4mm;font-size:7pt;font-family:verdana;font-style: normal;font-weight:normal;border:none;padding:1mm">
                      <div>Schedule K-1 (Form 1120S) box 13, code F, G, or P</div>  
                      
                      <div>Schedule K-1 (Form 1065) box 15, code F, G, or P</div>
                      </td>
                    <td style="padding:1mm;">
                      <img src="{$ImagePath}/8846_Bracket_SM.gif" alt="Curly Bracket Image" style="clear:both;" align="middle" />
                      <span style="letter-spacing:3.4mm;skiplink:display:none;">..</span>
                    </td>
                  </tr>
                </table>
              </div>
              <div class="styLNRightNumBox" style="padding-top:0mm;">
                <div style="height:7.5mm;background-color:lightgrey;"></div>
                5          
              </div>
              <div class="styLNAmountBox" style="height:11.25mm;">
                <div style="height:7mm;" />
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form8846Data/Form8846CreditsFromPassthruEnt" />
                </xsl:call-template>
              </div>
              <div class="styLNRightNumBoxNBB" style="width:8.25mm;border-right-width:1px;background-color:lightgrey;height:5mm;padding-top:0mm;padding-bottom:0mm;" />
            </div>
            <div style="width:187mm;">
              <div class="styLNLeftNumBox" style="height:4mm; padding-left:3mm">6</div>
              <div class="styLNDesc" style="height:4mm;">
                <span class="styBoldText">Current year credit.</span>
                Add lines 4 and 5
                <!--Dotted Line-->
                <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...................</span>
              </div>
              <div class="styLNRightNumBoxNBB" style="padding-top:0mm;padding-bottom:0mm;">6</div>
              <div class="styLNAmountBoxNBB">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form8846Data/TotalCurrentYearCredit" />
                </xsl:call-template>
              </div>
            </div>
          </div>
          <!-- End Part II Current Year Credit -->
          <!-- Begin Allowable credit section-->
       <div class="styBB" style="width: 187mm; height: 8mm">
  <div class="styPartName" style="margin-top: 2mm">Part II</div>
  <div class="styPartDesc" style="padding-top: 2mm; width: 172mm">Allowable Credit <span class="styNormalText">(See</span> Who must file Form 3800 <span class="styNormalText">to find out if you complete Part II or file Form 3800.)</span></div>
  </div>
   <div class="styBB" style="width:187mm;">
      <div style="width:187mm">  
        <div class="styLNLeftNumBox" style="padding-left:3mm">7</div>
        <div style="float:left;padding-top:.5mm;">
          Regular tax before credits:                
        </div>
        <div style="float:right">  
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Individuals. Enter the amount from Form 1040, line 44                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ..........
          </span>
          <div class="styIRS8846LNLeftNumBox" style="position:relative;width:25mm;">
              <!-- floating bracket -->
                <span style="position:absolute;top:0mm;left:-3mm;">
                  <img src="{$ImagePath}/8846_Bracket_Lger.gif" alt="bracket" border="0"/>
                </span>
              <!-- end bracket -->
          </div>  
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Corporations. Enter the amount from Form 1120, Schedule J, line 3; Form 1120-A,            
        </div>
        <div style="float:right">  
          <div class="styIRS8846LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"></div>
        <div style="float:left;padding-top:.5mm;">
          Part I, line 1; or the applicable line of your return                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ..........
          </span>
          <div class="styIRS8846LNLeftNumBox" style="width:25mm;">
          <span class="styDotLn">      
            ......
          </span>
          </div>  
          <div class="styIRS8846LNRightNumBox" style="height:4.5mm;">7</div>  
          <div class="styIRS8846LNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/RegularTaxBeforeCredits"/>
            </xsl:call-template>
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G,             
        </div>
        <div style="float:right">  
          <div class="styIRS8846LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"></div>
        <div style="float:left">
          lines 1a and 1b, or the amount from the applicable line of your return                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ....
          </span>
          <div class="styIRS8846LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
<!-- line 8 -->            
      <div style="width:187mm">      
        <div class="styLNLeftNumBox" style="padding-top:0mm;padding-bottom:0mm; padding-left:3mm">8</div>
        <div style="float:left">
          Alternative minimum tax:
        </div>
        <div style="float:right">  
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey"></div>
          <div class="styLNAmountBoxNBB" style="width:33mm;"></div>  
        </div>      
      </div>    
      
      <div style="width:187mm">      
        <div class="styLNLeftLtrBoxDD" style="padding-top:0mm;padding-bottom:0mm;"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Individuals. Enter the amount from Form 6251, line 35          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            ......        
          </span>
          <div class="styIRS8846LNLeftNumBox" style="position:relative;width:35mm;">
				<!-- floating bracket -->
				  <span style="position:absolute;top:0mm;left:-3mm;">
				    <img src="{$ImagePath}/8846_Bracket_Md.gif" alt="bracket" border="0"/>
				  </span>
				<!-- end bracket -->
          </div>  
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;">
          </div>        
        </div>    
      </div>    
          
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD" style="padding-top:0mm;padding-bottom:0mm;"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Corporations. Enter the amount from Form 4626, line 14          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            .......    
          </span>
          <div class="styIRS8846LNLeftNumBox" style="width:35mm;">
          <span class="styDotLn">  
            ........   
          </span>
          </div>  
          <div class="styIRS8846LNRightNumBox" style="height:4.5mm">8</div>
          <div class="styIRS8846LNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/AlternativeMinimumTax"/>
            </xsl:call-template>
          </div>  
        </div>
      </div>          
        
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD" style="padding-top:0mm;padding-bottom:0mm;"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            
          </span>
          <div class="styIRS8846LNLeftNumBox" style="width:35mm;"></div>  
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;">
          </div>      
        </div>
      </div>    
          
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm">9</div>
          <div class="styLNDesc" style="width:138mm;height:4mm;">
            Add lines 7 and 8
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..........................</span>
          </div>
          <div class="styLNRightNumBox" style="width:8mm;height:5mm;">    
          9
          </div>
          <div class="styLNAmountBox" style="height:5mm;">          
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/RegTaxPlusAlternativeMinTax" />
            </xsl:call-template>
          </div>
        </div>
        
          <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:1mm">
          10<span style="width: .5mm" />a
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Foreign tax credit
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">..................</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10a</div>      
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8846Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>          
    </div>

    <div style="width:187mm">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">
          b
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Credits from Form 1040, lines 48  through 54
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">.........</span>
       </div>
        <div class="styLNRightNumBox" style="height:4mm;">10b</div>      
        <div class="styLNAmountBox" >
    <!--      
    	   <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8846Data/?????"/>
          </xsl:call-template>
    -->
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
          
    </div>
    
    <div style="width:187mm">                        
    <div class="styLNLeftLtrBoxDD" style="height:4mm;">
          c
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Possessions tax credit (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">........</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10c</div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8846Data/PossessionsTaxCredit"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
                  
    </div><div style="width:187mm">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">
          d
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
         Nonconventional source fuel credit (Form 8907, line 23)
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">......</span>

        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10d</div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8846Data/CreditForFuelFromNnconvSource"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
                  
    </div>

    <div style="width:187mm">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">
          e
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
         Other specified credits (see instructions)
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">..........</span>       
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">10e</div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8846Data/OtherSpecifiedCredits"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>        
          
    </div>
    
    <div style="width:187mm">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">
        f
        </div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 10a through 10e
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">........................</span>
          
        </div>
      
        <div class="styLNRightNumBox">10f
          
        </div>
          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8846Data/TotalCredits"/>
          </xsl:call-template>    
        </div>
                
    </div>

        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">11</div>
          <div class="styLNDesc" style="width:138mm;height:4mm;">
            Net income tax. Subtract line 10f from line 9. If zero, skip lines 12 through 15 and enter -0- on line 16
            <!--Dotted Line-->
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">11
          </div>
          <div class="styLNAmountBox" style="height:4mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/NetIncomeTax" />
            </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">12</div>
          <div class="styLNDesc" style="width:98.25mm;height:4mm;">
            Net regular tax. Subtract line 10f from line 7. If zero or less, enter -0-
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;">12</div>
          <div class="styLNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/NetRegularTax" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">13</div>
          <div class="styLNDesc" style="width:98.25mm;height:4mm;">
            <span class="stySmallText">
              Enter 25% (.25) of the excess, if any, of line 12 over $25,000 (see instructions)
            </span>          
          </div>
          <div class="styLNRightNumBox" style="height:4.5mm;padding-top:0.5mm">13</div>
          <div class="styLNAmountBox" style="height:4.5mm;">          
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/TwentyFivePercentOfExcess" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;padding-top:0.5mm;border-right-width:1px;"></div>
        </div>
        <!--div style="width:187mm;">
          <div style="width:8mm;padding-top:.5mm;padding-bottom:.5mm;font-weight:bold;float:left; clear: none;height:4mm;">
            <div style="width:8mm;padding-left:1mm;">14</div>
            <div style="width:8mm;padding-left:4mm;"><li /></div>
            <div style="width:8mm;padding-left:4mm;"><li /></div>
            <div style="width:8mm;padding-left:4mm;"><li /></div>
          </div>
          <div class="styLNDesc" style="width:93mm;height:4mm;">
            Tentative minimum tax (see instructions):
            <br />Individuals. Enter the amount from Form 6251, line 33
            <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">....</span>
            <br />Corporations. Enter the amount from Form 4626, line 12             
            <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...</span>
            Estates and trusts. Enter the amount from Form 1041,<br />Schedule I, line 54
            <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
           </div>
          <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:2.5mm;">
            <img src="{$ImagePath}/8846_Bracket_Lger.gif" height="50mm" alt="Curly Bracket Image" />        
          </div>
          <div class="styLNRightNumBox" style="height:10mm;padding-top:6mm;">14</div>
          <div class="styLNAmountBox" style="height:10mm;padding-top:6mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/TentativeMinimumTax" />
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:17mm;border-right-width:1px;"></div>
        </div-->
      <div style="width:187mm">  
        <div class="styLNLeftNumBox">14</div>
        <div style="float:left;padding-top:.5mm;">
          Tentative minimum tax (see instructions):               
        </div>
        <div style="float:right">  
          <div class="styIRS8846LNRightNumBox" style="border-bottom:1;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:1;height:4.5mm;width:32mm;"></div>
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;"></div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
         Individuals. Enter the amount from Form 6251, line 33                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ....
          </span>
          <div class="styIRS8846LNLeftNumBox" style="position:relative;width:5mm;">
              <!-- floating bracket -->
                <span style="position:absolute;top:0mm;left:-1mm;">
                  <img src="{$ImagePath}/8846_Bracket_Lg.gif" alt="bracket" border="0"/>
                </span>
              <!-- end bracket -->
          </div>  
          <div class="styIRS8846LNRightNumBox" style="border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;width:32mm;"></div>
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;"></div>    
        </div>
      </div> 
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Corporations. Enter the amount from Form 4626, line 12            
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ...
          </span>
          <div class="styIRS8846LNLeftNumBox" style="width:5mm;"></div>  
          <div class="styIRS8846LNRightNumBox" style="height:4.5mm;">14
          </div>  
          <div class="styIRS8846LNAmountBox" style="height:4.5mm;width:32mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/TentativeMinimumTax" />
            </xsl:call-template>
          </div>
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"><img src="{$ImagePath}/8846_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Estates and trusts. Enter the amount from Form 1041,        
        </div>
        <div style="float:right">  
          <div class="styIRS8846LNLeftNumBox" style="width:5mm;;"></div>  
          <div class="styIRS8846LNRightNumBox" style="height:4.5mm;border:0;"></div>  
          <div class="styIRS8846LNAmountBox" style="height:4.5mm;width:32mm;border:0;"></div>
          <div class="styIRS8846LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8846LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBoxDD"></div>
        <div style="float:left;padding-top:.5mm;">
          Schedule I, line 54              
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ................
          </span>
          <div class="styIRS8846LNLeftNumBox" style="width:5mm;"></div>  
          <div class="styIRS8846LNRightNumBox" style="height:4.5mm;border:0;"></div>  
          <div class="styIRS8846LNAmountBox" style="height:4.5mm;border:0;width:32mm;"></div>    
          <div class="styIRS8846LNRightNumBox" style="height:4.5mm;background-color:lightgrey;"></div>  
          <div class="styIRS8846LNAmountBox" style="height:4.5mm;"></div>    
        </div>
      </div>    

        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">15</div>
          <div class="styLNDesc" style="width:138mm;height:4mm;">
            Enter the greater of line 13 or line 14
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">....................</span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">15</div>
          <div class="styLNAmountBox" style="height:4mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/GreaterOfTentMinTaxOrExcess" />
            </xsl:call-template>
          </div>
        </div>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">16</div>
          <div class="styLNDesc" style="width:138mm;height:4mm;">
            Subtract line 15 from line 11. If zero or less, enter -0-
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
          </div>
          <div class="styLNRightNumBox" style="height:4mm;">16</div>
          <div class="styLNAmountBox" style="height:4mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/SubtractNetIncmTaxFromGreater" />
            </xsl:call-template>
          </div>        
        </div>
        
        <div style="width:187mm;">
          <div class="styLNLeftNumBox" style="height:4mm;">17</div>
          <div class="styLNDesc" style="width:138mm;height:4mm;">
            <span class="styBoldText">Credit allowed for the current year.</span>
            Enter the <span class="styBoldText">smaller</span> of line 6 or line 16 here and on Form 1040, line 55; Form 1120, Schedule J, line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule G, line 2c; or the applicable line of your return. If line 16 is smaller than line 6, see instructions
          </div>
          <div class="styLNRightNumBoxNBB" style="height:6mm;background-color:lightgrey;"></div>
				<div class="styLNAmountBoxNBB" style="height:6mm;"></div>
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;padding-top:0mm">
          	17
          </div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8846Data/CreditAllowedForCurrentYear" />
            </xsl:call-template>
	        </div>
        </div>
      </div>
  
      <div style="width:187mm;">
      <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions.</span> 
        <span style="width:128px;"></span>  
        Cat. No. 16148Z
        <span style="width:115px;"></span>  
        Form <span class="styBoldText">8846</span> (2005)
      </div><br class="pageEnd" />
          <!-- BEGIN Left Over Table -->  
          <!-- Additonal Data Title Bar and Button -->
          <div class="styLeftOverTitleLine" id="LeftoverData">
            <div class="styLeftOverTitle">
              Additional Data        
            </div>
            <div class="styLeftOverButtonContainer">
              <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();" />
            </div>      
          </div>
          <!-- Additional Data Table -->
          <table class="styLeftOverTbl">
            <xsl:call-template name="PopulateCommonLeftover">
              <xsl:with-param name="TargetNode" select="$Form8846Data" />
              <xsl:with-param name="DescWidth" select="100" />
            </xsl:call-template>          
          </table>
          <!-- END Left Over Table -->    
        </form>
      </body>
    </html>
  </xsl:template>
</xsl:stylesheet>
