<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8847Style.xsl"/>

<xsl:output method="html" indent="yes" encoding="iso-8859-1"/>

<xsl:strip-space elements="*" />
<xsl:param name="FormData" select="$RtnDoc/IRS8847" />


<xsl:template match="/">
<html>
<head>  
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache"/>
  <meta http-equiv="Cache-Control" content="no-cache"/>
  <meta http-equiv="Expires" content="0"/>
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private"/>  
  <meta name="Description" content="Form IRS 8847"/>
  <meta name="GENERATOR" content="IBM WebSphere Studio"/>
  <xsl:call-template name="GlobalStylesForm"/>
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>  
  <style type="text/css">    
    <xsl:if test="not($Print) or $Print=''">  
      <xsl:call-template name="IRS8847Style"></xsl:call-template>
      <xsl:call-template name="AddOnStyle"></xsl:call-template>  
    </xsl:if>
  </style>      
  
</head>

<body class="styBodyClass">
  <form name="Form8847">    
    <xsl:call-template name="DocumentHeader"></xsl:call-template>  
    
  <!--Title of Form -->    
  <div class="styBB" style="width:187mm;height: 22mm">
    <div class="styFNBox" style="width:31mm;font-size: 7pt;height: 22mm">
      Form <span class="styFormNumber">8847</span>      
      <br/>
      <br/>
      <br/>
      <span class="styAgency">Department of the Treasury</span><br />
      <span class="styAgency">Internal Revenue Service &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;(99) </span>
    </div>
    <div class="styFTBox" style="width:125mm">
      <div class="styMainTitle" style="height:8mm;">Credit for Contributions to Selected Community <br/>Development Corporations<br/></div>
      <div class="styFST" style="padding-top: 1mm;height:5mm;font-size:7pt;margin-left:3mm;font-weight:bold"><br/><br/>
        <img src="{$ImagePath}/8847_Bullet.gif" alt="MediumBullet"/>  
        Attach to your tax return.
      </div>
    </div>
    <div class="styTYBox" style="width:30mm;height:22mm; border-left-width: 1px">
    <div class="styOMB" style="height:2mm;">OMB No. 1545-1416</div>
    <div class="styTY" style="height:11mm">20<span class="styTYColor">05</span></div>
    <div class="stySequence">Attachment<br/>Sequence No. <b>100</b></div>
  </div>
  </div>
  <!--  End title of Form  -->
    
  <!--  Name and Employer identification number  -->
  <div class="styBB" style="width:187mm">
    <div class="styNameBox" style="width:156mm;font-weight:normal;font-size:7pt;">
      Name(s) shown on return<br/>
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
    </div>
    <div class="styEINBox" style=" padding-left:2mm;font-size:7pt;"><span class="BoldText">Identifying number</span>
      <br/><br/>
      <div style="text-align:left; font-weight:normal;">    
        <xsl:choose>
          <xsl:when test="normalize-space($FormData/IdentifyingNumber) != ''">
            <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" select="$FormData/IdentifyingNumber" /></xsl:call-template>
          </xsl:when>  
          <xsl:otherwise>  
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>  
          </xsl:otherwise>
        </xsl:choose>
      </div>    
    </div>
  </div>  
  <!--  End Name and Employer indentification number  -->
  
  <!--  Part I -->
  <div class="styBB" style="width: 187mm">
    <div class="styPartName" style="height: 4mm">Part I</div>
    <div class="styPartDesc">Current Year Credit</div>
  </div>
  <!--  End Part I -->
  
  <!--  Line 1 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">1</div>
    <div style="float:left; padding-top: .5mm">
      Total qualified community development corporation (CDC) contributions from Part I of    
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="border-bottom-width: 0mm"></div>
      <div class="styLNAmountBox" style="border-bottom-width: 0mm"></div>          
    </div>
  </div>
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm"></div>
    <div style="float:left">
      Schedules A (Form 8847)    
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        .....................
      </span>        
      <div class="styLNRightNumBox">1</div>
      <div class="styLNAmountBox">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/TotalQualifiedCDCContributions"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 1 -->
  

  <!--  Line 2 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">2</div>
    <div style="float:left">
      Multiply line 1 by 5% (.05)    
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        .....................
      </span>        
      <div class="styLNRightNumBox">2</div>
      <div class="styLNAmountBox">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/CurrentYearCDCCredit"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 2 -->
  
  <!--  Line 3 -->  
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="padding-left: 2mm; height:4mm;">3</div>
    <div class="styLNDesc" style="width:30mm; height:4mm;">
      <div style = "width:30mm;">CDC credits from pass-through entities:</div>
    </div>
    <div class="styLNDesc" style="width:5mm; height:4mm;"> </div>
    <div class="styLNDesc" style="width:104.25mm; height:4mm;">
      <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Table for Work Opportunity Credit">
         <tr>
            <th class="styTableCell" scope="col" style="border-color: black; border-top-width: 1px; font-weight: normal; font-size: 6pt; width: 18.25mm; padding-right: 4mm">                
              If you are a—              
            </th>
            <th class="styTableCell" colspan="2" scope="col" style="border-color: black; font-weight: normal; border-right-width:0px; border-top-width:1px; font-size: 6pt; width: 69mm;text-align: left; padding-left: 1mm">
              Then enter the total of the current year CDC credit(s) from—
            </th>
         </tr>
         <tr>
            <td scope="row" style="width: 18.25mm; font-size: 6pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .7pt">
            <span class="styBoldText">a</span> Shareholder      
            <br/>
              <span class="styBoldText">b</span> Partner  
              </td>
            <td style="font-size:6pt;font-family:verdana;font-style: normal;font-weight:normal;border:none;padding:0mm; padding-left: 1mm">
              Schedule K-1 (Form 1120S), box 13, code U<br />
              Schedule K-1 (Form 1065), box 15, code U
            </td>
          <td style="width:27mm">
            <div class="styLNDesc" style="width:4mm">
              <img src="{$ImagePath}/8847_Bracket_Sm.gif" alt="Curly Bracket Image"/>                                    
            </div>
            <div class="styLNDesc" style="width:23mm">                  
              <span style="letter-spacing:4mm; font-weight:bold; font-size: 7pt">  
                ....
              </span>                  
            </div>
          </td>
         </tr>            
      </table>          
    </div>
    <div class="styLNRightNumBox" style="height:4mm;padding-top:0mm;">
      <div class="styLNRightNumBoxN" style="width:7.75mm;height:8mm"></div>
          3          
    </div>        
    <div class="styLNAmountBox" style="height: 12mm; width: 31.75mm; padding-top: 8mm">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CDCCreditsFromPassthruEntities"/>
      </xsl:call-template>
    </div>
  </div>      
  <!--  Line 3 -->  
  
  <!--  Line 4 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">4</div>
    <div style="float:left">
      <span class="styBoldText">Current year credit. </span> Add lines 2 and 3
    </div>    
    <div style="float:right">    
      <span style="letter-spacing:4mm; font-weight:bold; float:left">  
        ..................
      </span>        
      <div class="styLNRightNumBoxNBB">4</div>
      <div class="styLNAmountBoxNBB">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/TotalCurrentYearCDCCredit"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 4 -->
  
  <!--  Part II -->
  <div class="styBB" style="width: 187mm; border-top-width: 1px">
    <div class="styPartName" style="height: 4mm">Part II</div>
    <div class="styPartDesc" style="width: 172mm">Allowable Credit (<span class="styNormalText">See</span> Who must file Form 3800 <span class="styNormalText">to find out if you complete Part II or file Form 3800.)</span></div>
  </div>
  <!--  End Part II -->
    
  <!--  Line 5 -->  
  <div class="styBB" style="width:187mm;">
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="padding-left: 2mm;height:4mm;">5</div>
      <div class="styLNDesc" style="width:123mm;height:4mm;">
        Regular tax before credits:          
          <li style="padding-top: .75mm;position:relative;left:-4.25mm">Individuals. Enter the amount from Form 1040, line 44
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              .........
            </span>  
          </li>
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Corporations. Enter the amount from Form 1120, Schedule J, line 3; Form 1120-A,<br/>
            <span style="width:14px;float:left;"></span>Part I, line 1; or the applicable line of your return
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              ...........
            </span>  
          </li>
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G, lines 1a<br/>
            <span style="width:14px;float:left;"></span>and 1b, or the amount from the applicable line of your return
             <!--Dotted Line-->
             <span style="letter-spacing:4mm; font-weight:bold">  
              ........
            </span>  
          </li>                  
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:5.25mm;">
          <img src="{$ImagePath}/8847_Bracket_Lg.gif" alt="Curly Bracket Image"/>      
        </div>
        <div class="styLNDesc" style="width:10mm; height:14mm;">    
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold; float:left;width:10mm; height:14mm;padding-bottom:0mm;padding-top:9.5mm;">  
            ..
          </span>                                
        </div>

        <div class="styLNRightNumBox" style="width:7.75mm;height:11mm;padding-top=0mm;">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;height:7.25mm;">
          </div>
          5
        </div>
        <div class="styLNAmountBox" style="height:11mm;">
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/RegularTaxBeforeCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:11.25mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>
    <!-- End Line 5 -->
    
    <!-- Line 6 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="padding-left: 2mm; height:4mm;">6</div>
        <div class="styLNDesc" style="width:105mm;height:4mm;">
          Alternative minimum tax:          
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Individuals. Enter the amount from Form 6251, line 35
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold">  
                .....
              </span>  
            </li>
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Corporations. Enter the amount from Form 4626, line 14
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold">  
                .....
              </span>  
            </li>             
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56
            </li>                 
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:4mm;">
          <img src="{$ImagePath}/8847_Bracket_Md.gif" alt="Curly Bracket Image"/>        
        </div>
        <div class="styLNDesc" style="width:28mm; height:4mm;">                  
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold; float:left;width:28mm; height:14mm;padding-bottom:0mm;padding-top:6.5mm;">  
            .....
          </span>                  
        </div>

        <div class="styLNRightNumBox" style="width:7.75mm;height:8.25mm;padding-top=0mm;">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;padding-top=0.5mm;border-left-width:0px;background-color:lightgrey;">
        </div>
        6
        </div>
        <div class="styLNAmountBox" style="height:8.25mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/AlternativeMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:8mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>
      <!-- Line 6-->  
      
      <!-- Line 7-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="padding-left: 2.5mm; height:4mm;">7</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 5 and 6
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold">  
            .......................
          </span>  
        </div>
        <div class="styLNRightNumBox" style="width:8mm;height:5mm;padding-top=1mm;">    
        7
        </div>
        <div class="styLNAmountBox" style="height:5mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/RegTaxPlusAlternativeMinTax"/>
          </xsl:call-template>
        </div>
      </div>
      <!-- Line 7-->
      
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="padding-left: 2.5mm; height:4mm;">
          8a
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Foreign tax credit
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">..................</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8a</div>      
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>          
    </div>

    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          b
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Credits from Form 1040, lines 48 through 54
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">.........</span>
       </div>
        <div class="styLNRightNumBox" style="height:4mm;">8b</div>      
        <div class="styLNAmountBox" >
    <!--      
    	   <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/?????"/>
          </xsl:call-template>
    -->
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
          
    </div>
    
    <div style="width:187mm">                        
    <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          c
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Possessions tax credit (Form 5735, line 17 or 27)
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">.......</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8c</div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/PossessionsTaxCredit"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
                  
    </div><div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          d
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Nonconventional source fuel credit (Form 8907, line 23)
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">......</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8d</div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/CreditForFuelFromNnconvSource"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
    </div>
    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          e
        </div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Other specified credits (see instructions)
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">..........</span>       
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8e</div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherSpecifiedCredits"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>        
       </div>
     <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
        f
        </div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 8a through 8e
            <!--Dotted Line-->
            <span style="letter-spacing:3.4mm;font-weight:bold;skiplink:display:none;">........................</span>
          
        </div>
      
        <div class="styLNRightNumBox">8f
          
        </div>
          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TotalCredits"/>
          </xsl:call-template>    
        </div>
                
    </div>

      
      
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="padding-left:2mm; height:4mm;">9</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Net income tax.  Subtract line 8f from line 7.  If zero,
          skip lines 10 through 13 and enter -0-
        </div>
        <div class="styLNRightNumBoxNBB"></div>  
        <div class="styLNAmountBoxNBB" style="height:4mm;" ></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
           on line 14
          <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              .........................
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">9
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>
         <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">10</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Net regular tax. Subtract line 8f from line 5.  If zero
          or less, enter -0-
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">10</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NetRegularTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
         <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">11</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Enter 25% (.25) of the excess, if any, of line 10 over
          $25,000 (see instructions)
          <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              ................
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:8mm;padding-top:3.5mm">11</div>
        <div class="styLNAmountBox" style="height:8mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TwentyFivePercentOfExcess"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:8mm;padding-top:3.5mm;border-right-width:1px;"></div>
      </div>
        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">12</div>
        <div class="styLNDesc" style="width:93.25mm;height:4mm;">
          Tentative minimum tax(see instructions):          
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Individuals. Enter the amount from Form 6251, line 33</li>
            <span class="styBoldText">
            <span style="letter-spacing:4mm; font-weight:bold">  
              ..
            </span>                          
            </span>
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Corporations.  Enter the amount from Form 4626, line 12</li> 
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              ..
            </span>              
            <li style="padding-top: .75mm;position:relative;left:-4.25mm">Estates and trusts. Enter the amount from Form 1041, <br/> <span style="width:14px;float:left;"></span>Schedule I, line 54</li>
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold">  
              .............
            </span>                     
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:6mm;">
          <img src="{$ImagePath}/8847_Bracket_Md.gif" height="46" alt="Curly Bracket Image"/>        
        </div>
	<div style="width:40mm;float:left;clear:none;">
	        <div class="styLNRightNumBox" style="height:15mm;background-color:lightgrey;border-bottom-width:0px;"></div>
	        <div class="styLNAmountBox" style="height:15mm;border-bottom-width:0px;">
	        </div>
	        <div class="styLNRightNumBox" style="height:3.85mm;">12</div>
	        <div class="styLNAmountBox" style="height:3.85mm;">
	          <xsl:call-template name="PopulateAmount">
	            <xsl:with-param name="TargetNode" select="$FormData/TentativeMinimumTax"/>
	          </xsl:call-template>
	        </div>
			</div>        
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:19.25mm;border-right-width:1px;"></div>            
      </div>

      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">13</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Enter the greater of line 11 or line 12
          <span style="letter-spacing:4mm; font-weight:bold">  
            ..................
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">13</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/GreaterOfTentMinTaxOrExcess"/>
          </xsl:call-template>
        </div>
      </div>
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">14</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Subtract line 13 from line 9.  If zero or less, enter -0-
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold">  
            .............
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">14</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/SubtractNetIncmTaxFromGreater"/>
          </xsl:call-template>
        </div>        
      </div>      
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox">15</div>
        <div class="styLNDesc" style="width:138mm">
          <span class="styBoldText">Credit allowed for the current year. </span>
          Enter the <span class="styBoldText">smaller</span> of line 4 or line 14 here and on Form
          1040, line 55;Form 1120, Schedule J, line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule G, line 2c; or the applicable
          line of your return. If line 14 is smaller than line 4, see instructions
        </div>
        <div class="styLNRightNumBoxNBB" style="height:5mm;padding-top:0mm">
        <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
          <br/><br/>
        </div>
          15
        </div>
        <div class="styLNAmountBoxNBB" style="height:5mm;">
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/CDCCreditAllowedForCurrentYear"/>
          </xsl:call-template>
        </div>
      </div>
    </div>
        <div style="width:187mm;">
          <span class="styBoldText">For Paperwork Reduction Act Notice, see back of form. </span> 
          <span style="width:120px;"></span>                      
          Cat. No.16149K 
          <span style="width:125px;"></span>  
          Form <span class="styBoldText">8847</span> (2005)
        </div>
        <br class="pageEnd"/>
           <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$FormData" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
      <!-- END Left Over Table -->      
  </form>  
</body>
</html>
</xsl:template>    
</xsl:stylesheet>