<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8860Style.xsl"/>



<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8860Data" select="$RtnDoc/IRS8860" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8860Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    
    <meta name="Description" content="IRS Form 8860" />
    <META name="GENERATOR" content="IBM WebSphere Studio"/>
     <xsl:call-template name="GlobalStylesForm"/>
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>  
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <xsl:call-template name="IRS8860Style"></xsl:call-template>    
        <xsl:call-template name="AddOnStyle"></xsl:call-template>    
      </xsl:if>
    </style>
    <xsl:call-template name="GlobalStylesForm"/>
  </head>

<body class="styBodyClass">
  <form name="Form8860">
    <xsl:call-template name="DocumentHeader"></xsl:call-template>      
    
    <!-- Begin Form Number and Name -->
    <div class="styBB" style="width:187mm;">
    <div class="styFNBox" style="width:31mm;height:18mm">
      <span style="height:11mm;">
        Form <span class="styFormNumber">8860</span>
        <br /><br />
      </span>
      <span class="styAgency" style="line-height:110%;padding-top:2mm;">
        Department of the Treasury
        <br />
        Internal Revenue Service
      </span>
    </div>
    <div class="styFTBox" style="width:123mm;">
      <div style="height:10.5mm;padding-top:1mm;" class="styMainTitle"><br />
        Qualified Zone Academy Bond Credit
      </div>      
      <div class="styFST" style="height:5mm;font-size:7pt;">
        <img src="{$ImagePath}/8860_Bullet.gif" alt="Bullet Image"/>
        Attach to your tax return.
       
      </div>
    </div>
    <div class="styTYBox" style="width:32mm;">
      <div class="styOMB" style="height:2mm;">
        OMB No. 1545-1606
      </div>
      <div style="height:5mm;line-height:100%;font-size:22pt;" class="styTY">
        20<span class="styTYColor">05</span>
      </div>
      <div style="width:18mm;padding-right:8mm;line-height:110%;">Attachment</div>
        <div>Sequence No.<span class="styBoldText"><span style="width:4px;"></span>133</span>
      </div>
    </div>
  </div>    
  <!-- End Form Number and Name section -->
  
  <!-- Begin Name and Identifying number section -->
  <div class="styBB" style="width:187mm;">
    <div class="styNameBox" style="width:134mm;height:8mm;font-weight:normal;font-size:7pt;">
      Name<br/>
      <div style="font-family:verdana;font-size:6pt;height:6.25mm">
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
     </div>
    </div>    
    <div class="styEINBox" style="width:50mm;height:4mm;padding-left:2mm;font-size:7pt;">
      Employer identification number<br/><br/>
      <span style="font-weight:normal;">  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
      </span>  
    </div>
  </div>
  
  <!-- End Names and Identifying number section -->

  <!-- BEGIN Part I Title -->
  <div style="width:187mm" class="styBB">
    <div class="styGenericDiv" style="width:187mm;float:left;">
      <div class="styPartName">Part I</div>
      <div class="styPartDesc" style="width:167mm;">Current Year Credit</div>
    <!-- Table expand/collapse toggle button -->
      <div class="styGenericDiv" style="float:right;">
      <!--div style="width:5mm;float:right;vertical-align:top;"-->
          <xsl:call-template name="SetDynamicTableToggleButton">
          <xsl:with-param name="TargetNode" select="$Form8860Data/CurrentYearCreditInfo"/>
          <xsl:with-param name="containerHeight" select="5"/>
          <xsl:with-param name="headerHeight" select="1"/>
          <xsl:with-param name="containerID" select=" 'TPctn' "/>
          </xsl:call-template>
      </div>
    </div>
  </div>
  <!-- END Part I Title -->
    
  <div  id="TPctn" class="styTableContainerNBB">
    <xsl:call-template name="SetInitialState"/>
    <table style="font-size:7pt;border-color:black;" class="styTable" cellspacing="0" summary="Table displaying entity name or names and corresponding employer identification numbers" name="TYTable" id="TYTable" >
      <thead class="styTableThead">
        <tr>
          <th scope="col" class="styTableCell" style="width:5mm;font-size:7pt;border-right:none;border-bottom:none;font-weight:bold;"><span style="width:1mm;"/></th>
          <th scope="col" class="styTableCell" style="width:45mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(a)</th>
          <th scope="col" class="styTableCell" style="width:35mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(b)</th>
          <th scope="col" class="styTableCell" style="width:40mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(c)</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(d)</th>
          <th scope="col" class="styTableCell" style="width:42mm;font-size:7pt;text-align:center;border-bottom:none;border-right:none;font-weight:bold;">(e)</th>        
        </tr>
        <tr>
          <th scope="col" class="styTableCell" style="width:5mm;font-size:7pt;border-right:none;"><span style="width:1mm;"/></th>
          <th scope="col" class="styTableCell" style="width:45mm;font-size:7pt;text-align:center;font-weight:normal;">Bond issuer’s name, city <br />or town, and state</th>
          <th scope="col" class="styTableCell" style="width:35mm;font-size:7pt;text-align:center;font-weight:normal;">Month and year<br /> bond issued</th>
          <th scope="col" class="styTableCell" style="width:40mm;font-size:7pt;text-align:center;font-weight:normal;">Outstanding principal <br />amount of bond</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;font-weight:normal;">Credit rate</th>
          <th scope="col" class="styTableCell" style="width:42mm;font-size:7pt;text-align:center;border-right:none;font-weight:normal;">Credit ((c) x (d))</th>
        </tr>
      </thead>
    <tfoot></tfoot>
    <tbody>
    <xsl:for-each select="$Form8860Data/CurrentYearCreditInfo">
    	<xsl:if test="($Print != $Separated) or (count($Form8860Data/CurrentYearCreditInfo) &lt;=5)">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:value-of select="position()"/>
              </xsl:when>
              <xsl:otherwise>
                <span style="width:1px;"/>
              </xsl:otherwise>
            </xsl:choose>
          </td>    
          <td class="styTableCell" rowspan="1" style="width:45mm;text-align:left;font-size:6pt;font-weight:normal;font-family:verdana">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="BondIssuerName/BusinessNameLine1"/>
            </xsl:call-template>
            <xsl:if test="BondIssuerName/BusinessNameLine2 !=''">
            <br/>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="BondIssuerName/BusinessNameLine2"/>
              </xsl:call-template>          
            </xsl:if>
            <xsl:if test="City !=''">
            <br/>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="City"/>
              </xsl:call-template>,
            </xsl:if>
            <xsl:if test="State !=''">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="State"/>
              </xsl:call-template>
              <span style="width:1mm;"/>
            </xsl:if>
          </td>
          <td class="styTableCell" style="width:35mm;text-align:center;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthYearForYearMonthType">
              <xsl:with-param name="TargetNode" select="MonthYearBondIssued"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:40mm;text-align:right;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="OutstandingPrincipalAmtOfBond"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="CreditRate"/>
            </xsl:call-template>          
          </td>  
          <td class="styTableCell" style="width:42mm;text-align:right;border-right:none;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="CreditForThisBond"/>
            </xsl:call-template>
          </td>
        </tr>
       </xsl:if>
      </xsl:for-each>
          
      <xsl:if test="count($Form8860Data/CurrentYearCreditInfo) &lt; 1 or (($Print = $Separated) and (count($Form8860Data/CurrentYearCreditInfo) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;vertical-align:top;">1</td>
          <td class="styTableCell" rowspan="1" style="width:40mm;text-align:left;font-size:6pt;font-weight:normal;height:8mm;font-family:verdana">
          <xsl:choose>											
			<xsl:when test="($Print = $Separated) and (count($Form8860Data/CurrentYearCreditInfo) &gt; 5)">
				<xsl:call-template name="PopulateAdditionalDataTableMessage">
					<xsl:with-param name="TargetNode" select="$Form8860Data/CurrentYearCreditInfo/BondIssuerName/BusinessNameLine1"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<span class="styTableCellPad"></span>
			</xsl:otherwise>
          </xsl:choose>
          </td>
          <td class="styTableCell" style="width:35mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:40mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:42mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>      
      <xsl:if test="count($Form8860Data/CurrentYearCreditInfo) &lt; 2 or (($Print = $Separated) and (count($Form8860Data/CurrentYearCreditInfo) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:40mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:35mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:40mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:42mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8860Data/CurrentYearCreditInfo) &lt; 3 or (($Print = $Separated) and (count($Form8860Data/CurrentYearCreditInfo) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:40mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:35mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:40mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:42mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8860Data/CurrentYearCreditInfo) &lt; 4 or (($Print = $Separated) and (count($Form8860Data/CurrentYearCreditInfo) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:40mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:35mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:40mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:42mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8860Data/CurrentYearCreditInfo) &lt; 5 or (($Print = $Separated) and (count($Form8860Data/CurrentYearCreditInfo) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:40mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:35mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:40mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:42mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>                            
      </tbody>
    </table>        
      <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form8860Data/CurrentYearCreditInfo"/>
      <xsl:with-param name="containerHeight" select="5"/>
      <xsl:with-param name="headerHeight" select="1"/>
      <xsl:with-param name="containerID" select=" 'TPctn' "/>
      </xsl:call-template>  
  </div>

<!-- Part I Line 2a -->
  <div style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;">2a</div>
    <div class="styLNDesc" style="width:138mm;height:4mm;float:left;">
      Qualified zone academy bond credit from Schedule K-1 (Form 1120S), box 13, code U
            <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$Form8860Data/SchK1BondCredit"/>
      </xsl:call-template>    
      <span style="letter-spacing:3.5mm;font-weight:bold;">.....</span>
    </div>
    <div class="styLNRightNumBox" style="width:8mm;height:5.25mm;">2a</div>    
    <div class="styLNAmountBox" style="height:5.25mm;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$Form8860Data/SchK1BondCredit"/>
      </xsl:call-template>    
    </div>
  </div>
  
<!-- Part I Line 2b -->  
  <div style="width:187mm;">
    <div class="styLNLeftLtrBox" style="height:4mm;">b</div>
    <div class="styLNDesc" style="width:84mm;height:4mm;">
      Enter the S corporation’s employer identification number (EIN)
    </div>
    <div class="styUnderlineAmount" style="width:52mm;text-align:left;">
      <xsl:call-template name="PopulateEIN">
        <xsl:with-param name="TargetNode" select="$Form8860Data/SCorpEIN"/>
      </xsl:call-template>
    </div>
    <span style="width:2mm;float:left;"/>
    <div class="styLNRightNumBoxNBB" style="width:8mm;border-left-width:1px;background-color:lightgrey;height:4.5mm;"></div>
    <div class="styLNAmountBoxNBB" style="height:4.5mm;padding-top:0mm;"/>
  </div>

<!-- Part I, Line 3 -->
    <div class="styBB" style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">3</div>
        <div class="styLNDesc" style="width:129mm;height:4mm;">
          <span class="styBoldText">Current year credit.</span> Add line 2a and all amounts on line 1, column (e). 
          <span class="styBoldText">Caution.  </span>
          <span style="font-style:italic;">Holders of bonds, see the instructions for how and when to report the credit amount as interest income</span>    
           <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> ....</span>
        </div>
        <div class="styLNDesc" style="width:9mm; height:4mm;"></div>

        <div class="styLNRightNumBoxNBB" style="width:7.75mm;height:4mm;padding-top:0mm;">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;height:4mm;"></div>          
          3
        </div>
        <div class="styLNAmountBoxNBB" style="height:8mm;">
            <br/>
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/CYQlfyZoneAcademyBondCredit"/>
          </xsl:call-template>
        </div>
      </div>
<!-- End Part I -->

  <div class="styBB" style="width:187mm;">
    <span class="styBoldText">Note:</span><span class="styNormalText" style="font-style:italic;"> S Corporations - stop here - <span class="styBoldText">do not</span> complete Part II (see instructions).</span>
  </div>
      
  <!-- BEGIN Part II Title -->
  <div class="styBB" style="width:187mm;">
    <div class="styPartName">Part II</div>
    <div class="styPartDesc">Allowable Credit</div>
  </div>
  <!-- END Part II Title -->
  
  <!-- Part II, Line 4 -->
  <div class="styBB" style="width:187mm;">
    <div style="width:187mm">
   <div class="styLNLeftNumBox ">4</div>
   <div style="float:left">
    Regular tax before credits:
   </div>
   <div style="float:right">
    <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>
    <div class="styIRS8860LNAmountBox" style="border-bottom:0;height:4.5mm;"></div>
   </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8860LNLeftLtrBox"></div>
     <div style="float:left">
      <img src="{$ImagePath}/8860_Bullet_Round.gif" alt="dot" /> Individuals. Enter the amount from Form 1040, line 44
     </div>
     <div style="float:right">
       <span class="styDotLn">
         ...........                     
          </span>
          <div class="styIRS8860LNLeftNumBox" style="position:relative;width:15mm;">
            <span style="z-index:1;position:absolute;top:0mm;left:9mm;"><img src="{$ImagePath}/8860_Bracket_Lg.gif" alt="Curly Bracket Image"/></span>
          </div>
          <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8860LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8860LNLeftLtrBox"></div>
     <div style="float:left">
     <img src="{$ImagePath}/8860_Bullet_Round.gif" alt="dot" />
      Corporations. Enter the amount from Form 1120, Schedule J, line 3, or the applicable
     </div>
     <div style="float:right">
      <div class="styIRS8860LNLeftNumBox" style="width:15mm;"></div>
      <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8860LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styLNLeftNumBox"></div>
     <div style="float:left">
      line of your return  <span style="letter-spacing:3.5mm;font-weight:bold;">.....</span>
     </div>
     <div style="float:right">
             <span class="styDotLn">
             ...................
          </span>
          <div class="styIRS8860LNLeftNumBox" style="width:15mm;">
          </div>
      <div class="styIRS8860LNRightNumBox" style="height:4.2mm;">4</div>
      <div class="styIRS8860LNAmountBox">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form8860Data/RegularTaxBeforeCredits"/>
              </xsl:call-template>
      </div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8860LNLeftLtrBox"></div>
     <div style="float:left">
      <img src="{$ImagePath}/8860_Bullet_Round.gif" alt="dot"/>  Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G, lines
     </div>
     <div style="float:right">
      <div class="styIRS8860LNLeftNumBox" style="width:15mm;"></div>
      <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8860LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8860LNLeftNumBox"></div>
     <div style="float:left">
      1a and 1b, or the amount from the applicable line of your return
     </div>
     <div style="float:right"><span class="styDotLn">
         .........
         </span><div class="styIRS8860LNLeftNumBox" style="width:15mm;"></div>
      <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8860LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
      
  <!-- Part II, Line 5 -->
      <div style="width:187mm">
   <div class="styLNLeftNumBox ">5</div>
   <div style="float:left">
    Alternative minimum tax:
  </div>
   <div style="float:right">
    <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>
    <div class="styIRS8860LNAmountBox" style="border-bottom:0;;height:4.5mm;"></div>
   </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8860LNLeftLtrBox"></div>
     <div style="float:left">
      <img src="{$ImagePath}/8860_Bullet_Round.gif" alt="dot" /> Individuals. Enter the amount from Form 6251, line 35
     </div>
     <div style="float:right">
       <span class="styDotLn">
         ...........                   
          </span>
          <div class="styIRS8860LNLeftNumBox" style="position:relative;width:15mm;">
            <span style="z-index:1;position:absolute;top:0mm;left:9mm;"><img src="{$ImagePath}/8860_Bracket_Sm.gif" alt="Curly Bracket Image"/></span>
          </div>
          <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0"></div>
          <div class="styIRS8860LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8860LNLeftLtrBox"></div>
     <div style="float:left">
       <img src="{$ImagePath}/8860_Bullet_Round.gif" alt="dot" />
      Corporations. Enter the amount from Form 4626, line 14
   </div>
     <div style="float:right">
             <span class="styDotLn">
           ..........
              </span>
      <div class="styIRS8860LNLeftNumBox" style="width:15mm;"></div>
      <div class="styIRS8860LNRightNumBox" style="height:4.3mm;">5
      </div>
      <div class="styIRS8860LNAmountBox" >
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form8860Data/AlternativeMinimumTax"/>
              </xsl:call-template>
      </div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8860LNLeftLtrBox"></div>
     <div style="float:left">
      <img src="{$ImagePath}/8860_Bullet_Round.gif" alt="dot"/>  Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56
       </div>
     <div style="float:right">
       <span class="styDotLn">
         ....                     
          </span>
      <div class="styIRS8860LNLeftNumBox" style="width:15mm;"></div>
      <div class="styIRS8860LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8860LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
  
       
<!-- Part II, Line 6 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">6</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
          Add line 4 and line 5
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..........................</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="width:8mm;height:5mm;padding-top:1mm;">    
        6
        </div>
        <div class="styLNAmountBox" style="height:5mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/SumOfRegularTaxAndMinimumTax"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Part II, Line 7a -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">7a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
          Foreign tax credit
          </div>
          <div style="float:right;">
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.................</span>
            <span style="width:5px;"/>            
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7a</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- 2003V06 schema does not specify elements for data mapping for lines 7b through 7i -->      
<!-- Part II, Line 7b -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
            Credits from Form 1040, lines 48 through 54          
            </div>
        <div style="float:right;">        
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold;">........</span>
          <span style="width:5px;"/>
        </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7b</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
        <!-- No element specified in schema -->
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>


<!-- Part II, Line 7c -->      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Possessions tax credit (Form 5735, line 17 or 27)          </div>
          <div style="float:right;">  
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.......</span>
            <span style="width:5px;"/>            
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/PossessionsCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Part II Line 7d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Nonconventional source fuel credit (Form 8907, line 23)
         </div>
          <div style="float:right;">
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.....</span>
            <span style="width:5px;"/>          
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/CreditForFuelFromNnconvSource"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
<!-- Part II, Line 7e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">e</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Other specified credits (see instructions)
          </div>
          <div style="float:right;">  
            <!-- Dotted Line -->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..........</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7e</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/OtherSpecifiedCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Part II, Line 7f -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">f</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            General business credit (see instructions)
          </div>
          <div style="float:right;">          
            <!-- Dotted Line -->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..........</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7f</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/GeneralBusinessCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
<!-- Part II, Line 7g -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">g</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Credit for prior year minimum tax
          </div>
          <div style="float:right;">  
            <!-- Dotted Line -->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.............</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7g</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/PYMinimumTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
                  
<!-- Part II, Line 7h -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">h</div>
        <div class="styLNDesc" style="width:138mm;height:4.5mm;">
          <div style="float:left;">
            Add lines 7a through 7g
          </div>
          <div style="float:right;">  
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.........................</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7h
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/TotalCredits"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line Part II, Line 8 -->      
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4.5mm;">8</div>
        <div class="styLNDesc" style="width:138mm;height:4.5mm;">
          <div style="float:left;">
            Net income tax. Subtract line 7h from line 6
          </div>
          <div style="float:right;">  
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">...................</span>
            <span style="width:5px;"/>
          </div>          
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">8
      </div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8860Data/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Part II, Line 9 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">9</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;text-align:justified;">
            <span class="styBoldText">Credit allowed for the current year.</span> Enter the <span class="styBoldText">smaller</span> of line 3 or line 8 here and on Form
            1040, line 55; Form 1120, Schedule J, line 6f; Form 1041, Schedule G, line 3; or the applicable line of your return. 
            <span class="styBoldText">Caution.</span><span style="font-style:italic;"> If line 9 is <span class="styBoldText">smaller</span>
             than line 3, you generally should deduct the unallowed credit in figuring your taxable income for this tax year. Because this deduction will
            affect the allowable credit, refigure the unallowed credit until it equals the deduction. However, you may be able to deduct the unallowed 
            credit attributable to bonds sold after September 25, 2000, in the next tax year (see instructions)</span> 
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..........</span>
            <span style="width:5px;"/>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:20mm;padding-top:0mm">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
            <br/><br/><br/><br/><br/>
          </div>
          9
        </div>
        <div class="styLNAmountBoxNBB" style="height:20.75mm;">
          <br/><br/><br/><br/><br/>
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8860Data/QualifiedZoneAcademyBondCredit"/>
            </xsl:call-template>
        </div>
      </div>
    </div>

    <div style="width:187mm;" >
      <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions.</span> 
      <span style="width:110px;"></span>                      
      Cat. No. 24804G
      <span style="width:140px;"></span>  
      Form <span class="styBoldText">8860</span>(2005)
    </div>
    
    <br class="pageend" />    
    <!-- BEGIN Left Over Table -->  
    <!-- Additonal Data Title Bar and Button -->
    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>
    <!-- Additional Data Table -->
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form8860Data" />
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>          
    </table>
    <!-- END Left Over Table -->
        
        
       <!-- Separated Data for Part I -->
       <xsl:if test="($Print = $Separated) and (count($Form8860Data/CurrentYearCreditInfo) &gt; 5)">
       <br/><br/>
        <span class="styRepeatingDataTitle">Form 8860 - Part I - Current Year Credit, Line 1:</span><br/>               	  

		<table class="styDepTbl" style="font-size:7pt;" cellspacing="0" summary="Table displaying entity name or names and corresponding employer identification numbers" name="TYTable" id="TYTable" >
		      <thead class="styTableThead">
		        <tr class="styDepTblHdr">
		          <th scope="col" class="styDepTblCell" style="width:5mm;font-size:7pt;border-right:none;border-bottom:none;font-weight:bold;"><span 	style="width:1mm;"/>	</th>
		          <th scope="col" class="styDepTblCell" style="width:45mm;font-size:7pt;text-align:center; border-bottom:none; border-left:none;font-weight:bold;">(a)</th>
		          <th scope="col" class="styDepTblCell" style="width:35mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(b)</th>
		          <th scope="col" class="styDepTblCell" style="width:40mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(c)</th>
		          <th scope="col" class="styDepTblCell" style="width:20mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(d)</th>
		          <th scope="col" class="styDepTblCell" style="width:42mm;font-size:7pt;text-align:center;border-bottom:none;border-right:none;font-weight:bold;">(e)</th>        
		        </tr>
		        <tr class="styDepTblHdr">
		          <th scope="col" class="styDepTblCell" style="width:5mm;font-size:7pt;border-right:none;border-top:none;"><span style="width:1mm;"/></th>
		          <th scope="col" class="styDepTblCell" style="width:45mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none;border-left:none">Bond issuer’s name, city <br />or town, and 		state</th>
		          <th scope="col" class="styDepTblCell" style="width:35mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none">Month and year<br /> bond issued</th>
		          <th scope="col" class="styDepTblCell" style="width:40mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none">Outstanding principal <br />amount of bond	</th>
		          <th scope="col" class="styDepTblCell" style="width:20mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none">Credit rate</th>
		          <th scope="col" class="styDepTblCell" style="width:42mm;font-size:7pt;text-align:center;border-right:none;font-weight:normal;border-top:none">Credit ((c) x (d))</th>
		        </tr>
		      </thead>
		    <tfoot></tfoot>
		    <tbody>
		    <xsl:for-each select="$Form8860Data/CurrentYearCreditInfo">
		        <tr>
	                   <!-- Define background colors to the rows -->
	              	<xsl:attribute name="class">
	                        <xsl:choose>
	                          <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                          <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                        </xsl:choose>
	                   </xsl:attribute>
		          <td class="styDepTblCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;">
		            <xsl:choose>
		              <xsl:when test="position() = 1">
		                <xsl:value-of select="position()"/>
		              </xsl:when>
		              <xsl:otherwise>
		                <span style="width:1px;"/>
		              </xsl:otherwise>
		            </xsl:choose>
		          </td>    
		          <td class="styDepTblCell" rowspan="1" style="width:45mm;text-align:left;font-size:6pt;font-weight:normal;;border-left:none;font-family:verdana;">
		            <xsl:call-template name="PopulateText">
		              <xsl:with-param name="TargetNode" select="BondIssuerName/BusinessNameLine1"/>
		            </xsl:call-template>
		            <xsl:if test="BondIssuerName/BusinessNameLine2 !=''">
		            <br/>
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="BondIssuerName/BusinessNameLine2"/>
		              </xsl:call-template>          
		            </xsl:if>
		            <xsl:if test="City !=''">
		            <br/>
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="City"/>
		              </xsl:call-template>,
		            </xsl:if>
		            <xsl:if test="State !=''">
		              <xsl:call-template name="PopulateText">
		                <xsl:with-param name="TargetNode" select="State"/>
		              </xsl:call-template>
		              <span style="width:1mm;"/>
		            </xsl:if>
		          </td>
		          <td class="styDepTblCell" style="width:35mm;text-align:center;font-size:7pt;font-weight:normal;">
		            <xsl:call-template name="PopulateText">
		              <xsl:with-param name="TargetNode" select="MonthYearBondIssued"/>
		            </xsl:call-template>
		          </td>
		          <td class="styDepTblCell" style="width:40mm;text-align:right;font-size:7pt;font-weight:normal;">
		            <xsl:call-template name="PopulateAmount">
		              <xsl:with-param name="TargetNode" select="OutstandingPrincipalAmtOfBond"/>
		            </xsl:call-template>
		          </td>
		          <td class="styDepTblCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;">
		            <xsl:call-template name="PopulatePercent">
		              <xsl:with-param name="TargetNode" select="CreditRate"/>
		            </xsl:call-template>          
		          </td>  
		          <td class="styDepTblCell" style="width:42mm;text-align:right;border-right:none;font-size:7pt;font-weight:normal;">
		            <xsl:call-template name="PopulateAmount">
		              <xsl:with-param name="TargetNode" select="CreditForThisBond"/>
		            </xsl:call-template>
		          </td>
		        </tr>
      		</xsl:for-each>
   	     </tbody>
          </table>
          <br/>
       </xsl:if>
       <!-- /Separated Data for Part I -->
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
