<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8861Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8861Data" select="$RtnDoc/IRS8861" />


<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8861Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 8861" />
      
      
      
      <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
      <xsl:call-template name="InitJS"></xsl:call-template>

    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 8861 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS8861Style"></xsl:call-template>
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>  
    </style>
  <xsl:call-template name="GlobalStylesForm"/>
</head>

  <body class="styBodyClass">
    <form name="Form8861">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>

      <!-- Begin Form Number and Name -->
      <div class="styBB" style="width:187mm;">      
        <div class="styFNBox" style="width:31mm;height:21.5mm;">
          Form <span class="styFormNumber">8861</span>        
          <div style="padding-top:5.5mm;">
            <span class="styAgency">Department of the Treasury</span><br/>
            <span class="styAgency">Internal Revenue Service</span>
          </div>
        </div>
      <div class="styFTBox" style="width:125mm;height:21.5mm;">
        <div class="styMainTitle" style="height:9mm;padding-top:1mm;"><br />Welfare-to-Work Credit</div><br/>
        <div class="styFST" style="height:5mm;font-size:7pt;padding-top:2mm;"><img src="{$ImagePath}/8861_Bullet.gif" alt="Bullet Image"/><span style="width: .5mm" /> Attach to your tax return.</div>
      </div>
      <div class="styTYBox" style="width:30mm;height:21.5mm;">
        <div class="styOMB" style="height:2mm;">OMB No. 1545-1569</div>
          <div class="styTY" style="height:10mm;font-size:25pt">20<span class="styTYColor">05</span></div>
          <div style="width:18mm;padding-right:8mm;">Attachment</div>
        <div>Sequence No.<span class="styBoldText"><span style="width:4px;"></span>107</span></div>
      </div>
    </div>
  
<!-- Names and Identifying number Lines  -->
    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:156mm;height:8mm;font-weight:normal;font-size:7pt;">
        Name(s) shown on return<br/>
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>        
      </div>
      <div class="styEINBox" style="width:30mm;height:4mm;padding-left:2mm;font-size:7pt;">
        Identifying number<br/><br/>
        <span style="font-weight:normal;">  
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
        </span>          
      </div>
    </div>

<!-- Part I Current Year Credit -->

<!-- Line 1 -->
    <div class="styBB" style="width:187mm;">
      <div class="styPartName">Part I</div>
      <div class="styPartDesc" style="padding-left:3mm;">Current Year Credit</div>
    </div>
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:2mm;padding-left:2.75mm;">1</div>      
          <div class="styLNDesc" style="height:3mm;">        
            Enter on the applicable line below the qualified first- or second-year wages paid or incurred
            during the tax year and multiply by the percentage shown for services of employees who began
		  work for you before January 1, 2006, and are certified as long-term family assistance recipients.
            Members of a controlled group, see instructions.
          </div>
          <div class="styLNRightNumBoxNBB" style="width:8.25mm;height:14mm;border-right-width:1px;padding-top:6.75mm;">
        </div>
      </div>
      
<!-- Line 1a -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">a</div>
        <div class="styLNDesc" style="width:81.25mm;height:4mm;">
          Qualified first-year wages
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold;">...........</span>
        </div>
        <div class="styBB"  style ="width:3mm;float:left;clear:none;">
          $   
        </div>
        <div class="styBB"  style ="width:32mm;text-align:right;float:left;clear:none;">
          <xsl:if test="not($Form8861Data/TotalQualifiedFirstYearWages) or $Form8861Data/TotalQualifiedFirstYearWages = ''">
            <span style="width:1px;"></span>
          </xsl:if>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/QualifiedFirstYearWages"/>
          </xsl:call-template>
        </div>
        <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 35% (.35)</div>
        <div style="width:4mm;float:left;Clear:none;"></div>
        <div class="styLNRightNumBox">
          1a
        </div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/TotalQualifiedFirstYearWages"/>
          </xsl:call-template>        
        </div>
      </div>

<!-- Line 1b -->      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">b</div>
        <div class="styLNDesc" style="width:81.25mm;height:4mm;">
          Qualified second-year wages
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold;">..........</span>
        </div>
        
        <div class="styBB"  style ="width:3mm;float:left;clear:none;">
          $   
        </div>
        <div class="styBB"  style ="width:32mm;text-align:right;float:left;clear:none;"> 
          <xsl:if test="not($Form8861Data/QualifiedSecondYearWages) or $Form8861Data/QualifiedSecondYearWages = ''">
            <span style="width:1px;"></span>
          </xsl:if>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/QualifiedSecondYearWages"/>
          </xsl:call-template>
        </div>
        <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 50% (.50)</div>
        <div style="width:4mm;float:left;Clear:none;"></div>
        <div class="styLNRightNumBox">          
          1b
        </div>
        <div class="styLNAmountBox" >
        <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/TotalQualifiedSecondYearWages"/>
          </xsl:call-template>
        </div>
      </div>
      
<!-- Line 2 -->
      <div style="width:187mm;">
            <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.75mm;">2</div>
            <div class="styLNDesc" style="height:4mm;">
                Add lines 1a and 1b.  You <span class="styBoldText">must</span> subtract this amount from your deduction for salaries and wages
                <!--Dotted Line-->
                <span style="width:2px;"></span>  
                <!-- Form to Form Link -->
                <xsl:call-template name="SetFormLinkInline">
                   <xsl:with-param name="TargetNode" select="$Form8861Data/TotalQualified1stAnd2ndYrWages"/>
               </xsl:call-template>
        </div>        
        <div class="styLNRightNumBox" style="height:4mm;">
          2
        </div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/TotalQualified1stAnd2ndYrWages"/>
          </xsl:call-template>
        </div>
      </div>
            
<!-- Line 3 -->      <div style="width:187mm;">
              <div style="float:left">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.75mm;">3</div>
                <div class="styLNDesc" style="width:18mm; height:4mm;">
                    Welfare-to-work credits from pass-through entities:
                </div>
                <div class="styLNDesc" style="width:5mm; height:4mm;"> </div>
                <div class="styLNDesc" style="width:115mm; height:4mm;">
                  <table summary="Table for Work Opportunity Credit" style="width:115mm;font-size:7pt;" cellpadding="0" cellspacing="0" border="0" class="stytable">
                    <tr>
                      <th scope="col" class="styForm8861TBTable" style="width:29mm;text-align:center;" >
                          If you are a—
                        </th>
                       <th style="border-right:none;padding-left:2mm;width:73mm;text-align:left;" scope="col" class="styForm8861TBTable">
                          Then enter the total of the credits from—
                        </th>
                        <th style="padding-left:2mm;" scope="col"><span style="width:2px;"></span></th>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                         <span style="float:left;">
                           <span class="styBoldText">a</span> Shareholder
                         </span>
                         <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >..</span>
                         </span>
                       </td>
                       <td style="padding-left:2mm;">
                             <span style="float:left;">
                        Schedule K-1 (Form 1120S), box 13, code F, G, or K
                          </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >.</span>
                         </span>
                      </td>
                       <td rowspan="4">
                         <span style="float:left;">
                          <img alt="Bullet Image" src="{$ImagePath}/8844_Bracket_Sm.gif" />
                        </span>
                        <span style="float:right;letter-spacing:3.2mm;padding-right:3mm;font-weight:bold;padding-top:4.5mm;padding-left:1mm;">..</span>
                       </td>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                          <span style="float:left;">
                          <span class="styBoldText">b</span> Partner
                        </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >...</span>
                         </span>              
                       </td>
                       <td style="padding-left:2mm;">
                            <span style="float:left;">
                        Schedule K-1 (Form 1065), box 15, code F, G, or K
                         </span>
                           <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >.</span>
                         </span>              
                       </td>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                           <span style="float:left;">
                          <span class="styBoldText">c</span> Beneficiary
                         </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >..</span>
                         </span>
                      </td>
                       <td style="padding-left:2mm;">
                            <span style="float:left;">
                          Schedule K-1 (Form 1041), box 13, code G
                          </span>
                            <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >....</span>
                         </span>              
                      </td>
                    </tr>
                    <tr>
                       <td style="border-right:solid black .75pt;">
                           <span style="float:left;">
                          <span class="styBoldText">d</span> Patron
                         </span>
                          <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >....</span>
                         </span>
                      </td>
                       <td style="padding-left:2mm;">
                            <span style="float:left;">
                          Written statement from cooperative
                         </span>
                           <span style="float:right;padding-right:1.5mm;">
                           <span class = "styDotLn" >......</span>
                         </span>              
                       </td>
                    </tr>
                  </table>
                </div>
              </div>
              <div style="height:9mm;" class="styLNRightNumBoxNBB"></div>
              <div style="height:9mm;" class="styLNAmountBoxNBB"></div>
              <div style="height:4.5mm;" class="styLNRightNumBox">3</div>
              <div style="height:4.5mm;" class="styLNAmountBox">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form8861Data/WelfareToWorkCredits"/>
                </xsl:call-template>        
              </div>
              <div style="height:4.5mm;" class="styLNRightNumBoxNBB"></div>
              <div style="height:4.5mm;" class="styLNAmountBoxNBB"></div>
            </div>        

<!-- Line 4 -->            
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:3.5mm;padding-left:2.75mm;">4</div>
        <div class="styLNDesc" style="height:3.5mm;">
          <span class="styBoldText">
            Current year credit.
          </span>
          Add lines 2 and 3. (S corporations, partnerships, estates, trusts, cooperatives, regulated investment
          companies, and real estate investment trusts, see instructions.)
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold;">.....</span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:8mm;">
        <br/>
        4
        </div>
        <div class="styLNAmountBoxNBB" style="height:8mm;padding-top:3.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/CurrentYearCredit"/>
          </xsl:call-template>        
        </div>
      </div>
    </div>

<!-- Part II -->
    <div class="styBB" style="width:187mm;">
      <div class="styPartName">Part II</div>
      <div class = "styPartDesc" style="padding-left:3mm;font-size:8pt;width:172mm;">
        Allowable Credit <span class="styNormalText">(See </span><span class="styBoldText">Who must file Form
        3800</span><span class="styNormalText">  to find out if you complete Part II or file Form 3800.)</span>
      </div>
    </div>

<!-- Line 5 -->    
    <div class="styBB" style="width:187mm;">
      <div style="width:187mm">  
        <div class="styLNLeftNumBox" style="padding-left:2.75mm;">5</div>
        <div style="float:left;padding-top:.5mm;">
          Regular tax before credits:                
        </div>
        <div style="float:right">  
          <div class="styIRS8861LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8861LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBox" style="padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Individuals. Enter the amount from Form 1040, line 44                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ..........
          </span>
          <div class="styIRS8861LNLeftNumBox" style="position:relative;width:25mm;">
<!-- floating bracket -->
  <span style="z-index:1;position:absolute;top:0mm;left:-3mm;">
    <img src="{$ImagePath}/8861_Bracket_Lg.gif" alt="bracket" border="0"/>
  </span>
<!-- end bracket -->
          </div>  
          <div class="styIRS8861LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8861LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBox" style="padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Corporations. Enter the amount from Form 1120, Schedule J, line 3; Form 1120-A,            
        </div>
        <div style="float:right">  
          <div class="styIRS8861LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8861LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8861LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBox"></div>
        <div style="float:left;padding-top:.5mm;">
          Part I, line 1; or the applicable line of your return                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ..........
          </span>
          <div class="styIRS8861LNLeftNumBox" style="width:25mm;">
          <span class="styDotLn">      
            ......
          </span>
          </div>  
          <div class="styIRS8861LNRightNumBox" style="height:4.5mm;">5</div>  
          <div class="styIRS8861LNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8861Data/RegularTaxBeforeCredits"/>
            </xsl:call-template>
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styLNLeftLtrBox" style="padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left;padding-top:.5mm;">
          Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G,             
        </div>
        <div style="float:right">  
          <div class="styIRS8861LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8861LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8861LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
      <div style="width:187mm">  
        <div class="styIRS8861LNLeftNumBox"></div>
        <div style="float:left">
          lines 1a and 1b, or the amount from the applicable line of your return                
        </div>
        <div style="float:right">  
          <span class="styDotLn">      
            ....
          </span>
          <div class="styIRS8861LNLeftNumBox" style="width:25mm;"></div>  
          <div class="styIRS8861LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
          <div class="styIRS8861LNAmountBox" style="border-bottom:0;height:4.5mm;">
          </div>    
        </div>
      </div>    
<!-- line 6 -->            
      <div style="width:187mm">      
        <div class="styLNLeftNumBox" style="padding-top:0mm;padding-bottom:0mm;padding-left:2.75mm;">6</div>
        <div style="float:left">
          Alternative minimum tax:
        </div>
        <div style="float:right">  
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey"></div>
          <div class="styLNAmountBoxNBB" style="width:33mm;"></div>  
        </div>      
      </div>    
      
      <div style="width:187mm">      
        <div class="styLNLeftLtrBox" style="padding-top:0mm;padding-bottom:0mm;padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Individuals. Enter the amount from Form 6251, line 35          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            ......        
          </span>
          <div class="styIRS8861LNLeftNumBox" style="position:relative;width:35mm;">
<!-- floating bracket -->
  <span style="z-index:1;position:absolute;top:0mm;left:-3mm;">
    <img src="{$ImagePath}/8861_Bracket_Sm_L6.gif" alt="bracket" border="0"/>
  </span>
<!-- end bracket -->
          </div>  
          <div class="styIRS8861LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8861LNAmountBox" style="border-bottom:0;">
          </div>        
        </div>    
      </div>    
          
      <div style="width:187mm">  
        <div class="styLNLeftLtrBox" style="padding-top:0mm;padding-bottom:0mm;padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Corporations. Enter the amount from Form 4626, line 14          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            .......    
          </span>
          <div class="styIRS8861LNLeftNumBox" style="width:35mm;">
          <span class="styDotLn">  
            ........   
          </span>
          </div>  
          <div class="styIRS8861LNRightNumBox" style="height:4.5mm;">6</div>
          <div class="styIRS8861LNAmountBox" style="height:4.5mm;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8861Data/AlternativeMinimumTax"/>
            </xsl:call-template>
          </div>  
        </div>
      </div>          
        
      <div style="width:187mm">  
        <div class="styLNLeftLtrBox" style="padding-top:0mm;padding-bottom:0mm;padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div style="float:left">
          Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56          
        </div>
        <div style="float:right">  
          <span class="styDotLn">  
            
          </span>
          <div class="styIRS8861LNLeftNumBox" style="width:35mm;"></div>  
          <div class="styIRS8861LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8861LNAmountBox" style="border-bottom:0;">
          </div>      
        </div>
      </div>    

       
<!-- Line 7 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.75mm;">7</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Add lines 5 and 6
          
          <span style="letter-spacing:3.5mm;font-weight:bold;">...........................</span>
        </div>
        <div class="styLNRightNumBox" style="width:8mm;padding-top:1mm;height:5mm;">    
        7
        </div>
        <div class="styLNAmountBox" style="height:5mm;padding-top:1mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/RegularTaxPlusAltMinimumTax"/>
          </xsl:call-template>
        </div>
      </div>

<!-- line 8a -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.75mm;">8a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
          Foreign tax credit
          </div>
          <!--Dotted Line-->
          <div style="float:right;">
            <span style="letter-spacing:3.5mm;font-weight:bold;padding-right:.2mm;">.................</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">8a</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
<!-- line 8b -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left">
            Credits from Form 1040, lines 48  through 54
          </div>
          <div style="float:right;">
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;padding-right:.2mm;">........</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">8b</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
        <!-- No element specified in schema -->
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 8c -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
            Possessions tax credit (Form 5735, line 17 or 27)
          </div>
          <div style="float:right;">
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;padding-right:.2mm;">.......</span>
          </div>          
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">8c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/PossessionsTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 8d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">Nonconventional source fuel credit (Form 8907, line 23)
          </div>
          <!--Dotted Line-->
          <div style="float:right;">
            <span style="letter-spacing:3.5mm;font-weight:bold;padding-right:.2mm;">.....</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">8d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/CreditForFuelFromNnconvSource"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 8e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">e</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">Other specified credits (see instructions)
         </div>
          <div style="float:right;">
          <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;padding-right:.2mm;">.........</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">8e</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/OtherSpecifiedCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 8f -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">f</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
            Add lines 8a through 8e
          </div>
          <!--Dotted Line-->
          <div style="float:right;">
            <span style="letter-spacing:3.5mm;font-weight:bold;padding-right:.2mm;">........................</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">8f</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/TotalCredits"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line 9 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:2.75mm;">9</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
            Net income tax.  Subtract line 8f from line 7.  If zero,
            skip lines 10 through 13 and enter -0- on line 14
          </div>
          <!--Dotted Line-->
          <div style="float:right">
            <span style="letter-spacing:3.5mm;font-weight:bold">.</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">9
        </div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line 10 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">10</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Net regular tax.  Subtract line 8f from line 5.  If zero
          or less, enter -0- 
         <!--Dotted Line-->
         		<span style="letter-spacing:3.5mm;font-weight:bold">.</span>
         </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">10</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/NetRegularTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 11 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">11</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <span class="stySmallText">
            Enter 25% (.25) of the excess, if any, of line 10 over
            $25,000 (see instructions)
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;padding-top:0.5mm">11</div>
        <div class="styLNAmountBox" style="height:4.5mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/TwentyFivePercentOfExcess"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;padding-top:0.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 12 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">12</div>
        <div class="styLNDesc" style="width:93.25mm;height:4mm;">Tentative minimum tax (see instructions):</div>
        <div style="float:right">  
          <div class="styLNRightNumBoxNBB"></div>
          <div class="styLNAmountBoxNBB"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey"></div>
          <div class="styLNAmountBoxNBB" style="width:33mm;"></div>  
        </div>      
      </div>    
      
      <div style="width:187mm">      
        <div class="styLNLeftLtrBox" style="padding-top:0mm;padding-bottom:0mm;padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div class="styLNDesc" style="width:93.25mm;height:4mm;">
          Individuals. Enter the amount from Form 6251, line 33
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold;">.....</span>
        </div>
          <div class="styIRS8861LNLeftNumBox" style="position:relative;width:4mm;">
<!-- floating bracket -->
  <span style="z-index:1;position:absolute;top:1mm;left:-1mm;">
          <img src="{$ImagePath}/8861_Bracket_Md.gif" height="50mm" alt="Curly Bracket Image"/>
  </span>
<!-- end bracket -->
          </div>  
        <div style="float:right">  
          <div class="styLNRightNumBoxNBB"></div>
          <div class="styLNAmountBoxNBB"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey"></div>
          <div class="styLNAmountBoxNBB" style="width:33mm;"></div>  
        </div>      
      </div>
      <div style="width:187mm">      
        <div class="styLNLeftLtrBox" style="padding-top:0mm;padding-bottom:0mm;padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div class="styLNDesc" style="width:93.25mm;height:4mm;">
          Corporations.  Enter the amount from Form 4626, line 12             
          <!--Dotted Line-->
          <span style="letter-spacing:4.3mm;font-weight:bold;">....</span>            
        </div>
        <div style="float:right">  
          <div class="styLNRightNumBoxNBB"></div>
          <div class="styLNAmountBoxNBB"></div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey"></div>
          <div class="styLNAmountBoxNBB" style="width:33mm;"></div>  
        </div>      
      </div>
      <div style="width:187mm">      
        <div class="styLNLeftLtrBox" style="padding-top:0mm;padding-bottom:0mm;padding-left:4mm;"><img src="{$ImagePath}/8861_Bullet_Round.gif" alt="dot"/></div>
        <div class="styLNDesc" style="width:93.25mm;height:4mm;">
          Estates and trusts.  Enter the amount from Form 1041,<br/>   Schedule I, line 54
           <!-- Dotted Line -->
          <span style="letter-spacing:3.5mm;font-weight:bold;">................</span>            
        </div>
        <div style="float:right;">
          <div class="styLNRightNumBox" style="height:7.5mm;padding-top:3.5mm;">12</div>
          <div class="styLNAmountBox" style="height:7.5mm;padding-top:3.5mm;">
            <xsl:if test="not($Form8861Data/TentativeMinimumTax) or $Form8861Data/TentativeMinimumTax = ''">
              <span style="width:1px;"></span>
            </xsl:if>
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8861Data/TentativeMinimumTax"/>
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:7.5mm;"></div>
          <div class="styLNAmountBoxNBB" style="width:33mm;height:7.5mm;"></div>  
        </div>
      </div>

<!-- Line 13 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">13</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
            Enter the greater of line 11 or line 12
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold">.....................</span>
          </div>          
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">13</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/GreaterOfTentMinTaxOrExcess"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line 14  -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">14</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left">
            Subtract line 13 from line 9. If zero or less, enter -0-
          </div>
          <!--Dotted Line-->
          <div style="float:right;">
            <span style="letter-spacing:3.5mm;font-weight:bold;">................</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">14</div>
        <div class="styLNAmountBox" style="height:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/SubtractGreaterFromNetIncTax"/>
          </xsl:call-template>
        </div>        
      </div>    

<!-- Line 15 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">15</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <span class="styBoldText">Credit allowed for the current year.</span>
           Enter the <span class="styBoldText">smaller</span> of line 4 or line 14 here and on Form 1040, line 55; Form 1120, Schedule J, line 6d;
          Form 1120-A, Part I, line 2; Form 1041, Schedule G, line 2c; or the applicable line of your return. If line 14 is smaller than line 4, see instructions
          <span style="letter-spacing:4mm;font-weight:bold">.......</span>
        </div>
        <div class="styLNRightNumBoxNBB" style="height:11mm;padding-top:0mm">
        <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;"><br/><br/>
        </div>
        15
        </div>
        <div class="styLNAmountBoxNBB" style="height:11mm;">
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8861Data/CreditAllowedForCY"/>
          </xsl:call-template>
        </div>
      </div>
    </div>
  
    <div style="width:186mm;">
    <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions. </span> 
      <span style="width:30mm"></span>  
      Cat. No. 24858E 
      <span style="width:34mm"></span>  
      Form <span class="styBoldText">8861</span> (2005)
    </div>

    
    <p class="pageEnd"></p>
    
    <!-- BEGIN Left Over Table -->  
    <!-- Additonal Data Title Bar and Button -->
    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>
    <!-- Additional Data Table -->
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form8861Data" />
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>          
    </table>
    <!-- END Left Over Table -->    
          

      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
