<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8874Style.xsl"/>



<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8874Data" select="$RtnDoc/IRS8874" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8874Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    
    <meta name="Description" content="IRS Form 8874" />
    <META name="GENERATOR" content="IBM WebSphere Studio"/>
     <xsl:call-template name="GlobalStylesForm"/>
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>  
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <xsl:call-template name="IRS8874Style"></xsl:call-template>    
        <xsl:call-template name="AddOnStyle"></xsl:call-template>    
      </xsl:if>
    </style>
    <xsl:call-template name="GlobalStylesForm"/>
  </head>

<body class="styBodyClass">
  <form name="Form8874">
    <xsl:call-template name="DocumentHeader"></xsl:call-template>      
    
    <!-- Begin Form Number and Name -->
    <div class="styBB" style="width:187mm;">
    <div class="styFNBox" style="width:31mm;height:21mm;">
      Form <span class="styFormNumber">8874</span>
      <br/><br/>
      <div class="styAgency" style="padding-top:1.5mm">Department of the Treasury</div>
      <span class="styAgency">Internal Revenue Service</span>
    </div>
    <div class="styFTBox" style="width:123mm;height:21mm;">
      <div class="styMainTitle" style="height:8mm;">
        New Markets Credit
      </div>
      <br/>  
      <br/>
      <div class="styFST" style="padding-top: 3mm; height:5mm;font-size:7pt;">
        <img src="{$ImagePath}/8874_Bullet.gif" height="7mm" alt="Bullet Image"/>
        Attach to your tax return.
      </div>
    </div>
    <div class="styTYBox" style="width:32mm;height:21mm;">
      <div class="styOMB" style="height:2mm;">
        OMB No. 1545-1804
      </div>
      <div class="styTaxYear">
         20<span class="styTYColor">05</span>             
      </div>
      <div style="text-align: left; padding-left: 1mm">Attachment<br/> Sequence No.<span class="styBoldText"><span style="width:4px;"></span>127</span></div>
    </div>
  </div>    
  <!-- End Form Number and Name section -->
  <!-- Begin Names and Identifying number section -->

  <div class="styBB" style="width:187mm;">
    <div class="styNameBox" style="width:147mm;height:8mm;font-weight:normal;font-size:7pt;">
      Name(s) shown on return<br/>
      <span style="font-size:6pt;font-family:verdana;">         
       <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
       <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
     </span> 
    </div>
    <div class="styEINBox" style="width:30mm;height:4mm;padding-left:2mm;font-size:7pt;">
      Identifying number<br/><br/>
      <span style="font-weight:normal;">  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
      </span>  
    </div>
  </div>
  
  <!-- End Names and Identifying number section -->

  <!-- BEGIN Part I Title -->
  <div class="styBB" style="width:187mm;float: none; clear: none">
    <div class="styPartName" style="height: 3.75mm; width:12mm">Part I</div>
    <div class="styPartDesc" style="width:45mm;">Current Year Credit</div>
      <!-- Table expand/collapse toggle button -->
      <span style="width:122mm;"></span>
        <span style="width:7mm;padding-left:3.5mm;">
            <xsl:call-template name="SetDynamicTableToggleButton">
            <xsl:with-param name="TargetNode" select="$Form8874Data/CurrentYearCreditInfo"/>
            <xsl:with-param name="containerHeight" select="3"/>
            <xsl:with-param name="headerHeight" select="2"/>
            <xsl:with-param name="containerID" select=" 'TPctn' "/>
            </xsl:call-template>
        </span>      
    </div>
  <!-- END Part I Title -->
    
  <div class="styTableContainer" id="TPctn" >
    <xsl:call-template name="SetInitialState"/>
    <table class="styTable" cellspacing="0" summary="Table displaying entity name or names and corresponding employer identification numbers" >
    <thead class="styTableThead">
      <tr>
        <th scope="col" class="styTableCell" rowspan="3" style="width:7mm;border-right:none;font-weight:bold;"><span style="width:1mm;"/></th>
        <th scope="col" class="styTableCell" style="width:63mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(a)</th>
        <th scope="col" class="styTableCell" style="width:25mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(b)</th>
        <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(c)</th>
        <th scope="col" class="styTableCell" style="width:30mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(d)</th>
        <th scope="col" class="styTableCell" style="width:12mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(e)</th>
        <th scope="col" class="styTableCell" style="width:30mm;font-size:7pt;text-align:center;border-bottom:none;border-right:none;font-weight:bold;">(f)</th>
      </tr>
      <tr>
        <th scope="col" class="styTableCell" style="width:63mm;font-size:7pt;text-align:center;font-weight:normal;">Name and address of the qualified community development entity (CDE)</th>
        <th scope="col" class="styTableCell" style="width:25mm;font-size:7pt;text-align:center;font-weight:normal;">Employer identification number of CDE</th>
        <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;font-weight:normal;">Date of initial investment</th>
        <th scope="col" class="styTableCell" style="width:30mm;font-size:7pt;text-align:center;font-weight:normal;">Amount of qualified equity investment</th>
        <th scope="col" class="styTableCell" style="width:12mm;font-size:7pt;text-align:center;font-weight:normal;">Credit rate</th>
        <th scope="col" class="styTableCell" style="width:30mm;font-size:7pt;text-align:center;border-right:none;font-weight:normal;">Credit ((d) x (e))</th>
      </tr>
    </thead>
    <tfoot></tfoot>
    <tbody>
    <!-- Display all rows if the Print parameter is not Separated. If the Print parameter is Separated, but the number of -->
    <!-- elements is less than the container height, then also display all rows. -->
    <xsl:if test="($Print != $Separated) or (count($Form8874Data/CurrentYearCreditInfo) &lt;= 3) ">
      <xsl:for-each select="$Form8874Data/CurrentYearCreditInfo">
        <tr>
          <td class="styTableCell" style="width:7mm;font-size:7pt;text-align:center;vertical-align:top;border-right:none;font-weight:bold;">
            <xsl:if test="position()=1">1</xsl:if><span style="width:1px;"></span>
          </td> 
               
          <td class="styTableCell" rowspan="1" style="width:63mm;text-align:left;font-size:7pt;font-weight:normal;">
         <span style="font-family:verdana;font-size:6pt">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfCDE/BusinessNameLine1"/>
            </xsl:call-template>
            <xsl:if test="NameOfCDE/BusinessNameLine2 !=''">
            <br/>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="NameOfCDE/BusinessNameLine2"/>
              </xsl:call-template>          
            </xsl:if>
          </span>
          
            <xsl:if test="AddressOfCDE !=''">            
            <br/>
              <xsl:call-template name="PopulateUSAddressTemplate">
                <xsl:with-param name="TargetNode" select="AddressOfCDE"/>
              </xsl:call-template>
            </xsl:if>
          </td>
          
          <td class="styTableCell" style="width:25mm;text-align:center;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateEIN">
              <xsl:with-param name="TargetNode" select="IdentificationNumberOfCDE"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:20mm;text-align:center;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="DateOfInitialInvestment"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:30mm;text-align:right;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="AmountOfQlfyEquityInvestment"/>
            </xsl:call-template>          
          </td>
          <td class="styTableCell" style="width:12mm;text-align:right;font-size:7pt;padding-left:1mm;">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="CreditRate"/>
            </xsl:call-template>%
          </td>          
          <td class="styTableCell" style="text-align:right;width:30mm;border-right:none;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="CreditByRatio"/>
            </xsl:call-template>
          </td>
        </tr>
        </xsl:for-each>
      </xsl:if>
      <!-- Display blank filler rows. If the Print parameter is Separated and the number of elements exceeds the -->
      <!-- container height, then display a mesage in the first row directing the user to the additional data table -->
      <xsl:if test="count($Form8874Data/CurrentYearCreditInfo) &lt; 1 or
         (($Print = $Separated) and (count($Form8874Data/CurrentYearCreditInfo)&gt;3)) ">
        <tr>
          <td class="styTableCell" style="width:7mm;font-size:7pt;text-align:center;vertical-align:top;border-right:none;font-weight:bold;height:8mm">1</td>      
          <td class="styTableCell" rowspan="1" style="width:63mm;text-align:left;font-size:7pt;font-weight:normal;">
            <xsl:call-template name="PopulateAdditionalDataTableMessage">
              <xsl:with-param name="TargetNode" select="$Form8874Data/CurrentYearCreditInfo" />
            </xsl:call-template>
            <span style="width:1px;"/>
          </td>
          <td class="styTableCell" style="width:25mm;text-align:center;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:20mm;text-align:left;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:30mm;text-align:right;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:12mm;text-align:right;font-size:7pt;">%</td>
          <td class="styTableCell" style="text-align:right;width:30mm;border-right:none;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
        </tr>
      </xsl:if>  
      <xsl:if test="count($Form8874Data/CurrentYearCreditInfo) &lt; 2 or
         (($Print = $Separated) and (count($Form8874Data/CurrentYearCreditInfo)&gt;3)) ">
        <tr height="8mm">
          <td class="styTableCell" style="width:7mm;font-size:7pt;text-align:center;vertical-align:top;border-right:none;font-weight:bold;height:8mm"><span style="width:1px;"/></td>
          <td class="styTableCell" rowspan="1" style="width:63mm;text-align:left;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:25mm;text-align:center;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:20mm;text-align:left;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:30mm;text-align:right;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:12mm;text-align:right;font-size:7pt;">%</td>
          <td class="styTableCell" style="text-align:right;width:30mm;border-right:none;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
        </tr>
      </xsl:if>  
      <xsl:if test="count($Form8874Data/CurrentYearCreditInfo) &lt; 3 or
         (($Print = $Separated) and (count($Form8874Data/CurrentYearCreditInfo)&gt;3)) ">
        <tr height="8mm">
          <td class="styTableCell" style="width:7mm;font-size:7pt;text-align:center;vertical-align:top;border-right:none;font-weight:bold;height:8mm"><span style="width:1px;"/></td>
          <td class="styTableCell" rowspan="1" style="width:63mm;text-align:left;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:25mm;text-align:center;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:20mm;text-align:left;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:30mm;text-align:right;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
          <td class="styTableCell" style="width:12mm;text-align:right;font-size:7pt;">%</td>
          <td class="styTableCell" style="text-align:right;width:30mm;border-right:none;font-size:7pt;font-weight:normal;"><span style="width:1px;"/></td>
        </tr>
      </xsl:if>          
      </tbody>
    </table>        
      <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form8874Data/CurrentYearCreditInfo"/>
      <xsl:with-param name="containerHeight" select="3"/>
      <xsl:with-param name="headerHeight" select="2"/>
      <xsl:with-param name="containerID" select=" 'TPctn' "/>
      </xsl:call-template>  
  </div>

<!-- Line 2 caption -->
    <div style="width:187mm; float: none; clear: none;">
      <div class="styLNLeftNumBox" style="width:5mm;height:4mm;padding-left: 2mm">2</div>
        <div class="styLNDesc" style="width:141mm; height:2mm;padding-left: 2mm;padding-bottom:0mm;">          
          New markets credits from pass-through entities (if from more than one entity, see instructions):
           <!-- Form to Form links (Push Pins) -->
           <xsl:call-template name="SetFormLinkInline">        
            <xsl:with-param name="TargetNode" select="$Form8874Data/TotCreditFromPassThruEntities"/>
            <xsl:with-param name="IDstring">$Form8874Data/TotCreditFromPassThruEntities</xsl:with-param>
          </xsl:call-template>
        </div>
      <div class="styLNRightNumBoxNBB" style="height:2mm;width:9.25mm;border-right-width:1px;background-color:lightgrey;"/>
    </div>

<!-- Line 2 small table display -->        
    <div style="width:187mm">
      <div class="styLNLeftNumBox" style="width:5mm;height:4mm;"><span style="width:1px;"/></div>
      <div class="styLNDesc" style="width:114mm; height:2mm;">
        <table border="0" cellspacing="0" cellpadding="0" style="width:141mm;padding:0mm" summary="Table for New Markets Credit">
            <tr>
               <th class="styForm8874TBTable" style="width:28mm;text-align:left;padding-left: 2mm; font-size: 6pt" scope="col">                
                 If you are a—              
               </th>
               <th class="styForm8874TBTable" scope="col" style="width:70mm;text-align:left;padding-left:2mm;border-right:none; font-size: 6pt">
                 Then enter the total of the current year credits from—
               </th>
               <th style="width: 43mm"><span style="width: 1px"></span></th>
            </tr>
            <tr style="padding-top:.75mm">
               <td scope="row" style="width: 28mm; font-size: 6pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt; padding-left: 2mm">
             <span class="styBoldText">a</span> Shareholder
             </td>
             
             <td style="font-size:6pt;font-family:verdana;font-style: normal;font-weight:normal;border:none; padding-left:2mm; width: 70mm">
             Schedule K-1 (Form 1120S), box 13, code O
             </td>
               <td rowspan="2">
              <div class="styLNDesc" style="width:5mm; height:4mm;">
                <img src="{$ImagePath}/8874_Bracket_Sm.gif" alt="Curly Bracket Image"/>
                                  
              </div>
<!-- Line 2 EIN data display -->
              <div style="width:33mm;float:left;text-align:left;font-size:7pt;">        
                <xsl:if test="$Form8874Data/EINOfPassThroughEntity != ''">
                  <xsl:call-template name="PopulateEIN">
                    <xsl:with-param name="TargetNode" select="$Form8874Data/EINOfPassThroughEntity"/>
                  </xsl:call-template>              
                </xsl:if>
              </div>
              <div style="float:left;width:30mm;font-size:6pt;text-decoration:overline;">EIN of pass-through entity</div>
            </td>
             </tr>
             <tr>
             <td scope="row" style="font-size: 6pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt; padding-left: 2mm">
                 <span class="styBoldText">b</span> Partner  
              </td>
               <td style="font-size:6pt;font-family:verdana;font-style: normal;font-weight:normal;border:none;padding-left:2mm">
                 Schedule K-1 (Form 1065), box 15, code O
               </td>
            </tr>            
        </table>          
      </div>

<!-- Line 2 TotalCredit data display-->        
        <div class="styLNRightNumBox" style="width:8.75mm;text-align:center;padding-top:0mm;height:8.25mm;">
          <div class="styLNRightNumBoxNBB" style="width:8.75mm;text-align:center;border-left-width:0px;background-color:lightgrey;"/>
          2    
        </div>        
        <div class="styLNAmountBox" style="height:8.25mm;width:30mm;padding-top:4mm;">
          <!-- if the element CreditFromPassThruEntity has data then display otherwise display the element TotCreditFromPassThruEntities -->
          <xsl:choose>
            <xsl:when test="$Form8874Data/CreditFromPassThruEntity != ''">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form8874Data/CreditFromPassThruEntity"/>
              </xsl:call-template>              
            </xsl:when>
            <xsl:otherwise>
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form8874Data/TotCreditFromPassThruEntities"/>
              </xsl:call-template>            
            </xsl:otherwise>        
          </xsl:choose>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9.25mm;height:7.75mm;text-align:center;border-left-width:1px;border-right-width:1px;background-color:lightgrey;"/>        
      </div>
      
<!-- Line 3 -->            
      <div class="styBB" style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;width:5mm;padding-left: 2.5mm">3</div>
        <div class="styLNDesc" style="height:3mm;width:141mm;padding-left: 2mm">
          <span class="styBoldText">
            Current year credit.
          </span>
          Add the amounts on line 1, column (f), and line 2. S corporations and partnerships, see instructions
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">...........................</span>
        </div>
        <div class="styLNRightNumBox" style="height:6mm;width:8.75mm;text-align:center;border-bottom:none;padding-top:0mm;">
          <div class="styLNRightNumBoxNBB" style="height: 4.5mm; width:8.75mm;text-align:center;border-left-width:0px;background-color:lightgrey;"/>
          3    
        </div>        
        <div class="styLNAmountBox" style="height:8.25mm;width:30mm;border-bottom:none;padding-top:4mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/CurrentYearCredit"/>
          </xsl:call-template>
        </div>
      </div>

  <!-- BEGIN Part II Title -->
  <div class="styBB" style="width:187mm;">
    <div class="styPartName" style="width:15mm">Part II</div>
    <div class="styPartDesc" style="padding-left:1mm;width:172mm;">Allowable Credit <span class="styNormalText">(See</span> Who must file Form 3800 
       <span class="styNormalText">to find out if you complete Part II or Form 3800) </span>
    </div>
  </div>
  <!-- END Part II Title -->
  
  <!-- Begin Allowable Credit-->
  
  <div class="styBB" style="width:187mm;">
      <div style="width:187mm;">
<!-- Line 4 -->      
        <div class="styLNLeftNumBox" style="height:4mm; padding-left:3mm">4</div>
        <div class="styLNDesc" style="width:123mm;height:4mm;">
          Regular tax before credits:          
            <li style="padding-top:.75mm">Individuals. Enter the amount from Form 1040, line 44</li>
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold">...........</span>
            <li style="padding-top:.75mm">Corporations.  Enter the amount from Form 1120, Schedule J, line 3; 
            Form 1120-A, <br/><span style="width:14px;float:left;"></span>Part I, line 1, or the applicable line of your return</li>
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold">.............</span>
            <li style="padding-top:.75mm">Estates and trusts.  Enter the sum of the amounts from Form 1041, Schedule G,
             lines 1a<br/> <span style="width:14px;float:left;"></span> and 1b, or the amount from the applicable line of your return</li>
             <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold">.........</span>                  
        </div>
        <div class="styLNDesc" style="width:5mm; padding-top:3.5mm;">
          <img src="{$ImagePath}/8874_Bracket_Lgest.gif" alt="Curly Bracket Image"/>      
        </div>
        <div class="styLNDesc" style="width:10mm; height:14mm;">                  
          <span class="styBoldText" style="width:10mm; height:14mm;padding-bottom:0mm;padding-top:6.5mm;">              
            <span style="width:26px;"></span>
            <span style="width:12px;"></span>.
            <span style="width:12px;"></span>.                                                      
          </span>                  
        </div>

        <div class="styLNRightNumBox" style="width:7.75mm;height:11mm;padding-top=0mm;">
          <div class="styLNRightNumBoxNBB" style="width:8.5mm;border-left-width:0px;background-color:lightgrey;height:10.5mm;">
          </div>
          4
        </div>
        <div class="styLNAmountBox" style="height:14.5mm;">
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/RegularTaxBeforeCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;height:8.5mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>

<!-- Line 5 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm; padding-left: 3mm">5</div>
        <div class="styLNDesc" style="width:123mm;height:4mm;">
          Alternative minimum tax:
          
            <li style="padding-top:.75mm">Individuals. Enter the amount from Form 6251, line 35</li>
            <!--Dotted Line-->
            <span style="letter-spacing:3.6mm;font-weight:bold">...........</span>
            <li style="padding-top:.75mm">Corporations.  Enter the amount from Form 4626, line 14</li>             
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold">...........</span>
            <li style="padding-top:.75mm">Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56</li>
             <!--Dotted Line-->
            <span style="letter-spacing:3.9mm;font-weight:bold">.....</span>                   
        </div>
        <div class="styLNDesc" style="width:5mm; height:4mm;padding-top:4.5mm;">
          <img src="{$ImagePath}/8874_Bracket_Md.gif" alt="Curly Bracket Image"/>        
        </div>
        <div class="styLNDesc" style="width:10mm; height:15mm;">                  
          <span class="styBoldText" style="width:10mm; height:4mm;padding-bottom:0mm;padding-top:7mm;">
           .   
            <span style="width:12px;"></span>.    
          </span>                  
        </div>
        <div class="styLNRightNumBox" style="width:7.75mm;height:8.25mm;padding-top:0mm;">
          <div class="styLNRightNumBoxNBB" style="width:8.5mm;padding-top:4mm;border-left-width:0px;background-color:lightgrey;">
        </div>
        5
        </div>
        <div class="styLNAmountBox" style="height:11.75mm;padding-top:7.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/AlternativeMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;height:5mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>

<!-- Line 6 -->        
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm; padding-left: 3mm">6</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
        <div style="float:left;">
          Add lines 4 and 5
        </div>
        <div style="float:right;">  
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">...........................</span>
        </div>
        </div>
        <div class="styLNRightNumBox" style="width:8.75mm;height:5mm;padding-top:1mm;">    
        6
        </div>
        <div class="styLNAmountBox" style="height:5mm;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/RegularTaxPlusAltMinTax"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line 7a -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm; padding-left: 3mm">7a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
          Foreign tax credit
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">..................</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7a</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 7b -->      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm; padding-left: 4mm">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
            Credits from Form 1040, 48 through 54          </div>
          <div style="float:right;">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">...........</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7b</div>
        <div class="styLNAmountBox" style="height:4.5mm;"></div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>    
     
<!-- Line 7c -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left: 4mm">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
          Possessions tax credit
          (Form 5735, line 17 or 27)
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">........</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/PossessionsTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 7d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left: 4mm">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
          Nonconventional source fuel credit (Form 8907, line 23)
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">......</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/CreditForFuelFromNnconvSource"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 7e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left: 4mm">e</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
          Other specified credits (see instructions)
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">...........</span>          
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7e</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/OtherSpecifiedCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 7f -->      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm; padding-left: 4mm">f</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <div style="float:left;">
          Add lines 7a through 7e
          </div>
          <div style="float:right">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">................</span>
          </div>          
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">7f
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/TotalCredits"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 8 -->      
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm; padding-left: 3mm">8</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          Net income tax.  Subtract line 7f from line 6.  If zero,
          skip lines 9 through 12 and enter -0- on line 13
           <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">.</span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;width:8.75mm">8
<!--        <div class="styLNRightNumBoxNBB" style="background-color:orange;"></div>  
        <div class="styLNAmountBoxNBB" style="height:4.mm;" ></div>-->
      </div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line 9 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left: 3mm">9</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Net regular tax. Subtract line 7f from line 4.  If zero or less, enter
          -0-
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">9</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/NetRegularTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:9mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Line 10 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">10</div>
        <div class="styLNDesc" style="padding-top: .5mm; font-size: 6pt; width:98.25mm;height:4mm;">
          Enter 25% (.25) of the excess, if any, of line 9 over
          $25,000 (see instructions)
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold;font-size:7pt">..</span>
        </div>
        <div class="styLNRightNumBox" style="height: 4.5mm">10</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/TwentyFivePercentOfExcess"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="height: 4.5mm; width:9mm;background-color:lightgrey;border-right-width:1px;"></div>
      </div>
      
<!-- Line 11 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">11</div>
        <div class="styLNDesc" style="width: 98.25mm; height:4mm;">        
          Tentative minimum tax (see instructions):
        </div>
        <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm; border-right-width:0px;"></div>
        <div class="styLNAmountBoxNBB"></div>
        <div class="styLNRightNumBoxNBB" style="width: 9mm; background-color:lightgrey;height:4mm; border-right-width:1px;"></div>
      </div>
            
      <div style="width:187mm">
        <div style="float: left; width: ">
        <div class="styLNDesc" style="width:90.25mm;height:17mm; padding-left: 8mm">        
            <li style="padding-top:.25mm;">Individuals. Enter the amount from Form 6251, line 33</li>
            <span style="letter-spacing:3mm;font-weight:bold"> .</span>
            <li style="padding-top:.5mm;">Corporations.  Enter the amount from Form 4626, line 12</li>                         
            <li style="padding-top:.5mm;">Estates and trusts. Enter the amount from Form 1041, <br/> <span style="width:14px;float:left;"></span>Schedule I, line 54</li>
             
            <span style="letter-spacing:3.5mm;font-weight:bold">.............</span>                  
        </div>        
          <div class="styLNDesc" style="width: 4mm; padding-top:1mm;">
            <img src="{$ImagePath}/8874_Bracket_Lg.gif" alt="Curly Bracket Image" style="position:absolute;"/>        
          </div>
        </div>
          <div class="styDotLn" style="padding-top:6.5mm;height:16mm;width: 12mm">  
            ...
          </div>
          <div style="float:left; clear:none">
          <div class="styLNRightNumBox" style="height: 10mm; padding-top: 6mm">11</div>
          <div class="styLNAmountBox" style="height: 10mm; padding-top: 6mm">
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/TentativeMinimumTax"/>
            </xsl:call-template>
          </div>
          <div class="styLNRightNumBoxNBB" style="width: 8.75mm; background-color:lightgrey;height:17mm"></div>  
          <div class="styLNAmountBoxNBB" style="width: 31.75mm; height: 17mm; padding-top: 6mm"></div>  
          </div>
      </div>

<!-- Line 12 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">12</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
          Enter the greater of line 10 or line 11
          </div>
          <div style="float:right">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">.....................</span>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;width:8.75mm">12</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/GreaterOfTentMinTaxOrExcess"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line 13 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">13</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
          Subtract line 12 from line 8. If zero or less, enter -0-
          </div>
          <div style="float:right">
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">................</span>          
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;width:8.75mm">13</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/SubtractGreaterFromNetIncTax"/>
          </xsl:call-template>
        </div>        
      </div>      

<!-- Line 14 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">14</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <span class="styBoldText">Credit allowed for the current year. </span>
          Enter the <span class="styBoldText">smaller</span> of line 3 or line 13 here and on Form 1040,
          line 55; Form 1120, Schedule J, line 6d; Form 1120-A, Part I, line 2; Form 1041, Schedule G, line
          2c; or the applicable line of your return. If line 3 is greater than line 13, see instructions
          <!--Dotted Line-->
          <span style="letter-spacing:3.5mm;font-weight:bold">.......</span>          
        </div>
        <div class="styLNRightNumBoxNBB" style="height:8mm;padding-top:0mm">
        <div class="styLNRightNumBoxNBB" style="width:8.5mm;border-left-width:0px;background-color:lightgrey;padding-top: 4mm">
        </div>
          14
        </div>
        <div class="styLNAmountBoxNBB" style="padding-top: 7.75mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8874Data/NewMarketsCreditAllowedForCY"/>
          </xsl:call-template>
        </div>
      </div>
    </div>

    <div style="width:187mm;">
      <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions. </span> 
      <span style="width:120px;"></span>                      
      Cat. No. 31663N 
      <span style="width:125px;"></span>  
      Form <span class="styBoldText">8874</span> (2005)
    </div>
    <br class="pageEnd"/> 
    
    <!-- BEGIN Left Over Table -->  
    <!-- Additonal Data Title Bar and Button -->
    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>
    <!-- Additional Data Table -->
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form8874Data" />
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>          
    </table>
    <!-- END Left Over Table -->  
    
      <!-- Additional Data Table for Separated Data from Part I Line 1 -->
      <xsl:if test="($Print = $Separated) and (count($Form8874Data/CurrentYearCreditInfo) &gt; 3) ">
        <span class="styRepeatingDataTitle">
          Form 8874, Part I, Line 1 - Current Year Credit
        </span>
        <table class="styDepTbl" style="font-size:7pt">
          <thead class="styTableHead">
            <tr class="styDepTblHdr">
              <th scope="col" class="styDepTblCell" style="width:68mm;text-align:center;border-bottom:none;">(a)</th>
              <th scope="col" class="styDepTblCell" style="width:23mm;text-align:center;border-bottom:none;">(b)</th>
              <th scope="col" class="styDepTblCell" style="width:20mm;text-align:center;border-bottom:none;">(c)</th>
              <th scope="col" class="styDepTblCell" style="width:32mm;text-align:center;border-bottom:none;">(d)</th>
              <th scope="col" class="styDepTblCell" style="width:12mm;text-align:center;border-bottom:none;">(e)</th>
              <th scope="col" class="styDepTblCell" style="width:32mm;text-align:center;border-bottom:none;">(f)</th>
            </tr>
            <tr class="styDepTblHdr">
              <th scope="col" class="styDepTblCell" style="width:68mm;text-align:center;border-top:none;">
                Name and address of the qualified community development entity (CDE)
              </th>
              <th scope="col" class="styDepTblCell" style="width:23mm;text-align:center;border-top:none;">
                Employer identification number of CDE
              </th>
              <th scope="col" class="styDepTblCell" style="width:20mm;text-align:center;border-top:none;">
                Date of initial investment
              </th>
              <th scope="col" class="styDepTblCell" style="width:32mm;text-align:center;border-top:none;">
                Amount of qualified equity investment
              </th>
              <th scope="col" class="styDepTblCell" style="width:12mm;text-align:center;border-top:none;">Credit rate</th>
              <th scope="col" class="styDepTblCell" style="width:32mm;text-align:center;border-top:none;">Credit ((d) x     (e))  </th>
            </tr>
          </thead>
          <tfoot></tfoot>
          <tbody>
            <xsl:for-each select="$Form8874Data/CurrentYearCreditInfo">
              <tr>
                <xsl:attribute name="class">
                  <xsl:choose>
                    <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                    <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                  </xsl:choose>
                </xsl:attribute>
                
                <td class="styDepTblCell" style="width:68mm;text-align:left;">
                 <span style="font-family:verdana;font-size:6pt;">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="NameOfCDE/BusinessNameLine1"/>
                  </xsl:call-template>
                  <xsl:if test="NameOfCDE/BusinessNameLine2 !=''">
                  <br/>
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="NameOfCDE/BusinessNameLine2"/>
                    </xsl:call-template>          
                  </xsl:if>
                </span>
                  
                  <xsl:if test="AddressOfCDE !=''">            
                  <br/>
                    <xsl:call-template name="PopulateUSAddressTemplate">
                      <xsl:with-param name="TargetNode" select="AddressOfCDE"/>
                    </xsl:call-template>
                  </xsl:if>
                </td>
                
                <td class="styDepTblCell" style="width:23mm;text-align:center;">
                  <xsl:call-template name="PopulateEIN">
                    <xsl:with-param name="TargetNode" select="IdentificationNumberOfCDE"/>
                  </xsl:call-template>
                </td>
                <td class="styDepTblCell" style="width:20mm;text-align:center;">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="DateOfInitialInvestment"/>
                  </xsl:call-template>
                </td>
                <td class="styDepTblCell" style="width:32mm;text-align:right;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="AmountOfQlfyEquityInvestment"/>
                  </xsl:call-template>          
                </td>
                <td class="styDepTblCell" style="width:12mm;text-align:right;">
                  <xsl:call-template name="PopulateText">
                    <xsl:with-param name="TargetNode" select="CreditRate"/>
                  </xsl:call-template>%
                </td>          
                <td class="styDepTblCell" style="text-align:right;width:32mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="CreditByRatio"/>
                  </xsl:call-template>
                </td>
              </tr>
            </xsl:for-each>
          </tbody>
        </table>
      </xsl:if>
      <!-- End of Part I Line 1 Separated Data -->
        
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
