<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8895Style.xsl"/>



<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="FormData" select="$RtnDoc/IRS8895" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" 
    select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
 
    <meta name="Description" content="TY 2005 IRS Form 8895" />
    
    
    
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>
    
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''" >
        <!-- Form 8895 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS8895Style"></xsl:call-template>  
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if >
    </style>    
  <xsl:call-template name="GlobalStylesForm"/>
</head>

  <body class="styBodyClass">
    <form name="Form8895">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>
      
      <!-- Begin Form8895 Number and Name -->
      <div class="styBB" style="width:187mm;">
      <div class="styFNBox" style="width:31mm;height:20mm;">
        Form <span class="styFormNumber">8895</span>
         <!--The xsl: choose code block below enables this stylesheet to display data from more then one schema version -->
          <xsl:choose>
            <xsl:when test="$Version='2004v2.0' or $Version='2004v3.0'">
                 <br/>
           </xsl:when>
          <xsl:otherwise>
          <br/>
          </xsl:otherwise>
          </xsl:choose>
          <span class="styAgency">(August 2005)</span>
        <br/>
        <span class="styAgency">Department of the Treasury</span>
        <br/>
        <span class="styAgency">Internal Revenue Service</span>
      </div>
      <div class="styFTBox" style="width:123mm;height:10mm;">
        <span style="height: 1mm;" />
        <div class="styMainTitle" style="height:8mm;">
          One-Time Dividends Received Deduction for Certain Cash 
          Dividends from Controlled Foreign Corporations</div>
        <br/>
        <span style="text-align:center;">
        <img src="{$ImagePath}/8895_Bullet_Md.gif" alt="MediumBullet"/> 
          Attach to the corporation’s tax return.
        </span>

      </div>
      <div class="styTYBox" style="width:32mm;height:20mm;padding-top:8mm;">
        <div class="styOMB" style="height:2mm;border-bottom-width:0px">
          OMB No. 1545-1948
        </div>
      </div>
      
    </div>
    
<!-- End Form Number and Name section -->
 <!--  Name and Employer identification number  -->
  
  <div class="styTBB" style="width:187mm">
    <div class="styNameBox" style="width:141mm;font-size:7pt;">
      Name of corporation<br/>
      <div style="font-family:verdana;font-size:6pt;height:6.25mm">
       <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
       <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
     </div>
    </div>
    <div class="styEINBox" style=" padding-left:2mm;font-size:7pt;font-weight:normal">Employer identification number
      <br/><br/>
      <span style="font-weight:normal;">  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
      </span>    
    </div>
  </div>
    
  <!--  End Name and Employer indentification number  -->
 
    
<!-- Start part I -->

<div style="width:187mm;border-top-width:0px;" class="styBB">
  <div class="styPartName" style="width:15mm;">Part I</div>
  <div class="styPartDesc" style="padding-left:3mm;">
    Qualifying Information
  </div>
</div>
  
<!-- End PartI -->


<!-- Start line A -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          A
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
            Enter the date(s) the corporation’s domestic reinvestment plan(s) 
            (DRP) was approved by the corporation’s
         
          </span>
        </div>      
     </div>
  
<!-- End line A --> 
  

<!-- Start line A1 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styGenericDiv" style="height:4mm;">
                          president, CEO, or comparable official
                 <img src="{$ImagePath}/8895_Bullet_Md.gif" alt="MediumBullet"/>
                 <span style="width:2mm"></span>
        </div>      
          <div class="styUnderlineAmount" style="width:18mm;height:4mm;text-align:center;padding-top:0mm">
             <xsl:call-template name="PopulateMonthDayYear">
                <xsl:with-param name="TargetNode" select="$FormData/DRPApprovalDatePresident"/>
             </xsl:call-template>        
          </div>
         
       </div>  

<!-- End line A1 --> 

<!-- Start line B -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          B
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
            Enter the date(s) the DRP was approved by the corporation’s board of directors, 
            management committee,
        
          </span>
        </div>      
     </div>
  
<!-- End line B --> 

<!-- Start line B1 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styGenericDiv" style="height:4mm;">
                           executive committee, or similar body
                <img src="{$ImagePath}/8895_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm"></span>
        </div>      

          <div class="styUnderlineAmount" style="width:18mm;height:4mm;text-align:center;padding-top:0mm">
              <xsl:call-template name="PopulateMonthDayYear">
             <xsl:with-param name="TargetNode" select="$FormData/DRPApprovalDtBoardOfDirectors"/>
          </xsl:call-template>        
          </div>
       </div>  

<!-- End line B1 -->

<!-- Start line C -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          C
        </div>
        <div class="styGenericDiv" style="height:4mm;">
          
           The DRP states that the corporation anticipates completing all reinvestments 
           in the tax year ending
       
        </div>      
     </div>
  
<!-- End line C --> 

<!-- Start line C1 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
          <div class="styUnderlineAmount" style="width:18mm;height:4mm;text-align:center;padding-top:0mm">
                 <xsl:call-template name="PopulateMonthDayYear">
             <xsl:with-param name="TargetNode" select="$FormData/AnticipatedComplnReinvstTYDate"/>
          </xsl:call-template>        
          </div>
          
          <div class="styGenericDiv"><span style="width:2mm"></span>                
                See Notice 2005-10 for required attachment.
         </div>
       </div>  

<!-- End line C1 -->  

<!-- Start line D -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          D
        </div>
        <div class="styLNDesc" style="width:145mm;height:4mm;">
          <span style="float:left">
           
            Does the corporation have an applicable financial statement 
            (as defined in section 965(c)(1)) that shows a specific
       
          </span>
        </div>      
     </div>
  
<!-- End line D -->


<!-- Start line D1 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:145mm;height:4mm;">
          <span style="float:left">
           
            amount of earnings permanently reinvested outside the United States?
         
          </span>
         <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div> 
        
        <input type="checkbox" class="styCkbox" name="Checkbox" > 
                    <xsl:call-template name="PopulateYesCheckbox">
                      <xsl:with-param name="TargetNode" select="$FormData/FinancialStatementSect965c1" />
                      <xsl:with-param name="BackupName">IRS8895FinancialStatementSect965c1</xsl:with-param>
                      </xsl:call-template>
        </input>
        <label>
                     <xsl:call-template name="PopulateLabelYes">
                     <xsl:with-param name="TargetNode" select="$FormData/FinancialStatementSect965c1" />
                     <xsl:with-param name="BackupName">IRS8895FinancialStatementSect965c1</xsl:with-param>
                     </xsl:call-template> 
                     <span style="font-weight:bold;">Yes<span style="padding-left:5mm"></span></span>
      </label> 

         <input type="checkbox" class="styCkbox" name="Checkbox"> 
                    <xsl:call-template name="PopulateNoCheckbox">
                    <xsl:with-param name="TargetNode" select="$FormData/FinancialStatementSect965c1" />
                    <xsl:with-param name="BackupName">IRS8895FinancialStatementSect965c1</xsl:with-param>
                    </xsl:call-template>
        </input>
        <label>
                   <xsl:call-template name="PopulateLabelNo">
                   <xsl:with-param name="TargetNode" select="$FormData/FinancialStatementSect965c1" />
                   <xsl:with-param name="BackupName">IRS8895FinancialStatementSect965c1</xsl:with-param>
                   </xsl:call-template> 
                   <span style="font-weight:bold;">No</span>
       </label>
    </div>  
       

<!-- End line D1 -->


<!-- Start line D2-->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;padding-left:20px">
          <span style="float:left">
           
              If “Yes,” enter that amount on line 2 below. However, if the corporation
               is a member of a controlled group
          
          </span>
        </div>      
     </div>
  
<!-- End line D2 --> 

<!-- Start line D3-->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
              of corporations, see instructions.
        
          </span>
        </div>      
     </div>
  
<!-- End line D3 --> 

<!-- Start line D4-->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left;padding-left:20px">
           
          If “No,” complete item E below.
         
          </span>
        </div>      
     </div>

<!-- Start line E -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          E
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            
           If item D is “No,” does the corporation have an applicable financial 
           statement that shows a specific amount of
         
          </span>
        </div>      
     </div>
  
<!-- End line E -->


<!-- Start line E1 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:145mm;height:4mm;">
          <span style="float:left">
         
               tax liability attributable to earnings permanently reinvested outside the United States?
         
          </span>
         <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
               
        <input type="checkbox" class="styCkbox" name="Checkbox" > 
                    <xsl:call-template name="PopulateYesCheckbox">
                    <xsl:with-param name="TargetNode" select="$FormData/FinclStmtSpcfcAmountTaxLiab"/>
                    <xsl:with-param name="BackupName">IRS8895FinclStmtSpcfcAmountTaxLiab</xsl:with-param>
                    </xsl:call-template>
        </input>
        <label>
                   <xsl:call-template name="PopulateLabelYes">
                   <xsl:with-param name="TargetNode" select="$FormData/FinclStmtSpcfcAmountTaxLiab" />
                   <xsl:with-param name="BackupName">IRS8895FinclStmtSpcfcAmountTaxLiab</xsl:with-param>
                  </xsl:call-template> 
                  <span style="font-weight:bold;">Yes<span style="padding-left:5mm"></span></span>
       </label> 

         <input type="checkbox" class="styCkbox" name="Checkbox"> 
                   <xsl:call-template name="PopulateNoCheckbox">
                   <xsl:with-param name="TargetNode" select="$FormData/FinclStmtSpcfcAmountTaxLiab" />
                   <xsl:with-param name="BackupName">IRS8895FinclStmtSpcfcAmountTaxLiab</xsl:with-param>

                    </xsl:call-template>
        </input>
        <label>
                   <xsl:call-template name="PopulateLabelNo">
                   <xsl:with-param name="TargetNode" select="$FormData/FinclStmtSpcfcAmountTaxLiab" />
                   <xsl:with-param name="BackupName">IRS8895FinclStmtSpcfcAmountTaxLiab</xsl:with-param>

                   </xsl:call-template> 
                     <span style="font-weight:bold;">No</span>
       </label> 
     </div>  

<!-- End line E1 -->


<!-- Start line E2-->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;padding-left:20px">
          <span style="float:left">
          
              If “Yes,” divide the tax liability by 0.35 and enter the result on line 2 below.
               However, if the corporation is
         
          </span>
        </div>      
     </div>
  
<!-- End line E2 --> 

<!-- Start line E3-->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
         
             a member of a controlled group of corporations, see instructions.
         
          </span>
        </div>      
     </div>
  
<!-- End line E3 --> 

<!-- Start line E4-->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left;padding-left:20px">
          
         If “No,” enter -0- on line 2 below.
       
          </span>
        </div>      
     </div>
  
<!-- End line E4 --> 


<!-- Start line F -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          F
        </div>
        <div class="styLNDesc" style="width:150mm;height:4mm;">
          <span style="float:left">
       
           Is the corporation required to adjust the amount of its base
            period inclusions, APB 23 limitation, or related
        
          </span>
        </div>      
     </div>
  
<!-- End line F -->


<!-- Start line F1 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
        </div>
        <div class="styLNDesc" style="width:145mm;height:4mm;">
          <span style="float:left">
           
              party indebtedness pursuant to Notice 2005-38?
        
          </span>
         <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
    
          </span>
        </div>
        
               
        <input type="checkbox" class="styCkbox" name="Checkbox" > 
                    <xsl:call-template name="PopulateYesCheckbox">
                    <xsl:with-param name="TargetNode" select="$FormData/RequiredAdjustment" />
                    <xsl:with-param name="BackupName">IRS8895RequiredAdjustment</xsl:with-param>
                    </xsl:call-template>
        </input>
        <label>
                   <xsl:call-template name="PopulateLabelYes">
                     <xsl:with-param name="TargetNode" select="$FormData/RequiredAdjustment" />
                    <xsl:with-param name="BackupName">IRS8895RequiredAdjustment</xsl:with-param>
                   </xsl:call-template> 
                     <span style="font-weight:bold;">Yes<span style="padding-left:5mm"></span></span>
       </label> 
     
         <input type="checkbox" class="styCkbox" name="Checkbox"> 
                    <xsl:call-template name="PopulateNoCheckbox">
                    <xsl:with-param name="TargetNode" select="$FormData/RequiredAdjustment" />
                    <xsl:with-param name="BackupName">IRS8895RequiredAdjustment</xsl:with-param>
                    </xsl:call-template>
        </input>
        <label>
                   <xsl:call-template name="PopulateLabelNo">
                   <xsl:with-param name="TargetNode" select="$FormData/RequiredAdjustment" />
                   <xsl:with-param name="BackupName">IRS8895RequiredAdjustment</xsl:with-param>
                   </xsl:call-template> 
                     <span style="font-weight:bold;"> No</span>
       </label>


    </div>  

<!-- End line F1 -->

<!-- End part I -->     

<!-- Start PartII -->
  
<div style="width:187mm;border-top-width:1px;" class="styBB">
  <div class="styPartName" style="width:15mm;">Part II</div>
  <div class="styPartDesc" style="padding-left:3mm;">
    Dividends Received Deduction
  </div>
</div>
  
<!-- End PartII -->

<!-- Start line 1 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          1
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
            Enter the “cash dividends” that the corporation received from all controlled foreign 
            corporations
       
          </span>

        </div>      
        <div class="styLNRightNumBox" style="border-bottom-width:0px;">
                 
        </div>          
        <div class="styLNAmountBox" style="height:4mm;border-bottom-width:0px;" >
          
        </div>                
    </div>

<!-- End line 1 --> 

<!-- Start line 1a -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
            (CFCs) during the tax year. See instructions
       
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          
            
         </span>
        </div>      
        <div class="styLNRightNumBox">
          1          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/GrossCashDivRcvdFromCFCs"/>
          </xsl:call-template>    
        </div>                
    </div>
  


<!-- End line 1a --> 
  



<!-- Start line 2 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          2
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
           Earnings permanently reinvested outside the United States (see items D and E above)
   
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             
          </span>
        </div>      
        <div class="styLNRightNumBox">
          2          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/EarnPrmnntReinvstOutsideUS"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 2 --> 

<!-- Start line 3 -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          3
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-weight:bold;float:left">
                                                          Section 965(b)(1) limit.
            <span style="font-weight:normal">
                                 Enter the greater of line 2 or $500,000,000. However, if the corporation
            </span>
            </div>      
        <div class="styLNRightNumBox" style="border-bottom-width:0px;">
                 
        </div>          
        <div class="styLNAmountBox" style="height:4mm;border-bottom-width:0px;" >
     </div>                
    </div>

<!-- End line 3 --> 
  

<!-- Start line 3a -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
        
            is a member of a controlled group of corporations, see instructions
        
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           
           
          </span>
        </div>      
        <div class="styLNRightNumBox">
          3          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/Section965b1Limit"/>
          </xsl:call-template>    
        </div>                
    </div>
  


<!-- End line 3a --> 


<!-- Start line 4 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          4
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
           Section 965(b)(2) base period amount. Enter amount from Part VI, line 51
         
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           </span>
        </div>      
        <div class="styLNRightNumBox">
          4          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/BasePeriodAmount"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 4 --> 
 
<!-- Start line 5 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          5
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-weight:bold;float:left;">
            Section 965(b)(2) limit.
            <span style="font-weight:normal">  Subtract line 4 from line 1. If zero or less, stop here (see instructions).
                
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                    <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                 </span>
             
        </div>      
        <div class="styLNRightNumBox">
          5          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/Section965b2Limit"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 5 --> 
 
<!-- Start line 6 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          6
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-weight:bold;float:left;">
            Section 965(b)(4) limit.
            <span style="font-weight:normal">
                   Amounts to be reinvested in the United States under a DRP
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                    <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   

                   <!-- div class="styDotLn">.</div -->
             </span>
             
        </div>      
        <div class="styLNRightNumBox">
          6          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/Section965b4LmtAmtRinvstUS"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 6 --> 
  
<!-- Start line 7 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          7
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
            Enter the smallest of lines 3, 5, and 6</span>
        
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            
            
          </span>
        </div>      
        <div class="styLNRightNumBox">
          7          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/MinimumSection965bLimit"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 7 --> 

<!-- Start line 8 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          8
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            
            Enter the amount of CFC indebtedness to any related person as of the</span>
          
     
        </div>      
        <div class="styLNRightNumBox" style="height:4mm;background-color:lightgrey;border-bottom-width:0px">
                    
        </div>          
        <div class="styLNAmountBox" style="height:4mm;background-color:lightgrey;border-bottom-width:0px" >
          
        </div>                
    </div>

<!-- End line 8 --> 

<!-- Start line 8a -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
 
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">close of the tax year (see instructions)</span>
           <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           
          </span>
          
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">8</div>      
        <div class="styLNAmountBox" style="padding-right:1mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/CFCIndebtednessCloseTaxYear"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;background-color:lightgrey"></div>          
    </div>
      
<!-- End line 8a -->

<!-- Start line 9 -->


    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
         9
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Enter the amount of CFC indebtedness to any related 
           person as of the</span>
           
          
        </div>
        <div class="styLNRightNumBox" style="height:5mm;border-bottom-width:0px"></div>      
        <div class="styLNAmountBox" style="padding-right:1mm;height:5mm;border-bottom-width:0px" >
         
        </div>
        <div class="styShadingCell" style="width:8mm;height:5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:5mm;background-color:lightgrey"></div>          
    </div>
      
<!-- End line 9 -->
 
<!-- Start line 9a -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
 
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">close of October 3, 2004 (see instructions)</span>
           <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            
         
          </span>
          
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">9</div>      
        <div class="styLNAmountBox" style="padding-right:1mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/CFCIndebtednessAsOfOctober3"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;background-color:lightgrey"></div>          
    </div>
      
<!-- End line 9a -->

<!-- Start line 10 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          10
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-weight:bold;float:left">
                Section 965(b)(3) limit.
                <span style="font-weight:normal">
                   Subtract line 9 from line 8. If zero or less, enter -0-
                 
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>

              </span>
        </div>      
        <div class="styLNRightNumBox">
          10          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/Section965b3Limit"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 10 --> 

<!-- Start line 11 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          11
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;float:left;font-weight:bold">
           
            Qualifying dividends.
            <span style="font-weight:normal">Subtract line 10 from line 7. If zero or less, stop here 
            (see instructions). If more
         
          </span>
        </div>      
        <div class="styLNRightNumBox" style="border-bottom-width:0px;">
      </div>          
        <div class="styLNAmountBox" style="height:4mm;border-bottom-width:0px;" >
     </div>                
    </div>

<!-- End line 11 --> 
  

<!-- Start line 11a -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            
            than zero, enter the result here and on Form 1120, Schedule C, line 12, column (a)
         
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
       
           </span>
        </div>      
        <div class="styLNRightNumBox">
          11          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifyingDividends"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 11a --> 

<!-- Start line 12 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          12
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Enter all section 965(a)(2) amounts included on line 11 (see instructions)</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">12</div>      
        <div class="styLNAmountBox" style="padding-right:1mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/AmountsIncludedInQlfyDiv"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;background-color:white"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>          
    </div>
      
<!-- End line 12 -->

<!-- Start line 13 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          13
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-weight:bold;float:left">
                      Deductible portion of qualifying dividends. 
                      <span style="font-weight:normal">Multiply line 11 by 85%. Enter here and on Form 1120, 
           
          </span>
        </div>      
        <div class="styLNRightNumBox" style="border-bottom-width:0px;">
      </div>          
        <div class="styLNAmountBox" style="height:4mm;border-bottom-width:0px;" >
     </div>                
    </div>

<!-- End line 13 --> 
  

<!-- Start line 13a -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
         
            Schedule C, line 12, column (c)
       
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          
            
           </span>
        </div>      
        <div class="styLNRightNumBox">
          13          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/DeductiblePortionOfQlfyDiv"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 13a --> 


<!-- Start line 14 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          14
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left; font-size:8.9px;">Expenses disallowed under section 965(d)(2) with respect to line 13 amount</span>
          <span style="width:1px;"></span>
          <span style="width:1px;"></span>
          <span style="width:16px;">.</span>
          <span style="width:16px;">.</span>
          <span style="width:16px;">.</span>
           
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">14</div>      
        <div class="styLNAmountBox" style="padding-right:1mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/ExpensesDisallowed"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;background-color:white"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>          
    </div>
      
<!-- End line 14 -->

<!-- Start line 15 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          15
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-weight:bold;float:left;">
             Nondeductible CFC dividends. 
            <span style="font-weight:normal">Subtract line 13 from line 11. See instructions
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                  <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                  <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                  <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                 <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>

             </span>
        </div>      
        <div class="styLNRightNumBox" style="border-bottom-width:0px">
          15          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;border-bottom-width:0px" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NondeductibleCFCDividends"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 15 --> 

 

<!-- END Part II Line Items -->

  <!-- Start Part III -->
  
<div style="width:187mm;border-top-width:1px" class="styBB">
  <div class="styPartName" style="width:15mm;">Part III</div>
  <div class="styPartDesc" style="padding-left:3mm;">
    Regular Tax Liability for Computing Credit Limitations and Alternative Minimum Tax
  </div>
</div>


<!-- Start line 16 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          16
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
           Enter the corporation’s taxable income (Form 1120, line 30)
   
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
     
          </span>
        </div>      
        <div class="styLNRightNumBox">
          16          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TaxableIncome"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 16 --> 

<!-- Start line 17 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          17
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-weight:bold;float:left;">
             Taxable income excluding nondeductible CFC dividends. 
            <span style="font-weight:normal">
                 Subtract line 15 from line 16 
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                  <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>

                 </span>
             
        </div>      
        <div class="styLNRightNumBox">
          17          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TaxableIncomeExcldNondedCFCDiv"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 17 --> 


  
<!-- Start line 18 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          18
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            
           Enter the corporation’s regular tax liability (Form 1120, Schedule J, line 3)
            
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         
          </span>
        </div>      
        <div class="styLNRightNumBox">
          18          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/RegularTaxLiability"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 18 --> 

  
<!-- Start line 19 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          19
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;float:left;font-weight:bold">
            
            Tax on nondeductible CFC dividends.
            <span style="font-weight:normal">Enter the smaller of line 18 or 35% of line 15
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
          </span>
        
          
        </div>      
        <div class="styLNRightNumBox">
          19          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TaxOnNondedCFCDividends"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 19 --> 

<!-- Start line 20 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          20
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;float:left;font-weight:bold;">
           Tax on line 17 amount.
           <span style="font-weight:normal"> Subtract line 19 from line 18
           </span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                    <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                  
        </div>      
        <div class="styLNRightNumBox">
          20          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TaxOnTxblIncmExcldNondedCFCDiv"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 20 --> 
  
<!-- Start line 21 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          21
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;float:left;font-weight:bold">
                     Foreign tax credit that reduces tax on line 19 
                     <span style="font-weight:normal">(see instructions)
                     <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                   <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>

                     </span>
          
        </div>      
        <div class="styLNRightNumBox">
          21          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/ForeignTaxCrRdcTaxNondedCFCDiv"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 21 --> 

  
<!-- Start line 22 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          22
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
      
             Subtract line 21 from line 19
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
           
          </span>
        </div>      
        <div class="styLNRightNumBox">
          22          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/SbtrctFrgnTaxFromTaxNondCFCDiv"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 22 --> 

  
<!-- Start line 23 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          23
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;float:left;font-weight:bold">
                        Foreign tax credit that reduces tax on line 20.
                        <span style="font-weight:normal">Subtract line 21 from line 39
                        
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                            <span style="font-weight:bold;letter-spacing:3.7mm;">.</span>
                    </span>
        </div>      
        <div class="styLNRightNumBox">
          23          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/ForeignTaxCreditThatReducesTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 23 --> 

<!-- Start line 24 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          24
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
              Subtract line 23 from line 20
         
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox">
          24          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/FrgnTaxCrMinusTaxableIncome"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 24 --> 
  
<!-- Start line 25 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          25
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
         
               Alternative minimum tax (see instructions)
           
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox" style="border-bottom-width:0px;" >
          25          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;border-bottom-width:0px;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/AlternativeMinimumTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 25 --> 
  
<!-- End Part III -->

 
      <div class="styFooter" style="width:187mm; font-size:7pt; border-top:2 solid black;
                                                      padding-top:1mm;">    
        <div style="float:left; font-size:8pt">
          <b>For Paperwork Reduction Act Notice,</b><span style="padding-left:1mm"> see instructions.</span>
        </div>    
        <div style="float:right">
          Cat. No. 37703U
          <span style="width:35mm"></span>
          Form <b style="font-size:9pt">8895</b><span style="padding-left:1mm">(8-2005)</span>
        </div>      
      </div>        
      
      <p style="page-break-before:always" />      

<!-- Page 2 Header -->

      <div class="styBB" style="width:187mm;">
        <div style="float:left;">Form 8895 (8-2005)</div>
        <div style="float:right;">Page <span style="font-size:9pt;font-weight:bold;">2</span></div>
      </div>



  <!-- Start Part IV -->
  
<div style="width:187mm;border-top-width:1px" class="styBB">
  <div class="styPartName" style="width:15mm;">Part IV</div>
  <div class="styPartDesc" style="padding-left:3mm;">
    Foreign Tax Credit—Additional Limitation for Separate Categories With Nondeductible CFC
    Dividends<span style="font-weight:normal"> (see instructions)</span>
  </div>
</div>

<!-- Start line 26 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          26
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Enter the name of the separate category</span>
         
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
             <span style="width:16px;"></span>.
          
          
         <img src="{$ImagePath}/8895_Bullet_Md.gif" alt="MediumBullet"/> 
        </div>
        <div class="styLNRightNumBox" style="height:4mm;border-left-width:0px;
                                                                        border-bottom-width:0px;"></div>      
        <div class="styLNAmountBox" style="padding-right:1mm;border-left-width:0px;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NameOfSeparateCategory"/>
          </xsl:call-template>
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;background-color:lightgrey"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;background-color:lightgrey"></div>          
    </div>
      
      

<!-- Start line 27 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          27
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
         
           Enter the amount of nondeductible CFC dividends in the separate category
     
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          27          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NondedCFCDividendsSepCat"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 27 --> 
  
<!-- Start line 28 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          28
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
       
           Subtract line 27 from the amount on Form 1118, Schedule B, Part II, line 6
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox">
          28          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/SchJOrTotIncmBfrAdjMinusCFCDiv"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 28 --> 

  
<!-- Start line 29 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          29
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
           Subtract line 27 from the amount on Form 1118, Schedule B, Part II, line 7c
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox">
          29          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TotTxblIncmMinusAdjMinusCFCDiv"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 29 --> 

  
<!-- Start line 30 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          30
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
            Divide line 28 by line 29</span>
     
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox">
          30          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/LimitationFraction"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 30 --> 

<!-- Start line 31 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          31
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
           Enter 35% of line 27
       
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox">
          31          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/PercentOfNondedCFCDivSepCat"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 31 --> 
  
<!-- Start line 32 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          32
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
           Subtract line 31 from the amount on Form 1118, Schedule B, Part II, line 9
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox">
          32          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NetTotalUSTaxCrAllowed"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 32 --> 

  
<!-- Start line 33 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          33
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
             Multiply line 30 by line 32
           
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           
          </span>
        </div>      
        <div class="styLNRightNumBox">
          33          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TotalUSTaxSeparateCat"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 33 --> 

  
<!-- Start line 34 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          34
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
            Enter foreign taxes paid or accrued with respect to line 27 amount</span>
          
          <span class="styBoldText" style="float:right;padding-right:1mm">          
             <span style="width:1px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
          
             
            </span>
        </div>      
        <div class="styLNRightNumBox">
          34          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/ForeignTaxesPaidOrAccrued"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 34 --> 

<!-- Start line 35 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          35
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            
              Add lines 33 and 34
         
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           
          </span>
        </div>      
        <div class="styLNRightNumBox">
          35          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TotalTaxSeparateCat"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 35 --> 
  
<!-- Start line 36 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          36
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            
              Enter the credit computed for the separate category on Form 1118, Schedule B, Part III
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          36          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/CreditComputedSeparateCategory"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 36 --> 
 
  
<!-- Start line 37 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          37
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
             Enter the smaller of line 35 or line 36
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           </span>
        </div>      
        <div class="styLNRightNumBox">
          37          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/MinTotTaxSepCatOrCrCmptSepCat"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 37 --> 

  
<!-- Start line 38 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          38
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
           Enter the smaller of line 31 or line 34</span>
        
          <span class="styBoldText" style="float:right;padding-right:1mm">          
             <span style="width:1px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          38          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/MinPctSepCatOrFrgnTaxes"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 38 --> 

<!-- Start line 39 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          39
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
              Enter the corporation’s revised foreign tax credit for all separate categories (see     
                instructions)
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          39          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/RevisedFrgnTaxCreditSepCat"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 39 --> 
  
<!-- End Part IV -->


<!-- Start Part V -->
  
<div style="width:187mm;border-top-width:1px" class="styBB">
  <div class="styPartName" style="width:15mm;">Part V</div>
  <div class="styPartDesc" style="padding-left:3mm;">
    Schedule of Dividends <span style="font-weight:normal"> (see instructions)</span>
  </div>
</div>

<!-- BEGIN Schedule Title -->
  
 <div class="styTableContainer" style="height:31.5mm;" id="OFCctn">
    <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
    <!-- end -->      
    <table class="styTable" cellspacing="0" style="font-size:7pt;border-color:black;">
      <thead class="styTableThead">
        <tr>
<!--  Start Column a -->
        
          <th class="styTableCellHeader" scope="col" rowspan="2"
                style="width:60mm;font-weight:normal;padding-top:4px;">
                <span style="font-weight:bold;">(a)<br/>
                </span> Name of CFC</th>
                
<!-- End Column a -->
                
<!--  Start Column b -->
                     
          <th class="styTableCellHeader" scope="col" rowspan="2"
                style="width:25mm;font-weight:normal;"><span style="font-weight:bold;">(b)</span><br/>
                <span style="font-weight:normal;">Date Paid</span></th>

<!--  End Column b -->     

<!--  Start Column c -->
        
          <th class="styTableCellHeader" scope="col" colspan="2" style="width:69mm;font-weight:bold;">(c)<br/>
           <span style="font-weight:normal;">"Cash dividends”<br/>from CFCs</span></th>
           
<!--  End Column c -->

<!--  Start Column d -->
              
          <th class="styTableCellHeader" scope="col" rowspan="2"
                 style="width:21mm;font-weight:normal;border-right-width:1px;">
                 <span style="font-weight:bold;">(d)<br/></span> Check box if a section 965(a) (2)amount</th>
                 
<!--  End Column d -->
                 
<!--  Start Column e -->
                 
         <th class="styTableCellHeader" scope="col" rowspan="2" 
         style="width:32mm;font-weight:normal;border-right-width:0px">
         <span style="font-weight:bold;">(e)<br/>
         </span>Column (c)(2) line amounts the corporation specifically identifies as qualifying
          dividends (see instructions)</th>

<!--  End Column e -->

        </tr>
        <tr>
<!--  Start Column c-1 -->

          <th class="styTableCellHeader" scope="col" style="width:37mm;font-weight:normal;">
          <span class="styBoldText">(1)<br/></span>
          
          <span style="font-weight:normal">Functional</span><br/>
         
          <span style="font-weight:normal">Currency</span> </th>
          
<!--  End Column c-1 -->

<!--  Start Column c-2 -->
          
        <th class="styTableCellHeader" scope="col" style="width:32mm;font-weight:normal;">
          <span class="styBoldText">(2)<br/></span>
          <span style="font-weight:normal">U.S.</span><br/>
          <span style="font-weight:normal">Dollars</span> </th>

<!--  End Column c-2 -->
 
        </tr>
      </thead>

<!-- End Schedule Title -->

      <tfoot></tfoot>

<tbody>
 <xsl:if test="(count($FormData/Dividend)&lt; 16  or ($Print != $Separated))">  
<xsl:for-each  select="$FormData/Dividend">
              <tr>
               <td class="styTableCell" style="width:60mm;text-align:left;">
               <xsl:choose>
               <xsl:when test="position()=1">
                 <span class="styBoldText">40</span>
                 </xsl:when>  
                 <xsl:otherwise>
                 <span style="width:4mm"></span>
                 </xsl:otherwise>
                 </xsl:choose>
                 
               
                 <span style="padding-left:2mm;font-family:verdana;font-size:6pt;"></span>
                  <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfCFC/BusinessNameLine1"/>
                 </xsl:call-template>    
                  <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfCFC/BusinessNameLine2"/>
                 </xsl:call-template>    
              
               <span class="styTableCellPad"></span></td>
               
<!-- Date Paid (b) -->
               
               <td class="styTableCellCtr" style="width:25mm;">
                  <xsl:call-template name="PopulateMonthDayYear">
                  <xsl:with-param name="TargetNode" select="DatePaid"/>
                 </xsl:call-template>        

               <span style="width:1px;"></span></td>
               
 <!-- Functional Currancy c-1 -->
               
               <td class="styTableCell" style="width:37mm"><span class="styTableCellPad"></span>
               
             <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="FunctionalCurrencyFromCFC"/>
             </xsl:call-template>    
         </td>
         
<!-- US Doller c-2 -->
         
               <td class="styTableCell"><span class="styTableCellPad"></span>
                  <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="USDollarsFromCFC"/>
                  </xsl:call-template> 
              </td>
               
 <!-- check box d -->
          
             <td class="styTableCell" style="width:21mm;text-align:center">
             <input type="checkbox" class="styCkbox" name="Checkbox" > 
                    <xsl:call-template name="PopulateYesCheckbox">
                    <xsl:with-param name="TargetNode" select="Section965a2Amount" />
                    <xsl:with-param name="BackupName">IRS8895Section965a2Amount</xsl:with-param>
                    </xsl:call-template>
        </input>

      
      <label>
                <xsl:call-template name="PopulateLabelYes">
                <xsl:with-param name="TargetNode" select="Section965a2Amount" />
                <xsl:with-param name="BackupName">IRS8895Section965a2Amount</xsl:with-param>
               </xsl:call-template>
     </label>

         </td>
               <td class="styTableCell" style="width:32mm;border-right:0;"><span style="width:1px;"></span>
                <xsl:call-template name="PopulateAmount">
               <xsl:with-param name="TargetNode" select="SpecificQualifyingDividends"/>
               </xsl:call-template>    
               </td>
             </tr>
 </xsl:for-each>
 </xsl:if>       
    
   <xsl:if test="(count($FormData/Dividend)&lt; 16  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
       <tr>
               <td class="styTableCell" style="width:60mm;text-align:left">
                      <xsl:if test="((count($FormData/Dividend) &gt;=16) and ($Print = $Separated))">
                        <xsl:call-template name="PopulateAdditionalDataTableMessage">
                          <xsl:with-param name="TargetNode" select="$FormData/Dividend"/>
                        </xsl:call-template>
                      </xsl:if>
               		<span class="styTableCellPad"></span>
               	</td>
               <td class="styTableCellCtr" style="width:31mm;"><span style="width:1px;"></span></td>
               <td class="styTableCell" style="width:22mm"><span class="styTableCellPad"></span></td>
               <td class="styTableCell" style="width:21mm"><span class="styTableCellPad"></span></td>
               <td class="styTableCell" style="width:21mm;text-align:center"><input type="checkbox" id="noBox"/><label for="noBox"></label></td>
               <td class="styTableCell" style="width:32mm;border-right:0;"><span style="width:1px;"></span></td>
            </tr>

        </xsl:if>
       
   <xsl:if test="(count($FormData/Dividend)&lt; 15  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 14  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 13  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
    <xsl:if test="(count($FormData/Dividend)&lt; 12  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 11  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 10  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 9  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 8  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 7  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 6  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 5  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 4  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))"> 
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 3  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 2  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>
   <xsl:if test="(count($FormData/Dividend)&lt; 1  or ($Print!= $Separated)) or
                       (count($FormData/Dividend)&gt;= 16  and ($Print= $Separated))">  
            <xsl:call-template name="part5EmptyRow"/>
        </xsl:if>

       
      </tbody>
    </table>
  </div>
  
  <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">
        Total
        </div>
        <div class="styLNDesc" style="width:100.2mm;height:4mm;">
        
           <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.

           <img src="{$ImagePath}/8895_Bullet_Md.gif" alt="MediumBullet"/> 
          </span>
         
      </div>
      <div class="styLNAmountBoxNBB" style="width:30mm;height:4.5mm;">
      <xsl:if test="(count($FormData/Dividend)&lt; 16  or ($Print != $Separated))">  
      <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/TotalCashDividendsUSDollars"/>
                         </xsl:call-template> 
   </xsl:if>                          
</div>
      
      <div class="styLNAmountBoxNBB" style="width:18.9mm;height:4.5mm;
      background-color:lightgrey;border-rigth-width:1px"></div>         
      
      <div class="styLNAmountBoxNBB" style="width:29mm;height:4.5mm;
     ;border-rigth-width:0px;border-left-width:1px;"> 
     <xsl:if test="(count($FormData/Dividend)&lt; 16  or ($Print != $Separated))">  

      <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/TotalSpecificQualifyingDiv"/>
                         </xsl:call-template> 
              </xsl:if>        
         </div>
      </div>

 
  <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$FormData/Officer"/>
    <xsl:with-param name="containerHeight" select="5"/>
   <xsl:with-param name="headerHeight" select="2"/>
    <xsl:with-param name="containerID" select=" 'OFCctn' "/>
    <xsl:with-param name="imageID" select=" 'OFCimg' "/>
    <xsl:with-param name="buttonID" select=" 'OFCbtn' "/>
  </xsl:call-template>
  <!-- END Schedule  Table -->


  <!-- Start Part VI -->
  
<div style="width:187mm;border-top-width:1px" class="styBB">
  <div class="styPartName" style="width:15mm;">Part VI</div>
  <div class="styPartDesc" style="padding-left:3mm;">
   Section 965(b)(2) Base Period Amount <span style="font-weight:normal"> (see instructions)</span><br/>
   <span style="font-weight:normal">See instructions if the corporation has fewer than 5 tax years in its base period.</span>
  </div>
</div>

<!-- Start Header Line 41 -->

    <div class="styBB" style="width:187mm;">
 
<!-- Start Column 1 -->

  <div class="styNameBox" style="width:42.95mm;height:10mm;font-size:7pt;text-align:center;"><br/>
  Tax Years in Base Period
  </div>

<!-- End Column 1 --> 
      
<!-- Start Column a -->      
      <div class="styNameBox" style="width:36mm;height:10mm;font-size:7pt;text-align:center;
                         font-weight:bold">(a)<br/>
              <span style="font-weight:normal">Section 965(b)(2)(B)(i) dividends</span>
     </div>

<!-- End Column a -->

<!-- Start Column b -->

      <div class="styNameBox" style="width:36mm;height:10mm;font-size:7pt;text-align:center;
                         font-weight:bold">(b)<br/>
              <span style="font-weight:normal">Section 965(b)(2)(B)(ii) inclusions</span>
        
        
      </div>

<!-- End Column b -->      

 <!-- Start Column c -->

      <div class="styNameBox" style="width:36mm;height:10mm;font-size:7pt;text-align:center;
                         font-weight:bold">(c)<br/>
              <span style="font-weight:normal">Section 965(b)(2)(B)(iii) distributions</span>
      </div>

<!-- End Column c -->      

 <!-- Start Column d -->

      <div class="styNameBox" style="width:36mm;height:10mm;font-size:7pt;text-align:center;
                         font-weight:bold;border-right-width:0px">(d)<br/>
              <span style="font-weight:bold">Total.</span>
              <span style="font-weight:normal"> Add columns (a) through (c)</span>
      </div>

<!-- End Column d -->   

   </div>

<!-- End Header Line 41 -->


<!-- Start Line 41 -->

    <div class="styBB" style="width:187mm;">
 
<!-- Start Column 1 -->
        <div class="styLNLeftNumBox" style="height:4mm;">
          41
        </div>

  <div class="styNameBox" style="width:35mm;height:10mm;font-size:6pt;">
      Most recent tax year<br/>
     ending on or before<br/>
     June 30, 2003
  </div>

<!-- End Column 1 --> 
      
<!-- Start Column a -->      
      <div class="styLNAmountBox" style="width:36mm;height:10mm;font-size:7pt;
                          border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;padding-top:6mm">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod1Dividends"/>
                         </xsl:call-template>    
     </div>

<!-- End Column a -->

<!-- Start Column b -->

<div class="styLNAmountBox" style="width:36mm;height:10mm;font-size:7pt;
                          border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;padding-top:6mm">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod1Inclusions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column b -->      

 <!-- Start Column c -->

<div class="styLNAmountBox" style="width:36mm;height:10mm;font-size:7pt;
                          border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;padding-top:6mm">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PrevTaxPeriod1Distributions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column c -->      

 <!-- Start Column d -->

   <div class="styLNAmountBox" style="width:36mm;height:10mm;font-size:7pt;
                          border-bottom-width:0px;border-right-width:0px;border-left-width:0px;
                          padding-right:1mm;padding-top:6mm">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod1Total"/>
                         </xsl:call-template>    
     </div>

<!-- End Column d -->   


   </div>

<!-- End Line 41 -->


<!-- Start Line 42 -->

    <div class="styBB" style="width:187mm;">
 
<!-- Start Column 1 -->
        <div class="styLNLeftNumBox" style="height:6mm;">
          42
        </div>

  <div class="styNameBox" style="width:35mm;height:6mm;font-size:6.3pt;padding-top:1mm">
      Tax year prior to line 41 year
  </div>

<!-- End Column 1 --> 
      
<!-- Start Column a -->      
      <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod2Dividends"/>
                         </xsl:call-template>    
     </div>

<!-- End Column a -->

<!-- Start Column b -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod2Inclusions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column b -->      

 <!-- Start Column c -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PrevTaxPeriod2Distributions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column c -->      

 <!-- Start Column d -->

   <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:0px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod2Total"/>
                         </xsl:call-template>    
     </div>


<!-- End Column d -->   


   </div>

<!-- End Line 42 -->


<!-- Start Line 43 -->

    <div class="styBB" style="width:187mm;">
 
<!-- Start Column 1 -->
        <div class="styLNLeftNumBox" style="height:6mm;">
          43
        </div>

  <div class="styNameBox" style="width:35mm;height:6mm;font-size:6.3pt;padding-top:1mm">
      Tax year prior to line 42 year
  </div>

<!-- End Column 1 --> 
      
<!-- Start Column a -->      
      <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;border-top-width:0px">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod3Dividends"/>
                         </xsl:call-template>    
     </div>

<!-- End Column a -->

<!-- Start Column b -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod3Inclusions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column b -->      

 <!-- Start Column c -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PrevTaxPeriod3Distributions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column c -->      

 <!-- Start Column d -->

   <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:0px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod3Total"/>
                         </xsl:call-template>    
     </div>

<!-- End Column d -->   

   </div>

<!-- End Line 43 -->

<!-- Start Line 44 -->

    <div class="styBB" style="width:187mm;">
 
<!-- Start Column 1 -->
        <div class="styLNLeftNumBox" style="height:6mm;">
          44
        </div>

  <div class="styNameBox" style="width:35mm;height:6mm;font-size:6.3pt;padding-top:1mm">
      Tax year prior to line 43 year
  </div>

<!-- End Column 1 --> 
      
<!-- Start Column a -->      
      <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;border-top-width:0px">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod4Dividends"/>
                         </xsl:call-template>    
     </div>

<!-- End Column a -->

<!-- Start Column b -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod4Inclusions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column b -->      

 <!-- Start Column c -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PrevTaxPeriod4Distributions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column c -->      

 <!-- Start Column d -->

   <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:0px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod4Total"/>
                         </xsl:call-template>    
     </div>


<!-- End Column d -->   


   </div>

<!-- End Line 44 -->

<!-- Start Line 45 -->

    <div class="styBB" style="width:187mm;">
 
<!-- Start Column 1 -->
        <div class="styLNLeftNumBox" style="height:6mm;">
          45
        </div>

  <div class="styNameBox" style="width:35mm;height:6mm;font-size:6.3pt;padding-top:1mm">
      Tax year prior to line 44 year
  </div>

<!-- End Column 1 --> 
      
<!-- Start Column a -->      
      <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;border-top-width:0px">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod5Dividends"/>
                         </xsl:call-template>    
     </div>

<!-- End Column a -->

<!-- Start Column b -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod5Inclusions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column b -->      

 <!-- Start Column c -->

<div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:1px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PrevTaxPeriod5Distributions"/>
                         </xsl:call-template>    
     </div>


<!-- End Column c -->      

 <!-- Start Column d -->

   <div class="styLNAmountBox" style="width:36mm;height:6mm;font-size:7pt;padding-top:1mm
                          ;border-bottom-width:0px;border-right-width:0px;border-left-width:0px;
                          padding-right:1mm;">
                          <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/PreviousTaxPeriod5Total"/>
                         </xsl:call-template>    
     </div>


<!-- End Column d -->   


   </div>

<!-- End Line 45 -->




<!-- Start line 46 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          46
        </div>
        <div class="styLNDesc" style="width:135mm;height:4mm;">
          <span style="float:left">
            
           Add lines 41 through 45, column (d)
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox" style="width:7.6mm">
          46          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;width:36.2mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/TotalPrevTaxPeriodTotal"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 46 --> 
  
<!-- Start line 47 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          47
        </div>
        <div class="styLNDesc" style="width:135mm;height:4mm;">
          <span style="float:left">
           
           Enter the largest of lines 41 through 45, column (d)
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox" style="width:7.6mm">
          47          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;width:36mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/MaximumPreviousTaxPeriodTotal"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 47 --> 

  
<!-- Start line 48 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          48
        </div>
        <div class="styLNDesc" style="width:135mm;height:4mm;">
          <span style="float:left">
        
           Enter the smallest of lines 41 through 45, column (d)
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox" style="width:7.6mm">
          48          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;width:36mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/MinimumPreviousTaxPeriodTotal"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 48 --> 

  
<!-- Start line 49 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          49
        </div>
        <div class="styLNDesc" style="width:135mm;height:4mm;">
          <span style="float:left">
      
            Add lines 47 and 48</span>
   
          <span class="styBoldText" style="float:right;padding-right:1mm">          
          <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            </span>
        </div>      
        <div class="styLNRightNumBox" style="width:7.6mm">
          49          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;width:36mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/SumMaxMinPrevTaxPeriodTotal"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 49 --> 

<!-- Start line 50 -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          50
        </div>
        <div class="styLNDesc" style="width:135mm;height:4mm;">
          <span style="float:left">
         
           Subtract line 49 from line 46
     
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox" style="width:7.6mm">
          50          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;width:36mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/NetPreviousTaxPeriodTotal"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 50 --> 
  

<!-- Start line 51A -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          51
        </div>
        <div class="styLNDesc" style="width:135mm;height:4mm;">
          <span style="float:left">
            
             Divide line 50 by 3. (See instructions if the corporation has fewer than 5 tax years in its base   
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
          
            </span>
        </div>      
        <div class="styLNRightNumBox"  style="border-bottom-width:0px;width:7.6mm">
        </div>          
        <div class="styLNAmountBox" style="height:4mm;width:36mm;border-bottom-width:0px" >
          
        </div>                
    </div>

<!-- End line 51A --> 


<!-- Start line 51B -->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
         
        </div>
        <div class="styLNDesc" style="width:135mm;height:4mm;">
          <span style="float:left">
          
          period.) Enter the result here and on page 1, line 4
   
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
        </span>
        </div>      
        <div class="styLNRightNumBox"  style="border-bottom-width:0px;width:7.6mm">
         51        
        </div>          
        <div class="styLNAmountBox" style="height:4mm;width:36mm;border-bottom-width:0px" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/BasePeriodAmount"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 51B --> 


  
      <div class="styFooter" style="width:187mm; font-size:7pt; border-top:2 solid black;
                                                      padding-top:1mm;">    
          
        <div style="float:right">
         
          <span style="width:35mm"></span>
          Form <b style="font-size:8pt">8895</b><span style="padding-left:1mm">(8-2005)</span>

        </div>      
      </div>        
      
      <p style="page-break-before:always" />      
<!-- Additional Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>

    
         <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$FormData" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template> 
     </table>     

   
      
<!--  *******************************************************************************************************  -->     
 <xsl:if test="($Print = $Separated) and  (count($FormData/Dividend) &gt;= 16)">
 <span class="styRepeatingDataTitle">Form 8895, Part V, Schedule of Dividends (see instructions)</span>

<!-- BEGIN Schedule Title -->
  
 <div class="styTableContainer" style="height:31.5mm;" id="OFCctn">
    <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
    <!-- end -->      
    <table class="styTable" cellspacing="0" style="font-size:7pt;border-color:black;">
      <thead class="styTableThead">
        <tr  class="styDepTblHdr">
<!--  Start Column a -->
        
          <th class="styTableCellHeader" scope="col" rowspan="2"
                style="width:35mm;font-weight:normal;padding-top:4px;border-top-width:1px">
                <span style="font-weight:bold;">(a)<br/>
                </span> Name of CFC</th>
                
<!-- End Column a -->
                
<!--  Start Column b -->
                     
          <th class="styTableCellHeader" scope="col" rowspan="2"
                style="width:20mm;font-weight:normal;border-top-width:1px"><span style="font-weight:bold;padding-left:7mm">(b)</span><br/>
                <span style="font-weight:bold;padding-left:7mm">Date Paid</span></th>

<!--  End Column b -->     

<!--  Start Column c -->
        
          <th class="styTableCellHeader" scope="col" colspan="2" style="width:60mm;font-weight:bold;
          border-top-width:1px">(c)<br/>
           <span style="font-weight:norma;">"Cash dividends”</span></th>
           
<!--  End Column c -->

<!--  Start Column d -->
              
          <th class="styTableCellHeader" scope="col" rowspan="2"
                 style="width:20mm;font-weight:normal;border-right-width:1px;border-top-width:1px">
                 <span style="font-weight:bold;">(d)<br/></span> Check box if a section 965(a)(2)amount</th>
                 
<!--  End Column d -->
                 
<!--  Start Column e -->
                 
         <th class="styTableCellHeader" scope="col" rowspan="2" 
         style="width:32mm;font-weight:normal;border-right-width:0px;border-top-width:1px">
         <span style="font-weight:bold;">(e)<br/>
         </span>Column (c)(2) line amounts the corporation specifically identifies as qualifying
          dividends (see instructions)</th>

<!--  End Column e -->

        </tr>
        <tr  class="styDepTblHdr">
<!--  Start Column c-1 -->

          <th class="styTableCellHeader" scope="col" style="width:30mm;font-weight:normal;">
          <span class="styBoldText">(1)<br/></span>
          
          <span style="font-weight:normal">Functional</span><br/>
         
          <span style="font-weight:normal">Currency</span> </th>
          <th class="styTableCellHeader" scope="col" style="width:30mm;font-weight:normal;">
          
<!--  End Column c-1 -->

<!--  Start Column c-2 -->
          
          <span class="styBoldText">(2)<br/></span>
          <span style="font-weight:normal">U.S.</span><br/>
          <span style="font-weight:normal">Dollars</span> </th>

<!--  End Column c-2 -->

          
        </tr>
      </thead>
      

<!-- End Schedule Title -->

      
      <tfoot></tfoot>

<tbody>

<xsl:for-each  select="$FormData/Dividend">
              <tr>
                 <!-- Define background colors to the rows -->
                    <xsl:attribute name="class">
                      <xsl:choose>
                        <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                        <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                      </xsl:choose>
                    </xsl:attribute>

              
               <td class="styTableCell" style="width:60mm;text-align:left;">
               <xsl:choose>
               <xsl:when test="position()=1">
                 <span class="styBoldText">40</span>
                 </xsl:when>  
                 <xsl:otherwise>
                 <span style="width:4mm"></span>
                 </xsl:otherwise>
                 </xsl:choose>
                 
               
                 <span style="padding-left:2mm;font-family:verdana;font-size:6pt;"></span>
                  <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfCFC/BusinessNameLine1"/>
                 </xsl:call-template>    
                  <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfCFC/BusinessNameLine2"/>
                 </xsl:call-template>    
              
               <span class="styTableCellPad"></span></td>
               
<!-- Date Paid (b) -->
               
               <td class="styTableCellCtr" style="width:25mm;">
                  <xsl:call-template name="PopulateMonthDayYear">
                  <xsl:with-param name="TargetNode" select="DatePaid"/>
                 </xsl:call-template>        

               <span style="width:1px;"></span></td>
               
 <!-- Functional Currancy c-1 -->
               
               <td class="styTableCell"><span class="styTableCellPad"></span>
               
             <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="FunctionalCurrencyFromCFC"/>
             </xsl:call-template>    
         </td>
         
<!-- US Doller c-2 -->
         
               <td class="styTableCell"><span class="styTableCellPad"></span>
                  <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="USDollarsFromCFC"/>
                  </xsl:call-template> 
              </td>
               
 <!-- check box d -->
          
             <td class="styTableCell" style="width:21mm;text-align:center;">
             <input type="checkbox" class="styCkbox" name="Checkbox" > 
                    <xsl:call-template name="PopulateYesCheckbox">
                    <xsl:with-param name="TargetNode" select="Section965a2Amount" />
                    <xsl:with-param name="BackupName">IRS8895Section965a2Amount</xsl:with-param>
                    </xsl:call-template>
        </input>
        
        <label>
                     <xsl:call-template name="PopulateLabel">
                     <xsl:with-param name="TargetNode" select="$FormData/Section965a2Amount" />
                     <xsl:with-param name="BackupName">IRS8895Section965a2Amount</xsl:with-param>
                     </xsl:call-template> 
                     <span style="font-weight:bold;">Yes<span style="padding-left:5mm"></span></span>
      </label> 


             </td>
               <td class="styTableCell" style="width:32mm;border-right:0;"><span style="width:1px;"></span>
                <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="SpecificQualifyingDividends"/>
             </xsl:call-template>    
               </td>
             </tr>
 </xsl:for-each>
      
      </tbody>
    </table>
  </div>
  
  <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">
        Total
        </div>
        <div class="styLNDesc" style="width:100.2mm;height:4mm;">
        
           <span class="styBoldText" style="float:right;padding-right:1.5mm">          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
           <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.

           <img src="{$ImagePath}/8895_Bullet_Md.gif" alt="MediumBullet"/> 
          </span>
         
      </div>
      <div class="styLNAmountBoxNBB" style="width:30mm;height:4.5mm;">          
      <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/TotalCashDividendsUSDollars"/>
                         </xsl:call-template>    
</div>
      
      <div class="styLNAmountBoxNBB" style="width:18.9mm;height:4.5mm;
      background-color:lightgrey;border-rigth-width:1px"></div>         
      
      <div class="styLNAmountBoxNBB" style="width:29mm;height:4.5mm;
     ;border-rigth-width:0px;border-left-width:1px;"> 
      <xsl:call-template name="PopulateAmount">
                          <xsl:with-param name="TargetNode" 
                          select="$FormData/TotalSpecificQualifyingDiv"/>
                         </xsl:call-template>    
         </div>
      </div>

 
    
               </xsl:if>
<!--  *******************************************************************************************************  -->     

     
        <!-- END Left Over Table --> 
         
      </form>
    </body>
  </html>
</xsl:template>
<xsl:template name="part5EmptyRow">
            <tr>
               <td class="styTableCell" style="width:60mm;"><span class="styTableCellPad"></span></td>
               <td class="styTableCellCtr" style="width:25mm;"><span style="width:1px;"></span></td>
               <td class="styTableCell" style="width:37mm"><span class="styTableCellPad"></span></td>
               <td class="styTableCell" style="width:32mm"><span class="styTableCellPad"></span></td>
               <td class="styTableCell" style="width:21mm;text-align:center"><input type="checkbox" id="noBox"/><label for="noBox"></label></td>
               <td class="styTableCell" style="width:32mm;border-right:0;"><span style="width:1px;"></span></td>
            </tr>
</xsl:template>


</xsl:stylesheet>
