<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="IRS8903Style.xsl"/>
<xsl:include href="AddOnTable.xsl"/>

<xsl:output method="html" indent="yes" encoding="iso-8859-1"/>

<xsl:strip-space elements="*" />
<xsl:param name="FormData" select="$RtnDoc/IRS8903" />


<xsl:template match="/">
<html>
<head>  
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache"/>
  <meta http-equiv="Cache-Control" content="no-cache"/>
  <meta http-equiv="Expires" content="0"/>
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private"/>  
  <meta name="Author" content="Lisa Lane -Lisa.T.Lane@irs.gov" />
  <meta name="Description" content="Form IRS 8903"/>
  <meta name="GENERATOR" content="IBM WebSphere Studio"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/header.css"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/body.css"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/general.css"/>
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>  
  <style type="text/css">    
    <xsl:if test="not($Print) or $Print=''">  
      <xsl:call-template name="IRS8903Style"></xsl:call-template>
      <xsl:call-template name="AddOnStyle"></xsl:call-template>  
    </xsl:if>
  </style>      
  
</head>

<body class="styBodyClass">
  <form name="Form8903">    
    <xsl:call-template name="DocumentHeader"></xsl:call-template>  
    
  <!--Title of Form -->    
  <div class="styBB" style="width:187mm;height: 20mm;">
    <div class="styFNBox" style="width:31mm;font-size: 7pt;height: 22mm;">
      Form <span class="styFormNumber">8903</span>      
      <br/>
      <span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$FormData"/>
        </xsl:call-template>  
      </span>  
      <br/>
      <br/>
      <span class="styAgency">Department of the Treasury</span><br /><span class="styAgency">Internal Revenue Service</span>
    </div>
    <div class="styFTBox" style="height: 22mm;width:125mm;padding-top:4mm;">
      <div class="styMainTitle" style="height: 8mm">Domestic Production Activities Deduction</div>
      <div class="styFST" style="font-size:7pt;margin-left:3mm;font-weight:bold"><br/><br/>
        <img src="{$ImagePath}/8903_Bullet.gif" alt="MediumBullet"/>  
        Attach to your tax return. 
         <img src="{$ImagePath}/8903_Bullet.gif" alt="MediumBullet"/>  
        See separate instructions.
        <br/>
      </div>
    </div>
    <div class="styTYBox" style="width:30mm;height:22mm; border-left-width: 1px;">
      <div class="styOMB" style="height:2mm;">OMB No. 1545-1984</div>
      <div class="styTaxYear" style="height:10mm">20<span class="styTYColor">05</span></div>
      <div class="stySequence">Attachment<br/>Sequence No. <b>143</b></div>
    </div>
  </div>
  <!--  End title of Form  -->
    
  <!--  Name and Employer identification number  -->
  <div class="styBB" style="width:187mm">
    <div class="styNameBox" style="width:141mm;font-weight:normal;font-size:7pt;">
      Name(s) as shown on return<br/>
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>      
    </div>
    <div class="styEINBox" style=" padding-left:2mm;font-size:7pt;font-weight: normal;">Identifying number
      <br/><br/>
      <span style="font-weight:normal;">  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
      </span>    
    </div>
  </div>  
  <!--  End Name and Employer indentification number  -->
  
  <!--  Line 1 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBoxSD">1</div>
     <div style="float:left;padding-top:4mm;">
    		Domestic production gross receipts  
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
         	  ......................
         	</div>    
     	<div class="styLNRightNumBox" style="padding-top:4mm;">1</div>
     		<div class="styLNAmountBox" style="padding-top:4mm;">
     			 <xsl:call-template name="PopulateAmount">
         				<xsl:with-param name="TargetNode" select="$FormData/DomesticProdGrossReceipts"/>
     			 </xsl:call-template> 
     		</div>          
    	</div>
  </div>
  <!--  Line 1 -->
  
  <!--  Line 2 -->  
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBoxSD">2</div>
    	<div class="styIRS8903LNDesc">
    		Allocable cost of goods sold
    	</div>
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
         	  ...............
         	</div>    
     	<div class="styLNRightNumBox" style="padding-top:4mm;">2</div>
     	<div class="styLNAmountBox" style="padding-top:4mm;">
     	     <xsl:call-template name="PopulateAmount">
     		  <xsl:with-param name="TargetNode" select="$FormData/AllocatedCOGS"/>
         		</xsl:call-template>
     	</div> 
     	<div class="styShadingCellBox" ></div>
    		<div class="styShadingCell" style="height:8mm;background-color:white;"></div>
    	</div>
  </div>
  <!--  Line 2 -->
   
  <!--  Line 3 -->  
  <div style="width: 187mm">  
  	<div class="styIRS8903LNLeftNumBoxSD">3</div>
  	<div class="styIRS8903LNDesc">
     	Directly allocable deductions, expenses, or losses    
    	</div>    
    	<div style="float:right;"> 
    		<div class="styDotLn" style="padding-top:4mm;">  
            ........
          </div>     
      	<div class="styLNRightNumBox" style="padding-top:4mm;">3</div>
      	<div class="styLNAmountBox" style="padding-top:4mm;">
        		<xsl:call-template name="PopulateAmount">
          			<xsl:with-param name="TargetNode" select="$FormData/DirectDeductionsExpensesLosses"/>
        		</xsl:call-template>
     	</div>
     	<div class="styShadingCellBox"></div>
    		<div class="styShadingCell" style="height:8mm;background-color:white;"></div>
    </div>
  </div>
  <!--  Line 3 -->
  
  <!--  Line 4 -->  
  <div style="width: 187mm">  
  	<div class="styIRS8903LNLeftNumBoxSD">4</div>
     <div class="styIRS8903LNDesc">
	     Indirectly allocable deductions, expenses, or losses.    
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
            .......
          </div>      
      	<div class="styLNRightNumBox" style="padding-top:4mm;">4</div>
      	<div class="styLNAmountBox" style="padding-top:4mm;">
        		<xsl:call-template name="PopulateAmount">
          		<xsl:with-param name="TargetNode" select="$FormData/IndDeductionsExpensesLosses"/>
        		</xsl:call-template>
     	</div>
     	<div class="styShadingCellBox"></div>
    		<div class="styShadingCell" style="height:8mm;background-color:white;"></div>
    	</div>
  </div>
  <!--  Line 4 -->
    
   <!--  Line 5 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBoxSD">5</div>
     <div class="styIRS8903LNDesc">
      	Add lines 2 through 4   
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
         	  ...........................
         	</div>      
     	<div class="styLNRightNumBox" style="padding-top:4mm;">5</div>
     	<div class="styLNAmountBox" style="padding-top:4mm;">
     		<xsl:call-template name="PopulateAmount">
     			<xsl:with-param name="TargetNode" select="$FormData/TotalAllocatedCOGSDedExpLosses"/>
     		</xsl:call-template>
     	</div>          
    	</div>
  </div>
  <!--  Line 5 -->

  <!--  Line 6 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBoxSD">6</div>
     <div class="styIRS8903LNDesc">
     	Subtract line 5 from line 1   
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
         	  ..........................
         	</div>      
     	<div class="styLNRightNumBox" style="padding-top:4mm;">6</div>
     	<div class="styLNAmountBox" style="padding-top:4mm;">
     		<xsl:call-template name="PopulateAmount">
     			<xsl:with-param name="TargetNode" select="$FormData/NetDomesticProdGrossReceipts"/>
     		</xsl:call-template>
     	</div>          
    	</div>
  </div>
  <!--  Line 6 -->
  
  
   <!--  Line 7  -->
  <div style="width:187mm;">
    <div class="styIRS8903LNLeftNumBoxSD" style="height:7mm; padding-left: 2mm;padding-top:4mm;">7</div>
    <div class="styLNDesc" style="width:18mm; height:27mm;padding-top:4mm;">
      <div style = "width:17mm;">Qualified production activities income from pass-through entities:</div>
    </div>
    <div class="styLNDesc" style="width:1.75mm; height:27mm;"> </div>
    <div class="styLNDesc" style="width:118mm; height:27mm;padding-top:4mm;">
      <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Table for Work Opportunity Credit">
         <tr>
            <th class="styTableCell" scope="col" style="border-color: black; border-top-width: 1px; font-weight: normal; font-size: 6.5pt; width: 22mm; padding-left: 2mm; text-align: left;padding-top:1mm;">                
              If you are a—              
            </th>
            <th class="styTableCell" scope="col" style="border-color: black; font-weight: normal; border-right-width:0px; border-top-width:1px; font-size: 6.5pt; width: 88mm;padding-left: 2mm; text-align: left;padding-top:1mm;">
              Then enter the total qualified production activities income from—
            </th>
         </tr>
         <tr>
            <td scope="row" style="width: 22mm; font-size: 7pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt;vertical-align:top;padding-left: 2mm;">
            <div  style="width:21mm;padding-top:1mm;">
            	<span class="styBoldText">a</span> 
            	Shareholder      
            </div>
            <div style="width:21mm;padding-top:1mm;">
            	 <span class="styBoldText">b</span>
            	 Partner 
            </div>
            <div style="width:21mm;padding-top:6mm;">
             	<span class="styBoldText">c</span> 
             	Beneficiary
             </div> 
             </td>
             <td style="font-size:7pt;font-style: normal;font-weight:normal;border:none;width:88mm;vertical-align:top;padding-left:2mm;">
             	<div  style="width:87mm;padding-top:1mm;">
              		Schedule K-1 (Form 1120S), box 12, code Q
              		<span class="styDotLn" style="float: none; font-size: 7pt">.......</span>
               </div>
               <div  style="width:87mm;padding-top:1mm;">
	              Schedule K-1 (Form 1065), box 13, code U
               </div>
               <div  style="width:87mm;padding-top:1.5mm;">
               	Schedule K-1 (Form 1065-B), box 9, code S2
                	<span class="styDotLn" style="float: none; font-size: 7pt">.......</span>
          	</div>
          	<div  style="width:87mm;padding-top:1.5mm;">
	               Schedule K-1 (Form 1041), box 14, code C
	          <span class="styDotLn" style="float: none; font-size: 7pt">........</span>
               </div>
             </td>
          <td style="width:4mm">
            <div class="styLNDesc" style="width:4mm">
              <img style= "height:17mm" src="{$ImagePath}/8903_Bracket_Lg.gif" alt="Curly Bracket Image"/>                                    
            </div>            
          </td>
          <td class="styDotLn" style="font-size: 7pt; padding-bottom: 4mm;">
          
          </td>
         </tr>            
      </table>          
    </div>
    <div style="float:right">
    		<div class="styLNRightNumBox" style="height:14mm;padding-top:0mm;">
      		<div style="width:7.75mm;background-color:lightgrey;height:11mm;"></div>
          	7         
   		</div>        
    		<div class="styLNAmountBox" style="height:14mm;padding-top:11mm;">
      		<xsl:call-template name="PopulateAmount">
        			<xsl:with-param name="TargetNode" select="$FormData/QlfyPassThroughIncome"/>
      		</xsl:call-template>
    		</div>  
      	<div class="styLNRightNumBoxNBB" style="height: 12.5mm;background-color: lightgrey;"></div>
     	 <div class="styLNAmountBoxNBB" style="height: 12.5mm;"></div>          
  	</div>
  </div>      
<!--  Line 7  -->    

  <!--  Line 8 -->    
  <div style="width: 187mm;">
  	<div class="styIRS8903LNLeftNumBoxSD">8</div>
     <div class="styIRS8903LNDesc" style="width:139mm;">
       <span class="styBoldText">Qualified production activities income.</span>
        Add lines 6 and 7. If zero or less, enter -0- here,
	  skip lines 9 
    	</div>    
    	<div style="float:right;">
    		<div class="styShadingCellBox" style="height:8mm;"></div>
      	<div class="styLNAmountBoxNBB"  style="height:8mm;">
      	</div>        
    	</div>
  </div>
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox" style="padding-top:0mm;"></div>
     <div class="styIRS8903LNDesc" style="padding-top:0mm;">
       through 15, and enter -0- on line 16 
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn">  
            ......................
          </div> 
      	<div class="styLNRightNumBox">8</div>
      	<div class="styLNAmountBox">
        		<xsl:call-template name="PopulateAmount">
          		<xsl:with-param name="TargetNode" select="$FormData/QlfyIncomeOrIncomeLimitation"/>
        		</xsl:call-template>
      	</div>          
    	</div>
  </div>
  
  <!--  Line 8 -->
  
  <!--  Line 9 -->  
  <div style="width:187mm;">
  	<div class="styIRS8903LNLeftNumBoxSD">9</div>
     <div class="styIRS8903LNDesc" style="width:134mm;">
       	Income limitation (see instructions):          
          <li style="padding-top:1mm;">
          	Individuals, estates, and trusts. Enter your adjusted gross income figured without the domestic 
			<br/>
			<span style="width:4mm;"></span>production activities deduction
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold;">  
              ..................
            </span>
          </li>
          <li style="padding-top:1mm;">
          	All others. Enter your taxable income figured without the domestic production activities 
			<br/>
			<span style="width:4mm;"></span>deduction (tax-exempt organizations, see instructions)
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold;">  
              ...........
            </span>  
          </li>
        </div>
        
        <div class="styGenericDiv" style="width:5mm; height:13mm;padding-top:4mm;">    
          <img style="height:17mm" src="{$ImagePath}/8903_Bracket_Lg.gif" alt="Curly Bracket Image"/>                                 
        </div>
	   <div style="float:right">
       	 <div class="styLNRightNumBox" style="width:7.75mm;height:14mm;padding-top=0mm;">
          	<div style="width:7.75mm;border-left-width:0px;background-color:lightgrey;height:11mm;"></div>
          	9
        	</div>
        	<div class="styLNAmountBox" style="height:14mm;padding-top:11mm;">
         	 	<xsl:call-template name="PopulateAmount">
           	 <xsl:with-param name="TargetNode" select="$FormData/IncomeLimitation"/>
          	</xsl:call-template>
       	</div>
         	<div class="styLNRightNumBoxNBB" style="height: 8.25mm;background-color: lightgrey;"></div>
     		<div class="styLNAmountBoxNBB" style="height: 8.25mm;"></div>  
        </div>
      </div>
  <!-- End Line 9 -->
    
  <!--  Line 10 -->    
  <div style="width: 187mm;">
  	<div class="styIRS8903LNLeftNumBox">10</div>
     <div class="styIRS8903LNDesc" style="width:139mm;">
       Enter the smaller of line 8 or line 9. If zero or less, enter -0- here, skip lines 11 through 15, and enter 
    	</div>    
    	<div style="float:right;">
    		<div class="styShadingCellBox" style="height:8mm;"></div>
      	<div class="styLNAmountBoxNBB"  style="height:8mm;">
      	</div>        
    	</div>
  </div>
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox" style="padding-top:0mm;"></div>
     <div class="styIRS8903LNDesc" style="padding-top:0mm;">
       -0- on line 16  
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn">  
            ..............................
          </div> 
      	<div class="styLNRightNumBox">10</div>
      	<div class="styLNAmountBox">
        		<xsl:call-template name="PopulateAmount">
          		<xsl:with-param name="TargetNode" select="$FormData/QlfyIncomeOrIncomeLimitation"/>
        		</xsl:call-template>
      	</div>          
    	</div>
  </div>
  
  <!--  Line 10 -->
  
  <!--  Line 11 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox">11</div>
     <div class="styIRS8903LNDesc">
       Enter 3% of line 10   
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
         	  ............................
         	</div>    
     	<div class="styLNRightNumBox" style="padding-top:4mm;">11</div>
     	<div class="styLNAmountBox" style="padding-top:4mm;">
     		<xsl:call-template name="PopulateAmount">
     			<xsl:with-param name="TargetNode" select="$FormData/PercentOfIncome"/>
     		</xsl:call-template>
     	</div>          
    	</div>
  </div>
  <!--  Line 11 -->

  <!--  Line 12 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox">12</div>
     <div class="styIRS8903LNDesc">
       Form W-2 wages (see instructions)  
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
         	  .......................
         	</div> 
     	<div class="styLNRightNumBox" style="padding-top:4mm;">12</div>
     	<div class="styLNAmountBox" style="padding-top:4mm;">
     		<xsl:call-template name="PopulateAmount">
     			<xsl:with-param name="TargetNode" select="$FormData/W2Wages"/>
     		</xsl:call-template>
     	</div>          
    	</div>
  </div>
  <!--  Line 12 -->

  <!--  Line 13  -->
  <div style="width:187mm;">
    <div class="styIRS8903LNLeftNumBox" style="height:7mm; padding-top:4mm;">13</div>
    <div class="styLNDesc" style="width:18mm; height:22mm;padding-top:4mm;">
      <div style = "width:17mm;">Form W-2 wages from pass-through entities:</div>
    </div>
    <div class="styLNDesc" style="width:1.75mm; height:22mm;"> </div>
    <div class="styLNDesc" style="width:118mm; height:22mm;padding-top:4mm;">
      <table border="0" cellspacing="0" cellpadding="0" style="padding:0mm" summary="Table for Work Opportunity Credit">
         <tr>
            <th class="styTableCell" scope="col" style="border-color: black; border-top-width: 1px; font-weight: normal; font-size: 6.5pt; width: 22mm; padding-left: 2mm; text-align: left;padding-top:1mm;">                
              If you are a—              
            </th>
            <th class="styTableCell" scope="col" style="border-color: black; font-weight: normal; border-right-width:0px; border-top-width:1px; font-size: 6.5pt; width: 88mm;padding-left: 2mm; text-align: left;padding-top:1mm;">
              Then enter the total W-2 wages from—
            </th>
         </tr>
         <tr>
            <td scope="row" style="width: 22mm; font-size: 7pt;font-family:verdana;font-style: normal;font-weight:normal;border-right:solid black .75pt;vertical-align:top;padding-left:2mm;">
            <div style="width:21mm;padding-top:1mm;">
            	<span class="styBoldText">a</span> 
            	Shareholder      
            </div>
            <div style="width:21mm;padding-top:1mm;">             
            	<span class="styBoldText">b</span>
            	Partner 
            </div>
            <div style="width:21mm;padding-top:6mm;">
            <span class="styBoldText">c</span>
            Beneficiary
            </div> 
            </td>
            <td style="font-size:7pt;font-style: normal;font-weight:normal;border:none;padding-left: 2mm;vertical-align:top;">
            <div style="width:87mm;padding-top:1mm;">
              	Schedule K-1 (Form 1120S), box 12, code R
             	<span class="styDotLn" style="float: none; font-size: 7pt">.......</span>
            </div>
            <div style="width:87mm;padding-top:1mm;">
            	Schedule K-1 (Form 1065), box 13, code V
            </div>
            <div style="width:87mm;padding-top:1.5mm;">
               Schedule K-1 (Form 1065-B), box 9, code S3
               <span class="styDotLn" style="float: none; font-size: 7pt">.......</span>
            </div>
            <div style="width:87mm;padding-top:1.5mm;">
               Schedule K-1 (Form 1041), box 14, code D
               <span class="styDotLn" style="float: none; font-size: 7pt">........</span>
            </div>
            </td>
            <td style="width:4mm">
            	<div class="styLNDesc" style="width:4mm;">
              		<img style= "height:17mm" src="{$ImagePath}/8903_Bracket_Lg.gif" alt="Curly Bracket Image"/>                                    
            	</div>            
            </td>
            <td class="styDotLn" style="font-size: 7pt; padding-bottom: 4mm;">      
            </td>
         </tr>            
      </table>          
    </div>
    <div style="float:right">
    		<div class="styLNRightNumBox" style="height:14mm;padding-top:0mm;">
      		<div style="width:7.75mm;background-color:lightgrey;height:11mm;"></div>
          	13         
   		</div>        
    		<div class="styLNAmountBox" style="height:14mm;padding-top:11mm;">
      		<xsl:call-template name="PopulateAmount">
        			<xsl:with-param name="TargetNode" select="$FormData/PassThroughW2Wages"/>
      		</xsl:call-template>
    		</div>  
      	<div class="styLNRightNumBoxNBB" style="height: 13mm;background-color: lightgrey;"></div>
     	 <div class="styLNAmountBoxNBB" style="height: 13mm;"></div>          
  	</div>
  </div>      
<!--  Line 13  -->    

<!--  Line 14 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox">14</div>
     <div class="styIRS8903LNDesc" >
       	Add lines 12 and 13   
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
            ............................
          </div> 
      	<div class="styLNRightNumBox" style="padding-top:0mm;">
      		<div style="width:7.75mm;background-color:lightgrey;height:4mm;"></div>
      		14
      	</div>
      	<div class="styLNAmountBox" style="padding-top:4mm;">
        		<xsl:call-template name="PopulateAmount">
          		<xsl:with-param name="TargetNode" select="$FormData/TotalW2Wages"/>
        		</xsl:call-template> 
      	</div>          
    	</div>
  </div>
  <!--  Line 14 -->
  
  <!--  Line 15 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox">15</div>
    	<div class="styIRS8903LNDesc">
     	 Form W-2 wage limitation. Enter 50% of line 14 
   	</div>    
   	<div style="float:right;">
   		<div class="styDotLn" style="padding-top:4mm;">  
            ...................
          </div> 
      	<div class="styLNRightNumBox" style="padding-top:4mm;">15</div>
      	<div class="styLNAmountBox" style="padding-top:4mm;">
        		<xsl:call-template name="PopulateAmount">
          		<xsl:with-param name="TargetNode" select="$FormData/W2WageLimitation"/>
        		</xsl:call-template>
      	</div>          
    	</div>
  </div>
  <!--  Line 15 -->
  
  <!--  Line 16 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox">16</div>
     <div class="styIRS8903LNDesc">
       Enter the smaller of line 11 or line 15   
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
            ......................
          </div> 
      	<div class="styLNRightNumBox" style="padding-top:4mm;">16</div>
      	<div class="styLNAmountBox" style="padding-top:4mm;">
        		<xsl:call-template name="PopulateAmount">
          		<xsl:with-param name="TargetNode" select="$FormData/IncomePctOrW2WageLimitation"/>
        		</xsl:call-template>
      	</div>          
    	</div>
  </div>
  <!--  Line 16 -->

  <!--  Line 17 -->  
  <div style="width: 187mm;">
  	<div class="styIRS8903LNLeftNumBox">17</div>
     <div class="styIRS8903LNDesc">
       Domestic production activities deduction from cooperatives. Enter deduction from Form 
	  1099-PATR, 
    	</div>    
    	<div style="float:right;">
    		<div class="styShadingCellBox" style="height:8mm;"></div>
      	<div class="styLNAmountBoxNBB"  style="height:8mm;">
      	</div>        
    	</div>
  </div>
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox" style="padding-top:0mm;"></div>
     <div class="styIRS8903LNDesc" style="padding-top:0mm;">
       box 6   
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn">  
            ................................
          </div> 
      	<div class="styLNRightNumBox">17</div>
      	<div class="styLNAmountBox">
        		<xsl:call-template name="PopulateAmount">
          		<xsl:with-param name="TargetNode" select="$FormData/CoopDomesticProductionDed"/>
        		</xsl:call-template>
      	</div>          
    	</div>
  </div>
  <!--  Line 17 -->
  
  <!--  Line 18 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox">18</div>
     <div class="styIRS8903LNDesc">
        Expanded affiliated group allocation (see instructions)
        <span style="width:2px;"></span>
      <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$FormData/ExpandedGroupAllocation"/>
      </xsl:call-template>
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn" style="padding-top:4mm;">  
         	 ...............
         	</div> 
     	<div class="styLNRightNumBox" style="padding-top:4mm;">18</div>
     	<div class="styLNAmountBox" style="padding-top:4mm;">
     		<xsl:call-template name="PopulateAmount">
     			<xsl:with-param name="TargetNode" select="$FormData/ExpandedGroupAllocation"/>
      		</xsl:call-template>
      	</div>          
    	</div>
  </div>
  <!--  Line 18 -->

  <!--  Line 19 -->    
  <div style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox">19</div>
     <div class="styIRS8903LNDesc">
     	<b>Domestic production activities deduction.</b> Combine lines 16 through 18 and enter the result
      	 here and on 
    	</div>    
    	<div style="float:right;">
    		<div class="styShadingCellBox" style="height:8mm;"></div>
      	<div class="styLNAmountBoxNBB"  style="height:8mm;">
      	</div> 
     </div>
  </div>
  
   <div class="StyTBB" style="width: 187mm;">  
  	<div class="styIRS8903LNLeftNumBox" style="padding-top:0mm;"></div>
     <div class="styIRS8903LNDesc" style="padding-top:0mm;">
     	Form 1040. line 35; Form 1120, line 25; Form 1120-A, line 21; or the applicable
		line of your return  
    	</div>    
    	<div style="float:right;">
    		<div class="styDotLn">  
            .
          </div> 
      	<div class="styLNRightNumBox">19</div>
      		<div class="styLNAmountBox">
        			<xsl:call-template name="PopulateAmount">
          			<xsl:with-param name="TargetNode" select="$FormData/DomesticProductionDeduction"/>
        			</xsl:call-template>
      		</div>          
     </div>
  </div>

  <!--  Line 19 -->
  
  <!--  FOOTER-->
        <div style="width:187mm;">
          <span class="styBoldText">For Paperwork Reduction Act Notice, see separate instructions. </span> 
          <span style="width:120px;"></span>                      
          Cat. No. 37712F 
          <span style="width:80px;"></span>  
          Form <span class="styBoldText">8903</span> (2005)
        </div> 
        <br class="pageEnd"/>
        
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$FormData" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
      <!-- END Left Over Table -->      
  </form>  
</body>
</html>
</xsl:template>    

</xsl:stylesheet>