<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" />
  <xsl:strip-space elements="*" />
  
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddHeader.xsl"/>
  <xsl:include href="AddOnTable.xsl"/>

  <xsl:param name="DependencyData" select="$RtnDoc/ToWhomGasolineSoldStatement" />
  <!-- Template to display ToWhomGasolineSoldStatement dependency -->
  <xsl:template name="DependencyTemplate">
    <!-- ToWhomGasolineSoldStatement dependency data -->

        <div class="styTopSectionLine" style="clear:both">
          <div class="styTopSectionLineLbl" style="float:left">
            <b>Gasoline Seller Name:</b>
          </div>
          <div style="float:left">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$DependencyData/GasolineSeller/Name/BusinessNameLine1" /></xsl:call-template>     
            <xsl:if test="normalize-space($DependencyData/GasolineSeller/Name/BusinessNameLine2) != ''">
              <br /><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$DependencyData/GasolineSeller/Name/BusinessNameLine2" /></xsl:call-template>     
            </xsl:if>
          </div>                  
        </div>  

        <div class="styTopSectionLine" style="width:187mm;">
          <div class="styTopSectionLineLbl" style="float:left;clear:both;">
            Gasoline Seller TIN:
          </div>
          <div style="float:left;clear:right;;">
            <xsl:choose>
              <xsl:when test="$DependencyData/GasolineSeller/SSN">
                <xsl:call-template name="PopulateSSN"><xsl:with-param name="TargetNode" select="$DependencyData/GasolineSeller/SSN" /></xsl:call-template>                              
              </xsl:when>
              <xsl:otherwise>
                <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" select="$DependencyData/GasolineSeller/EIN" /></xsl:call-template>                            
              </xsl:otherwise>
            </xsl:choose>
          </div>
        </div>        

        <div class="styTopSectionLine">
          <div class="styDepGenericDiv" style="clear:both;text-align:right;">
            <span class="styTopSectionLineLbl">Number of Gallons Sold:</span>
          </div>
          <div class="styDepGenericDiv" style="clear:right;text-align:right;">
            <span style="width:44mm;text-align:right;">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$DependencyData/GasolineSeller/GallonsSold" />
              </xsl:call-template>
            </span>
          </div>
        </div>        

  </xsl:template>
  
  
  
  <!-- Main template -->
  <xsl:param name="depDocTitle">
    <xsl:call-template name="PopulateDisplayName"><xsl:with-param name="TargetNode" select="$DependencyData" /></xsl:call-template>  
  </xsl:param>
  <!-- Main template -->
  <xsl:template match="/" >

    <html>
      <head>
           <title><xsl:value-of select="$depDocTitle" /></title>
         <!-- No Browser Caching -->
         <meta http-equiv="Pragma" content="no-cache" />
         <meta http-equiv="Cache-Control" content="no-cache" />
         <meta http-equiv="Expires" content="0" />
         <!-- No Proxy Caching -->
         <meta http-equiv="Cache-Control" content="private" />
         <!-- Define Character Set -->
         <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />       
         <meta name="Description" content="{$depDocTitle}" />
         <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js"></script>
        <xsl:call-template name="InitJS"></xsl:call-template>

        
        <style type="text/css">
        </style>
        <style type="text/css">
  <xsl:if test="not($Print) or $Print=''">
    <xsl:call-template name="AddOnStyle"></xsl:call-template>    
  </xsl:if>
</style>
      <xsl:call-template name="GlobalStylesDep"/>
</head>
    
      <body class="styBodyClass">

        <xsl:call-template name="DocumentHeaderDependency"  />  
        <div class="styDepTitleLine">
          <span class="styDepTitle">
            <span style="width:60mm;"><xsl:value-of select="$depDocTitle" /></span>          
          </span>
        </div>
        <xsl:call-template name="PopulateDepCommonLeftover"><xsl:with-param name="TargetNode" select="$DependencyData"/></xsl:call-template>
        
        <!-- Transform Itemized Other Income Schedule -->
        <xsl:call-template name="DependencyTemplate" />
        
        <br />
      
      </body>
    </html>
  </xsl:template>
</xsl:stylesheet>
