<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
    <!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
  <xsl:output method="html" indent="yes"/>
  <xsl:strip-space elements="*"/>
  <!-- Defines the stage of the data, e.g. original or latest -->
  
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="AddHeader.xsl"/>  
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddOnTable.xsl"/>
  <xsl:include href="IRS1118ScheduleJStyle.xsl"/>
  
  <xsl:param name="FormData" select="$RtnDoc/IRS1118ScheduleJ"/>

<xsl:template match="/">
<html>
<head>
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>

  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache" />
  <meta http-equiv="Cache-Control" content="no-cache" />
  <meta http-equiv="Expires" content="0" />
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private" />
  <!-- Define Character Set -->
  <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
  <meta name="Description" content="IRS Form 1118 Schedule J" />
   

  <!-- javascript include -->
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>
  <!-- Commented out the following line because of the defect 2296 --> 
  <!--xsl:call-template name="AddOnStyle"></xsl:call-template-->
  <style type="text/css">
    <xsl:if test="not($Print) or $Print=''">
      <xsl:call-template name="IRS1118ScheduleJStyle"/>
      <xsl:call-template name="AddOnStyle"/>
    </xsl:if>
  </style>

  
<xsl:call-template name="GlobalStylesForm"/>
</head>
<body class="styBodyClass">

<xsl:call-template name="DocumentHeaderLandscape"></xsl:call-template>
<!-- BEGIN FORM HEADER -->
<div class="IRS1118ScheduleJ_LineContainerLong">
  <!-- Form Name -->
  <div class="IRS1118ScheduleJ_FormNumBlock">
     <span style="font-weight:bold;font-size:11pt;font-family:Arial">Schedule J
 <xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData"/>
</xsl:call-template>
    <br/><span style="font-size:9pt">(Form 1118)</span></span>
     <br />
     <div style="font-size:6pt;padding-top:1.75mm">(Rev. December 2004)</div>
     <br/>
     <span class="styAgency">Department of the Treasury</span>
     <br />
     <span class="styAgency">Internal Revenue Service</span>
  </div>

  <!-- Form Title Box -->
  <div class="IRS1118ScheduleJ_FormTitleBlock">
    <!-- Form Title -->
    <span class="styMainTitle">Adjustments to Separate Limitation Income (Loss) Categories for Determining<br/>Numerators of Limitation Fractions, Year-End Recharacterization Balances, and<br/>Overall Foreign Loss Account Balance</span>
    <br/>
    For calendar year <span style="width:10mm;border-bottom: 1 solid black">
    <xsl:call-template name="PopulateReturnHeaderTaxYear"></xsl:call-template>
  </span>  , or other tax year beginning <span style="width:19mm;border-bottom: 1 solid black;text-align:left;">
    <xsl:call-template name="PopulateReturnHeaderTaxPeriodBeginDate"></xsl:call-template>
  </span>  , and ending <span style="width:19mm;border-bottom: 1 solid black;text-align:left;">
    <xsl:call-template name="PopulateReturnHeaderTaxPeriodEndDate"></xsl:call-template>
  </span>  .  <!-- Form Subtitle -->
    <br /><br/>
    <span style="font-weight:bold">
       <img src="{$ImagePath}\1118SchJ_Bullet.gif" alt="Right arrow" border="0"/> Attach to Form 1118.  For Paperwork Reduction Act Notice, see the Instructions for Form 1118.
    </span>
  </div>
    <!-- OMB No. -->
  <div class="IRS1118ScheduleJ_FormYearBlock">OMB No. 1545-0122</div>
</div>
<!-- Name and Address -->
<div class="IRS1118ScheduleJ_LineContainerLong">
  <div class="IRS1118ScheduleJ_NameBox" style="border-bottom-width: 0px;">
     Name of corporation<br/>
    <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
    <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
  </div>
  <div class="IRS1118ScheduleJ_EINBox" style="height:9.5mm;border-bottom-width: 0px;padding-left:2mm; ">
      <span style="font-weight:bold">Employer identification number<br/><br /></span>
     <div style="font-size:7pt;padding-top:0mm;text-align:left;">
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>      
    </div>    
  </div>
</div>
<!-- Part I-->
<div class="IRS1118ScheduleJ_LineContainerLong">
  <div class="IRS1118ScheduleJ_PartIndex" style="height:4.7mm;border-bottom-width:1px;">Part I</div>
  <div class="IRS1118ScheduleJ_LineDescLong" style="height:4.7mm;font-size:8pt;padding-left:4px;border-right-width:0px;border-top-width:1px;border-bottom-width:1px;width:240mm;">
       <span style="font-weight:bold;">
         Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of Limitation Fractions 
       </span>
       (See instructions.)
  </div>
</div>


<!-- If the Separate Print Solution is ON and there exists any data for the repeating element more than once, -->
<!-- display an EMPTY table.                                                                                  -->
<xsl:if test="($Print = $Separated) and 
               ( (count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/OtherIncomeColm) &gt; 1) )">

	<!-- Part I table 1 -->
	<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="adjSepLimInc">
	   <table cellspacing="0" style="font-size:7pt;">
	     <thead style="display:table-header-group;font-weight:normal;text-align:center;">
	     <tr>
	      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(i)</span><br/>General limitation income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(ii)</span><br/>Passive income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(iii)</span><br/>High withholding tax interest
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(iv)</span><br/>Financial services income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(v)</span><br/>Shipping income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(vi)</span><br/>Dividends from a DISC or former DISC
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(vii)</span><br/>Taxable income attributable to foreign trade income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(viii)</span><br/>Certain distributions from a FSC or former FSC
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;border-right-width:0px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(ix)</span>
	        <br/>Other income*
	      </th>
	    </tr>
	     </thead>
	     <tfoot></tfoot>
	     <tbody>
	    <tr>
	      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;padding-right:5mm;" scope="row">1</td>
	      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">Income or (loss) before adjustments (see </td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
	    </tr>         
	    <tr>
	      <td class="IRS1118ScheduleJ_IndexCell" scope="row"><span style="width:16px;"></span></td>
	      <td class="IRS1118ScheduleJ_DescCell" scope="row">instructions). </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="text-align:left;"> 
				<xsl:call-template name="PopulateAdditionalDataTableMessage">
				  <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome"/>
				  <xsl:with-param name="ShortMessage"	select=" 'true' " />
				</xsl:call-template>
				<span class="styTableCellPad"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
	    </tr>
	    <tr>
        <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">2</td>
        <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Allocation of current year separate limitation losses:</td>
      </tr>  
		 <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
	    </tr>
	    <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
        <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
       </tr>
       <tr>
         <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
       </tr>
       <tr>
         <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
		  </tr>
		  <tr>
         <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
		  </tr>
		  <tr>
         <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
		  </tr>
		  <tr>
         <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row"><span>Taxable income attributable to foreign trade income</span> </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
		  </tr>
		  <tr>
         <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
	    </tr>
      <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
      </tr>
      <tr>
        <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">3</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2i</td>
        <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
       </tr>
       <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">4</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Overall foreign losses </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
		  </tr>
		  <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">5</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses </td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
		  </tr>
		 <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Subtract line 5 from line 3.</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">7</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
    </tr>
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"  style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"  style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
		  </tr>
       <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">8</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 through 7i.</td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
		  </tr>
     </tbody>
   </table>
 </div>

   <!--BEGIN FOOTER-->
      <div style="width:256mm">
        <div style="float: left; clear: none;"><span class="styBoldText">* Important: </span> <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>in instructions.</span></div>        
        <div style="float:right">
          Cat. No. 10309U 
          <span style="width:200px"></span>
          <span class="styBoldText">Schedule J (Form 1118) (Rev. 12-2004)</span>
        </div>      
      </div>     
      <div class="pageEnd"></div>
      <!--END FOOTER-->  
        
      <!--BEGIN HEADER-->
      <div class="styBB" style="width:256mm">
        <div style="float: left; clear: none">Schedule J (Form 1118) (Rev. 12-2004)</div>        
        <div style="float:right">
          Page <span class="styBoldText" style="font-size: 8pt">2</span>
        </div>      
      </div> 
    <!--END HEADER-->

<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="limFracNum">
   <table cellspacing="0" style="font-size:7pt;">
     <thead style="display:table-header-group;font-weight:normal;text-align:center;">
     <tr>
      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(i)</span><br/>General limitation income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ii)</span><br/>Passive income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span><br/>High withholding tax interest
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(iv)</span><br/>Financial services income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(v)</span><br/>Shipping income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(vi)</span><br/>Dividends from a DISC or former DISC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(vii)</span><br/>Taxable income attributable to foreign trade income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(viii)</span><br/>Certain distributions from a FSC or former FSC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;border-right-width:0px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
        <br/>Other income*
      </th>
    </tr>
     </thead>
     <tfoot></tfoot>
     <tbody>       
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;padding-right:5mm;" scope="row">10</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">Allocation of current year U.S. source losses</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">(see instructions)</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;padding-right:5mm;" scope="row">11</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;font-family:'arial narrow'" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Subtract line 10</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;font-family:'arial narrow'" scope="row">from line 9.  Enter each result here and on Part II,</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-family:'arial narrow'" scope="row">line 6, of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	      <!-- Part II title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part II</span>
        <span style="width:3mm;"></span> 
        Year-End Balances of Future Separate Limitation Income That Must Be Recharacterized
      </td>
    </tr>  
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
       <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
       <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
       <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-right-width:0px;"><span style="width:4px;"></span></td>
	  </tr>
	  <!-- Part III title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part III</span>
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br/><span style="padding-left:17.5mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	  </tr> 
	 </tbody>
  </table>
 </div>
 <!--BEGIN FOOTER-->
      <div style="width:256mm">
        <div style="float: left; clear: none;"><span class="styBoldText">* Important: </span> <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>in instructions.</span></div>              
      </div>     
      <div class="pageEnd"></div>
      <!--END FOOTER-->  


</xsl:if>

<!-- If the Separate Print Option is OFF OR if the Separate Print Option is ON and there is 0 or 1 data -->
<!-- for each repeating element, print the table with data inline.                                      -->
<xsl:if test=" ($Print != $Separated) or 
               ( ($Print = $Separated) and 
                 ( (count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome) &lt; 2) and
                   (count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome) &lt; 2) and
                   (count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome) &lt; 2) and
                   (count($FormData/OtherIncomeColm) &lt; 2) ) )">
                
<!-- Part I table 1 -->                 
<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="adjSpLmInc">
   <table cellspacing="0" style="font-size:7pt;">
     <thead style="display:table-header-group;font-weight:normal;text-align:center;">
     <tr>
      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(i)</span><br/>General limitation income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ii)</span><br/>Passive income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span><br/>High withholding tax interest
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iv)</span><br/>Financial services income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(v)</span><br/>Shipping income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(vi)</span><br/>Dividends from a DISC or former DISC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(vii)</span><br/>Taxable income attributable to foreign trade income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(viii)</span><br/>Certain distributions from a FSC or former FSC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;border-right-width:0px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(ix)</span>
			<xsl:call-template name="SetFormLinkInline">
			    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]"/>
			</xsl:call-template>
        <br/>Other income*
      </th>
    </tr>
     </thead>
     <tfoot></tfoot>
     <tbody>
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">Income or (loss) before adjustments (see </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">instructions). </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Allocation of current year separate limitation losses:</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span>Taxable income attributable to foreign trade income</span> </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>

    <!--Tanuja  Need to show the row I even when there is no data -->
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)">
      <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
      </tr>
    </xsl:if>
       
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px; border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2i</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Subtract line 5 from line 3.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
    </tr>         
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber" >
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>
    
    <!-- Tanuja: Need to show row i even when there is no data --> 
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome)">
      <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
      </tr>
    </xsl:if>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 through 7i.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
    </tr>         
  </tbody>
</table>
</div>
   <!--BEGIN FOOTER-->
      <div style="width:256mm">
        <div style="float: left; clear: none;"><span class="styBoldText">* Important: </span> <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>in instructions.</span></div>        
        <div style="float:right">
          Cat. No. 10309U 
          <span style="width:200px"></span>
          <span class="styBoldText">Schedule J (Form 1118) (Rev. 12-2004)</span>
        </div>      
      </div>     
      <div class="pageEnd"></div>
      <!--END FOOTER-->  
        
      <!--BEGIN HEADER-->
      <div class="styBB" style="width:256mm">
        <div style="float: left; clear: none">Schedule J (Form 1118) (Rev. 12-2004)</div>        
        <div style="float:right">
          Page <span class="styBoldText" style="font-size: 8pt">2</span>
        </div>      
      </div> 
    <!--END HEADER-->
<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="lmFracNum">
   <table cellspacing="0" style="font-size:7pt;">
     <thead style="display:table-header-group;font-weight:normal;text-align:center;">
     <tr>
      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(i)</span><br/>General limitation income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ii)</span><br/>Passive income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span><br/>High withholding tax interest
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(iv)</span><br/>Financial services income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(v)</span><br/>Shipping income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(vi)</span><br/>Dividends from a DISC or former DISC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(vii)</span><br/>Taxable income attributable to foreign trade income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(viii)</span><br/>Certain distributions from a FSC or former FSC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;border-right-width:0px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]"/>
</xsl:call-template>
        <br/>Other income*
      </th>
    </tr>
     </thead>
     <tfoot></tfoot>
     <tbody>       
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;padding-left:.5mm;" scope="row">10</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">Allocation of current year U.S. source losses</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">(see instructions)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;padding-left:.5mm;" scope="row">11</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;font-family:'arial narrow'" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Subtract line 10</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;font-family:'arial narrow'" scope="row">from line 9.  Enter each result here and on Part II,</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-family:'arial narrow'" scope="row">line 6, of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Part II title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part II</span>
        <span style="width:3mm;"></span> 
        Year-End Balances of Future Separate Limitation Income That Must Be Recharacterized
      </td>
    </tr>  
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>  
       
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)">
      <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
      </tr>
    </xsl:if>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <!-- Part III title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part III</span>
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))
        <span style="font-style:italic;font-weight:normal;"><br/><span style="padding-left:17.5mm;">
        Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
    </tr>
    </tbody>         
  </table>
  </div>
<!--BEGIN FOOTER-->
      <div style="width:256mm">
        <div style="float: left; clear: none;"><span class="styBoldText">* Important: </span> <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>in instructions.</span></div>              
      </div>     
      <div class="pageEnd"></div>
      <!--END FOOTER-->  
  </xsl:if>      
  

  <!-- If the Separate Print Option is OFF, repeat table for the repeating column ix. -->
  <!-- the repeating columns of column ix is displayed below -->
  <!-- first column ix -->
  <xsl:if test="($Print != $Separated) and count($FormData/OtherIncomeColm) &gt; 1">
    <xsl:for-each select="$FormData/OtherIncomeColm">
      <xsl:variable name="pos" select="position()"/>
      <xsl:if test="$pos mod 9 = 2">
        <!-- //////////////////////////////////////////////////////////////////////////////////////////
        
          Repeat the Whole Table Here 
          
          ///////////////////////////////////////////////////////////////////////////////////////// -->

<!-- Part I-->
<div class="IRS1118ScheduleJ_LineContainerLong">
  <div class="IRS1118ScheduleJ_PartIndex" style="border-bottom-width:1px;">Part I</div>
  <div class="IRS1118ScheduleJ_LineDescLong" style="font-size:8pt;padding-left:4px;border-right-width:0px;border-top-width:1px;border-bottom-width:1px;width:240mm;">
       <span style="font-weight:bold;">
         Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of Limitation Fractions 
       </span>
       (See instructions.)
  </div>
</div>
<!-- Part I table 1 -->

<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="adSeLmIn">
   <table cellspacing="0" style="font-size:7pt;">
     <thead style="display:table-header-group;">
     <tr>
      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 4]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;border-right-width:0px;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
    </tr>
    </thead>
    <tfoot></tfoot>
    <tbody>
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">Income or (loss) before adjustments (see </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">instructions). </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Allocation of current year separate limitation losses</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>  
         
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2i</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Subtract line 5 from line 3.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
    </tr>         
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>  
         
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 through 7i.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
  </tbody>
</table>
</div>
 <!--BEGIN FOOTER-->
      <div style="width:256mm">
        <div style="float: left; clear: none;"><span class="styBoldText">* Important: </span> <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>in instructions.</span></div>        
        <div style="float:right">
          Cat. No. 10309U 
          <span style="width:35px"></span>
          <span class="styBoldText">Schedule J (Form 1118) (Rev. 12-2004)</span>
        </div>      
      </div>     
      <div class="pageEnd"></div>
      <!--END FOOTER-->  
        
      <!--BEGIN HEADER-->
      <div class="styBB" style="width:256mm">
        <div style="float: left; clear: none">Schedule J (Form 1118) (Rev. 12-2004)</div>        
        <div style="float:right">
          Page <span class="styBoldText" style="font-size: 8pt">2</span>
        </div>      
      </div> 
    <!--END HEADER-->
<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="lmFrNm">
   <table cellspacing="0" style="font-size:7pt;">
     <thead style="display:table-header-group;font-weight:normal;text-align:center;">
     <tr>
      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(i)</span><br/>General limitation income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ii)</span><br/>Passive income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span><br/>High withholding tax interest
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iv)</span><br/>Financial services income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(v)</span><br/>Shipping income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(vi)</span><br/>Dividends from a DISC or former DISC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(vii)</span><br/>Taxable income attributable to foreign trade income
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(viii)</span><br/>Certain distributions from a FSC or former FSC
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;border-right-width:0px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]"/>
</xsl:call-template>
        <br/>Other income*
      </th>
    </tr>
     </thead>
     <tfoot></tfoot>
     <tbody>
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;padding-left:.5mm;" scope="row">10</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">Allocation of current year U.S. source losses</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">(see instructions)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;padding-left:.5mm;" scope="row">11</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;font-family:'arial narrow'" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Subtract line 10</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;font-family:'arial narrow'" scope="row">from line 9.  Enter each result here and on Part II,</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-family:'arial narrow'" scope="row">line 6, of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Part II title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part II</span>
        <span style="width:3mm;"></span> 
        Balances of Future Separate Limitation Income That Must Be Recharacterized
      </td>
    </tr>  
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>  
         
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <!-- Part III title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part III</span>
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br/><span style="padding-left:17.5mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>    
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 4]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
    </tr>
    </tbody>         
  </table>
  </div>
    <!--BEGIN FOOTER-->
      <div style="width:256mm">
        <div style="float: left; clear: none;"><span class="styBoldText">* Important: </span> <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>in instructions.</span></div>              
      </div>     
      <div class="pageEnd"></div>
      <!--END FOOTER-->      
      </xsl:if>
    </xsl:for-each>
  </xsl:if>
  <!-- end display repeating column x -->
  
  
        <!-- leftover data table -->
        <br />
        <br />
        <br />
        
<!-- BEGIN Left Over Table -->  
  <!-- Additonal Data Title Bar and Button -->
  <div class="styLeftOverTitleLineLandscape" id="LeftoverData">
    <div class="styLeftOverTitle">
      Additional Data        
    </div>
    <div class="styLeftOverButtonContainerLandscape">
      <input class="styLeftoverTableBtn" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
    </div>      
  </div>
  <!-- Additional Data Table -->
  <table class="styLeftOverTblLandscape">
    <xsl:call-template name="PopulateCommonLeftoverLandscape">
      <xsl:with-param name="TargetNode" select="$FormData" />
      <xsl:with-param name="DescWidth" select="100"/>
    </xsl:call-template>
  </table>  
<!-- END Left Over Table -->  


<!-- If the Separate Print Solution is ON and there exists any data for the repeating element -->
<!-- more than once, display the additional data in the table here.                           -->
<xsl:if test="($Print = $Separated) and 
               ( (count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/OtherIncomeColm) &gt; 1) )">

<span class="styRepeatingDataTitle" style="width:256mm;">Form 1118 Schedule J, Part I - Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of Limitation Fractions (See instructions.):</span>
<!-- Part I table 1 -->
	<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;" id="adjSLmInc">
	   <table class="styDepTblLandscape" cellspacing="0" style="font-size:7pt;">
	     <thead class="styTableThead" style="display:table-header-group;font-weight:normal;text-align:center;">
	     <tr class="styDepTblHdr">
	      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(i)</span><br/>General limitation income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(ii)</span><br/>Passive income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(iii)</span><br/>High withholding tax interest
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(iv)</span><br/>Financial services income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(v)</span><br/>Shipping income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(vi)</span><br/>Dividends from a DISC or former DISC
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(vii)</span><br/>Taxable income attributable to foreign trade income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-family: 'Arial Narrow';font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(viii)</span><br/>Certain distributions from a FSC or former FSC
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;border-right-width:0px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(ix)</span>
	<xsl:call-template name="SetFormLinkInline">
	    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]"/>
	</xsl:call-template>
	        <br/>Other income*
	      </th>
	    </tr>
     </thead>
     <tfoot></tfoot>
     <tbody>
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Income or (loss) before adjustments (see <br/>instructions).</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row">Allocation of current year separate limitation losses:</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span>Taxable income attributable to foreign trade income</span> </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>
 
    
    <!--Need to show the row I even when there is no data -->
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)">
      <tr class="styDepTblRow1">    
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>
        </td>
      </tr>
    </xsl:if>
       
    <!-- Tracks the number of rows repeating for i to determine the color that row 3 would start. -->
    <xsl:variable name="twoICounter" select="count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)"/>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>    
      <!-- If the position of the repeating i row is odd, then the current row is set to styDepTblRow1. -->
      <!-- Otherwise, the current row is set to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="position() mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px; border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>     
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2i</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row"><br/>6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><br/><span style="font-weight:bold;">Subtotal&#151;</span>Subtract line 5 from line 3.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
    </tr>         
<!-- repeating rows -->       
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber" >
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>
    
    <!-- Need to show row i even when there is no data -->     
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome)">
      <tr>
        <!-- ADDED -->
			 <!-- If the number of repeating 2i rows is odd or there is no data, then set curent row to styDepTblRow1.-->
			 <!-- Otherwise, set it to styDepTblRow2                                                                  -->
			 <xsl:choose>
				 <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
				   <xsl:choose>
				     <xsl:when test="position() mod 2 = 1">
				       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
				     </xsl:when>
				     <xsl:otherwise>
				       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
				     </xsl:otherwise>
				   </xsl:choose>
				 </xsl:when>
				 <xsl:otherwise>
				   <xsl:choose>
				     <xsl:when test="position() mod 2 = 1">
				       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
				     </xsl:when>
				     <xsl:otherwise>
				       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
				     </xsl:otherwise>
				   </xsl:choose>
				 </xsl:otherwise>
			 </xsl:choose>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
      </tr>
    </xsl:if>

    <!-- Tracks the number of rows repeating for i to determine the color that the row 8 would start. -->
    <xsl:variable name="sevenICount" select="count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome)" />
    
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
			 <!-- If the number of repeating 2i rows is odd or there is no data, then set curent row to styDepTblRow1.-->
			 <!-- Otherwise, set it to styDepTblRow2                                                                  -->
	 <xsl:choose>
		 <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
		   <xsl:choose>
		     <xsl:when test="position() mod 2 = 1">
		       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
		     </xsl:when>
		     <xsl:otherwise>
		       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
		     </xsl:otherwise>
		   </xsl:choose>
		 </xsl:when>
		 <xsl:otherwise>
		   <xsl:choose>
		     <xsl:when test="position() mod 2 = 1">
		       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
		     </xsl:when>
		     <xsl:otherwise>
		       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
		     </xsl:otherwise>
		   </xsl:choose>
		 </xsl:otherwise>
	 </xsl:choose>
   <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
   <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
   <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecharacterizationSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>    
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.       -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current row to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                  -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 through 7i.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
    </tr>         
        
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.       -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current row to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                  -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-top-width:1px;" scope="row"><br/>9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><br/><span style="font-weight:bold;">Subtotal&#151;</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.       -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current row to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                  -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">10</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of current year U.S. source losses<br/>(see instructions)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.       -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current row to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                  -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">11</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-family:'arial narrow'" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Subtract line 10
        <br/>from line 9.  Enter each result here and on Part II,<br/>line 6, of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Part II title -->       
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part II</span>
        <span style="width:3mm;"></span> 
        Year-End Balances of Future Separate Limitation Income That Must Be Recharacterized
      </td>
    </tr>  
<!-- repeating rows -->       
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>      
        
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)">
      <tr>
	      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
	      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
	      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
	      <xsl:choose>
	        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
	          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
	        </xsl:when>
	        <xsl:otherwise>
	          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
	        </xsl:otherwise>
	      </xsl:choose>

        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span>
        </td>
      </tr>
    </xsl:if>

    <!-- Tracks the number of rows repeating for i to determine the color the row following i should start. -->
    <xsl:variable name="partTwoICntr" select="count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)"/>   

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i and 7i.   -->
      <!-- Therefore, if the sum of the number of data for 2i and 7i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:choose>
            <xsl:when test="position() mod 2 = 1">
              <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="position() mod 2 = 1">
              <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <!-- Part III title -->       
    <tr>
   	 <!-- The color of the current row is dependent on the number of rows in 2i, 7i, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2i, 7i, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part III</span>
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br/><span style="padding-left:17.5mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i, 7i, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2i, 7i, and Part II i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i, 7i, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2i, 7i, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i, 7i, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2i, 7i, and Part II i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i, 7i, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2i, 7i, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal--</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i, 7i, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2i, 7i, and Part II i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2i, 7i, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2i, 7i, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row"><br/>6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><br/><span style="font-weight:bold;">Ending balance--</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/HighWthldTaxInterestColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/FinancialServicesIncmColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/ShippingIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DivDISCOrFormerDISCColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/TxblIncmToFrgnTrdIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/DistriFSCOrFormerFSCColm/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
    </tr>
    </tbody>         
  </table>
  </div>



  <!-- display repeating column ix -->
  <!-- the repeating columns of column ix are displayed below -->
  <!-- first column ix -->
  <xsl:if test="count($FormData/OtherIncomeColm) &gt; 1">
    <xsl:for-each select="$FormData/OtherIncomeColm">
      <xsl:variable name="pos" select="position()"/>
      <xsl:if test="$pos mod 9 = 2">
        <!-- //////////////////////////////////////////////////////////////////////////////////////////
        
          Repeat the Whole Table Here 
          
          ///////////////////////////////////////////////////////////////////////////////////////// -->

<!-- Part I-->
<br />
<span class="styRepeatingDataTitle" style="width:256mm;">Column (ix) Repeating data: Form 1118 Schedule J, Part I - Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of Limitation Fractions (See instructions.):</span>
<!-- Part I table 1 -->

<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;" id="adjSepLmInc">
   <table class="styDepTblLandscape" cellspacing="0" style="font-size:7pt;">
     <thead class="styTableThead" style="display:table-header-group;">
     <tr class="styDepTblHdr">
      <th class="IRS1118ScheduleJ_GenericCell" style="width:56mm;height:16mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 4]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:16mm;font-size:7pt;border-right-width:0px;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(ix)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
    </tr>
    </thead>
    <tfoot></tfoot>
    <tbody>
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Income or (loss) before adjustments (see <br/>instructions).</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Allocation of current year separate limitation losses</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>               
    
    <!-- Tracks the number of rows repeating for i to determine the color that the row after i would start. -->
    <xsl:variable name="twoICtr" select="count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)"/>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <!-- If the position of the repeating i row is odd, then the current row is set to styDepTblRow1. -->
      <!-- Otherwise, the current row is set to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="position() mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>       
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2i</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row"><br/>6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><br/><span style="font-weight:bold;">Subtotal&#151;</span>Subtract line 5 from line 3.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
    </tr>         
<!-- repeating rows -->       
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    
    <!-- Tracks the number of rows repeating for i to determine the color that the row after 7i would start. -->
    <xsl:variable name="sevenICtr" select="count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome)" />

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
		 <!-- If the number of repeating 2i rows is odd or there is no data, then set curent row to styDepTblRow1.-->
		 <!-- Otherwise, set it to styDepTblRow2                                                                  -->
		 <xsl:choose>
			 <xsl:when test="$twoICtr mod 2 = 1">
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:when>
			 <xsl:otherwise>
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:otherwise>
		 </xsl:choose>
    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal--</span>Combine lines 6 through 7i.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row"><br/>9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><br/><span style="font-weight:bold;">Subtotal--</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">10</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of current year U.S. source losses<br/>(see instructions)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">11</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-family:'arial narrow'" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction--</span>Subtract line 10
        <br/>from line 9.  Enter each result here and on Part II,
        <br/>line 6, of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Part II title -->       
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part II</span>
        <span style="width:3mm;"></span> 
        Balances of Future Separate Limitation Income That Must Be Recharacterized
      </td>
    </tr>  
<!-- repeating rows -->       
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General limitation income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">High withholding tax interest </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/HighWithholdingTaxInterest"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">d</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Financial services income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/FinancialServicesIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">e</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Shipping income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/ShippingIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">f</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Dividends from a DISC or former DISC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/DividendsFromDISCOrFormerDISC"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">g</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Taxable income attributable to foreign trade income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/TaxableIncomeForeignTrdIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i and 7i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">h</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Certain distributions from a FSC or former FSC </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/EOYBalancesOfFutureSepLmtIncm/DistributionFromFSCOrFormerFSC"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Tracks the number of rows repeating for i to determine the color that the row following i would start. -->
    <xsl:variable name="partTwoICtr" select="count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)"/>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
		 <!-- If the number of repeating 2i rows and 7i rows is odd, and if the current data position is odd,          -->
		 <!-- then set curent row to styDepTblRow1, but if the current data position is even, set it to styDepTblRow2. -->
		 <!-- Otherwise if the sum of rows in 2i and 7i is even, and if the current data position is set it to         -->
		 <!-- styDepTblRow2, but if the current data position is even then set it to styDepTblRow1.                    -->
		 <xsl:choose>
			 <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:when>
			 <xsl:otherwise>
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:otherwise>
		 </xsl:choose>
    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">i</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;"></td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <!-- Part III title -->       
    <tr>
      <!-- If the number of data for 2i, 7i, and Part II i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;">
        <span style="background-color:black;color:white;">Part III</span>
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br/><span style="padding-left:17.5mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <!-- If the number of data for 2i, 7i, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>      
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i, 7i, and Part II i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i, 7i, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i, 7i, and Part II i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal--</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i, 7i, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>    
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 4]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2i, 7i, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance--</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 3]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 4]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 5]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 6]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 7]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 8]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
    </tr>
    </tbody>         
  </table>
  </div>
      </xsl:if>
    </xsl:for-each>
  </xsl:if>

</xsl:if>


   </body>
</html>
</xsl:template>

</xsl:stylesheet>
