<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" >

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS990Style.xsl"/>
<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />
<xsl:param name="Form990Data" select="$RtnDoc/IRS990" />
<xsl:template match="/">

<html>
  <head>
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form990Data)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache" />
  <meta http-equiv="Cache-Control" content="no-cache" />
  <meta http-equiv="Expires" content="0" />
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private" />
  <!-- Define Character Set -->
  <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
  <meta name="Description" content="IRS Form 990" />
  
  
  
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <xsl:call-template name="IRS990Style"></xsl:call-template>
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>
    </style>
  <xsl:call-template name="GlobalStylesForm"/>
</head>
  <body class="styBodyClass">
    <form name="Form990">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>
      <div class="styTBB" style="width:187mm;">
        <div class="styFNBox" style="width:28mm;height:23mm;">
          <div style="padding-top:1mm;">
            Form<span class="styFormNumber">990</span>
            <br/>
            <span style="width:2px;"></span>
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data"/>
            </xsl:call-template>            
          </div>
          <div style="padding-top:2mm;">
            <span class="styAgency">Department of the Treasury</span><br/>
            <span class="styAgency">Internal Revenue Service</span>
          </div>
        </div>
        <div class="styFTBox" style="width:128mm;">
          <div class="styMainTitle" style="padding-top:1mm">Return of Organization Exempt From Income Tax</div>
          <div class="styFBT" style="height:5mm;">
            Under section 501(c), 527, or 4947(a)(1) of the Internal Revenue Code (except black lung benefit trust or private foundation)
          </div>
          <div>
            <br/>
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            The organization may have to use a copy of this return to satisfy state reporting requirements.
          </div>
        </div>
        <div class="styTYBox" style="width:30mm;">
          <div class="styOMB" style="height:2mm;">OMB No. 1545-0047</div>
          <div class="styTY" >20<span class="styTYColor">05</span></div>
          <div class="styPartName" style="height:8mm; width:30.5mm;padding-top:0.3mm">Open to Public Inspection</div>
        </div>
      </div>

      <div style="width:187mm;font-weight:bold;">
          <span class="styBoldText" style="width:3mm;">A</span> For the 
        <span style="width:8mm;">
        <xsl:call-template name="PopulateReturnHeaderTaxYear"></xsl:call-template>
        </span>
        calendar year,
        or tax year beginning
         <span style="width:18mm;">
        <xsl:call-template name="PopulateReturnHeaderTaxPeriodBeginDate"></xsl:call-template>
        </span>
        and ending         
          <span style="width:18mm;">
        <xsl:call-template name="PopulateReturnHeaderTaxPeriodEndDate"></xsl:call-template>
        </span>
      </div>

      <div style="width:187mm;">
        <div style="width:25mm;float:left;font-size:6pt;padding-top:2mm">
          <span class="styBoldText" style="float:left;width:2.75mm;">B</span>Check if applicable:
          <span style="width:3.5mm;padding-top:1mm">
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/AddressChange" />
                <xsl:with-param name="BackupName">IRS990AddressChange</xsl:with-param>
              </xsl:call-template>
            </input> 
          </span>
          
          <span style="width:21.4mm;padding-top:1mm">
            <label>
              <xsl:call-template name="PopulateLabel">
                <xsl:with-param name="TargetNode" select="$Form990Data/AddressChange" />
                <xsl:with-param name="BackupName">IRS990AddressChange</xsl:with-param>
              </xsl:call-template>Address change
            </label>
          </span>
          
          <span style="width:3.5mm;padding-top:2mm">
              <input type="checkbox" class="styCkbox" TabIndex="-1" id="NameChange" onclick="return false;"/>
          </span>
          <span style="width:21.4mm;padding-top:1mm">
              <label for="NameChange">Name change</label>
          </span>
          
          <span style="width:3.5mm;padding-top:2mm">
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/InitialReturn" />
                <xsl:with-param name="BackupName">IRS990InitialReturn</xsl:with-param>
              </xsl:call-template>
            </input> 
          </span>
          <span style="width:21.4mm;padding-top:2mm">
            <label>
              <xsl:call-template name="PopulateLabel">
                <xsl:with-param name="TargetNode" select="$Form990Data/InitialReturn" />
                <xsl:with-param name="BackupName">IRS990InitialReturn</xsl:with-param>
              </xsl:call-template>
              Initial return
            </label>
          </span>
          <span style="width:3.5mm;padding-top:2mm">
            <input type="checkbox" class="styCkbox" TabIndex="-1" id="FinalReturn" onclick="return false;"/>
          </span>
          <span style="width:21.4mm;padding-top:1mm">
            <label for="FinalReturn">Final return</label>
          </span>
          <span style="width:3.5mm;padding-top:2mm">
            <input type="checkbox" class="styCkbox" TabIndex="-1" id="AmendedReturn" onclick="return false;"/>
          </span>
          <span style="width:21.4mm;padding-top:2mm">
            <label for="AmendedReturn">Amended return</label>
          </span>
          <span style="width:3.5mm;padding-top:2mm">
            <input type="checkbox" class="styCkbox" TabIndex="-1" id="ApplicationPending" onclick="return false;"/>
          </span>
          <span style="width:21.4mm;padding-top:2mm">
            <label for="ApplicationPending">Application pending</label>
          </span>
        </div>
        
        <div class="styGenericDiv" style="width:112mm;">
          <div class="styLblNameAddr" style="width:112mm;height:27mm;">
              <div class="styUseLbl" style="width:14mm;height:27mm;border-right-width:0px;">Please use IRS label or print or type. See Specific Instruc- tions.</div>

            <div class="styNameAddr" style="width:96.25mm;height:9mm;border-left-width:1px;">
              <span class="styBoldText" style="float:left;">C</span>Name of organization<br/>
              <span class="stySmallText" style="padding-left:2mm;">
                <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
                <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
                <br/>
                <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">InCareOfName</xsl:with-param></xsl:call-template>
              </span>
            </div>
            
            <div class="styNameAddr" style="width:82.25mm;height:9mm;border-right-width:1px;border-left-width:1px;">
              <span style="width:2mm;"/>Number and street (or P.O. box if mail is not delivered to street address)<br/>
              <span class="stySmallText" style="padding-left:2mm;">
                <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">AddressLine1</xsl:with-param></xsl:call-template><br />
                <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">AddressLine2</xsl:with-param></xsl:call-template>
              </span>
            </div>
            <div class="styNameAddr" style="width:14mm;height:9mm;">
              Room/suite<br/>
            </div>
            <div class="styNameAddr" style="width:96.25mm;height:9mm;border-left-width:1px;">
              <span style="width:6pt;"/>City or town, state or country, and ZIP + 4<br/>
              <span class="stySmallText" style="padding-left:2mm;">
                <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">CityStateInfo</xsl:with-param></xsl:call-template>
                <br />
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">Country</xsl:with-param><xsl:with-param name="MainForm">true</xsl:with-param></xsl:call-template>
              </span>
            </div>
          </div>
        </div>
        
        <div class="styEINDateAssets" style="width:50mm;height:9mm;border-top-width:1px;">
          <span class="styBoldText">D Employer identification number</span>
          <br/><br/>
          <span class="styEINFld" style="padding-left:2mm;font-size:7pt">
            <!-- Since this is a main form, we must check for and display an updated EIN.  To do this, we use the EINChanged parameter when calling PopulateReturnHeaderFiler.-->
            <xsl:call-template name="PopulateReturnHeaderFiler">
              <xsl:with-param name="EINChanged">true</xsl:with-param>
              <xsl:with-param name="TargetNode">EIN</xsl:with-param>
            </xsl:call-template>
          </span>
        </div>
        
        <div class="styEINDateAssets" style="width:50mm;height:9mm;">
          <span class="styBoldText">E Telephone number</span>
          <br/><br/>
          <span style="padding-left:2mm;font-size:7pt">
            <xsl:if test="$Location = 'RET' ">
              <xsl:call-template name="PopulateReturnHeaderFiler">
                <xsl:with-param name="TargetNode">Phone</xsl:with-param>
              </xsl:call-template>
            </xsl:if>
          </span>
        </div>
        <div class="styEINDateAssets" style="width:50mm;height:12.3mm;padding-top:1mm;">
            <span class="styBoldText" style="font-family:Arial">F Accounting method:</span>
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/MethodOfAccountingCash" />
                <xsl:with-param name="BackupName">IRS990MethodOfAccountingCash</xsl:with-param>
              </xsl:call-template>
            </input> 
            <label>
              <xsl:call-template name="PopulateLabel">
                <xsl:with-param name="TargetNode" select="$Form990Data/MethodOfAccountingCash" />
                <xsl:with-param name="BackupName">IRS990MethodOfAccountingCash</xsl:with-param>
              </xsl:call-template>
              Cash
            </label>
            <span style="width:2mm;"></span>
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/MethodOfAccountingAccrual" />
                <xsl:with-param name="BackupName">IRS990MethodOfAccountingAccrual</xsl:with-param>
              </xsl:call-template>
            </input> 
            <label>
              <xsl:call-template name="PopulateLabel">
                <xsl:with-param name="TargetNode" select="$Form990Data/MethodOfAccountingAccrual" />
                <xsl:with-param name="BackupName">IRS990MethodOfAccountingAccrual</xsl:with-param>
              </xsl:call-template>
              Accrual
            </label>
          <span style="width:2mm;padding-top:1mm;"></span>
          <input type="checkbox" class="styCkbox">
            <xsl:call-template name="PopulateCheckbox">
              <xsl:with-param name="TargetNode" select="$Form990Data/MethodOfAccountingOther" />
              <xsl:with-param name="BackupName">IRS990MethodOfAccountingOther</xsl:with-param>
            </xsl:call-template>
          </input> 
          <label>
            <xsl:call-template name="PopulateLabel">
              <xsl:with-param name="TargetNode" select="$Form990Data/MethodOfAccountingOther" />
              <xsl:with-param name="BackupName">IRS990MethodOfAccountingOther</xsl:with-param>
            </xsl:call-template>
            Other (specify)
          </label>
          <span style="width:8px;"></span>
          <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
          <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/MethodOfAccountingOther/@note" /></xsl:call-template>
        </div>
      </div>





      <!-- Begin Sections G through M -->

      <div class="styBB" style="width:187mm;float:none;">
        <!--Begin Left Side of Sections G through M -->
        <div class="styGenericDiv" style="width:118.9mm;">
          <div class="styGenericDiv" style="width:25mm;height:10mm;"></div>
          <div class="styGenericDiv" style="width:5mm;height:10mm;padding-left:1.5mm;padding-top:1.0mm;">
              <img src="{$ImagePath}/990_Bullet_Round.gif" alt="RoundBullet"/>
          </div>
          <div class="styGenericDiv" style="width:88mm;height:10mm;font-weight:bold;padding-top:1.5mm;">
            <span class="stySmallText">
              Section 501(c)(3) organizations and 4947(a)(1) nonexempt charitable trusts must
              attach a completed Schedule A (Form 990 or 990-EZ).
            </span>
          </div>
          <div class="styBB" style="width:118.9mm;float:left;height:4.5mm;padding-top:0mm;">
            <div class="styGenericDiv" style="width:4mm;font-weight:bold;">G </div>
            <div class="styGenericDiv" style="width:17mm;"><span class="styBoldText">Web site:</span><span style="width:2px"></span><img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/></div>
            <div class="styGenericDiv" style="width:97mm;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/WebSite" /></xsl:call-template></div>
          </div>
          <div class="styBB" style="width:118.9mm;float:left;height:7.0mm;padding-top:2.5mm;">
            <div class="styGenericDiv" style="width:4mm;font-weight:bold;">J </div>
            <div class="styGenericDiv" style="width:114mm;font-size:6pt;">
              <span class="styBoldText">Organization type</span> (check only one)
              <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
              <span style="width:6px;"></span>
              <input type="checkbox" class="styCkbox" name="Checkbox">
                <xsl:call-template name="PopulateCheckbox">
                  <xsl:with-param name="TargetNode" select="$Form990Data/Organization501c" />
                  <xsl:with-param name="BackupName">IRS990Organization501c</xsl:with-param>
                </xsl:call-template>
              </input>
              <span style="width:3px;"></span>
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/Organization501c"/>
              </xsl:call-template>
              <span style="width:2px;"></span>
              <label>
                <xsl:call-template name="PopulateLabel">
                  <xsl:with-param name="TargetNode" select="$Form990Data/Organization501c" />
                  <xsl:with-param name="BackupName">IRS990Organization501c</xsl:with-param>                
                </xsl:call-template>
                501(c)
              </label>
              (<xsl:call-template name="PopulateText">
                 <xsl:with-param name="TargetNode" select="$Form990Data/Organization501c/@typeOf501cOrganization" />
               </xsl:call-template>)
              <img src="{$ImagePath}/990_Bullet_Left.gif" alt="LeftBullet"/>
              (insert no.)
              <span style="width:9px;"></span>
              <input type="checkbox" class="styCkbox" name="Checkbox">
                <xsl:call-template name="PopulateCheckbox">
                  <xsl:with-param name="TargetNode" select="$Form990Data/Organization4947a1" />
                  <xsl:with-param name="BackupName">IRS990Organization4947a1</xsl:with-param>
                </xsl:call-template>
              </input>
              <label>
                <xsl:call-template name="PopulateLabel">
                  <xsl:with-param name="TargetNode" select="$Form990Data/Organization4947a1" />
                  <xsl:with-param name="BackupName">IRS990Organization4947a1</xsl:with-param>
                </xsl:call-template>
                4947(a)(1)
              </label>
                or
              <span style="width:6px;"></span>
              <span class="styBoldText">
                <input type="checkbox" class="styCkbox" name="Checkbox">
                  <xsl:call-template name="PopulateCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form990Data/Organization527" />
                    <xsl:with-param name="BackupName">IRS990Organization527</xsl:with-param>
                  </xsl:call-template>
                </input>
              </span>
                <label>
                  <xsl:call-template name="PopulateLabel">
                    <xsl:with-param name="TargetNode" select="$Form990Data/Organization527" />
                    <xsl:with-param name="BackupName">IRS990Organization527</xsl:with-param>
                  </xsl:call-template>
                  527
                </label>
            </div>
          </div>
          <div class="styBB" style="width:118.9mm;height:12mm;float:left;padding-top:1.5mm">
            <div class="styGenericDiv" style="width:4mm;font-weight:bold;">K </div>
            <div class="styGenericDiv" style="width:114mm;">
              <span class="stySmallText">
                Check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width=1mm;"></span>
                <input type="checkbox" class="styCkbox" name="Checkbox">
                  <xsl:call-template name="PopulateCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form990Data/AreGrossReceiptsLessThanLimit" />
                    <xsl:with-param name="BackupName">IRS990AreGrossReceiptsLessThanLimit</xsl:with-param>
                  </xsl:call-template>
                </input>
                <label>
                  <xsl:call-template name="PopulateLabel">
                    <xsl:with-param name="TargetNode" select="$Form990Data/AreGrossReceiptsLessThanLimit" />
                    <xsl:with-param name="BackupName">IRS990AreGrossReceiptsLessThanLimit</xsl:with-param>
                  </xsl:call-template>
                  if the organization's gross receipts are normally not more than $25,000.
                </label> 
                The organization need not file a return with the IRS; but if the organization 
                chooses to file a return, be sure to file a complete return. Some states require 
                a complete return.
              </span>
            </div>
          </div>
          <div class="styGenericDiv" style="width:118.9mm;padding-top:2.5mm;float:bottom;vertical-align:bottom;">
            <span style="width:4mm;font-weight:bold">L </span>
            <span style="width:80mm">
                Gross receipts: Add lines 6b, 8b, 9b, and 10b to line 12
                <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            </span>
            <span style="width:34mm;">
              <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossReceipts" /></xsl:call-template>
            </span>
          </div>
        </div>
        <!--End Left Side of Sections G through M -->
        <!--Begin Right Side of Sections G through M -->
        <div class="styIRS990RightSideSection" style="width:67.5mm;">
          <div class="styGenericDiv" style="width:67mm;padding-top:0.5mm;font-size:6pt;padding-left:2mm;">
            <span class="styBoldText">H</span><span style="width:4px;"></span><span class="styItalicText">and</span><span style="width:4px;"></span><span class="styBoldText">I</span>
            <span class="styItalicText"> are not applicable to section 527 organizations.</span>
          </div>
          <div class="styGenericDiv" style="width:67mm;padding-left:2mm;">
              <div class="styIRS990RightSideLeftNumBox"><span style="font-size:7pt">H(a)</span></div>
            <div class="styGenericDiv" style="width:57mm;padding-top:0.75mm">
              <span class="stySmallText">
                Is this a group return for affiliates?
                <span style="height:3.0mm;width:3.0mm;padding-left:1.5mm">
                  <xsl:call-template name="PopulateSpan">
                    <xsl:with-param name="TargetNode" select="$Form990Data/GroupReturn" />
                  </xsl:call-template>
                  <input type="checkbox" class="styCkbox" name="Checkbox">
                    <xsl:call-template name="PopulateYesCheckbox">
                      <xsl:with-param name="TargetNode" select="$Form990Data/GroupReturn" />
                      <xsl:with-param name="BackupName">IRS990GroupReturnYes</xsl:with-param>
                    </xsl:call-template>
                  </input>
                </span>
                <label>
                  <xsl:call-template name="PopulateLabelYes">
                    <xsl:with-param name="TargetNode" select="$Form990Data/GroupReturn" />
                    <xsl:with-param name="BackupName">IRS990GroupReturnYes</xsl:with-param>
                  </xsl:call-template>
                  Yes
                </label>
                <span style="width:8px;"></span>
                <span style="height:3.0mm;width:3.0mm;">
                  <xsl:call-template name="PopulateSpan">
                    <xsl:with-param name="TargetNode" select="$Form990Data/GroupReturn" />
                  </xsl:call-template>
                  <input type="checkbox" class="styCkbox" name="Checkbox">
                    <xsl:call-template name="PopulateNoCheckbox">
                      <xsl:with-param name="TargetNode" select="$Form990Data/GroupReturn" />
                      <xsl:with-param name="BackupName">IRS990GroupReturnNo</xsl:with-param>
                    </xsl:call-template>
                  </input>
                </span>
                <label>
                  <xsl:call-template name="PopulateLabelNo">
                    <xsl:with-param name="TargetNode" select="$Form990Data/GroupReturn" />
                    <xsl:with-param name="BackupName">IRS990GroupReturnNo</xsl:with-param>
                  </xsl:call-template>
                  No
                </label>
              </span>
            </div>
          </div>
          <div class="styGenericDiv" style="width:67mm;padding-left:2mm;">
            <div class="styIRS990RightSideLeftNumBox"><span class="font-size:7pt">H(b)</span></div>
            <div class="styGenericDiv" style="width:41mm;padding-top:0.95mm">
              <span class="stySmallText">
                If "Yes" enter number of affiliates
                <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>                
              </span>
            </div>
           
            <div class="styFixedUnderline" style="width:14mm;font-size:6pt;padding-top:0.65mm">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="MaxSize" select="6" />
                <xsl:with-param name="TargetNode" select="$Form990Data/NumberOfAffiliates" />
              </xsl:call-template>
            </div>
          </div>
          <div class="styGenericDiv" style="width:67mm;padding-left:2mm;">
            <div class="styIRS990RightSideLeftNumBox"><span class="font-size:7pt">H(c)</span></div>
            <div class="styGenericDiv" style="width:35mm;padding-top:0.95mm;">
              <span class="stySmallText">
                Are all affiliates included?
                <span style="width:2px;"></span>
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="$Form990Data/AllAffiliatesIncluded"/>
                </xsl:call-template>
              </span>
            </div>
            <div class="styGenericDiv" style="width:22mm;padding-top:0.85mm;padding-left:4.5mm;font-size:6pt;">
              <span style="height:3.0mm;width:3.0mm;">
                <xsl:call-template name="PopulateSpan">
                  <xsl:with-param name="TargetNode" select="$Form990Data/AllAffiliatesIncluded" />
                </xsl:call-template>
                <input type="checkbox" class="styCkbox" name="Checkbox">
                  <xsl:call-template name="PopulateYesCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form990Data/AllAffiliatesIncluded" />
                    <xsl:with-param name="BackupName">IRS990AllAffiliatesIncludedYes</xsl:with-param>
                  </xsl:call-template>
                </input>
              </span>
              <label>
                <xsl:call-template name="PopulateLabelYes">
                  <xsl:with-param name="TargetNode" select="$Form990Data/AllAffiliatesIncluded" />
                  <xsl:with-param name="BackupName">IRS990AllAffiliatesIncludedYes</xsl:with-param>
                </xsl:call-template>
                Yes
              </label>
              <span style="width:8px;"></span>
              <span style="height:3.0mm;width:3.0mm;">
                <xsl:call-template name="PopulateSpan">
                  <xsl:with-param name="TargetNode" select="$Form990Data/AllAffiliatesIncluded" />
                </xsl:call-template>
                <input type="checkbox" class="styCkbox" name="Checkbox">
                  <xsl:call-template name="PopulateNoCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form990Data/AllAffiliatesIncluded" />
                    <xsl:with-param name="BackupName">IRS990AllAffiliatesIncludedNo</xsl:with-param>
                  </xsl:call-template>
                </input>
              </span>
              <label>
                <xsl:call-template name="PopulateLabelNo">
                  <xsl:with-param name="TargetNode" select="$Form990Data/AllAffiliatesIncluded" />
                  <xsl:with-param name="BackupName">IRS990AllAffiliatesIncludedNo</xsl:with-param>
                </xsl:call-template>
                No
              </label>
            </div>
          </div>
          <div class="styGenericDiv" style="width:67mm;padding-left:2mm;">
            <div class="styIRS990RightSideLeftNumBox"></div>
            <div class="styGenericDiv" style="width:54mm;padding-top:0.5mm">
              <span class="stySmallText">
                (If "No," attach a list. See instructions.)
              </span>
            </div>
          </div>
          <div class="styGenericDiv" style="width:67mm;padding-left:2mm;">
              <div class="styIRS990RightSideLeftNumBox"><span class="font-size:7pt;">H(d)</span></div>
            <div class="styGenericDiv" style="width:57mm;padding-top:0.95mm;font-size:6pt;">
              <span class="stySmallText">
                Is this a separate return filed by an organization
              </span>
            </div>
          </div>

          <div class="styBB" style="width:67mm;float:left;font-size:6pt;padding-left:2mm;">
            <div class="styIRS990RightSideLeftNumBox"></div>
            <div class="styGenericDiv" style="width:33.5mm;">
              <span class="stySmallText">
                covered by a group ruling?
              </span>
            </div>
            <div class="styGenericDiv" style="width:23mm;padding-left:5.75mm">
              <span style="height:3.0mm;width:3.0mm;">
                <xsl:call-template name="PopulateSpan">
                  <xsl:with-param name="TargetNode" select="$Form990Data/SepReturnFiledByMemberOfGroup" />
                </xsl:call-template>
                <input type="checkbox" class="styCkbox" name="Checkbox">
                  <xsl:call-template name="PopulateYesCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form990Data/SepReturnFiledByMemberOfGroup" />
                    <xsl:with-param name="BackupName">IRS990SepReturnFiledByMemberOfGroupYes</xsl:with-param>
                  </xsl:call-template>
                </input>
              </span>
              <label>
                <xsl:call-template name="PopulateLabelYes">
                  <xsl:with-param name="TargetNode" select="$Form990Data/SepReturnFiledByMemberOfGroup" />
                  <xsl:with-param name="BackupName">IRS990SepReturnFiledByMemberOfGroupYes</xsl:with-param>
                </xsl:call-template>
                Yes
              </label>
              <span style="width:8px;"></span>
              <span style="height:3.0mm;width:3.0mm;">
                <xsl:call-template name="PopulateSpan">
                  <xsl:with-param name="TargetNode" select="$Form990Data/SepReturnFiledByMemberOfGroup" />
                </xsl:call-template>
                <input type="checkbox" class="styCkbox" name="Checkbox">
                  <xsl:call-template name="PopulateNoCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form990Data/SepReturnFiledByMemberOfGroup" />
                    <xsl:with-param name="BackupName">IRS990SepReturnFiledByMemberOfGroupNo</xsl:with-param>
                  </xsl:call-template>
                </input>
              </span>
              <label>
                <xsl:call-template name="PopulateLabelNo">
                  <xsl:with-param name="TargetNode" select="$Form990Data/SepReturnFiledByMemberOfGroup" />
                  <xsl:with-param name="BackupName">IRS990SepReturnFiledByMemberOfGroupNo</xsl:with-param>
                </xsl:call-template>
                No
              </label>
            </div>            
          </div>

          <div class="styBB" style="width:67mm;float:left;padding-left:2mm;">
            <div class="styIRS990RightSideLeftNumBox">I</div>
            <div class="styGenericDiv" style="width:57mm;padding-top:0.5mm;">
                Group Exemption Number <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:3mm;"></span>
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/GroupExemptionNumber" /></xsl:call-template>
            </div>
          </div>
          <div class="styGenericDiv" style="width:67mm;padding-left:2mm;">
            <div class="styIRS990RightSideLeftNumBox">M</div>
            <span class="stySmallText" style="padding-top:0.75mm;padding-bottom:0.75mm">
                Check <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                <input type="checkbox" class="styCkbox" name="Checkbox">
                  <xsl:call-template name="PopulateCheckbox">
                    <xsl:with-param name="TargetNode" select="$Form990Data/ScheduleBNotRequired" />
                    <xsl:with-param name="BackupName">IRS990ScheduleBNotRequired</xsl:with-param>
                  </xsl:call-template>
                </input>
                <label>
                  <xsl:call-template name="PopulateLabel">
                    <xsl:with-param name="TargetNode" select="$Form990Data/ScheduleBNotRequired" />
                    <xsl:with-param name="BackupName">IRS990ScheduleBNotRequired</xsl:with-param>
                  </xsl:call-template>
                  if the organization is <span class="styBoldText">not</span> required to attach Sch. B (Form 990, 990-EZ, or 990-PF).
                </label>                
            </span>
            </div>
          </div>
        <!--End Right Side of Sections G through M -->
        </div>

      <!-- End Sections G through M -->

      <!-- BEGIN Part I -->
      <table class="styTable" style="font-size:7pt;width:187mm;" cellspacing="0">
        <thead>
          <tr scope="col">
            <th class="styBB" colspan="8" style="padding-bottom:0;padding-top:0;">
                <span class="styPartName" style="width:14mm;">Part I</span>
              <span class="styPartDesc" style="width:172mm;">
                Revenue, Expenses, and Changes in Net Assets or Fund Balances
                <span class="styNormalText">(See the instructions.)</span>
              </span>             
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody valign="top">
          <!-- Begin Part I Revenue Section -->
          <tr>
            <td class="styIRS990VTImageBox" rowspan="28" valign="middle"><img src="{$ImagePath}/990_Revenue.gif" alt="Revenue"/></td>
            <td class="styLNLeftNumBox" style="height:4.5mm;">1</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">Contributions, gifts, grants, and similar amounts received:</td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm;border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:10px;"></span>a</td>
            <td class="styLNDesc" style="width:91mm;height:4.5mm;" colspan="2">Direct public support
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">1a</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DirectPublicSupport" /></xsl:call-template></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right-width: 0px"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:10px;"></span>b</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;" colspan="2">Indirect public support
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">1b</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/IndirectPublicSupport" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:10px;"></span>c</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;" colspan="2">Government contributions (grants)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">1c</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GovernmentContributions" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:10px;padding-top: 1.25mm"></span>d</td>
            <td class="styLNDesc" style="width:132mm;height:4.5mm;font-size:7pt;" colspan="4">
              <span class="styBoldText">Total</span> (add lines 1a through 1c)
              (cash $
               <span class="styFixedUnderline" style="float:none;width:29mm;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form990Data/TotalCashContributions" />
                </xsl:call-template>
              </span>
              noncash $ 
              <span class="styFixedUnderline" style="float:none;width:29mm;">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="$Form990Data/TotalNoncashContributions" />
                </xsl:call-template>
              </span> )
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">1d</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalContributions" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">2</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Program service revenue including government fees and contracts (from Part VII, line 93)
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">2</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ProgramServiceRevenue" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">3</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Membership dues and assessments
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">................</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">3</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MembershipDues" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">4</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Interest on savings and temporary cash investments
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">4</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InterestOnSavingsTempCashInvst" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">5</td>
            <td class="styLNDesc" style="width:132mm;height:4.5mm;" colspan="4">
              Dividends and interest from securities
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">................</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">5</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DividendsAndIntFromSecurities" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">6a</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;" colspan="2">Gross rents
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">6a</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossRents" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:7px;"></span>b</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;" colspan="2">
              Less: rental expenses
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">6b</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LessRentalExpenses" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:7px;"></span>c</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Net rental income or (loss) (subtract line 6b from line 6a)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">6c</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncomeLoss" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">7</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Other investment income (describe
              <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
              <span style="width:1mm;"></span>
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/OtherInvestmentIncome"/>
              </xsl:call-template><span style="width:1mm;"/>)
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">7</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherInvestmentIncome" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>

          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">8a</td>
            <td class="styLNDesc" style="width:53mm;height:4.5mm;" rowspan="2"><!-- Combine rows below for correct JAWS reading -->
              Gross amount from sales of assets <br/>
              <div style="padding-top: 1mm">other than inventory<span style="letter-spacing:4mm; font-weight:bold; margin-left:2mm">.....</span></div> 
            </td>
            <td class="styLNAmountBox" style="border-top-width:1px;height:4.5mm;text-align:center;">
              <span class="styBoldText">(A)</span> Securities
            </td>
            <td class="styLNRightNumBox" style="border-top-width:1px;height:4.5mm;"><span style="width:1px;"></span></td>
            <td class="styLNAmountBox" style="border-top-width:1px;height:4.5mm;text-align:center;">
              <span class="styBoldText">(B)</span> Other
            </td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"></td>            
            <td class="styLNAmountBox" style="height:4.5mm;font-size:6pt;">
              <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GroAmtSaleOfAssetsOthInventory/Securities" /></xsl:call-template>
              
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">8a</td>
            <td class="styLNAmountBox" style="height:4.5mm;font-size:6pt;">
              <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GroAmtSaleOfAssetsOthInventory/Other" /></xsl:call-template>    
            </td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:7px;"></span>b</td>
            <td class="styLNDesc" style="width:53mm;height:4.5mm;">
              <span style="font-size:6pt">
                  Less: cost or other basis and sales expenses
              </span>
            </td>
            <td class="styLNAmountBox" style="height:4.5mm;font-size:6pt;">
              <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LessCostOrOtherBasis/Securities" /></xsl:call-template>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">8b</td>
            <td class="styLNAmountBox" style="height:4.5mm;font-size:6pt;">
              <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LessCostOrOtherBasis/Other" /></xsl:call-template>
            </td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:7px;"></span>c</td>
            <td class="styLNDesc" style="width:53mm;height:4.5mm;">Gain or (loss) (attach schedule)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..</span>
            </td>
            <td class="styLNAmountBox" style="height:4.5mm;font-size:6pt;">
            <span style="float: left; clear:none">
            <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/GainLoss/Securities"/>
              </xsl:call-template>
              </span>
              <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GainLoss/Securities" /></xsl:call-template>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">8c</td>
            <td class="styLNAmountBox" style="height:4.5mm;font-size:6pt;">
            <span style="float: left; clear:none">
            <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/GainLoss/Other"/>
              </xsl:call-template>  
              </span>
              <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GainLoss/Other" /></xsl:call-template>    
            </td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:7px;"></span>d</td>
            <td class="styLNDesc" style="width:132mm;height:4.5mm;" colspan="4">
              Net gain or (loss) (combine line 8c, columns (A) and (B))
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">8d</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetGainOrLossFromSaleOfAssets" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">9</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              <label>
                <xsl:call-template name="PopulateLabel">
                  <xsl:with-param name="TargetNode" select="$Form990Data/IsAnyRevenueFromGaming" />
                  <xsl:with-param name="BackupName">IRS990IsAnyRevenueFromGaming</xsl:with-param>
                </xsl:call-template>
                Special events and activities (attach schedule). If any amount is from <span class="styBoldText">gaming</span>, check here
              </label>                
              <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
              <span style="width:2px;"></span>
              <input type="checkbox" class="styCkbox" name="Checkbox">
                <xsl:call-template name="PopulateCheckbox">
                  <xsl:with-param name="TargetNode" select="$Form990Data/IsAnyRevenueFromGaming" />
                  <xsl:with-param name="BackupName">IRS990IsAnyRevenueFromGaming</xsl:with-param>
                </xsl:call-template>
              </input>
            </td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm"><span style="width:10px;"></span>a</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm" colspan="2" rowspan="2">
              Gross revenue (not including $ <span class="styFixedUnderline" style="float:none;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SpecialEventsGrossRevenue/@contributionsReportedOnLine1a" /></xsl:call-template></span> of
              contributions reported on line 1a)
              <span style="width:2px;"></span>
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/SpecialEventsGrossRevenue"/>
              </xsl:call-template>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
            </td>
            <td class="styLNDesc" style="width:40mm;height:4.5mm" colspan="2"></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm"><span style="width:1px;"></span></td>
            <td class="styLNRightNumBox" style="height:4.5mm">9a</td>
            <td class="styLNAmountBox" style="height:4.5mm"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SpecialEventsGrossRevenue" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:10px;"></span>b</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;" colspan="2">
              Less: direct expenses other than fundraising expenses
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">9b</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SpecialEventsDirectExpenses" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:10px;"></span>c</td>
            <td class="styLNDesc" style="width:132mm;height:4.5mm;" colspan="4">
              Net income or (loss) from special events (subtract line 9b from line 9a)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">9c</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SpecialEventsNetIncomeLoss" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>

          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">10a</td>
            <td class="styLNDesc" style="width:91mm;height:4.5mm;" colspan="2">
              Gross sales of inventory, less returns and allowances
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">10a</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossSalesOfInventory" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>b</td>
            <td class="styLNDesc" style="width:91mm;height:4.5mm;" colspan="2">
              Less: cost of goods sold
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">10b</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CostOfGoodsSold" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>

          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>c</td>
            <td class="styLNDesc" style="width:132mm;height:4.5mm;padding-top:0.75mm;" colspan="4">
                <span class="stySmallText">
                Gross profit or (loss) from sales of inventory (attach schedule)
                (subtract line 10b from line 10a)
              </span>
              <span style="width:2px;"></span>
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/GroProfitLossSalesOfInventory"/>
              </xsl:call-template>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">....</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">10c</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GroProfitLossSalesOfInventory" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>

          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">11</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Other revenue (from Part VII, line 103)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">11</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherRevenue" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBoxBB" style="height:4.5mm;">12</td>
            <td class="styIRS990LNDescBB" style="width:125mm;height:4.5mm;" colspan="4">
              <span class="styBoldText">Total revenue</span> (add lines 1d, 2, 3, 4, 5, 6c, 7, 8d, 9c, 10c, and 11)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">12</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalRevenue" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styIRS990VTImageBox" rowspan="5" valign="middle"><img src="{$ImagePath}/990_Expenses.gif" alt="Expenses"/></td>
            <td class="styLNLeftNumBox" style="height:4.5mm;">13</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Program services (from line 44, column (B))
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">13</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ProgramServicesExpenses" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">14</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Management and general (from line 44, column (C))
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">14</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ManagementAndGeneralExpenses" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">15</td>
            <td class="styLNDesc" style="width:132mm;height:4.5mm;" colspan="4">
              Fundraising (from line 44, column (D))
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">................</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">15</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/FundraisingExpenses" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">16</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Payments to affiliates (attach schedule)
              <span style="width:2px;"></span>
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/PaymentsToAffiliates"/>
              </xsl:call-template>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">16</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PaymentsToAffiliates" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBoxBB" style="height:4.5mm;">17</td>
            <td class="styIRS990LNDescBB" style="width:132mm;height:4.5mm;" colspan="4">
              <span class="styBoldText">Total expenses</span>
              (add lines 16 and 44, column (A))
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">............</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">17</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalExpenses" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styIRS990VTImageBox" rowspan="4" valign="middle"><img src="{$ImagePath}/990_NetAssets.gif" alt="Assets"/></td>
            <td class="styLNLeftNumBox" style="height:4.5mm;">18</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Excess or (deficit) for the year (subtract line 17 from line 12)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">18</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ExcessOrDeficitForYear" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">19</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Net assets or fund balances at beginning of year (from line 73, column (A))
              <span style="width:2px;"></span>
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/NetAssetsOrFundBalancesBOY"/>
              </xsl:call-template>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.....</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">19</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetAssetsOrFundBalancesBOY" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">20</td>
            <td class="styLNDesc" style="width:125mm;height:4.5mm;" colspan="4">
              Other changes in net assets or fund balances (attach explanation)
              <xsl:call-template name="SetFormLinkInline">        
                <xsl:with-param name="TargetNode" select="$Form990Data/OtherChangesInNetAssets"/>
              </xsl:call-template>  
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">20</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherChangesInNetAssets" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBoxBB" style="height:4.5mm;">21</td>
            <td class="styIRS990LNDescBB" style="width:132mm;height:4.5mm;" colspan="4">
              Net assets or fund balances at end of year (combine lines 18, 19, and 20)
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">......</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">21</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetAssetsOrFundBalancesEOY" /></xsl:call-template><span style="width:1px;"></span></td>
          </tr>
        </tbody>
      </table>
    <!-- END Part I -->

      <div style="width:187mm;float:none;clear:both;padding-top:.5mm;" class="pageend">
        <div class="styGenericDiv" style="width:117mm;font-weight:bold;">For Privacy Act and Paperwork Reduction Act Notice, see the separate instructions.</div>
        <div class="styGenericDiv" style="width:23mm;">Cat. No. 11282Y</div>
        <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
      </div>
      
      <!-- header -->
      <div style="width:187mm;clear:both;padding-bottom:.5mm;float:none;clear:both;" class="styBB">
        <div style="width:90mm;" class="styGenericDiv">Form 990 (2005)</div>
        <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
        <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">2</span></div>
      </div>


    <!-- Begin Part II-->
    <!-- BEGIN Part II Title -->
    <div class="styBB" style="width:187mm;float:none;height:9mm;">
      <div class="styPartName" style="float:left;width:14mm;">Part II</div>
      <div class="styPartDesc" style="width:43mm;">Statement of Functional Expenses</div>
      <div class="styGenericDiv" style="width:129mm;">
        <span style="font-size: 7pt">
          All organizations must complete column (A). Columns (B), (C), and (D) are required for section 501(c)(3)
          and (4) organizations and section 4947(a)(1) nonexempt charitable trusts but optional for others.
          (See the instructions.)
        </span>
      </div>
    </div>
    <!-- END Part II Title -->
    <!-- Begin Part II Table-->
    <table class="styTable" style="font-size:7pt;width:187mm;" cellspacing="0">
      <thead>
        <tr scope="col">
          <th scope="col" colspan="2" align="center" style="width:77mm;height:9mm;padding-top:0mm; border-bottom:1 solid black">
            <span class="styItalicText" style="font-weight:normal;">
              Do not include amounts reported on line <br/>
              6b, 8b, 9b, 10b, or 16 of Part I.
            </span>
          </th>
          <th class="styShadingCell" style="width:6mm;border-left:1 solid black; border-bottom:1 solid black">
              <span style="width:1px;"></span>
          </th>
          <th scope="col" align="center" style="width:26mm;font-size:6pt;border-left:1 solid black; border-bottom:1 solid black">
            (A) Total
          </th>
          <th scope="col" align="center" style="width:26mm;font-size:6pt;border-left:1 solid black; border-bottom:1 solid black">
            (B)<span class="styNormalText"> Program<br/>services</span>
          </th>
          <th scope="col" align="center" style="width:26mm;font-size:6pt;border-left:1 solid black; border-bottom:1 solid black">
            (C)<span class="styNormalText"> Management<br/>and general</span>
          </th>
          <th scope="col" align="center" style="width:26mm;font-size:6pt;border-left:1 solid black; border-bottom:1 solid black">
            (D)<span class="styNormalText"> Fundraising</span>
          </th>
        </tr>
      </thead>
      <tfoot></tfoot>
  <tbody valign="top">
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:9mm;">22</td>
      <td class="styLNDesc" style="float:left;width:69mm;height:4.5mm;" >
          Grants and allocations (attach schedule) 
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/GrantsAndAllocationsPaid"/>
        </xsl:call-template>
        <br/>
        (cash $<span class="styFixedUnderline" style="float:none;width:20mm;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsAndAllocationsPaid/@cash" /></xsl:call-template></span>
        noncash $<span class="styFixedUnderline" style="float:none;width:20mm;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsAndAllocationsPaid/@noncash" /></xsl:call-template></span> )
        <br />
        <span style="font-size:6pt;padding-right:2mm;">If this amount includes foreign grants, check here</span>
      <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      <span style="width:2mm;"></span>
      <input type="checkbox" class="styCkbox" name="Checkbox">
        <xsl:call-template name="PopulateCheckbox">
          <xsl:with-param name="TargetNode" select="$Form990Data/GrantsAndAllocationsPaid/@includesForeignGrants" />
          <xsl:with-param name="BackupName">IRS990ForeignGrants</xsl:with-param>
        </xsl:call-template>
      </input>
      <label>
        <xsl:call-template name="PopulateLabel">
          <xsl:with-param name="TargetNode" select="$Form990Data/GrantsAndAllocationsPaid/@includesForeignGrants" />
          <xsl:with-param name="BackupName">IRS990ForeignGrants</xsl:with-param>
        </xsl:call-template>
      </label>        
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:9mm;padding-top:5mm;">22</td>
      <td class="styLNAmountBoxSmall" style="width:26mm;height:9mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsAndAllocationsPaid/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="width:26mm;height:9mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsAndAllocationsPaid/ProgramServices" /></xsl:call-template></td>
      <td class="styShadingCell" style="width:26mm;height:9mm;"><span style="width:1px"/></td>
      <td class="styShadingCell" style="width:26mm;height:9mm;"><span style="width:1px"/></td>
    </tr>

    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">23</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        <span class="stySmallText">
          Specific assistance to individuals (attach schedule)
        </span>
        <span style="width:1px"></span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/SpecificAssistanceIndividuals"/>
        </xsl:call-template>
      </td>      
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">23</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SpecificAssistanceIndividuals/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SpecificAssistanceIndividuals/ProgramServices" /></xsl:call-template></td>
      <td class="styShadingCell" style="width:26mm;height:4.5mm;"><span style="width:1px"/></td>
      <td class="styShadingCell" style="width:26mm;height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">24</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        <span class="stySmallText">
          Benefits paid to or for members (attach schedule)
        </span>
        <span style="width:1px"></span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/BenefitsPaidToOrForMembers"/>
        </xsl:call-template>
      </td>      
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">24</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/BenefitsPaidToOrForMembers/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/BenefitsPaidToOrForMembers/ProgramServices" /></xsl:call-template></td>
      <td class="styShadingCell" style="width:26mm;height:4.5mm; border-bottom:1 solid black"><span style="width:1px"/></td>
      <td class="styShadingCell" style="width:26mm;height:4.5mm; border-bottom:1 solid black"><span style="width:1px"/></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">25</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Compensation of officers, directors, etc.
        <span style="width:1px"></span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/CompensationOfficersDirectors"/>
        </xsl:call-template>
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">25</td>
      <td class="styLNAmountBoxSmall" style="width:26mm;height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CompensationOfficersDirectors/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="width:26mm;height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CompensationOfficersDirectors/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="width:26mm;height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CompensationOfficersDirectors/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="width:26mm;height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CompensationOfficersDirectors/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">26</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Other salaries and wages
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">26</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherSalariesAndWages/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherSalariesAndWages/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherSalariesAndWages/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherSalariesAndWages/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">27</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Pension plan contributions
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">......</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">27</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PensionPlanContributions/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PensionPlanContributions/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PensionPlanContributions/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PensionPlanContributions/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">28</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Other employee benefits
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">28</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherEmployeeBenefits/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherEmployeeBenefits/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherEmployeeBenefits/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherEmployeeBenefits/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">29</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Payroll taxes
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">29</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PayrollTaxes/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PayrollTaxes/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PayrollTaxes/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PayrollTaxes/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">30</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Professional fundraising fees
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">......</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">30</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ProfessionalFundraisingFees/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ProfessionalFundraisingFees/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ProfessionalFundraisingFees/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ProfessionalFundraisingFees/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">31</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Accounting fees
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">31</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountingFees/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountingFees/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountingFees/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountingFees/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">32</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Legal fees
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">32</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LegalFees/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LegalFees/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LegalFees/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LegalFees/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">33</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Supplies
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">33</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Supplies/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Supplies/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Supplies/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Supplies/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">34</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Telephone
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">34</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Telephone/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Telephone/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Telephone/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Telephone/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">35</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Postage and shipping
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">35</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PostageAndShipping/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PostageAndShipping/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PostageAndShipping/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PostageAndShipping/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">36</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Occupancy
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">36</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Occupancy/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Occupancy/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Occupancy/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Occupancy/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">37</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Equipment rental and maintenance
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">....</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">37</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/EquipmentRentalAndMaintenance/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/EquipmentRentalAndMaintenance/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/EquipmentRentalAndMaintenance/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/EquipmentRentalAndMaintenance/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">38</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Printing and publications
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">38</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PrintingAndPublication/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PrintingAndPublication/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PrintingAndPublication/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PrintingAndPublication/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">39</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Travel
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">............</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">39</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Travel/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Travel/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Travel/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Travel/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">40</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Conferences, conventions, and meetings
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">40</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ConferencesConventionsMeetings/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ConferencesConventionsMeetings/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ConferencesConventionsMeetings/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ConferencesConventionsMeetings/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">41</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Interest
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...........</span>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">41</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Interest/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Interest/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Interest/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Interest/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">42</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Depreciation, depletion, etc. (attach schedule)
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/DepreciationDepletionEtc"/>
        </xsl:call-template>
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">42</td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DepreciationDepletionEtc/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DepreciationDepletionEtc/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DepreciationDepletionEtc/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DepreciationDepletionEtc/Fundraising" /></xsl:call-template></td>
    </tr>
    <tr>
      <td class="styLNLeftNumBox" style="width:6mm;height:4.5mm;">43</td>
      <td class="styLNDesc" style="width:69mm;height:4.5mm;">
        Other expenses not covered above (itemize):
      </td>
      <td class="styLNRightNumBoxNBB" style="width:6mm;height:4.5mm;"><span style="width:1px"/></td>
      <td class="styLNAmountBoxSmallNBB" style="height:4.5mm;"><span style="width:1px"/></td>
      <td class="styLNAmountBoxSmallNBB" style="height:4.5mm;"><span style="width:1px"/></td>
      <td class="styLNAmountBoxSmallNBB" style="height:4.5mm;"><span style="width:1px"/></td>
      <td class="styLNAmountBoxSmallNBB" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>

    <xsl:for-each select="$Form990Data/OtherExpenses">
              <xsl:if test="($Print != $Separated) or (count($Form990Data/OtherExpenses) &lt;= 7) "> 
      <xsl:choose>
        <xsl:when test="position() = 1">
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">a</span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43a</td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:when>
        <xsl:when test="position() = 2">
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">b</span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43b</td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:when>
        <xsl:when test="position() = 3">
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">c</span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43c</td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:when>
        <xsl:when test="position() = 4">
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">d</span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43d</td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:when>
        <xsl:when test="position() = 5">
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">e</span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43e</td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:when>
        <xsl:when test="position() = 6">
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">f</span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43f</td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:when>
        <xsl:when test="position() = 7">
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">g</span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43g</td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:when>
        <xsl:otherwise>
    <tr>
            <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText"><xsl:number value="position()" format="a"/></span></td>
            <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43<xsl:number value="position()" format="a"/></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styLNAmountBoxSmall" style="height:4.5mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
    </xsl:for-each>    
    <xsl:if test="count($Form990Data/OtherExpenses) &lt; 1 or ((count($Form990Data/OtherExpenses) &gt; 7) and ($Print = $Separated))">
    <tr>
        <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">a</span></td>
        <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;">                  
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/OtherExpenses"/>                      
                  </xsl:call-template>
            <span style="width:6px;"></span></td>
        <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43a</td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form990Data/OtherExpenses) &lt; 2 or ((count($Form990Data/OtherExpenses) &gt; 7) and ($Print = $Separated))">
    <tr>
        <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">b</span></td>
        <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><span style="width:6px;"></span></td>
        <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43b</td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form990Data/OtherExpenses) &lt; 3 or ((count($Form990Data/OtherExpenses) &gt; 7) and ($Print = $Separated))">
    <tr>
        <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">c</span></td>
        <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><span style="width:6px;"></span></td>
        <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43c</td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form990Data/OtherExpenses) &lt; 4 or ((count($Form990Data/OtherExpenses) &gt; 7) and ($Print = $Separated))">
    <tr>
        <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">d</span></td>
        <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><span style="width:6px;"></span></td>
        <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43d</td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form990Data/OtherExpenses) &lt; 5 or ((count($Form990Data/OtherExpenses) &gt; 7) and ($Print = $Separated))">
    <tr>
        <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">e</span></td>
        <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><span style="width:6px;"></span></td>
        <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43e</td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form990Data/OtherExpenses) &lt; 6 or ((count($Form990Data/OtherExpenses) &gt; 7) and ($Print = $Separated))">
    <tr>
        <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">f</span></td>
        <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><span style="width:6px;"></span></td>
        <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43f</td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="count($Form990Data/OtherExpenses) &lt; 7 or ((count($Form990Data/OtherExpenses) &gt; 7) and ($Print = $Separated))">
    <tr>
        <td class="styLNLeftLtrBoxDD" style="width:3mm;height:4.5mm;"><span class="styBoldText">g</span></td>
        <td class="styIRS990LNAmountBoxNLB" style="width:69mm;height:4.5mm;text-align:left;"><span style="width:6px;"></span></td>
        <td class="styLNRightNumBox" style="width:6mm;height:4.5mm;">43g</td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
        <td class="styLNAmountBoxSmall" style="height:4.5mm;"><span style="width:1px"/></td>
    </tr>
    </xsl:if>
    <tr>
      <td class="styLNLeftNumBoxBB" style="width:6mm;height:9mm;">44</td>
      <td class="styIRS990LNDescBB" style="width:69mm;height:9mm;font-size:6pt;padding-bottom:0;">
        <span class="styBoldText">Total functional expenses.</span> Add lines 22 through 43. (Organizations completing columns (B)-(D), carry these totals to lines 13–15)
      </td>
      <td class="styLNRightNumBox" style="width:6mm;height:9mm;padding-top:5mm;">44</td>
      <td class="styLNAmountBoxSmall" style="height:9mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalFunctionalExpenses/Total" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:9mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalFunctionalExpenses/ProgramServices" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:9mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalFunctionalExpenses/ManagementAndGeneral" /></xsl:call-template></td>
      <td class="styLNAmountBoxSmall" style="height:9mm;vertical-align:bottom;padding-right:0.75mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalFunctionalExpenses/Fundraising" /></xsl:call-template></td>

    </tr>
      </tbody>
    </table>
    <!-- End Part II Table-->

    <div style="width:187mm">
      <span class="styBoldText">Joint Costs.</span> Check
      <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      <span style="width:2mm;"></span>
      <input type="checkbox" class="styCkbox" name="Checkbox">
        <xsl:call-template name="PopulateCheckbox">
          <xsl:with-param name="TargetNode" select="$Form990Data/JointCosts" />
          <xsl:with-param name="BackupName">IRS990JointCosts</xsl:with-param>
        </xsl:call-template>
      </input>
      <label>
        <xsl:call-template name="PopulateLabel">
          <xsl:with-param name="TargetNode" select="$Form990Data/JointCosts" />
          <xsl:with-param name="BackupName">IRS990JointCosts</xsl:with-param>
        </xsl:call-template>
        if you are following SOP 98-2.
      </label>
    </div>
    <div style="width:187mm">
      Are any joint costs from a combined educational campaign and fundraising solicitation reported in
      <span class="styBoldText">(B)</span> Program services?
      <span style="width:4mm"></span>
      <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      <span style="height:3.5mm;padding-left:2mm">
        <xsl:call-template name="PopulateSpan">
          <xsl:with-param name="TargetNode" select="$Form990Data/JointCostsRptInProgramService" />
        </xsl:call-template>
        <input type="checkbox" class="styCkbox" name="Checkbox">
          <xsl:call-template name="PopulateYesCheckbox">
            <xsl:with-param name="TargetNode" select="$Form990Data/JointCostsRptInProgramService" />
            <xsl:with-param name="BackupName">IRS990JointCostsRptInProgramServiceYes</xsl:with-param>
          </xsl:call-template>
        </input>
      </span>
      <span class="styBoldText">
        <label>
          <xsl:call-template name="PopulateLabelYes">
            <xsl:with-param name="TargetNode" select="$Form990Data/JointCostsRptInProgramService" />
            <xsl:with-param name="BackupName">IRS990JointCostsRptInProgramServiceYes</xsl:with-param>
          </xsl:call-template>
          Yes
        </label>
      </span>
      <span style="height:3.5mm;padding-left:1.5mm">
        <xsl:call-template name="PopulateSpan">
          <xsl:with-param name="TargetNode" select="$Form990Data/JointCostsRptInProgramService" />
        </xsl:call-template>
        <input type="checkbox" class="styCkbox" name="Checkbox">
          <xsl:call-template name="PopulateNoCheckbox">
            <xsl:with-param name="TargetNode" select="$Form990Data/JointCostsRptInProgramService" />
            <xsl:with-param name="BackupName">IRS990JointCostsRptInProgramServiceNo</xsl:with-param>
          </xsl:call-template>
        </input>
      </span>
      <span class="styBoldText">
        <label>
          <xsl:call-template name="PopulateLabelNo">
            <xsl:with-param name="TargetNode" select="$Form990Data/JointCostsRptInProgramService" />
            <xsl:with-param name="BackupName">IRS990JointCostsRptInProgramServiceNo</xsl:with-param>
          </xsl:call-template>
          No
        </label>
      </span>
    </div>
    <div class="styBB" style="width:187mm;clear:both;padding-bottom:1mm">
      If "Yes," enter <span class="styBoldText">(i)</span> the aggregate amount of these joint costs
      $<span class="styFixedUnderline" style="float:none;width:19.5mm;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AggregateAmountOfJointCosts" /></xsl:call-template></span>;
      <span class="styBoldText">(ii)</span> the amount allocated to Program services
      $<span class="styFixedUnderline" style="float:none;width:19.5mm;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AmountAllocatedToProgramSrvc" /></xsl:call-template></span>;
      <span class="styBoldText">(iii)</span> the amount allocated to Management and general 
      $<span style="float:none;width:19.5mm;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AmountAllocatedToManagementGen" /></xsl:call-template></span>; and
      <span class="styBoldText">(iv)</span> the amount allocated to Fundraising
      $<span style="float:none;width:19.5mm;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AmountAllocatedToFundraising" /></xsl:call-template></span>
    </div>
    <!-- End Part II-->

    <!-- Footer -->
    <div style="width:187mm;float:none;clear:both;padding-top:.5mm;" class="pageend">
      <div class="styGenericDiv" style="width:105mm;"></div>
      <div class="styGenericDiv" style="width:25mm;"></div>
      <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
    </div>
      
    <!-- header -->
    <div style="width:187mm;clear:both;padding-bottom:.5mm;float:none;clear:both;" class="styBB">
      <div style="width:90mm;" class="styGenericDiv">Form 990 (2005)</div>
      <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
      <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">3</span></div>
    </div>

    <!-- BEGIN Part III Title -->
    <div class="styBB" style="width:187mm;float:none;">
      <div class="styPartName">Part III</div>
      <div class="styPartDesc" style="width:158mm">
        Statement of Program Service Accomplishments
        <span class="styNormalText">(See the instructions.)</span>
      </div>
    </div>
    <div class="styBB" style="width:187mm;float:none;">
Form 990 is available for public inspection and, for some people, serves as the primary or sole source of information about a
particular organization. How the public perceives an organization in such cases may be determined by the information presented
on its return. Therefore, please make sure the return is complete and accurate and fully describes, in Part III, the organization’s
programs and accomplishments.
      <div class="styGenericDiv" style="float:right">
         <!-- button display logic -->
          <xsl:call-template name="SetDynamicTableToggleButton">
          <xsl:with-param name="TargetNode" select="$Form990Data/ProgramServiceAccomplishments"/>
                    <xsl:with-param name="containerHeight" select="4"/>
          <xsl:with-param name="containerID" select=" 'PSActn' "/>
          </xsl:call-template>
         <!-- end button display logic -->
      </div>
    </div>    
    <!-- END Part III Title -->

    <!-- BEGIN Part III Table -->
    <div class="styTableContainer" id="PSActn" style="height:60mm;">
      <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>
      <!-- end -->
      <table class="styTable" cellspacing="0" style="font-size:7pt;">
      <!-- Removed the thead class as it is causing the PrimaryExemptPurpose explanation to repeat on every page and there is no other way keep it separate and have the class and not cause the display problems with the table --> 
        <!--thead class="styTableThead"-->
          <tr style="border-color: black; border-style: solid;">
            <th class="styTableCellHeader" scope="col" colspan="2" style="width:154.5mm;height:20mm;text-align:left;">
                <span class="styNormalText" style="vertical-align:top">
              What is the organization's primary exempt purpose?
              <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
              </span>
              <span style="width:1mm"></span>
              <span class="styFixedUnderline" style="float:none;width:71mm;font-weight:normal"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/PrimaryExemptPurpose" /></xsl:call-template></span> <br/>
              <span class="stySmallText">
                <span class="styNormalText">
                  All organizations must describe their exempt purpose achievements in a clear and concise manner. State the number
                  of clients served, publications issued, etc. Discuss achievements that are not measurable. (Section 501(c)(3) and (4)
                  organizations and 4947(a)(1) nonexempt charitable trusts must also enter the amount of grants and allocations to others.)
                </span>
              </span>
            </th>
            <th class="styTableCellHeader" scope="col" style="width:32mm;height:20mm; border-right-width:0px">
              Program Service Expenses<br/>
              <span class="stySmallText" style="text-align:center">
                <span class="styNormalText">
                  (Required for 501(c)(3) and (4) orgs., and 4947(a)(1) trusts; but optional for others.)
                </span>
              </span>
            </th>
          </tr>
        <!--/thead-->
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/ProgramServiceAccomplishments">
           <xsl:if test="($Print != $Separated) or (count($Form990Data/ProgramServiceAccomplishments) &lt;= 4) "> 
            <tr style="border-color: black; border-style: solid;">
              <xsl:choose>
                <xsl:when test="position() = 1">
                  <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText">a</span></td>
                </xsl:when>
                <xsl:when test="position() = 2">
                  <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText">b</span></td>
                </xsl:when>
                <xsl:when test="position() = 3">
                  <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText">c</span></td>
                </xsl:when>
                <xsl:when test="position() = 4">
                  <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText">d</span></td>
                </xsl:when>
                <xsl:otherwise>
                  <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText"></span></td>
                </xsl:otherwise>
              </xsl:choose>
              <td class="styTableCell" style="width:149.5mm;text-align:left;height: 15mm" valign="top">
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="DescriptionProgramServiceAccom" /></xsl:call-template><span class="styTableCellPad"></span><br/>
                <span style="margin-top: 7mm;width:70mm;">(Grants and allocations $ <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="GrantsAndAllocations" /></xsl:call-template>) </span>
                <span>If this amount includes foreign grants, check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                  <input type="checkbox" class="styCkbox" name="Checkbox">
                    <xsl:call-template name="PopulateCheckbox">
                      <xsl:with-param name="TargetNode" select="GrantsAndAllocations/@includesForeignGrants" />
                      <xsl:with-param name="BackupName">IRS990ForeignGrants</xsl:with-param>
                    </xsl:call-template>
                  </input>
                  <label>
                    <xsl:call-template name="PopulateLabel">
                      <xsl:with-param name="TargetNode" select="GrantsAndAllocations/@includesForeignGrants" />
                      <xsl:with-param name="BackupName">IRS990ForeignGrants</xsl:with-param>
                    </xsl:call-template>
                  </label>                                   
                </span>
              </td>
              <td class="styTableCell" style="border-right-width:0px" valign="bottom"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServiceExpenses" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          </xsl:for-each>
          <xsl:if test="count($Form990Data/ProgramServiceAccomplishments) &lt; 1 or ((count($Form990Data/ProgramServiceAccomplishments) &gt; 4) and ($Print = $Separated))">
            <tr style="border-color: black; border-style: solid;">
              <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText">a</span></td>
              <td class="styTableCell" style="width:149.5mm;text-align:left;height: 12mm" valign="top">
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px">
                  <xsl:if test="((count($Form990Data/ProgramServiceAccomplishments) &gt; 4) and ($Print = $Separated))">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/ProgramServiceAccomplishments" />
                  </xsl:call-template>
                  </xsl:if>
                  <span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width:70mm;">(Grants and allocations $ <span style="width:30mm;" />) </span>
                <span>If this amount includes foreign grants, check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                <input type="checkbox" class="styCkbox" name="Checkbox" id="empty"></input>
                <label for="empty"></label>                    
                </span>
              </td>
              <td class="styTableCell" style="border-right-width:0px" valign="top"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/ProgramServiceAccomplishments) &lt; 2 or ((count($Form990Data/ProgramServiceAccomplishments) &gt; 4) and ($Print = $Separated))">
            <tr style="border-color: black; border-style: solid;">
              <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText">b</span></td>
              <td class="styTableCell" style="width:149.5mm;text-align:left;height: 12mm" valign="top">
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width:70mm;">(Grants and allocations $ <span style="width:30mm;" />) </span>
                <span>If this amount includes foreign grants, check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                <input type="checkbox" class="styCkbox" name="Checkbox" id="empty"></input>
                <label for="empty"></label>                  
                </span>
              </td>
              <td class="styTableCell" style="border-right-width:0px" valign="top"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/ProgramServiceAccomplishments) &lt; 3 or ((count($Form990Data/ProgramServiceAccomplishments) &gt; 4) and ($Print = $Separated))">
            <tr style="border-color: black; border-style: solid;">
              <td class="styGenericDiv" style="width:5mm;text-align:center;height: 12mm" valign="top"><span class="styBoldText">c</span></td>
              <td class="styTableCell" style="width:149.5mm;text-align:left;" valign="top">
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width:70mm;">(Grants and allocations $ <span style="width:30mm;" />) </span>
                <span>If this amount includes foreign grants, check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                <input type="checkbox" class="styCkbox" name="Checkbox" id="empty"></input>
                <label for="empty"></label>                  
                </span>
              </td>
              <td class="styTableCell" style="border-right-width:0px" valign="top"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/ProgramServiceAccomplishments) &lt; 4 or ((count($Form990Data/ProgramServiceAccomplishments) &gt; 4) and ($Print = $Separated))">
            <tr style="border-color: black; border-style: solid;">
              <td class="styGenericDiv" style="width:5mm;text-align:center;height: 12mm" valign="top"><span class="styBoldText">d</span></td>
              <td class="styTableCell" style="width:149.5mm;text-align:left;" valign="top">
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width: 148mm; border-style:solid; border-color:black; border-left-width:0px; border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px"><span class="styTableCellPad"></span></span><br/>
                <span style="width:70mm;">(Grants and allocations $ <span style="width:30mm;" />) </span>
                <span>If this amount includes foreign grants, check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                <input type="checkbox" class="styCkbox" name="Checkbox" id="empty"></input>
                <label for="empty"></label>                   
                </span>
              </td>
              <td class="styTableCell" style="border-right-width:0px"  valign="top"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <tr style="border-color: black; border-style: solid;">
            <td class="styGenericDiv" style="width:5mm;text-align:center;" valign="top"><span class="styBoldText">e</span></td>
            <td class="styTableCell" style="width:149.5mm;text-align:left;">
              Other program services (attach schedule)<br />
                <span style="width:70mm;">(Grants and allocations $ <span style="width:30mm;" />) </span>
                <span>If this amount includes foreign grants, check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                <input type="checkbox" class="styCkbox" name="Checkbox" id="empty"></input>
                <label for="empty"></label>                    
                </span>
            </td>
            <td class="styTableCell" style="border-right-width:0px" valign="bottom"><span class="styTableCellPad"></span></td>
          </tr>
          <tr style="border-color: black; border-style: solid;border-bottom-width: 0px">
            <td class="styGenericDiv" style="width:5mm;text-align:center;border-bottom-width: 0px" valign="top"><span class="styBoldText">f</span></td>
            <td class="styTableCell" style="width:149.5mm;text-align:left;border-right-width:0px;border-bottom-width: 0px">
              <span class="styBoldText">Total of Program Service Expenses</span>
              (should equal line 44, column (B), Program services)
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm; margin-right:1mm">....</span>
              <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            </td>
            <td class="styTableCell" style="border-right-width:0px;border-bottom-width: 0px" valign="bottom"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalProgramServicesExpenses" /></xsl:call-template><span class="styTableCellPad"></span></td>

          </tr>
        </tbody>
      </table>
    </div>
    <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form990Data/ProgramServiceAccomplishments"/>
      <xsl:with-param name="containerHeight" select="4"/>
      <xsl:with-param name="containerID" select=" 'PSActn' "/>
    </xsl:call-template>
    <!-- END Part III Table -->

    <!-- Footer -->
    <div style="width:187mm;float:none;clear:both;padding-top:.5mm;" class="pageend">
      <div class="styGenericDiv" style="width:105mm;"></div>
      <div class="styGenericDiv" style="width:25mm;"></div>
      <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
    </div>
      
    <!-- header -->
    <div style="width:187mm;clear:both;padding-bottom:.5mm;float:none;clear:both;" class="styBB">
      <div style="width:90mm;" class="styGenericDiv">Form 990 (2005)</div>
      <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
      <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">4</span></div>
    </div>

    <!-- Begin Part IV Table-->

    <table class="styTable" style="font-size:7pt;width:187mm;" cellspacing="0">
      <thead>
        <tr scope="col">
          <th class="styBB" colspan="8" style="padding-top:1.5mm;padding-bottom:1.5mm;">
            <span class="styPartName">Part IV</span>
            <span class="styPartDesc" style="width:158mm;">
              Balance Sheets <span class="styNormalText">(See the instructions.)</span>
            </span>
          </th>
        </tr>
        <tr scope="col">
          <th colspan="2" class="styBB" style="padding-bottom:3mm;width:13mm;">Note:</th>
          <th colspan="3" class="styBB" style="width:100mm;">
            <span class="styItalicText" style="font-weight:normal;">
              Where required, attached schedules and amounts within the description<br/>
              column should be for end-of-year amounts only.
            </span>
          </th>          
          <th scope="col" align="center" style="font-weight:normal; border-left:1 solid black; border-bottom:1 solid black">
            <b>(A)</b><br/>Beginning of year
          </th>
          <th scope="col" class="styLNRightNumBox"><span style="width:1px;"></span></th>          
          <th scope="col" align="center" style="font-weight:normal; border-left:1 solid black; border-bottom:1 solid black">
            <b>(B)</b><br/>End of year
          </th>
        </tr>
      </thead>
      <tfoot></tfoot>
      <tbody valign="top">
        <!-- Begin Part IV Assets Section -->
        <tr>
          <td class="styIRS990VTImageBox" rowspan="25" valign="middle"><img src="{$ImagePath}/990_Assets.gif" alt="Assets"/></td>
          <td class="styLNLeftNumBox" style="height:4.5mm;">45</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Cash&#151;non-interest-bearing
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CashNonInterestBearing/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">45</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CashNonInterestBearing/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">46</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Savings and temporary cash investments
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SavingsAndTempCashInvestments/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">46</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SavingsAndTempCashInvestments/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNDesc" style="width:110mm;height:4.5mm;" colspan="4"><span style="width:32mm;"></span></td>
          <td class="styLNAmountBoxNBB" style="width:32mm;height:4.5mm;"><span style="width:32mm;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:8mm;"></span></td>
          <td class="styLNAmountBoxNBB" style="width:32mm;height:4.5mm;"><span style="width:32mm;"></span></td>
        </tr>
        <tr style="width:187mm;">
          <td class="styLNLeftNumBox" style="height:4.5mm;">47a</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">Accounts receivable
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.....</span>
          </td>
          <td class="styLNRightNumBox" style="height:4.5mm;">47a</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountsReceivable" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>b</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">Less: allowance for doubtful accounts</td>
          <td class="styLNRightNumBox" style="height:4.5mm;">47b</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ArAllowanceDoubtfulAccounts" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountsReceivableNet/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">47c</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountsReceivableNet/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="height:4.5mm;width:8mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr style="width:187mm;">
          <td class="styLNLeftNumBox" style="height:4.5mm;">48a</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">Pledges receivable
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">......</span>
          </td>
          <td class="styLNRightNumBox" style="height:4.5mm;">48a</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PledgesReceivable" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>b</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">Less: allowance for doubtful accounts</td>
          <td class="styLNRightNumBox" style="height:4.5mm;">48b</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PledgesRcvblAllowanceDbtflAcct" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PledgesReceivableNet/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">48c</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PledgesReceivableNet/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">49</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Grants receivable
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsReceivable/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">49</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsReceivable/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">50</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">
            Receivables from officers, directors, trustees, and key employees (attach schedule)
            <span style="width:2px;"></span>
            
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ReceivablesFromOfficersEtc/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;vertical-align:bottom;">50</td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';">
          <span style="float: left; clear:none">
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/ReceivablesFromOfficersEtc/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ReceivablesFromOfficersEtc/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">51a</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;vertical-align:middle;" rowspan="2">
            Other notes and loans receivable (attach schedule)
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
          </td>
          <td class="styLNDesc" style="width:40mm;height:4.5mm;" colspan="2"></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:18px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">51a</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherNotesAndLoansReceivable" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>b</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">
            Less: allowance for doubtful accounts
            <span style="width:2px;"></span> </td>
          <td class="styLNRightNumBox" style="height:4.5mm;">51b</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherRcvblAllowanceDbtflAcct" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherNotesLoansReceivableNet/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">51c</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';vertical-align:bottom;font-family:'Arial';">
          <span style="float:left; clear:none">
             <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/OtherNotesLoansReceivableNet/EOY"/>
            </xsl:call-template>
          </span><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherNotesLoansReceivableNet/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">52</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Inventories for sale or use
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InventoriesForSaleOrUse/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">52</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InventoriesForSaleOrUse/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">53</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Prepaid expenses and deferred charges
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.........</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PrepaidExpensesDeferredCharges/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">53</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PrepaidExpensesDeferredCharges/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">54</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Investments&#151;securities (attach schedule)
            <span style="width:2px;"></span>
            
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:normal; margin-left:6mm">.</span>
            <span style="width:2mm"></span>
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            <span style="width:3mm"></span>
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsSecuritiesCost" />
                <xsl:with-param name="BackupName">IRS990InvestmentsSecuritiesCost</xsl:with-param>
              </xsl:call-template>
            </input>
            <label>
              <xsl:call-template name="PopulateLabel">
                <xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsSecuritiesCost" />
                <xsl:with-param name="BackupName">IRS990InvestmentsSecuritiesCost</xsl:with-param>
              </xsl:call-template>
              Cost
            </label>
            <span style="width:6px"></span>
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsSecuritiesFMV" />
                <xsl:with-param name="BackupName">IRS990InvestmentsSecuritiesFMV</xsl:with-param>
              </xsl:call-template>
            </input>
            <label>
              <xsl:call-template name="PopulateLabel">
                <xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsSecuritiesFMV" />
                <xsl:with-param name="BackupName">IRS990InvestmentsSecuritiesFMV</xsl:with-param>
              </xsl:call-template>
              FMV
            </label>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsSecurities/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">54</td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';">
          <span style="float: left; clear: none">
          <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsSecurities/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsSecurities/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>

        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">55a</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;vertical-align:middle;" rowspan="2">
            Investments&#151;land, buildings, and equipment: basis
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">......</span>
          </td>
          <td class="styLNDesc" style="width:40mm;height:4.5mm;" colspan="2"></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">55a</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvstInLandBuildingsEtcBasis" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>b</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">Less: accumulated depreciation (attach schedule)
            <span style="width:2px;"></span>
            
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
          </td>
          <td class="styLNRightNumBox" style="height:4.5mm;padding-top:3mm;">55b</td>
          <td class="styLNAmountBox" style="height:4.5mm;padding-top:3mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvstLandEtcAccumDeprec" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvstLandBuildingsEtcNet/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;vertical-align:bottom;">55c</td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';">
          <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/InvstLandBuildingsEtcNet/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvstLandBuildingsEtcNet/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">56</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">
            Investments&#151;other (attach schedule)
            <span style="width:2px;"></span>
            
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsOther/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">56</td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';">
          <span style="float:left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsOther/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InvestmentsOther/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">57a</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">Land, buildings, and equipment:basis</td>
          <td class="styLNRightNumBox" style="height:4.5mm;">57a</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LandBuildingsEquipmentBasis" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>b</td>
          <td class="styLNDesc" style="width:55mm;height:4.5mm;">Less: accumulated depreciation (attach schedule)
            <span style="width:2px;"></span>
                     
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
          </td>
          <td class="styLNRightNumBox" style="height:4.5mm;padding-top:3mm;">57b</td>
          <td class="styLNAmountBox" style="height:4.5mm;padding-top:3mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LandBldgEquipmentAccumDeprec" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LandBuildingsEquipmentBasisNet/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;vertical-align:bottom;">57c</td>
          <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;font-family:'Arial';">
          <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/LandBuildingsEquipmentBasisNet/EOY"/>
            </xsl:call-template></span> 
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LandBuildingsEquipmentBasisNet/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        
        <!-- Revise Part IV - Line 58 to show form and data correctly and accommodate Jaws reading -->          
        <!-- Tanuja : In reference to defect number 2638, seperator has been changed to <br/> from a comma -->
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">58</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">
            <div style="width:36mm;float:left;"> Other assets            
            (describe <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/></div>
            <div style="width:57mm;float:right;clear:none;">
              <xsl:if test="not($Form990Data/OtherAssetsTotal) or ($Form990Data/OtherAssetsTotal= '')">
                <span style="border-bottom:1 solid black; width:55mm;" /><span style="width:2mm;"></span>
              </xsl:if>
              <xsl:if test="$Form990Data/OtherAssetsTotal">
              <xsl:for-each select="$Form990Data/OtherAssetsTotal">
                      <xsl:choose>
                        <xsl:when test="((position() = 1) and (position() = last()))">
                     <span style="border-bottom:1 solid black; width:57mm">
                       <xsl:call-template name="PopulateText">        
                        <xsl:with-param name="TargetNode" select="Description" />                  
                      </xsl:call-template> 
                      <span style="width:3px;"></span>             
                      <xsl:call-template name="PopulateAmount">                      
                        <xsl:with-param name="TargetNode" select="Amount" />
                      </xsl:call-template>
                       <span style="width:5mm;"> </span>
                    </span>
                  </xsl:when>
                  <xsl:when test="position() = 1">
                     <span style="border-bottom:1 solid black; width:57mm">
                       <xsl:call-template name="PopulateText">        
                        <xsl:with-param name="TargetNode" select="Description" />                  
                      </xsl:call-template> 
                      <span style="width:3px;"></span>             
                      <xsl:call-template name="PopulateAmount">                      
                        <xsl:with-param name="TargetNode" select="Amount" />
                      </xsl:call-template>
                    </span>
                  </xsl:when>
                  <xsl:otherwise>
                    <span class="styBB" style="width:57mm;">
                      <xsl:call-template name="PopulateText">        
                        <xsl:with-param name="TargetNode" select="Description" />                  
                      </xsl:call-template> 
                      <span style="width:3px;"></span>             
                      <xsl:call-template name="PopulateAmount">                      
                        <xsl:with-param name="TargetNode" select="Amount" />
                      </xsl:call-template>
                      <xsl:choose>
                        <xsl:when test="position() = last()">
                          <span style="width:5mm;"> </span>
                        </xsl:when>
                        <xsl:otherwise>
                          <br/>
                        </xsl:otherwise>
                      </xsl:choose>
                    </span>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:for-each></xsl:if>)
            </div>
          </td>
          <td class="styLNAmountBox" valign="bottom" style="font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherAssetsTotal/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" valign="bottom">58</td> <!-- Middle number box -->
          <td class="styLNAmountBox" valign="bottom" style="font-family:'Arial';">
          <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/OtherAssetsTotal/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherAssetsTotal/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3"></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNRightNumBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBoxBB" style="height:4.5mm;">59</td>
          <td class="styIRS990LNDescBB" style="width:95mm;height:4.5mm;" colspan="3">
            <span class="styBoldText">Total assets</span> (must equal line 74). Add lines 45 through 58.
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalAssets/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">59</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalAssets/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <!-- End Part IV Assets Section -->

        <!-- Begin Part IV Liabilities Section -->
        <tr>
          <td class="styIRS990VTImageBox" rowspan="10" valign="middle"><img src="{$ImagePath}/990_Liabilities.gif" alt="Liabilities"/></td>
          <td class="styLNLeftNumBox" style="height:4.5mm;">60</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Accounts payable and accrued expenses
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountsPayableAccruedExpenses/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">60</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AccountsPayableAccruedExpenses/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">61</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Grants payable
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsPayable/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">61</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrantsPayable/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">62</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Deferred revenue
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DeferredRevenue/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">62</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DeferredRevenue/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">63</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">
            Loans from officers, directors, trustees, and key employees (attach
          </td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">schedule)
            <span style="width:2px;"></span>
            
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LoansFromOfficersEtc/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">63</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';">
          <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/LoansFromOfficersEtc/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LoansFromOfficersEtc/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">64a</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Tax-exempt bond liabilities (attach schedule)
            <span style="width:2px;"></span>
            
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">......</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TaxExemptBondLiabilities/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">64a</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';">
          <span style="float: left; clear: none">
              <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/TaxExemptBondLiabilities/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TaxExemptBondLiabilities/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:12px;"></span>b</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">
            Mortgages and other notes payable (attach schedule)
            <span style="width:2px;"></span>
            
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">....</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MortgagesAndNotesPayable/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">64b</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';">
          <span style="float:left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/MortgagesAndNotesPayable/EOY"/>
            </xsl:call-template></span>
            <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MortgagesAndNotesPayable/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>        
        
        <!-- Revise Part IV - Line 65 to show form and data correctly and accommodate Jaws reading -->  
        <!-- Tanuja : In reference to defect number 2638, seperator has been changed to <br/> from a comma -->
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">65</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">
            <div style="width:40mm;float:left;">Other liablilities
            (describe 
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            </div>
            <div style="width:54mm;float:right;clear:none;">
              <xsl:if test="not($Form990Data/OtherLiabilitiesTotal) or ($Form990Data/OtherLiabilitiesTotal= '')">
                <span style="border-bottom:1 solid black; width:55mm;" /><span style="width:2mm;"></span>
              </xsl:if>
              <xsl:if test="$Form990Data/OtherLiabilitiesTotal">
              <xsl:for-each select="$Form990Data/OtherLiabilitiesTotal">
                      <xsl:choose>
                        <xsl:when test="((position() = 1) and (position() = last()))">
                     <span style="border-bottom:1 solid black; width:50mm">
                       <xsl:call-template name="PopulateText">        
                        <xsl:with-param name="TargetNode" select="Description" />                  
                      </xsl:call-template> 
                      <span style="width:3px;"></span>             
                      <xsl:call-template name="PopulateAmount">                      
                        <xsl:with-param name="TargetNode" select="Amount" />
                      </xsl:call-template>
                       <span style="width:5mm;"> </span>
                    </span>
                  </xsl:when>
                        <xsl:when test="position() = 1">
                     <span style="border-bottom:1 solid black; width:50mm">
                       <xsl:call-template name="PopulateText">        
                        <xsl:with-param name="TargetNode" select="Description" />                  
                      </xsl:call-template> 
                      <span style="width:3px;"></span>             
                      <xsl:call-template name="PopulateAmount">                      
                        <xsl:with-param name="TargetNode" select="Amount" />
                      </xsl:call-template>
                    </span>
                  </xsl:when>
                  <xsl:otherwise>
                    <span class="styBB" style="width:50mm;">
                      <xsl:call-template name="PopulateText">        
                        <xsl:with-param name="TargetNode" select="Description" />                  
                      </xsl:call-template> 
                      <span style="width:3px;"></span>             
                      <xsl:call-template name="PopulateAmount">                      
                        <xsl:with-param name="TargetNode" select="Amount" />
                      </xsl:call-template>
                      <xsl:choose>
                        <xsl:when test="position() = last()">
                          <span style="width:5mm;"> </span>
                        </xsl:when>
                        <xsl:otherwise>
                          <br/>
                        </xsl:otherwise>
                      </xsl:choose>
                    </span>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:for-each> </xsl:if>)</div>             
          </td>
          <td class="styLNAmountBox" valign="bottom" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherLiabilitiesTotal/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" valign="bottom" style="height:4.5mm;">65</td>
          <td class="styLNAmountBox" valign="bottom" style="height:4.5mm;font-family:'Arial';">
          <span style="float: left; clear: none">
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form990Data/OtherLiabilitiesTotal/EOY" />
            </xsl:call-template>
          </span>
          
          <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherLiabilitiesTotal/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3"></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNRightNumBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBoxBB" style="height:4.5mm;">66</td>
          <td class="styIRS990LNDescBB" style="width:95mm;height:4.5mm;" colspan="3">
            <span class="styBoldText">Total liabilities</span> Add lines 60 through 65
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">........</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalLiabilities/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">66</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalLiabilities/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <!-- End Part IV Liabilities Section -->
        <!-- Begin Part IV Net Assets Section -->
        <tr>
          <td class="styIRS990VTImageBox" rowspan="12" valign="middle"><img src="{$ImagePath}/990_Balances.gif" alt="Net Assets or Fund Balances"/></td>
          <td class="styLNDesc" style="width:103mm;height:4.5mm;" colspan="4">
            <span style="width:4px;"></span>
            <span class="styBoldText">
              <label>
                <xsl:call-template name="PopulateLabel">
                  <xsl:with-param name="TargetNode" select="$Form990Data/OrgFollowsSFAS117" />
                  <xsl:with-param name="BackupName">IRS990OrgFollowsSFAS117</xsl:with-param>
                </xsl:call-template>
                Organizations that follow SFAS 117, check here
              </label>
            </span>
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            <span style="width:2mm;"></span>
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/OrgFollowsSFAS117" />
                <xsl:with-param name="BackupName">IRS990OrgFollowsSFAS117</xsl:with-param>
              </xsl:call-template>
            </input>
            and complete lines <br/>
            <span style="width:36px;"></span>67 through 69 and lines 73 and 74.
          </td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">67</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Unrestricted
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">................</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/UnrestrictedNetAssets/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">67</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/UnrestrictedNetAssets/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">68</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Temporarily restricted
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TemporarilyRestrictedNetAssets/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">68</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TemporarilyRestrictedNetAssets/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">69</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Permanently restricted
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.............</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PermanentlyRestrictedNetAssets/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">69</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PermanentlyRestrictedNetAssets/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNDesc" style="width:103mm;height:4.5mm;" colspan="4">
            <span style="width:4px;"></span>
            <span class="styBoldText">
              <label>
                <xsl:call-template name="PopulateLabel">
                  <xsl:with-param name="TargetNode" select="$Form990Data/OrgDoesNotFollowSFAS117" />
                  <xsl:with-param name="BackupName">IRS990OrgDoesNotFollowSFAS117</xsl:with-param>
                </xsl:call-template>
                Organizations that do not follow SFAS 117, check here
              </label>
            </span>
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            <span style="width:2mm;"></span>
            <input type="checkbox" class="styCkbox">
              <xsl:call-template name="PopulateCheckbox">
                <xsl:with-param name="TargetNode" select="$Form990Data/OrgDoesNotFollowSFAS117" />
                <xsl:with-param name="BackupName">IRS990OrgDoesNotFollowSFAS117</xsl:with-param>
              </xsl:call-template>
            </input>
            and <br/>
            <span style="width:36px;"></span>complete lines 70 through 74.
          </td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">70</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Capital stock, trust principal, or current funds
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CapitalStockTrustPrincipalEtc/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">70</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/CapitalStockTrustPrincipalEtc/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">71</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">Paid-in or capital surplus, or land, building, and equipment fund
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PaidinOrCapitalSurplusEtc/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">71</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PaidinOrCapitalSurplusEtc/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">72</td>
          <td class="styLNDesc" style="width:101mm;height:4.5mm;" colspan="3">Retained earnings, endowment, accumulated income, or other funds
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/RetainedEarningsEndowmentEtc/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">72</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/RetainedEarningsEndowmentEtc/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;">73</td>
          <td class="styLNDesc" style="width:95mm;height:4.5mm;" colspan="3">
            <span class="styBoldText">Total net assets or fund balances</span> (add lines 67 through 69
            <span class="styBoldText">or</span> lines <br/>
            70 through 72;
          </td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styShadingCell" style="width:8mm;height:4.5mm;"><span style="width:1px;"></span></td>
          <td class="styLNAmountBoxNBB" style="height:4.5mm;"><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
          <td class="styLNDesc" style="width:101mm;height:4.5mm;" colspan="3">
            column (A) <span class="styBoldText">must</span> equal line 19;
            column (B) <span class="styBoldText">must</span> equal line 21)
            <!--Dotted Line-->
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">...</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalNetAssetsOrFundBalances/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;">73</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalNetAssetsOrFundBalances/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <tr>
          <td class="styLNLeftNumBoxBB" style="height:4.5mm;">74</td>
          <td class="styIRS990LNDescBB" style="width:95mm;height:4.5mm;font-size:6pt;" colspan="3">
            <span class="styBoldText">Total liabilities and net assets / fund balances</span> Add lines 66 and 73.
            <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..</span>
          </td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalLiabilitiesAndNetAssets/BOY" /></xsl:call-template><span style="width:1px;"></span></td>
          <td class="styLNRightNumBox" style="height:4.5mm;vertical-align:top">74</td>
          <td class="styLNAmountBox" style="height:4.5mm;font-family:'Arial';"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalLiabilitiesAndNetAssets/EOY" /></xsl:call-template><span style="width:1px;"></span></td>
        </tr>
        <!-- End Part IV Net Assets Section -->
      </tbody>
    </table>
    <!-- End Part IV Table-->

    <!-- Footer -->
    <div style="width:187mm;float:none;clear:both;padding-top:.5mm;" class="pageend">
      <div class="styGenericDiv" style="width:105mm;"></div>
      <div class="styGenericDiv" style="width:25mm;"></div>
      <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
    </div>
    <!-- header -->
    <div style="width:187mm;clear:both;padding-bottom:.5mm;float:none;clear:both;" class="styBB">
      <div style="width:90mm;" class="styGenericDiv">Form 990 (2005)</div>
      <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
      <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">5</span></div>
    </div>
    
    <!-- Begin Parts IV-A -->
      <table class="styTable" style="font-size:7pt;width:187mm;" cellspacing="0">
        <thead>
          <tr scope="col">
            <th class="styBB" colspan="6" style="padding-bottom:0;padding-top:0;">
               <span class="styPartName" style="width:18mm;">Part IV-A</span>
              <span class="styPartDesc" style="width:158mm;">
                Reconciliation of Revenue per Audited Financial Statements With Revenue per Return <span class="styNormalText" style="font-style:italic;">(See the instructions.)</span>
              </span>             
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody valign="top">
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">a</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Total revenue, gains, and other support per audited financial statements
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">a</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotRevenueEtcAuditedFinclStmt" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">b</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Amounts included on line <span class="styBoldText">a</span> but not on Part I, line 12:</td>
            <td class="styShadingCell" style="width:8mm;height:4.5mm;border-left-width:1px;"><span class="styTableCellPad"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">1</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Net unrealized gains on investments
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b1</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetUnrealizedGainsInvestments" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">2</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Donated services and use of facilities
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b2</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DonatedSrvcAndUseOfFacilities" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">3</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Recoveries of prior year grants
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b3</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/RecoveriesOfPriorYearGrants" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">4</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Other (specify):  <span class="styBB" style="width:62mm;float:none;">
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/TotOthRevenueOnLnaButNotOnLn12"/>
              </xsl:call-template>
              </span> <br />
              <span class="styBB" style="width:85mm;float:none;"></span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b4</td>
            <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotOthRevenueOnLnaButNotOnLn12" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Add lines <span class="styBoldText">b1</span> through <span class="styBoldText">b4</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">....................</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">b</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotAmtIncldOnLnaButNotOnLn12" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">c</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Subtract line <span class="styBoldText">b</span> from line <span class="styBoldText">a</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">....................</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">c</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PartIVALineaMinusLineb" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">d</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Amounts included on Part I, line 12, but not on line <span class="styBoldText">a</span>:</td>
            <td class="styShadingCell" style="width:8mm;height:4.5mm;border-left-width:1px;"><span class="styTableCellPad"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">1</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Investment expenses not included on Part I, line 6b
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.....</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">d1</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PartIVAInvstExpensesNotOnLn6b" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">2</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Other (specify):  <span class="styBB" style="width:62mm;float:none;">
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/TotOthRevenueOnLn12ButNotOnLna"/>
              </xsl:call-template>
              </span> <br />
              <span class="styBB" style="width:85mm;float:none;"></span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">d2</td>
            <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotOthRevenueOnLn12ButNotOnLna" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Add lines <span class="styBoldText">d1</span> and <span class="styBoldText">d2</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.....................</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">d</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotAmtIncldOnLnaButNotOnLn12" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;border: solid black 1px; border-top-width:0; border-left-width:0;border-right-width:0px;">e</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;border: solid black 1px; border-top-width:0; border-left-width:0;border-right-width:0px;" colspan="3"><span class="styBoldText">Total revenue</span> (Part I, line 12). Add lines <span class="styBoldText">c</span> and <span class="styBoldText">d</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..............<img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/></span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0;border-bottom-width:1px;">e</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalRevenuePerLine12" /></xsl:call-template></td>
          </tr>    
        </tbody>
      </table>

    <!-- Begin Parts IV-B -->
      <table class="styTable" style="font-size:7pt;width:187mm;" cellspacing="0">
        <thead>
          <tr scope="col">
            <th class="styBB" colspan="6" style="padding-bottom:0;padding-top:0;">
               <span class="styPartName" style="width:18mm;">Part IV-B</span>
              <span class="styPartDesc" style="width:158mm;">
                Reconciliation of Expenses per Audited Financial Statements With Expenses per Return              
              </span>             
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody valign="top">
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">a</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Total expenses and losses per audited financial statements
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.........</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">a</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotExpensesEtcAuditedFinclStmt" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">b</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Amounts included on line <span class="styBoldText">a</span> but not on Part I, line 17:</td>
            <td class="styShadingCell" style="width:8mm;height:4.5mm;border-left-width:1px;"><span class="styTableCellPad"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">1</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Donated services and use of facilities
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.......</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b1</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DonatedServicesUseOfFacilities" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">2</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Prior year adjustments reported on Part I, line 20
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.....</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b2</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PriorYearAdjustmentsOnLine20" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">3</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Losses reported on Part I, line 20
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..........</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b3</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/LossesReportedOnLine20" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">4</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Other (specify):  <span class="styBB" style="width:62mm;float:none;">
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/TotOtherExpOnLineaNotOnLine17"/>
              </xsl:call-template>
              </span> <br />
              <span class="styBB" style="width:85mm;float:none;"></span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">b4</td>
            <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotOtherExpOnLineaNotOnLine17" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Add lines <span class="styBoldText">b1</span> through <span class="styBoldText">b4</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">....................</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">b</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalAmtIncludedOnAButNotOn17" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">c</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Subtract line <span class="styBoldText">b</span> from line <span class="styBoldText">a</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">....................</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">c</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PartIVBLineaMinusLineb" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;">d</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Amounts included on Part I, line 17, but not on line <span class="styBoldText">a:</span></td>
            <td class="styShadingCell" style="width:8mm;height:4.5mm;border-left-width:1px;"><span class="styTableCellPad"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">1</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Investment expenses not included on Part I, line 6b
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.....</span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">d1</td>
            <td class="styLNAmountBox" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/PartIVBInvstExpensesNotOn6b" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;">2</td>
            <td class="styLNDesc" style="width:85mm;height:4.5mm;">Other (specify):  <span class="styBB" style="width:62mm;float:none;">
              <xsl:call-template name="SetFormLinkInline">
                <xsl:with-param name="TargetNode" select="$Form990Data/TotOtherExpensesOnLn17NotOnLna"/>
              </xsl:call-template>
              </span> <br />
              <span class="styBB" style="width:85mm;float:none;"></span>
            </td>
            <td class="styLNRightNumBox" style="height:4.5mm;">d2</td>
            <td class="styLNAmountBox" style="height:4.5mm;vertical-align:bottom;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotOtherExpensesOnLn17NotOnLna" /></xsl:call-template><span style="width:1px;"></span></td>
            <td class="styShadingCellRB" style="width:8mm;height:4.5mm; border-right:0"><span style="width:1px;"></span></td>
            <td class="styLNAmountBoxNBB" style="height:4.5mm; border-left-width: 1px;"><span class="styTableCellPad"></span></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;"></td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;" colspan="3">Add lines <span class="styBoldText">d1</span> and <span class="styBoldText">d2</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">.....................</span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">d</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalAmtIncldOnLn17ButNotOnLna" /></xsl:call-template></td>
          </tr>    
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;border: solid black 1px; border-top-width:0; border-left-width:0;border-right-width:0px;">e</td>
            <td class="styLNDesc" style="width:130mm;height:4.5mm;border: solid black 1px; border-top-width:0; border-left-width:0;border-right-width:0px;" colspan="3"><span class="styBoldText">Total expenses</span> (Part I, line 17). Add lines <span class="styBoldText">c</span> and <span class="styBoldText">d</span>
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm">..............<img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/></span>
            </td>
            <td class="styLNRightNumBox" style="width:8mm;height:4.5mm; border-right:0">e</td>
            <td class="styLNAmountBox" style="height:4.5mm; border-left-width: 1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalExpensesPerLine17" /></xsl:call-template></td>
          </tr>    
        </tbody>
      </table>



    <!-- BEGIN Part V Title -->
    <div class="styBB" style="width:187mm;float:none;">
      <div class="styPartName" style="width:17mm;">Part V-A</div>
      <div class="styPartDesc" style="width:169mm">
        Current Officers, Directors, Trustees, and Key Employees
        <span class="styNormalText">(List each person who was an officer, director, trustee, or key employee at any time during the year even if they were not compensated.)
          <span class="styItalicText">(See the instructions.)</span>
        </span>
      </div>
      <div class="styGenericDiv" style="float:right">
         <!-- button display logic -->
          <xsl:call-template name="SetDynamicTableToggleButton">
          <xsl:with-param name="TargetNode" select="$Form990Data/OfcrDirTrusteesOrKeyEmployee"/>
          <xsl:with-param name="containerHeight" select="10"/>
          <xsl:with-param name="containerID" select=" 'ODTctn' "/>
          </xsl:call-template>
         <!-- end button display logic -->
      </div>
    </div>
    <!-- END Part V Title -->

    <!-- BEGIN Part V Table -->
    <div class="styTableContainerNBB" id="ODTctn" style="height:81mm;">
      <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>
      <!-- end -->
      <table class="styTable" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead" style="font-size:6pt;">
          <tr>
            <th class="styTableCellHeader" scope="col" style="width:55mm;">(A) <span style="font-weight:normal">Name and address</span></th>
            <th class="styTableCellHeader" scope="col" style="width:32mm;">(B) <span style="font-weight:normal">Title and average hours per week devoted to position</span></th>
            <th class="styTableCellHeader" scope="col" style="width:32mm;">(C) <span style="font-weight:normal">Compensation</span><br/> (If not paid, enter -0-.)</th>
            <th class="styTableCellHeader" scope="col" style="width:32mm;">(D) <span style="font-weight:normal">Contributions to employee benefit plans &amp; deferred compensation plans</span></th>
            <th class="styTableCellHeader" scope="col" style="width:32mm; border-right-width:0px" >(E) <span style="font-weight:normal">Expense<br/> account and other<br/> allowances</span></th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/OfcrDirTrusteesOrKeyEmployee">
          <!-- Adding the separator section -->
          <xsl:if test="($Print != $Separated) or (count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt;= 10)">
            <tr>
              <td class="styTableCellText" style="width:55mm;padding-left:1mm;">

                <xsl:choose>
                  <xsl:when test="PersonName">
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="PersonName" />    </xsl:call-template>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine1" />    </xsl:call-template>
                    <xsl:if test="BusinessName/BusinessNameLine2">
                      <br />
                      <xsl:call-template name="PopulateText">
                        <xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine2" />    
                      </xsl:call-template>
                    </xsl:if>
                  </xsl:otherwise>
                </xsl:choose>
                    
                <span style="width:2px;"></span>
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="PersonName"/>
                </xsl:call-template>  
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="BusinessName"/>
                </xsl:call-template>  
                <br/>    
                <div>        
                <xsl:choose>
                  <xsl:when test="AddressUS">                    
                      <xsl:call-template name="PopulateUSAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressUS" />
                      </xsl:call-template>                    
                  </xsl:when>
                  <xsl:otherwise>
                      <xsl:call-template name="PopulateForeignAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressForeign" />
                      </xsl:call-template>
                  </xsl:otherwise>  
                </xsl:choose>
                </div>
              </td>
              <td class="styTableCellText" style="width:36mm;text-align:left;">
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Title" /></xsl:call-template><br/>
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AvgHoursPerWkDevotedToPosition" /></xsl:call-template><span style="width:4px"></span>              
              </td>
              <td class="styTableCell"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Compensation" /></xsl:call-template><span style="width:4px;"></span></td>
              <td class="styTableCell"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ContriToEmplBenefitPlansEtc" /></xsl:call-template><span style="width:4px;"></span></td>
              <td class="styTableCell" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExpenseAccountOtherAllowances" /></xsl:call-template><span style="width:4px;"></span></td>
            </tr>
            </xsl:if>
          </xsl:for-each>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 1 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
              <tr>
                <td class="styTableCellText" style="width:71mm;">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/OfcrDirTrusteesOrKeyEmployee" />
                  </xsl:call-template>
                <br/><span style="width:4px"></span></td>
                <td class="styTableCell" style="width:36mm;text-align:left;"><span style="width:4px"></span></td>
                <td class="styTableCell"><span style="width:4px;"></span></td>
                <td class="styTableCell"><span style="width:4px;"></span></td>
                <td class="styTableCell" style="border-right-width:0px"><span style="width:4px;"></span></td>
              </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 2 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 3 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 4 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 5 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 6 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 7 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 8 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 9 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &lt; 10 or ((count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>          
        </tbody>
      </table>
    </div>
    <!-- Set Initial Height of Above Table -->
    <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form990Data/OfcrDirTrusteesOrKeyEmployee"/>
      <xsl:with-param name="containerHeight" select="10"/>
      <xsl:with-param name="containerID" select=" 'ODTctn' "/>
    </xsl:call-template>
    <!-- End Set Initial Height of Above Table -->
    <!-- END Part V Table -->
    
      <div style="width:187mm;float:none;clear:both;padding-top:.5mm;" class="pageend">
        <div class="styGenericDiv" style="width:105mm;"></div>
        <div class="styGenericDiv" style="width:25mm;"></div>
        <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
      </div>
      
      <!-- header -->
      <div style="width:187mm;clear:both;padding-bottom:.5mm;float:none;clear:both;" class="styBB">
        <div style="width:90mm;" class="styGenericDiv">Form 990 (2005)</div>
        <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
        <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">6</span></div>
      </div>

    <!-- BEGIN Part V-A Title -->
    <div class="styBB" style="width:187mm;float:none;">
      <div class="styPartName" style="float:left;height:4.3mm;width:16mm;">Part V-A</div>
      <div class="styPartDesc" style="float:left;width:150mm;">Current Officers, Directors, Trustees, and Key Employees <span class="styNormalText" style="font-style:italic;">(continued)</span></div>
      <div class="styIRS990LNYesNoBox" style="float:left;border-bottom-width:0px;"><span class="styBoldText">Yes</span></div>
      <div class="styIRS990LNYesNoBox" style="float:left;border-bottom-width:0px;"><span class="styBoldText">No</span></div>
    </div>
    <!-- END Part V-A Title -->

    <!-- BEGIN Part V-A Line Items -->
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">75a</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          Enter the total number of officers, directors, and trustees permitted to vote on organization business at board
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          meetings <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.....................</span>
         <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
         <span style="border-bottom: solid black 1px;width:25mm;">
           <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="$Form990Data/NumberOfOfficers" />
           </xsl:call-template>
         </span>
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;">b</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          Are any officers, directors, trustees, or key employees listed in Form 990, Part V-A, or highest compensated
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          employees listed in Schedule A, Part I, or highest compensated professional and other independent
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          contractors listed in Schedule A, Part II-A or II-B, related to each other through family or business
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
       relationships? If “Yes,” attach a statement that identifies the individuals and explains the relationship(s)
      <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/AreAnyRelated"/>
       </xsl:call-template>
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">75b</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/AreAnyRelated" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/AreAnyRelated" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;">c</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          Do any officers, directors, trustees, or key employees listed in Form 990, Part V-A, or highest compensated
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          employees listed in Schedule A, Part I, or highest compensated professional and other independent
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          contractors listed in Schedule A, Part II-A or II-B, receive compensation from any other organizations, whether
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
       tax exempt or taxable, that are related to this organization through common supervision or common control?
      <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/CompensationFromRelatedOrg"/>
       </xsl:call-template>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">75c</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/CompensationFromRelatedOrg" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/CompensationFromRelatedOrg" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          <span class="styBoldText">Note.</span> Related organizations include section 509(a)(3) supporting organizations.
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          If “Yes,” attach a statement that identifies the individuals, explains the relationship between this
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          organization and the other organization(s), and describes the compensation arrangements,
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          including amounts paid to each individual by each related organization.
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;border-bottom: solid black 1px;">d</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;border-bottom: solid black 1px;">
       Does the organization have a written conflict of interest policy?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.............</span>       
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">75d</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ConflictOfInterestPolicy" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ConflictOfInterestPolicy" /></xsl:call-template></div>
    </div>

    <!-- BEGIN Part V-B Title -->
    <div class="styBB" style="width:187mm;float:none;">
      <div class="styPartName" style="width:17mm;">Part V-B</div>
      <div class="styPartDesc" style="width:169mm">
        Former Officers, Directors, Trustees, and Key Employees That Received Compensation or Other Benefits
        <span class="styNormalText">(If any former officer, director, trustee, or key employee received compensation or other benefits (described below) during the year, list that person below and enter the amount of compensation or other benefits in the appropriate column. See the instructions.)
        </span>
      </div>
      <div class="styGenericDiv" style="float:right">
         <!-- button display logic -->
          <xsl:call-template name="SetDynamicTableToggleButton">
          <xsl:with-param name="TargetNode" select="$Form990Data/OfcrDirTrusteesOrKeyEmployee"/>
          <xsl:with-param name="containerHeight" select="10"/>
          <xsl:with-param name="containerID" select=" 'ODTctn2' "/>
          </xsl:call-template>
         <!-- end button display logic -->
      </div>
    </div>
    <!-- END Part V-B Title -->

    <!-- BEGIN Part V-B Table -->
    <div class="styTableContainerNBB" id="ODTctn2" style="height:81mm;">
      <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>
      <!-- end -->
      <table class="styTable" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead" style="font-size:6pt;">
          <tr>
            <th class="styTableCellHeader" scope="col" style="width:55mm;">(A) <span style="font-weight:normal">Name and address</span></th>
            <th class="styTableCellHeader" scope="col" style="width:32mm;">(B) <span style="font-weight:normal">Loans and Advances</span></th>
            <th class="styTableCellHeader" scope="col" style="width:32mm;">(C) <span style="font-weight:normal">Compensation</span></th>
            <th class="styTableCellHeader" scope="col" style="width:32mm;">(D) <span style="font-weight:normal">Contributions to employee benefit plans and deferred compensation plans</span></th>
            <th class="styTableCellHeader" scope="col" style="width:32mm; border-right-width:0px" >(E) <span style="font-weight:normal">Expense account and other allowances</span></th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/FrmrOfcrDirTrstOrKeyEmployee">
          <!-- Adding the separator section -->
          <xsl:if test="($Print != $Separated) or (count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt;= 10)">
            <tr>
              <td class="styTableCellText" style="width:55mm;padding-left:1mm;">
               
                <xsl:choose>
                  <xsl:when test="PersonName">
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="PersonName" />    </xsl:call-template>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine1" />    </xsl:call-template>
                    <xsl:if test="BusinessName/BusinessNameLine2">
                      <br />
                      <xsl:call-template name="PopulateText">
                        <xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine2" />    
                      </xsl:call-template>
                    </xsl:if>
                  </xsl:otherwise>
                </xsl:choose>
                
                <span style="width:2px;"></span>
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="PersonName"/>
                </xsl:call-template>  
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="BusinessName"/>
                </xsl:call-template>  
                <br/>            
                <xsl:choose>
                  <xsl:when test="AddressUS">
                    <div style="">
                      <xsl:call-template name="PopulateUSAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressUS" />
                      </xsl:call-template>
                    </div>
                  </xsl:when>
                  <xsl:otherwise>
                    <div style="">
                      <xsl:call-template name="PopulateForeignAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressForeign" />
                      </xsl:call-template>
                    </div>
                  </xsl:otherwise>  
                </xsl:choose>
              </td>
              <td class="styTableCell"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="LoansAndAdvances" /></xsl:call-template><span style="width:4px;"></span></td>
              <td class="styTableCell"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ContriToEmplBenefitPlansEtc" /></xsl:call-template><span style="width:4px;"></span></td>
              <td class="styTableCell"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Compensation" /></xsl:call-template><span style="width:4px;"></span></td>
              <td class="styTableCell" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExpenseAccountOtherAllowances" /></xsl:call-template><span style="width:4px;"></span></td>
            </tr>
            </xsl:if>
          </xsl:for-each>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 1 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
              <tr>
                <td class="styTableCellText" style="width:71mm;">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/FrmrOfcrDirTrstOrKeyEmployee" />
                  </xsl:call-template>
                <br/><span style="width:4px"></span></td>
                <td class="styTableCell" style="width:36mm;text-align:left;"><span style="width:4px"></span></td>
                <td class="styTableCell"><span style="width:4px;"></span></td>
                <td class="styTableCell"><span style="width:4px;"></span></td>
                <td class="styTableCell" style="border-right-width:0px"><span style="width:4px;"></span></td>
              </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 2 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 3 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 4 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 5 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 6 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 7 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 8 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 9 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &lt; 10 or ((count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVTableFillerRow"></xsl:call-template>
          </xsl:if>          
        </tbody>
      </table>
    </div>
    <!-- Set Initial Height of Above Table -->
    <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form990Data/FrmrOfcrDirTrstOrKeyEmployee"/>
      <xsl:with-param name="containerHeight" select="10"/>
      <xsl:with-param name="containerID" select=" 'ODTctn2' "/>
    </xsl:call-template>
    <!-- End Set Initial Height of Above Table -->
    <!-- END Part V Table -->
    


    <!-- BEGIN Part VI Title -->
    <div class="styBB" style="width:187mm;float:none;">
      <div class="styPartName" style="float:left;height:4.3mm">Part VI</div>
      <div class="styPartDesc" style="float:left;width:152mm;">Other Information <span class="styNormalText" style="font-style:italic;">(See the instructions.)</span></div>
      <div class="styIRS990LNYesNoBox" style="float:left;border-bottom-width:0px;"><span class="styBoldText">Yes</span></div>
      <div class="styIRS990LNYesNoBox" style="float:left;border-bottom-width:0px;"><span class="styBoldText">No</span></div>
    </div>
    <!-- END Part VI Title -->

    <!-- BEGIN Part VI Line Items -->
    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">76</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        <span class="stySmallText" style="padding-top:0.0mm;">
          Did the organization engage in any activity not previously reported to the IRS? If "Yes," attach a detailed description
          of each activity
          <span style="width:2px;"></span>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$Form990Data/ActivitiesNotPreviouslyRpt"/>
          </xsl:call-template>
        </span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">76</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ActivitiesNotPreviouslyRpt" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ActivitiesNotPreviouslyRpt" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">77</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        Were any changes made in the organizing or governing documents but not reported to the IRS?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.....</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">77</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/MadeChangesToOrgnzngEtcDoc" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/MadeChangesToOrgnzngEtcDoc" /></xsl:call-template></div>
    </div>

    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        If "Yes," attach a conformed copy of the changes.
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>

    <div>
      <div class="styLNLeftNumBox" style="height:4.5mm;">78a</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        <span class="stySmallText" style="padding-top:0.5mm;">
          Did the organization have unrelated business gross income of $1,000 or more during the year covered by this return?
        </span>
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">....</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">78a</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrganizationHadUBI" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrganizationHadUBI" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;">b</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        If "Yes," has it filed a tax return on <span class="styBoldText">Form 990-T</span> for this year?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">..............</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">78b</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrganizationFiled990T" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrganizationFiled990T" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-top:0;">79</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        <span class="stySmallText">
          Was there a liquidation, dissolution, termination, or substantial contraction during the year? If "Yes," attach a statement
        </span>
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">....</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">79</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrganizationDissolvedEtc" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrganizationDissolvedEtc" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-top:0;">80a</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        <span class="stySmallText">
          Is the organization related (other than by association with a statewide or nationwide organization) through common membership, 
        </span>
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div>
      <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        <span class="stySmallText">
           governing bodies, trustees, officers, etc., to any other exempt or nonexempt organization?
        </span>
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">..........</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">80a</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgIsRelatedToAnotherOrg" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgIsRelatedToAnotherOrg" /></xsl:call-template></div>
    </div>
    
    <!--Empty row when element does not exist-->
    
     <xsl:if test="not($Form990Data/NameOfRelatedOrganization) or ((count($Form990Data/NameOfRelatedOrganization) &gt; 1) and ($Print = $Separated))">
       <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:5mm;padding-top:1.75mm;padding-left:4.5mm;">b</div>
        <div class="styLNDesc" style="width:150mm;height:5mm;">
          If "Yes," enter the name of the organization <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/><span style="width:4px;"></span>
            <span class="styFixedUnderline" style="float:none;width:80mm;">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/NameOfRelatedOrganization"/>                      
                  </xsl:call-template>
            </span>
            <br/>
           <span class="styFixedUnderline" style="float:none;width:60mm;"/>
          and check whether it is 
          <span style="width:2mm;"></span>
          <input type="checkbox" class="styCkbox" name="Checkbox" onclick="return false;" id="dummyidexempt">
          </input>
          <label for="dummyidexempt">          
            exempt
          </label>
          <span class="styBoldText">or</span>
          <span style="width:2mm;"></span>
          <input type="checkbox" class="styCkbox" name="Checkbox" onclick="return false;" id="dummyidnonexempt">
          
          </input>
          <label for="dummyidnonexempt">
            nonexempt
          </label>
        </div>
        <div class="styShadingCell" style="width:8mm;height:10mm;"></div>
        <div class="styShadingCell" style="width:10mm;height:10mm;"></div>
        <div class="styShadingCell" style="width:10mm;height:10mm;"></div>
      </div>     
     </xsl:if>
    
    
    <xsl:for-each select="$Form990Data/NameOfRelatedOrganization">
      <xsl:if test="($Print != $Separated) or (count($Form990Data/NameOfRelatedOrganization) = 1) "> 
      <div style="width:187mm;float:none;clear:both;">
        <div class="styLNLeftLtrBoxDD" style="height:7mm;padding-left:4.5mm;">b</div>
        <div class="styGenericDiv" style="height:100%;width:179mm;">
                <div class="styLNDesc" style="width:150mm;height:100%;">
          <div class="styGenericDiv" style="width:61mm;">If "Yes," enter the name of the organization <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/><span style="width:4px;"></span></div>
          
            <span class="styFixedUnderline" style="float:none;width:87mm;">
              <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessNameLine1" /></xsl:call-template>
            </span>
            <span class="styFixedUnderline" style="float:none;width:70mm;padding-top:.5mm;">
              <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessNameLine2" /></xsl:call-template>
            </span>
          and check whether it is 
          <span style="width:2mm;"></span>
          <span style="height:3.5mm;">
            <xsl:call-template name="PopulateSpan">
              <xsl:with-param name="TargetNode" select="@exempt" />
            </xsl:call-template>
            <input type="checkbox" class="styCkbox" name="Checkbox">
              <xsl:call-template name="PopulateYesCheckbox">
                <xsl:with-param name="TargetNode" select="@exempt" />
                <xsl:with-param name="BackupName">IRS990exemptYes</xsl:with-param>
              </xsl:call-template>
            </input>
          </span>
          <label>
            <xsl:call-template name="PopulateLabelYes">
              <xsl:with-param name="TargetNode" select="@exempt" />
              <xsl:with-param name="BackupName">IRS990exemptYes</xsl:with-param>
            </xsl:call-template>
            exempt
          </label>
          <span class="styBoldText">or</span>
          <span style="width:2mm;"></span>
          <span style="height:3.5mm;">
            <xsl:call-template name="PopulateSpan">
              <xsl:with-param name="TargetNode" select="@exempt" />
            </xsl:call-template>
            <input type="checkbox" class="styCkbox" name="Checkbox">
              <xsl:call-template name="PopulateNoCheckbox">
                <xsl:with-param name="TargetNode" select="@exempt" />
                <xsl:with-param name="BackupName">IRS990exemptNo</xsl:with-param>
              </xsl:call-template>
            </input>
          </span>
          <label>
            <xsl:call-template name="PopulateLabelNo">
              <xsl:with-param name="TargetNode" select="@exempt" />
              <xsl:with-param name="BackupName">IRS990exemptNo</xsl:with-param>
            </xsl:call-template>
            nonexempt
          </label>
        </div>
        <div class="styShadingCell" style="width:8mm;height:100%;"></div>
        <div class="styShadingCell" style="width:10mm;height:100%;"></div>
        <div class="styShadingCell" style="width:10mm;height:100%;"></div>
        </div>
      </div>
      </xsl:if>
    </xsl:for-each>
    
    
    
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">81a</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        Enter direct or indirect political expenditures. (See line 81 instructions.)
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">...</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">81a</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DirectIndirectPoliticalExpend" /></xsl:call-template><span style="width:1px;"></span></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;border-bottom:solid black 1px;">b</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;border-bottom:solid black 1px;">
        Did the organization file <span class="styBoldText">Form 1120-POL</span> for this year?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">................</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">81b</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/DidOrgFileForm1120POLThisYear" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/DidOrgFileForm1120POLThisYear" /></xsl:call-template></div>
    </div>
    
      <div style="width:187mm;float:none;clear:both;padding-top:.5mm;" class="pageend">
        <div class="styGenericDiv" style="width:105mm;"></div>
        <div class="styGenericDiv" style="width:25mm;"></div>
        <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
      </div>
      
      <!-- header -->
      <div style="width:187mm;clear:both;padding-bottom:.5mm;float:none;clear:both;" class="styBB">
        <div style="width:90mm;" class="styGenericDiv">Form 990 (2005)</div>
        <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
        <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">7</span></div>
      </div>
    
     <!-- BEGIN Part VI Title -->
    <div class="styBB" style="width:187mm;float:none;">
      <div class="styPartName" style="float:left;height:4.3mm">Part VI</div>
      <div class="styPartDesc" style="float:left;width:152mm;">Other Information <span class="styNormalText" style="font-style:italic;">(continued)</span></div>
      <div class="styIRS990LNYesNoBox" style="float:left;border-bottom-width:0px;"><span class="styBoldText">Yes</span></div>
      <div class="styIRS990LNYesNoBox" style="float:left;border-bottom-width:0px;"><span class="styBoldText">No</span></div>
    </div>
    <!-- END Part VI Title -->
    
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:8.5mm;">82a</div>
      <div class="styLNDesc" style="width:150mm;height:8.5mm;">
        Did the organization receive donated services or the use of materials, equipment, or facilities at no charge
        or<br/> at substantially less than fair rental value?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">...................</span>
      </div>
      <div class="styLNRightNumBox" style="height:8.5mm;padding-top:4.5mm;">82a</div>
      <div class="styIRS990LNYesNoBox" style="height:8.5mm;padding-top:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedDonatedServicesEtc" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:8.5mm;padding-top:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedDonatedServicesEtc" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;">b</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        <span class="stySmallText" style="padding-top:0.5mm;">
          If "Yes," you may indicate the value of these items here. Do not include this amount
          as revenue
        </span>
      </div>
      <div class="styLNDesc" style="width:8mm;height:4.5mm;"></div>
      <div class="styLNDesc" style="width:32mm;height:4.5mm;"><span style="width:1px;"></span></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;"></div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        <span class="stySmallText">
          in Part I or as an expense in Part II. (See instructions in Part III.)
        </span>
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.......</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">82b</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/ValueOfDonatedServicesEtc" /></xsl:call-template><span style="width:1px;"></span></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">83a</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        Did the organization comply with the public inspection requirements for returns and exemption applications?
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">83a</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgCompliedWithPublicInspRqr" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgCompliedWithPublicInspRqr" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;">b</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        Did the organization comply with the disclosure requirements relating to quid pro quo contributions?
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">...</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">83b</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgCompliedWithDisclosureRqr" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgCompliedWithDisclosureRqr" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">84a</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        Did the organization solicit any contributions or gifts that were not tax deductible?
          <!--Dotted Line-->
          <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">........</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">84a</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/NondeductibleContribSoliciated" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/NondeductibleContribSoliciated" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;">b</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        If "Yes," did the organization include with every solicitation an express statement that such contributions or
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        gifts were not tax deductible?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">......................</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">84b</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgIncldStatement" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgIncldStatement" /></xsl:call-template></div>
    </div>

    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">85</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          <span class="styItalicText">501(c)(4), (5), or (6) organizations.</span><span class="styBoldText" style="padding-left:1mm;">a</span>
        Were substantially all dues nondeductible by members?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">......</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">85a</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/DuesNondeductibleByMembers" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/DuesNondeductibleByMembers" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;">b</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        Did the organization make only in-house lobbying expenditures of $2,000 or less?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">........</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">85b</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/MadeOnlyInhouseLobbyingExpend" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/MadeOnlyInhouseLobbyingExpend" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:8mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:8mm;">
        If "Yes," was answered to either 85a or 85b, <span class="styBoldText">do not</span>
        complete 85c through 85h below unless the organization received a waiver for proxy tax owed the prior year.
      </div>
      <div class="styShadingCell" style="width:8mm;height:8mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:8mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:8mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;">c</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        Dues assessments, and similar amounts from members
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.......</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">85c</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DuesAssessmentsEtc" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;">d</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        Section 162(e) lobbying and political expenditures
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">........</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">85d</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/Section162eExpenditures" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;">e</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        Aggregate nondeductible amount of section 6033(e)(1)(A) dues notices
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">..</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">85e</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AggregateNondeductibleAmount" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;">f</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        Taxable amount of lobbying and political expenditures (line 85d less 85e)
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">..</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">85f</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TaxableAmount" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;">g</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        Does the organization elect to pay the section 6033(e) tax on the amount on line 85f?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.......</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">85g</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgElectedToPay6033eTax" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OrgElectedToPay6033eTax" /></xsl:call-template></div>
    </div>

    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:11mm;">h</div>
      <div class="styLNDesc" style="width:150mm;height:11mm;">
        If section 6033(e)(1)(A) dues notices were sent, does the organization agree to add the amount on line 85f to its
        reasonable estimate of dues allocable to nondeductible lobbying and political expenditures for the following tax year?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.............................</span>
      </div>
      <div class="styLNRightNumBox" style="height:11mm;padding-top:6mm;">85h</div>
      <div class="styIRS990LNYesNoBox" style="height:11mm;padding-top:6mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/SentDuesNotices" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:11mm;padding-top:6mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/SentDuesNotices" /></xsl:call-template></div>
    </div>


    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">86</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        <span class="styItalicText">501(c)(7) orgs.</span> Enter: <span class="styBoldText">a</span>
        Initiation fees and capital contributions included on line 12
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">86a</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/InitiationFeesAndCapitalContri" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;">b</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        Gross receipts, included on line 12, for public use of club facilities
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">....</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">86b</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossReceiptsForPublicUse" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">87</div>
      <div class="styLNDesc" style="width:110mm;height:4.5mm;">
        <span class="styItalicText">501(c)(12) orgs.</span> Enter: <span class="styBoldText">a</span>
        Gross income from members or shareholders
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">...</span>
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">87a</div>
      <div class="styLNAmountBox" style="height:4.5mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossIncomeFromMembers" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:8mm;">b</div>
      <div class="styLNDesc" style="width:110mm;height:8mm;">
        Gross income from other sources. (Do not net amounts due or paid to other sources against amounts due or received from them.)
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.......</span>
      </div>
      <div class="styLNRightNumBox" style="height:8mm;padding-top:3mm;">87b</div>
      <div class="styLNAmountBox" style="height:8mm;padding-top:3mm;padding-right:0.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossIncomeFromOtherSources" /></xsl:call-template></div>
      <div class="styShadingCell" style="width:8mm;height:8mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:8mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:8mm;"></div>
    </div>

    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:11mm;">88</div>
      <div class="styLNDesc" style="width:150mm;height:11mm;">
        At any time during the year, did the organization own a 50% or greater interest in a taxable corporation or
        partnership, or an entity disregarded as separate from the organization under Regulations sections
        301.7701-2 and 301.7701-3? If "Yes," complete Part IX
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">..................</span>
      </div>
      <div class="styLNRightNumBox" style="height:11mm;padding-top:6mm;">88</div>
      <div class="styIRS990LNYesNoBox" style="height:11mm;padding-top:6mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OwnershipOfTaxableCorporation" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:11mm;padding-top:6mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/OwnershipOfTaxableCorporation" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">89a</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
        <span class="styItalicText">501(c)(3) organizations</span>. Enter: Amount of tax imposed on the organization during the year under:<br/>
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;font-size:6pt;">
      <div class="styLNLeftNumBox" style="height:4.5mm;font-size:6pt;"></div>
      <div class="styLNDesc" style="width:17.5mm;height:4.5mm;">
        section 4911 <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      </div>
      <div class="styIRS990LNAmountBoxNLB" style="width:31mm;text-align:right;font-size:7pt"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TaxImposedUnderIRC4911" /></xsl:call-template></div>
      <div class="styLNDesc" style="width:19.5mm;height:4.5mm;padding-left:0.5mm">
        ; section 4912 <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      </div>
      <div class="styIRS990LNAmountBoxNLB" style="width:31mm;text-align:right;font-size:7pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TaxImposedUnderIRC4912" /></xsl:call-template></div>      
      <div class="styLNDesc" style="width:19.5mm;height:4.5mm;padding-left:0.5mm">
        ; section 4955 <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      </div>
      <div class="styIRS990LNAmountBoxNLB" style="width:31mm;text-align:right;font-size:7pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TaxImposedUnderIRC4955" /></xsl:call-template></div>
      <div class="styLNDesc" style="width:0.5mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;">b</div>
      <div class="styLNDesc" style="width:150mm;height:10mm;">
        <span class="styItalicText">501(c)(3) and 501(c)(4) orgs.</span> Did the organization engage in any section 4958 excess
        benefit transaction during the year or did it become aware of an excess benefit transaction from a prior year? If "Yes,"
        attach a statement explaining each transaction
        <span style="width:2px;"></span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$Form990Data/EngagedInExcessBenefitTrans"/>
        </xsl:call-template>
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.......................</span>
      </div>
      <div class="styLNRightNumBox" style="height:10mm;padding-top:6mm;">89b</div>
      <div class="styIRS990LNYesNoBox" style="height:10mm;padding-top:6mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/EngagedInExcessBenefitTrans" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:10mm;padding-top:6mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/EngagedInExcessBenefitTrans" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:7mm;padding-left:4.5mm;">c</div>
      <div class="styLNDesc" style="width:146mm;height:7mm;">
        Enter: Amount of tax imposed on the organization managers or disqualified persons during the year under
        sections 4912, 4955, and 4958
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">....................</span>
        <span style="width:2mm;"></span><img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      </div>
      <div class="styIRS990LNAmountBoxNLB" style="height:7mm;padding-top:3mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AmountOfTaxImposedOnOrgMgr" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;">d</div>
      <div class="styLNDesc" style="width:146mm;height:4.5mm;">
        Enter: Amount of tax on line 89c, above, reimbursed by the organization
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.........</span>
        <span style="width:2mm;"></span><img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      </div>
      <div class="styIRS990LNAmountBoxNLB" style="height:4.5mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/AmountOfTaxReimbursedByOrg" /></xsl:call-template></div>
    </div>

    <div style="width:187mm;">
      <div class="styLNLeftNumBox">90a</div>  
      <div class="styLNDesc" style="width: 76mm">List the states with which a copy of this return is filed 
        <img src="{$ImagePath}/990_Bullet_Md.gif" alt="bullet"/>
      </div>
      <div class="styFixedUnderline" style="width: 102mm; font-size: 7pt">
        <xsl:for-each select="$Form990Data/StatesWhereCopyOfReturnIsFiled">
         <xsl:if test="($Print != $Separated) or (count($Form990Data/StatesWhereCopyOfReturnIsFiled) &lt;= 18) "> 
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="." />
          </xsl:call-template><xsl:if test="position()!=last()"><span style="width: 2px">, </span></xsl:if>
          </xsl:if>
        </xsl:for-each>
        <xsl:if test="count($Form990Data/StatesWhereCopyOfReturnIsFiled) &lt; 1 or ((count($Form990Data/StatesWhereCopyOfReturnIsFiled) &gt;18) and ($Print = $Separated))">
              <xsl:call-template name="PopulateAdditionalDataTableMessage">
                <xsl:with-param name="TargetNode" select="$Form990Data/StatesWhereCopyOfReturnIsFiled"/>                      
              </xsl:call-template>
        </xsl:if>
      </div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm;">b</div>
      <div class="styLNDesc" style="height:4mm;">
        Number of employees employed in the pay period that includes March 12, 2005 (See instructions.)
      </div>
      <div class="styLNRightNumBox" style="height:4mm;">90b</div>
      <div class="styLNAmountBox" style="height:4mm;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="6" />
          <xsl:with-param name="TargetNode" select="$Form990Data/NumberOfEmployees" />
        </xsl:call-template>
      </div>
    </div>

    <div style="width:187mm;">
      <div class="styLNLeftNumBox">91a</div>
      <div class="styLNDesc" style="width:178mm">
        The books are in care of
        <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
        <span class="styFixedUnderline" style="width:80mm;float:none;padding-left:2mm">
          <xsl:choose>
            <xsl:when test="$Form990Data/TheBooksAreInCareOf/NamePerson">
              <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/NamePerson" /></xsl:call-template>
            </xsl:when>
            <xsl:otherwise>  
              <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/NameBusiness/BusinessNameLine1" /></xsl:call-template>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/NameBusiness/BusinessNameLine2">
                <br />
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode"   select="$Form990Data/TheBooksAreInCareOf/NameBusiness/BusinessNameLine2" /></xsl:call-template>
              </xsl:if>            
            </xsl:otherwise>
          </xsl:choose>                      
        </span>
        <span style="width:10px;"></span>
        Telephone no.
        <img src="{$ImagePath}/990_Bullet_Md.gif" alt="bullet"/>
        <span class="styFixedUnderline" style="width:38.25mm;float:none;padding-left:2mm;">
          <xsl:call-template name="PopulatePhoneNumber"><xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/TelephoneNumber" /></xsl:call-template>
        </span>
      </div>
    </div>
    <xsl:choose>
      <xsl:when test="$Form990Data/TheBooksAreInCareOf/AddressForeign">
        <div style="width:187mm;">
          <div class="styLNLeftNumBox"></div>
          <div class="styLNDesc" style="width:178mm">
            Located at
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            <span class="styFixedUnderline" style="width:97.75mm;float:none;padding-left:2mm">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressForeign/AddressLine1" />
              </xsl:call-template>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressForeign/AddressLine2 != ''">
                <br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode"   select="$Form990Data/TheBooksAreInCareOf/AddressForeign/AddressLine2" />
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressForeign/City != '' ">
                <br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressForeign/City" />
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressForeign/City != '' and $Form990Data/TheBooksAreInCareOf/AddressForeign/ProvinceOrState != ''">,</xsl:if>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressForeign/ProvinceOrState != ''">
                <span style="width:4px;"></span>
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode"   select="$Form990Data/TheBooksAreInCareOf/AddressForeign/ProvinceOrState" />
                </xsl:call-template>
              </xsl:if>
              <span style="width:6px;"></span>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressForeign/Country" />
              </xsl:call-template>
            </span>
            <span style="width:10px;"></span>
            ZIP + 4
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            <span class="styFixedUnderline" style="width:46mm;float:none;padding-left:2mm">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressForeign/PostalCode" />
              </xsl:call-template>
            </span>
          </div>
        </div>
      </xsl:when>
      <xsl:otherwise>
        <div style="width:187mm;">
          <div class="styLNLeftNumBox"></div>
          <div class="styLNDesc" style="width:178mm">
            Located at
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            <span class="styFixedUnderline" style="width:97.75mm;float:none;padding-left:2mm">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressUS/AddressLine1" />
              </xsl:call-template>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressUS/AddressLine2 != ''">
                <br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressUS/AddressLine2" />
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressUS/City != ''">
                <br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressUS/City" />
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressUS/City != '' and $Form990Data/TheBooksAreInCareOf/AddressUS/State != ''">,
              </xsl:if>
              <xsl:if test="$Form990Data/TheBooksAreInCareOf/AddressUS/State != ''">
                <span style="width:4px;"></span>
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressUS/State" />
                </xsl:call-template>
              </xsl:if>
            </span>
            <span style="width:10px;"></span>
            ZIP + 4
            <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
            <span class="styFixedUnderline" style="width:46mm;float:none;padding-left:2mm">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="$Form990Data/TheBooksAreInCareOf/AddressUS/ZIPCode" />
              </xsl:call-template>
            </span>
          </div>
        </div>
      </xsl:otherwise>
    </xsl:choose>

    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;">b</div>
      <div class="styLNDesc" style="width:150mm;height:11mm;">
          At any time during the calendar year, did the organization have an interest in or a signature or other authority over a financial account in a foreign country (such as a bank account, securities account, or other financial account)?      
      </div>
      <div class="styIRS990LNYesNoBox" style="width:8mm;height:4.5mm;margin-top:2mm;border-left-width:0px;border-bottom-width:0"><span style="width:1px;" /></div>
      <div class="styIRS990LNYesNoBox" style="width:10mm;height:4.5mm;margin-top:2mm;border-top-width:1px;border-bottom-width:0">Yes</div>
      <div class="styIRS990LNYesNoBox" style="width:10mm;height:4.5mm;margin-top:2mm;border-top-width:1px;border-bottom-width:0">No</div>
      <div class="styLNRightNumBox" style="height:4.5mm;border-top-width:1px;">91b</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;border-top-width:1px"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ForeignFinancialAccount" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;border-top-width:1px"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ForeignFinancialAccount" /></xsl:call-template></div>
    </div>

    <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
          If “Yes,” enter the name of the foreign country      
        <img src="{$ImagePath}/990_Bullet_Md.gif" alt="bullet"/>
        <span class="styFixedUnderline" style="width:80mm;float:none;padding-left:2mm;padding-top:0;padding-bottom:0;">
          <xsl:if test="(count($Form990Data/ForeignFinancialAccountCountry) &lt;= 1) or ((count($Form990Data/ForeignFinancialAccountCountry) &gt; 1) and ($Print != $Separated))">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/ForeignFinancialAccountCountry" /></xsl:call-template>
                 </xsl:if>
                <xsl:if test="($Print = $Separated) and (count($Form990Data/ForeignFinancialAccountCountry) &gt; 1) ">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage"> 
                    <xsl:with-param name="TargetNode" select="$Form990Data/ForeignFinancialAccountCountry" />
                  </xsl:call-template>
                </xsl:if>                 
        </span>
      </div>
      <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div>
    </div>
    <xsl:if test="(count($Form990Data/ForeignFinancialAccountCountry) &gt; 1) and ($Print != $Separated)">
      <div style="width:187mm;float:none;">
          <xsl:for-each select="$Form990Data/ForeignFinancialAccountCountry">
            <xsl:if test="position() != 1">
              <div style="width:71mm;float:left;clear:none;" ></div>
              <div class="styFixedUnderline" style="width:80mm;padding-left:2mm;padding-top:0;padding-bottom:0;">
                   <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="." /></xsl:call-template>
              </div >
              <div style="width:7.25mm;float:left;clear:none;" ></div>
              <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div >
              <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div >
              <div class="styShadingCell" style="width:10mm;height:4.5mm;"></div >              
            </xsl:if>
          </xsl:for-each>
        </div>
      </xsl:if>    
      <div style="width:187mm;float:none;">
      <div class="styLNLeftNumBox" style="height:8mm;padding-left:3mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:8mm;">
          See the instructions for exceptions and filing requirements for <span class="styBoldText">Form TD F 90-22.1</span>, Report of Foreign Bank and Financial Accounts.      
      </div>
      <div class="styShadingCell" style="width:8mm;height:8mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:8mm;"></div>
      <div class="styShadingCell" style="width:10mm;height:8mm;"></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;">c</div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
         At any time during the calendar year, did the organization maintain an office outside of the United States?
      </div>
      <div class="styLNRightNumBox" style="height:4.5mm;">91c</div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateYesBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ForeignOffice" /></xsl:call-template></div>
      <div class="styIRS990LNYesNoBox" style="height:4.5mm;"><xsl:call-template name="PopulateNoBoxText"><xsl:with-param name="TargetNode" select="$Form990Data/ForeignOffice" /></xsl:call-template></div>
    </div>
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;"></div>
      <div class="styLNDesc" style="width:150mm;height:4.5mm;">
         If “Yes,” enter the name of the foreign country
        <img src="{$ImagePath}/990_Bullet_Md.gif" alt="bullet"/>
        <span class="styFixedUnderline" style="width:80mm;float:none;padding-left:2mm;">
          <xsl:if test="(count($Form990Data/ForeignOfficeCountry) &lt;= 1) or ((count($Form990Data/ForeignOfficeCountry) &gt; 1) and ($Print != $Separated))">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/ForeignOfficeCountry" /></xsl:call-template>
          </xsl:if>
          <xsl:if test="($Print = $Separated) and (count($Form990Data/ForeignOfficeCountry) &gt; 1) ">
            <xsl:call-template name="PopulateAdditionalDataTableMessage"> 
              <xsl:with-param name="TargetNode" select="$Form990Data/ForeignOfficeCountry" />
            </xsl:call-template>
          </xsl:if>
        </span>
      </div>
    </div>
    <xsl:if test="(count($Form990Data/ForeignOfficeCountry) &gt; 1) and ($Print != $Separated)">
      <div style="width:187mm;">
         <xsl:for-each select="$Form990Data/ForeignOfficeCountry">
            <xsl:if test="position() != 1"> 
              <div class="styFixedUnderline" style="width:80mm;float:none;padding-left:2mm;margin-left:71mm;padding-top:0;padding-bottom:0;">
                   <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="." /></xsl:call-template>
              </div>
            </xsl:if>
          </xsl:for-each>
      </div>
    </xsl:if>    
    <div style="width:187mm;">
      <div class="styLNLeftNumBox">92</div>
      <div class="styLNDesc" style="width: 178mm;">
        <span style="float:left">
        <label>
          <xsl:call-template name="PopulateLabel">
            <xsl:with-param name="TargetNode" select="$Form990Data/NECTFilingForm990" />
            <xsl:with-param name="BackupName">IRS990NECTFilingForm990</xsl:with-param>
          </xsl:call-template>
          <i>Section 4947(a)(1) nonexempt charitable trusts filing Form 990 in lieu of <b>Form 1041&#151;</b></i>Check here 
        </label>
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.........</span>
        <span style="width:2mm;"></span><img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>    
        </span>        
        <span style="float:right">
        <input type="checkbox" class="styCkbox">
          <xsl:call-template name="PopulateCheckbox">
            <xsl:with-param name="TargetNode" select="$Form990Data/NECTFilingForm990" />
            <xsl:with-param name="BackupName">IRS990NECTFilingForm990</xsl:with-param>
          </xsl:call-template>
        </input>
        </span>
      </div>
    </div>


    <div class="styBB" style="width:187mm;">
      <div class="styLNLeftLtrBoxDD" style="height:4mm;"></div>
      <div class="styLNDesc" style="height:4mm;">
        and enter the amount of tax-exempt interest received or accrued during the tax year
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">....</span>
        <span style="width:2mm;"></span><img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      </div>
      <div class="styLNRightNumBox" style="height:4mm;border-bottom:none">92</div>
      <div class="styLNAmountBox" style="height:4mm;border-bottom:none"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NECTFilingForm990/@amountOfInterest" /></xsl:call-template></div>
    </div>

      <!--<div class="styBB" style="width:187mm;float:none;"></div>-->
      <div style="width:187mm;float:none;clear:both;padding-top:.5mm;" class="pageend">
        <div class="styGenericDiv" style="width:105mm;"></div>
        <div class="styGenericDiv" style="width:25mm;"></div>
        <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
      </div>
      
      <!-- header -->
      <div style="width:187mm;clear:both;padding-bottom:.5mm;float:none;clear:both;" class="styBB">
        <div style="width:90mm;" class="styGenericDiv">Form 990 (2005)</div>
        <div style="width:55mm;text-align:center;" class="styGenericDiv"></div>
        <div style = "float:right;" class="styGenericDiv">Page <span class="styBoldText" style="font-size:8pt;">8</span></div>
      </div>

    <!-- BEGIN Part VII Title -->
    <div class="styBB" style="width:187mm;float:none; border-top-width:0px;">
      <div class="styPartName" style="float:left;">Part VII</div>
      <div class="styPartDesc" style="float:left;width:161mm">Analysis of Income-Producing Activities <span class="styNormalText">(See the instructions.)</span></div>
    </div>
    <!-- END Part VII Title -->


    <!-- BEGIN Part VII Table -->
    <div style="width:187mm;float:none;">
      <table class="styTable" cellspacing="0">
        <thead class="styTableThead">
          <tr>
            <th class="styGenericDiv" scope="col" rowspan="2" colspan="3" style="width:77mm;font-size:7pt;text-align:left;padding-top:0.75mm" valign="top">
              <span class="styBoldText">Note:</span><span style="width:4px;"></span><span class="styItalicText" style="font-weight:normal">Enter gross amounts unless otherwise indicated.</span>
              <!--
              <br/>
              <br/>
              <br/>
              <span class="styLNLeftNumBox" style="font-size:7pt;">93</span>
              <span style="font-weight:normal;font-size:7pt;vertical-align:bottom">Program service revenue:</span>
              -->
            </th>
            <th class="styIRS990TableCellHeaderLB" scope="col" colspan="2" style="width:42mm;font-weight: normal">Unrelated business income</th>
            <th class="styTableCellHeader" scope="col" colspan="2" style="width:42mm;font-weight:normal">Excluded by section 512, 513, or 514</th>
            <th class="styTableCellHeader" scope="col" rowspan="2" style="width:27mm;border-right-width:0px"><span style="font-weight:bold;">(E)</span><span class="styNormalText"><br/> Related or<br/> exempt function<br/> income</span></th>
          </tr>
          <tr>
            <th class="styIRS990TableCellHeaderLB" scope="col" style="width:15mm;">(A)<br/><span class="styNormalText">Business code</span></th>
            <th class="styTableCellHeader" scope="col" style="width:27mm;">(B)<br/><span class="styNormalText">Amount</span></th>
            <th class="styTableCellHeader" scope="col" style="width:15mm;">(C)<br/><span class="styNormalText">Exclusion code</span></th>
            <th class="styTableCellHeader" scope="col" style="width:27mm;">(D)<br/><span class="styNormalText">Amount</span></th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">93</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Program service revenue:</td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;border-bottom-width:0px"><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-bottom-width:0px;"><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm;border-bottom-width:0px;text-align: left"><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-bottom-width:0px;"><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-bottom-width:0px;border-right-width:0px"><span class="styTableCellPad"></span></td>
          </tr>
          <xsl:for-each select="$Form990Data/ProgramServiceRevenuePartVII">
            <xsl:if test="($Print != $Separated) or (count($Form990Data/ProgramServiceRevenuePartVII) &lt;= 5) "> 
            <tr>
              <xsl:choose>
                <xsl:when test="position() = 1">
                  <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>a</td>
                </xsl:when>
                <xsl:when test="position() = 2">
                  <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>b</td>
                </xsl:when>
                <xsl:when test="position() = 3">
                  <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>c</td>
                </xsl:when>
                <xsl:when test="position() = 4">
                  <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>d</td>
                </xsl:when>
                <xsl:when test="position() = 5">
                  <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>e</td>
                </xsl:when>
                <xsl:otherwise>
                  <td class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:18px;"></span></td>
                </xsl:otherwise>
              </xsl:choose>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm;text-align: center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
            </xsl:if>
          </xsl:for-each>
          <xsl:if test="count($Form990Data/ProgramServiceRevenuePartVII) &lt; 1 or ((count($Form990Data/ProgramServiceRevenuePartVII) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top"><span style="width:18px;"></span>a</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/ProgramServiceRevenuePartVII"/>                      
                  </xsl:call-template>
              <span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/ProgramServiceRevenuePartVII) &lt; 2  or ((count($Form990Data/ProgramServiceRevenuePartVII) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>b</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/ProgramServiceRevenuePartVII) &lt; 3 or ((count($Form990Data/ProgramServiceRevenuePartVII) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>c</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/ProgramServiceRevenuePartVII) &lt; 4 or ((count($Form990Data/ProgramServiceRevenuePartVII) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>d</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/ProgramServiceRevenuePartVII) &lt; 5  or ((count($Form990Data/ProgramServiceRevenuePartVII) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>e</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>f</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Medicare/Medicaid payments
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.....</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/MedicareMedicaidPayments/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MedicareMedicaidPayments/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/MedicareMedicaidPayments/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MedicareMedicaidPayments/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MedicareMedicaidPayments/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>g</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Fees and contracts from government agencies</td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/FeesContractsFromGovtAgencies/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/FeesContractsFromGovtAgencies/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/FeesContractsFromGovtAgencies/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/FeesContractsFromGovtAgencies/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/FeesContractsFromGovtAgencies/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>

          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">94</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Membership dues and assessments
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">...</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/MembershipDuesAndAssessments/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MembershipDuesAndAssessments/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/MembershipDuesAndAssessments/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MembershipDuesAndAssessments/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/MembershipDuesAndAssessments/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">95</td>
            <td class="styLNDesc" style="width:70mm;">Interest on savings and temporary cash investments</td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/IntOnSavingsAndTempCashInvst/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/IntOnSavingsAndTempCashInvst/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/IntOnSavingsAndTempCashInvst/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/IntOnSavingsAndTempCashInvst/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/IntOnSavingsAndTempCashInvst/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">96</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Dividends and interest from securities
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">...</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/DividendsAndIntFromSecPartVII/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DividendsAndIntFromSecPartVII/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/DividendsAndIntFromSecPartVII/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DividendsAndIntFromSecPartVII/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/DividendsAndIntFromSecPartVII/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">97</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Net rental income or (loss) from real estate:</td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styShadingCell" style="width:15mm; border-width:1px"><span style="width:1px"/></td>
            <td class="styShadingCell" style="width:25mm; border-bottom-width:1px; border-top-width:1px; border-right-width:1px; border-left-width:0px;"><span style="width:1px"/></td>
            <td class="styShadingCell" style="width:15mm; border-bottom-width:1px; border-top-width:1px; border-right-width:1px; border-left-width:0px;"><span style="width:1px"/></td>
            <td class="styShadingCell" style="width:25mm; border-bottom-width:1px; border-top-width:1px; border-right-width:1px; border-left-width:0px;"><span style="width:1px"/></td>
            <td class="styShadingCell" style="width:25mm; border-bottom-width:1px; border-top-width:1px; border-left-width:0px;"><span style="width:1px"/></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>a</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">debt-financed property
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.......</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmReDebtFincdProp/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmReDebtFincdProp/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmReDebtFincdProp/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmReDebtFincdProp/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmReDebtFincdProp/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>b</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">non debt-financed property
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">......</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetRntlIncmReNotDebtFincdProp/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRntlIncmReNotDebtFincdProp/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetRntlIncmReNotDebtFincdProp/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRntlIncmReNotDebtFincdProp/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRntlIncmReNotDebtFincdProp/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">98</td>
            <td class="styLNDesc" style="width:70mm;">Net rental income or (loss) from personal property</td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmPersonalProperty/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmPersonalProperty/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmPersonalProperty/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmPersonalProperty/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetRentalIncmPersonalProperty/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">99</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Other investment income
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">......</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/OtherInvestmentIncomePartVII/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherInvestmentIncomePartVII/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/OtherInvestmentIncomePartVII/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherInvestmentIncomePartVII/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/OtherInvestmentIncomePartVII/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">100</td>
            <td class="styLNDesc" style="width:70mm;">
                Gain or (loss) from sales of assets other than inventory
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/GainSalesAssetsOthThanInvntry/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GainSalesAssetsOthThanInvntry/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/GainSalesAssetsOthThanInvntry/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GainSalesAssetsOthThanInvntry/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GainSalesAssetsOthThanInvntry/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">101</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Net income or (loss) from special events
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">..</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetIncomeLossFromSpecialEvents/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetIncomeLossFromSpecialEvents/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/NetIncomeLossFromSpecialEvents/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetIncomeLossFromSpecialEvents/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/NetIncomeLossFromSpecialEvents/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">102</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Gross profit or (loss) from sales of inventory</td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/GrossProfitLossSalesOfInvntry/BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossProfitLossSalesOfInvntry/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form990Data/GrossProfitLossSalesOfInvntry/ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossProfitLossSalesOfInvntry/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/GrossProfitLossSalesOfInvntry/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>

          <xsl:for-each select="$Form990Data/OtherRevenueDescribed">
            <xsl:if test="($Print != $Separated) or (count($Form990Data/OtherRevenueDescribed) &lt;= 5) "> 
            <tr>
              <xsl:choose>
                <xsl:when test="position() = 1">
                  <tr>
                    <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;">103</td>
                    <td class="styLNDesc" style="width:70mm;font-size:7pt;"><span style="width:25mm;float:left;">Other revenue: <span class="styBoldText">a</span> <span style="width:6px;"></span></span><span style="width:40mm;border-style:solid;border-color:black;border-top-width:0px;border-bottom-width:1px;border-left-width:0px;border-right-width:0px;float:right;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></span></td>
                    <td class="styGenericDiv" style="width:4mm;"></td>
                    <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall" style="width:15mm; text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
                  </tr>
                </xsl:when>
                <xsl:otherwise>
                  <tr>
                    <xsl:choose>
                      <xsl:when test="position() = 2">
                        <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>b</td>
                      </xsl:when>
                      <xsl:when test="position() = 3">
                        <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>c</td>
                      </xsl:when>
                      <xsl:when test="position() = 4">
                        <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>d</td>
                      </xsl:when>
                      <xsl:when test="position() = 5">
                        <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;vertical-align:top;"><span style="width:18px;"></span>e</td>
                      </xsl:when>                      
                      <xsl:otherwise>
                        <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span></td>                      
                      </xsl:otherwise>
                    </xsl:choose>
                    <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template><span style="width:1px;"></span></td>
                    <td class="styGenericDiv" style="width:4mm;"></td>
                    <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall" style="width:15mm;text-align:center"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
                  </tr>
                </xsl:otherwise>
              </xsl:choose>
            </tr>
          </xsl:if>
          </xsl:for-each>

          <xsl:if test="count($Form990Data/OtherRevenueDescribed) &lt; 1or ((count($Form990Data/OtherRevenueDescribed) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;">103</td>
              <td class="styLNDesc" style="width:70mm;font-size:7pt;">Other revenue: <span class="styBoldText">a</span> <span style="width:6px;"></span><span style="width:40mm;border-style:solid;border-color:black;border-top-width:0px;border-bottom-width:1px;border-left-width:0px;border-right-width:0px;">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/OtherRevenueDescribed"/>                      
                  </xsl:call-template>
</span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align: center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>

          <xsl:if test="count($Form990Data/OtherRevenueDescribed) &lt; 2 or ((count($Form990Data/OtherRevenueDescribed) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>b</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align: center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/OtherRevenueDescribed) &lt; 3 or ((count($Form990Data/OtherRevenueDescribed) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>c</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align: center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/OtherRevenueDescribed) &lt; 4 or ((count($Form990Data/OtherRevenueDescribed) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>d</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align: center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/OtherRevenueDescribed) &lt; 5 or ((count($Form990Data/OtherRevenueDescribed) &gt; 5) and ($Print = $Separated))">
            <tr>
              <td class="styLNLeftNumBox" style="height:4.5mm;font-size:7pt;"><span style="width:18px;"></span>e</td>
              <td class="styIRS990LNAmountBoxNLBSmall" style="width:70mm;font-size:7pt;text-align:left;"><span style="width:1px;"></span></td>
              <td class="styGenericDiv" style="width:4mm;"></td>
              <td class="styIRS990TableCellLB" style="width:15mm;text-align:center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="width:15mm; text-align: center"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall"><span class="styTableCellPad"></span></td>
              <td class="styTableCellSmall" style="border-right-width:0px"><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>

          <tr>
            <td class="styLNLeftNumBox" style="font-size:7pt;">104</td>
            <td class="styLNDesc" style="width:70mm;font-size:7pt;">Subtotal (add columns (B), (D), and (E))
              <!--Dotted Line-->
              <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">..</span>
            </td>
            <td class="styGenericDiv" style="width:4mm;"></td>
            <td class="styShadingCell" style="width:15mm;text-align:center;border-width:1px"><span style="width:1px" /></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SubtotalsPartVII/UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styShadingCell" style="width:15mm;border-width:1px"><span style="width:1px" /></td>
            <td class="styTableCellSmall"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SubtotalsPartVII/ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
            <td class="styTableCellSmall" style="border-right-width:0px"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/SubtotalsPartVII/RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
          </tr>
        </tbody>
      </table>
    </div>
    <!-- END Part VII Table -->

    <div class="styGenericDiv" style="width:187mm;clear:both;">
      <div class="styLNLeftNumBox">105</div>
      <div class="styLNDesc" style="width:146mm;">
        <span class="styBoldText">Total</span>
        (add line 104, columns (B), (D), and (E))
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">.................</span>
        <span style="width:2mm;"></span>
        <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
      </div>
      <div class="styIRS990LNAmountBoxNLB"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="$Form990Data/TotalPartVII" /></xsl:call-template><span style="width:1px;"></span></div>
    </div>

    <div class="styBB" style="width:187mm;clear:both;padding-bottom:1mm">
        <span class="styBoldText">Note:</span>
        <span class="styItalicText">
          Line 105 plus line 1d, Part I, should equal the amount on line 12, Part I.
        </span>
    </div>

    <!-- A manual page break here. Why? -->
    <!-- If this one is used, there will be no border printed above the title of Part VIII.
    <br class="pageEnd"></br>
         The one below prints an upper border -->
    <!-- Remove the line <div style="width:187mm;clear:both;border-style:solid; border-color: black;border-top-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-right-width: 0px;page-break-before:always;">
    </div>--> 

    <!-- BEGIN Part VIII Title -->
    <div class="styBB" style="width:187mm;clear:both;">
      <div class="styPartName" style="float:left;width:18mm">Part VIII</div>
      <div class="styPartDesc" style="float:left;width:164mm">
        Relationship of Activities to the Accomplishment of Exempt Purposes
        <span class="styNormalText">(See the instructions.)</span>
      </div>
      <div class="styGenericDiv" style="float:right">
         <!-- button display logic -->
          <xsl:call-template name="SetDynamicTableToggleButton">
            <xsl:with-param name="TargetNode" select="$Form990Data/RlnOfActyToAccomOfExemptPrps"/>
            <xsl:with-param name="containerHeight" select="4"/>
            <xsl:with-param name="containerID" select=" 'ROActn' "/>
          </xsl:call-template>
         <!-- end button display logic -->
      </div>
    </div>
    <!-- END Part VIII Title -->


    <!-- BEGIN Part VIII Table -->
    <div class="styTableContainerNBB" id="ROActn" style="height:25mm;">
      <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>
      <!-- end -->
      <table class="styTable" style="font-size:7pt;float:none;clear:both;" cellspacing="0">
        <thead class="styTableThead">
          <tr>
            <th class="styTableCellHeader" scope="col" style="width:12mm;">Line No. <br/><img src="{$ImagePath}/990_Bullet_Dn.gif" alt="DownBullet"/></th>
            <th class="styTableCellHeader" scope="col" style="width:174mm; font-weight:normal; text-align:left;border-right-width:0px;">
              Explain how each activity for which income is reported in column (E) of Part VII contributed importantly
              to the accomplishment<br/>of the organization's exempt purposes (other than by providing funds for such purposes).
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/RlnOfActyToAccomOfExemptPrps">
            <xsl:if test="($Print != $Separated) or (count($Form990Data/RlnOfActyToAccomOfExemptPrps) &lt;= 4) "> 
            <tr>
              <td class="styTableCellCtr" style="width:12mm;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="LineNumber" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styTableCellText" style="width:174mm;border-right-width:0px;" valign="top"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="RelationshipStatement" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
            </xsl:if>
          </xsl:for-each>
          <xsl:if test="count($Form990Data/RlnOfActyToAccomOfExemptPrps) &lt; 1 or ((count($Form990Data/RlnOfActyToAccomOfExemptPrps) &gt; 4) and ($Print = $Separated))">
            <tr>
              <td class="styTableCellText" style="width:8mm;"><span class="styTableCellPad"></span></td>
              <td class="styTableCellText" style="width:178mm;border-right-width:0px">                  
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/RlnOfActyToAccomOfExemptPrps"/>                      
                  </xsl:call-template>
                  <span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/RlnOfActyToAccomOfExemptPrps) &lt; 2 or ((count($Form990Data/RlnOfActyToAccomOfExemptPrps) &gt; 4) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVIIITableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/RlnOfActyToAccomOfExemptPrps) &lt; 3 or ((count($Form990Data/RlnOfActyToAccomOfExemptPrps) &gt; 4) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVIIITableFillerRow"></xsl:call-template>
          </xsl:if>
          <xsl:if test="count($Form990Data/RlnOfActyToAccomOfExemptPrps) &lt; 4 or ((count($Form990Data/RlnOfActyToAccomOfExemptPrps) &gt; 4) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartVIIITableFillerRow"></xsl:call-template>
          </xsl:if>
        </tbody>
      </table>
    </div>
    <!-- Set Initial Height of Above Table -->
    <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form990Data/RlnOfActyToAccomOfExemptPrps"/>
      <xsl:with-param name="containerHeight" select="4"/>
      <xsl:with-param name="containerID" select=" 'ROActn' "/>
    </xsl:call-template>
    <!-- End Set Initial Height of Above Table -->
    <!-- END Part VIII Table -->    

    <!-- BEGIN Part IX Title -->
    <div class="styBB" style="width:187mm;clear:both; border-top:1 solid black">
      <div class="styPartName" style="width:15mm;">Part IX</div>
      <div class="styPartDesc" style="width:167mm;">
        Information Regarding Taxable Subsidiaries and Disregarded Entities
        <span class="styNormalText">(See the instructions.)</span>
      </div>
      <div class="styGenericDiv" style="float:right">
         <!-- button display logic -->
          <xsl:call-template name="SetDynamicTableToggleButton">
          <xsl:with-param name="TargetNode" select="$Form990Data/TxblSbsdryDisregardedEntInfo"/>
          <xsl:with-param name="containerHeight" select="4"/>
          <xsl:with-param name="containerID" select=" 'IRTctn' "/>
          </xsl:call-template>
         <!-- end button display logic -->
      </div>
    </div>
    <!-- END Part IX Title -->


    <!-- BEGIN Part IX Table -->
    <div class="styTableContainerNBB" id="IRTctn" style="height:23mm;">
      <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>
      <!-- end -->
      <table class="styTable" cellspacing="0">
        <thead class="styTableThead">
          <tr>
            <th class="styTableCellHeader" scope="col" style="width:56mm;">
              (A)<br/><span class="styNormalText"> Name, address, and EIN of corporation, partnership, or disregarded entity</span>
            </th>
            <th class="styTableCellHeader" scope="col" style="width:25mm;">
              (B)<br/><span class="styNormalText">Percentage of ownership interest</span>
            </th>
            <th class="styTableCellHeader" scope="col" style="width:55mm;">
              (C)<br/><span class="styNormalText">Nature of activities</span>
            </th>
            <th class="styTableCellHeader" scope="col" style="width:25mm;">
              (D)<br/><span class="styNormalText">Total income</span>
            </th>
            <th class="styTableCellHeader" scope="col" style="width:25mm;border-right-width:0px;">
                (E)<br/><span class="styNormalText">End-of-year<br/> assets</span>
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/TxblSbsdryDisregardedEntInfo">
           <xsl:if test="($Print != $Separated) or (count($Form990Data/TxblSbsdryDisregardedEntInfo) &lt;= 4) "> 
            <tr>
              <td class="styTableCellText" style="width:56mm;padding-left:1mm;">
                <!--span style="width:4px"></span--><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Name/BusinessNameLine1" /></xsl:call-template>
                <xsl:if test="Name/BusinessNameLine2 != ''">
                  <br/><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Name/BusinessNameLine2" /></xsl:call-template>
                </xsl:if>
                <br/>
                <xsl:choose>
                  <xsl:when test="AddressUS">  
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/AddressLine1" /></xsl:call-template>
                    <xsl:if test="AddressUS/AddressLine2 != ''">
                    <br/><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/AddressLine2" /></xsl:call-template>
                    </xsl:if>
                    <br/><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/City" /></xsl:call-template>,<span style="width:4px"></span><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/State" /></xsl:call-template>
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/ZIPCode" /></xsl:call-template><br/>
                  </xsl:when>                  
                  <xsl:otherwise>
                    <div style="">
                      <xsl:call-template name="PopulateForeignAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressForeign" />
                      </xsl:call-template>
                    </div>
                  </xsl:otherwise>  
                </xsl:choose>
                <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" select="EIN" /></xsl:call-template>
              </td>
              <td class="styTableCell" style="width:25mm;">                
                <xsl:call-template name="PopulatePercent">
                  <xsl:with-param name="TargetNode" select="PercentageOfOwnershipInterest" />
                </xsl:call-template>
                <xsl:if test="normalize-space(PercentageOfOwnershipInterest) = ''">%</xsl:if>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styTableCellText" style="width:55mm;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="NatureOfActivities" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styTableCell" style="width:25mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="TotalIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styTableCell" style="width:25mm;border-right-width:0px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="EndOfYearAssets" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:if>
          </xsl:for-each>
          
          <xsl:if test="count($Form990Data/TxblSbsdryDisregardedEntInfo) &lt; 1 or ((count($Form990Data/TxblSbsdryDisregardedEntInfo) &gt; 4) and ($Print = $Separated)) ">
            <tr>
              <td class="styTableCellText" style="width:56mm;">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$Form990Data/TxblSbsdryDisregardedEntInfo"/>                      
                  </xsl:call-template>
              <span style="width:4px"></span></td>
              <td class="styTableCell" style="width:25mm;"><span style="width:4px">%</span></td>
              <td class="styTableCell" style="width:55mm;"><span style="width:4px"></span></td>
              <td class="styTableCell" style="width:25mm;"><span style="width:4px"></span></td>
              <td class="styTableCell" style="width:25mm;border-right-width:0px"><span style="width:4px"></span></td>
            </tr>
          </xsl:if>
          <xsl:if test="count($Form990Data/TxblSbsdryDisregardedEntInfo) &lt; 2 or ((count($Form990Data/TxblSbsdryDisregardedEntInfo) &gt; 4) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartIXTableFillerRow"/>
          </xsl:if>
          <xsl:if test="count($Form990Data/TxblSbsdryDisregardedEntInfo) &lt; 3 or ((count($Form990Data/TxblSbsdryDisregardedEntInfo) &gt; 4) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartIXTableFillerRow"/>
          </xsl:if>
          <xsl:if test="count($Form990Data/TxblSbsdryDisregardedEntInfo) &lt; 4 or ((count($Form990Data/TxblSbsdryDisregardedEntInfo) &gt; 4) and ($Print = $Separated))">
            <xsl:call-template name="IRS990PartIXTableFillerRow"/>
          </xsl:if>
          
        </tbody>
      </table>
    </div>
    <!-- Set Initial Height of Above Table -->
    <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form990Data/TxblSbsdryDisregardedEntInfo"/>
      <xsl:with-param name="containerHeight" select="4"/>
      <xsl:with-param name="containerID" select=" 'IRTctn' "/>
    </xsl:call-template>
    <!-- End Set Initial Height of Above Table -->
    <!-- END Part IX Table -->
    <!-- Putting manual page break as the form does not display play properly when the break occurs inside the signature section -->
    <!-- Please DO NOT remove this manual break unless a solution to this problem is found. -->
    <div style="page-break-before:always;">
    </div>

    <!-- BEGIN Part X Title -->
    <div class="styBB" style="width:187mm;clear:both;border-top-width:1px;">
      <div class="styPartName" style="width:15mm; height:4.5mm">Part X</div>
      <div class="styPartDesc" style="width:171mm;">
        Information Regarding Transfers Associated with Personal Benefit Contracts
        <span class="styNormalText">(See the instructions.)</span>
      </div>
    </div>
    <!-- END Part X Title -->

    <div style="width:187mm;clear:both;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">(a)</div>
      <div class="styLNDesc" style="width:158mm;height:4.5mm;padding-top:1mm">
        <span class="stySmallText">
          Did the organization, during the year, receive any funds, directly or indirectly, to pay premiums on a
          personal benefit contract?
        </span>
          <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">....</span>
      </div>
      <div class="styGenericDiv" style="width:10mm;">
        <span style="height:3.5mm;">
          <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedFundsToPayPremiums" />
          </xsl:call-template>
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateYesCheckbox">
              <xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedFundsToPayPremiums" />
              <xsl:with-param name="BackupName">IRS990OrgReceivedFundsToPayPremiumsYes</xsl:with-param>
            </xsl:call-template>
          </input>
        </span>
        <span class="styBoldText">
          <label>
            <xsl:call-template name="PopulateLabelYes">
              <xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedFundsToPayPremiums" />
              <xsl:with-param name="BackupName">IRS990OrgReceivedFundsToPayPremiumsYes</xsl:with-param>
            </xsl:call-template>
            Yes
          </label>
        </span>
      </div>
      <div class="styGenericDiv" style="width:10mm;">
        <span style="height:3.5mm;">
          <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedFundsToPayPremiums" />
          </xsl:call-template>
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateNoCheckbox">
              <xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedFundsToPayPremiums" />
              <xsl:with-param name="BackupName">IRS990OrgReceivedFundsToPayPremiumsNo</xsl:with-param>
            </xsl:call-template>
          </input>
        </span>
        <span class="styBoldText">
          <label>
            <xsl:call-template name="PopulateLabelNo">
              <xsl:with-param name="TargetNode" select="$Form990Data/OrgReceivedFundsToPayPremiums" />
              <xsl:with-param name="BackupName">IRS990OrgReceivedFundsToPayPremiumsNo</xsl:with-param>
            </xsl:call-template>
            No
          </label>
        </span>
      </div>
    </div>

    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4.5mm;">(b)</div>
      <div class="styLNDesc" style="width:158mm;height:4.5mm;">
        Did the organization, during the year, pay premiums, directly or indirectly, on a
        personal benefit contract?
        <!--Dotted Line-->
        <span style="letter-spacing:4mm; font-weight:bold; font-size:7pt; margin-left:2mm;">...</span>
      </div>
      <div class="styGenericDiv" style="width:10mm;">
        <span style="height:3.5mm;">
          <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form990Data/OrganizationPaidPremiums" />
          </xsl:call-template>
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateYesCheckbox">
              <xsl:with-param name="TargetNode" select="$Form990Data/OrganizationPaidPremiums" />
              <xsl:with-param name="BackupName">IRS990OrganizationPaidPremiumsYes</xsl:with-param>
            </xsl:call-template>
          </input>
        </span>
        <span class="styBoldText">
          <label>
            <xsl:call-template name="PopulateLabelYes">  
              <xsl:with-param name="TargetNode" select="$Form990Data/OrganizationPaidPremiums" />
              <xsl:with-param name="BackupName">IRS990OrganizationPaidPremiumsYes</xsl:with-param>
            </xsl:call-template>
            Yes
          </label>
        </span>
      </div>
      <div class="styGenericDiv" style="width:10mm;">
        <span style="height:3.5mm;">
          <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form990Data/OrganizationPaidPremiums" />
          </xsl:call-template>
          <input type="checkbox" class="styCkbox" name="Checkbox">
            <xsl:call-template name="PopulateNoCheckbox">
              <xsl:with-param name="TargetNode" select="$Form990Data/OrganizationPaidPremiums" />
              <xsl:with-param name="BackupName">IRS990OrganizationPaidPremiumsNo</xsl:with-param>
            </xsl:call-template>
          </input>
        </span>
        <span class="styBoldText">
          <label>
            <xsl:call-template name="PopulateLabelNo">  
              <xsl:with-param name="TargetNode" select="$Form990Data/OrganizationPaidPremiums" />
              <xsl:with-param name="BackupName">IRS990OrganizationPaidPremiumsNo</xsl:with-param>
            </xsl:call-template>
            No
          </label>
        </span>
      </div>
    </div>
  <div style="clear:both;">
    <div class="styBB" style="width:187mm;">
      <div class="styLNLeftNumBox" style="width:12mm;height:4.5mm;">NOTE:</div>
      <div class="styLNDesc" style="width:174mm;height:4.5mm;">
        <span class="styItalicText">
          If "Yes" to <span class="styBoldText">(b),</span> file Form 8870 <span class="styBoldText">and</span>
          Form 4720 (see instructions).
        </span>
      </div>
    </div>
  </div>
<!-- BEGIN Signature Section -->

<!-- Implementing the signature section in table -->
<table border="0" cellspacing="0" cellpadding="0" style="width:187mm;font-size:6pt;clear:both;">
  <tr>
    <td rowspan="5" style="width:15mm;font-size: 8pt;font-weight:bold;border-right:1 solid black;border-bottom:1 solid black;">Please Sign Here</td>
    <td colspan="3" style="padding-left:1mm;padding-bottom:1mm;">Under penalties of perjury, I declare that I have examined this return, including accompanying schedules and statements, and to the best of my knowledge
and belief, it is true, correct, and complete. Declaration of preparer (other than officer) is based on all information of which preparer has any knowledge. </td>
  </tr>
  <tr>
    <td rowspan="2" style="padding-left:1mm;"><img style="width:2mm;height:8mm;" src="{$ImagePath}/990_Bullet_Jumbo.gif" alt="JumboBullet"/></td>
    <td style="width:103mm;border-bottom:1 solid black;vertical-align:bottom;border-right:1 solid black;">
        <xsl:call-template name="PopulateReturnHeaderOfficer">
          <xsl:with-param name="TargetNode">TaxpayerPIN</xsl:with-param> 
        </xsl:call-template>
        <span style="width:1px;"></span>
     </td>
    <td style="width:53mm;border-bottom:1 solid black;vertical-align:bottom;padding-left:1mm;">
      <xsl:call-template name="PopulateReturnHeaderOfficer">
        <xsl:with-param name="TargetNode">DateSigned</xsl:with-param>
      </xsl:call-template>
    </td>
  </tr>
  <tr>
    <td style="vertical-align:top;">Signature of officer</td>
    <td style="vertical-align:top;padding-left:1mm;">Date</td>
  </tr>
  <tr>
    <td rowspan="2" style="border-bottom:1 solid black;padding-left:1mm;padding-top:1mm;"><img style="width:2mm;height:8mm;" src="{$ImagePath}/990_Bullet_Jumbo.gif" alt="JumboBullet"/></td>
    <td style="border-bottom:1 solid black;vertical-align:bottom;" colspan="2">
        <xsl:call-template name="PopulateReturnHeaderOfficer">
          <xsl:with-param name="TargetNode">Name</xsl:with-param>
        </xsl:call-template>
        <span style="width:4px"></span>
        <xsl:call-template name="PopulateReturnHeaderOfficer">
          <xsl:with-param name="TargetNode">Title</xsl:with-param>
        </xsl:call-template>
    </td>
  </tr>
  <tr>
    <td style="vertical-align:top;border-bottom:1 solid black;" colspan="2">Type or print name and title.</td>
  </tr>
</table>
   <!-- End Signature Section -->




    <!--div style="page-break-before:always;">
    </div-->


          <!-- BEGIN PREPARER SIGNATURE SECTION -->        
        <!-- Implementing the preparer section in table -->
<table border="0" cellspacing="0" cellpadding="0" style="width:187mm;font-size:6pt;border-color:black;clear:both;">
  <tr>
    <td rowspan="3" style="width:15mm;font-size:10pt;font-weight:bold;font-family:'arial narrow';border-right:1 solid black;vertical-align:top;padding-top:5mm;border-bottom:1 solid black;">Paid Preparer's Use Only</td>
    <td style="width:75mm;border-bottom:1 solid black;border-right:1 solid black;">
      <span style="width:13mm;padding-left:1mm;" class="styGenericDiv">Preparer's <br />signature</span> 
      <span class="styGenericDiv" style="border:0 solid red;"><img src="{$ImagePath}/990_Bullet_Jumbo.gif" align="middle" alt="Big Right Arrow" border="0"/></span>
      <span class="styGenericDiv" style="border:0 solid red;padding-left:2mm;padding-top:2mm;">
        <xsl:call-template name="PopulateReturnHeaderPreparer">
          <xsl:with-param name="TargetNode">Name</xsl:with-param>
        </xsl:call-template>
      </span>

    </td>
    <td style="width:30mm;border-right:1 solid black;border-bottom:1 solid black;padding-left:1mm;vertical-align:top;padding-top:1mm;">
        Date <br />
        <xsl:call-template name="PopulateReturnHeaderPreparer">
          <xsl:with-param name="TargetNode">DatePrepared</xsl:with-param>
        </xsl:call-template>
    </td>
    <td style="width:20mm;border-right:1 solid black;border-bottom:1 solid black;padding-left:1mm;">                
        <nobr>
          <label for="dummyid1">
            <xsl:call-template name="PopulateReturnHeaderPreparer">
              <xsl:with-param name="TargetNode">SelfEmployedLabel</xsl:with-param>
              <xsl:with-param name="BackupName">PreparerSelfEmployed</xsl:with-param>
            </xsl:call-template>Check if <br/> self-<br />empolyed
          </label>            
        </nobr>
        <span style="width:2px;"></span>
        <img src="{$ImagePath}/990_Bullet_Sm.gif" width="4" height="7" alt="right pointing bullet image" border="0"/><span style="width:5px;"></span>         
        <input class="styCkbox" type="checkbox"  id="dummyid1" style="width:4mm;">
          <xsl:call-template name="PopulateReturnHeaderPreparer">
            <xsl:with-param name="TargetNode">SelfEmployedCheckbox</xsl:with-param>
            <xsl:with-param name="BackupName">PreparerSelfEmployed</xsl:with-param>
          </xsl:call-template>
        </input>
     </td>
    <td style="width:50mm;border-bottom:1 solid black;padding-left:1mm;vertical-align:top;padding-top:1mm;">Preparer’s SSN or PTIN (See Gen. Inst. W)
        <br />
        <xsl:call-template name="PopulateReturnHeaderPreparer">
          <xsl:with-param name="TargetNode">SSN</xsl:with-param>
        </xsl:call-template>
        <xsl:call-template name="PopulateReturnHeaderPreparer">
          <xsl:with-param name="TargetNode">PTIN</xsl:with-param>
        </xsl:call-template>
    </td>
  </tr>
  <tr>
    <td rowspan="2" colspan="3" style="border-bottom:1 solid black;padding-left:1mm;border-right:1 solid black;">
        <span class="styGenericDiv" style="padding-right:.5mm;">Firm’s name (or yours<br />
if self-employed),<br />
address, and ZIP + 4</span>
        <span class="styGenericDiv" style="padding-left:1mm;">
          <img src="{$ImagePath}/990_Bullet_Jumbo.gif" align="middle" alt="Big Right Arrow" border="0"/>
        </span> 
       <span style="padding-left:1mm;" class="styGenericDiv">
          <div style="border-bottom:1 solid black;width:90mm;" >
            <xsl:call-template name="PopulateReturnHeaderPreparerFirm">
              <xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param>
            </xsl:call-template>
            <br />
            <xsl:call-template name="PopulateReturnHeaderPreparerFirm">
              <xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param>   
            </xsl:call-template>
          </div>
         <div style="border-top:0 solid black;">
            <xsl:call-template name="PopulateReturnHeaderPreparerFirm">
              <xsl:with-param name="TargetNode">AddressLine1</xsl:with-param>
            </xsl:call-template>
            <br />
            <xsl:call-template name="PopulateReturnHeaderPreparerFirm">
              <xsl:with-param name="TargetNode">AddressLine2</xsl:with-param>
            </xsl:call-template>
            <br />
            <xsl:call-template name="PopulateReturnHeaderPreparerFirm">
              <xsl:with-param name="TargetNode">CityStateInfo</xsl:with-param>
            </xsl:call-template>
            <br />
            <xsl:call-template name="PopulateReturnHeaderPreparerFirm">
              <xsl:with-param name="TargetNode">Country</xsl:with-param>
            </xsl:call-template>
          </div>
        </span>
        
        
            
    </td>
    <td style="border-bottom:1 solid black;padding-left:1mm;">EIN
<span style="width:2px;"></span>
        <img src="{$ImagePath}/990_Bullet_Sm.gif" width="4" height="7" alt="right pointing bullet image" border="0"/><span style="width:5px;"></span>  
        <xsl:call-template name="PopulateReturnHeaderPreparerFirm">
          <xsl:with-param name="TargetNode">EIN</xsl:with-param>
        </xsl:call-template>
     </td>
  </tr>
  <tr>
    <td style="border-bottom:1 solid black;padding-left:1mm;"> Phone no. 
<span style="width:2px;"></span>
        <img src="{$ImagePath}/990_Bullet_Sm.gif" width="4" height="7" alt="right pointing bullet image" border="0"/><span style="width:5px;"></span>          
        <xsl:call-template name="PopulateReturnHeaderPreparer">
          <xsl:with-param name="TargetNode">Phone</xsl:with-param>
        </xsl:call-template>
    </td>
  </tr>
</table>

    
    
  <div style="width:187mm;float:none;clear:both;padding-top:1mm;">
    <div class="styGenericDiv" style="width:105mm;"><span class="styBoldText"></span></div>
    <div class="styGenericDiv" style="width:25mm;"></div>
    <div class="styGenericDiv" style="float:right;">Form <span class="styBoldText">990</span> (2005)</div>
  </div>
    
  

  <br class="pageEnd"/>

  <!-- BEGIN Left Over Table -->  
    <!-- Additonal Data Title Bar and Button -->
    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" type="button" TabIndex="1" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>
    <!-- Additional Data Table -->
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form990Data" />
      </xsl:call-template>
    </table>
  <!-- END Left Over Table -->  
<!-- Separated data tables -->
<!-- Begin Part II line 43 -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/OtherExpenses) &gt; 7)">
      <span class="styRepeatingDataTitle">Form 990, Part II, Line 43 -  Other expenses not covered above (itemize):</span>
    <table class="styDepTbl" style="font-size:7pt;width:187mm;" cellspacing="0">
      <thead>
        <tr scope="col" class="styDepTblHdr">
          <th scope="col" colspan="2" class="styDepTblCell">
            <span class="styItalicText">
              Do not include amounts reported on line <br/>
              6b, 8b, 9b, 10b, or 16 of Part I.
              </span>
          </th>
          <th class="styDepTblCell">
              <span style="width:1px;"></span>
          </th>
          <th scope="col" class="styDepTblCell">
            (A) Total
          </th>
          <th scope="col" class="styDepTblCell">
            (B)  Program<br/>services
          </th>
          <th scope="col" class="styDepTblCell">
            (C)  Management<br/>and general
          </th>
          <th scope="col" class="styDepTblCell">
            (D)  Fundraising
          </th>
        </tr>
      </thead>
      <tfoot></tfoot>
  <tbody valign="top">
    <xsl:for-each select="$Form990Data/OtherExpenses">
    <tr>
               <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
            <td class="styDepTblCell" style="width:3mm;height:4.5mm;valign:top;border-right-width:0px;"><span class="styBoldText"><xsl:number value="position()" format="a" /></span></td>
            <td class="styDepTblCell" style="width:63mm;height:4.5mm;text-align:left;valign:top;border-left-width:0px;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template></td>
            <td class="styDepTblCell" style="width:6mm;height:4.5mm;valign:top;font-weight:bold;">43<xsl:number value="position()" format="a" /></td>
            <td class="styDepTblCell" style="height:4.5mm;padding-right:0.75mm;valign:top;width:28mm;text-align:right;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Total" /></xsl:call-template></td>
            <td class="styDepTblCell" style="height:4.5mm;padding-right:0.75mm;valign:top;text-align:right;font-size:6pt;width:29mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServices" /></xsl:call-template></td>
            <td class="styDepTblCell" style="height:4.5mm;padding-right:0.75mm;valign:top;width:28mm;text-align:right;font-size:6pt;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ManagementAndGeneral" /></xsl:call-template></td>
            <td class="styDepTblCell" style="height:4.5mm;padding-right:0.75mm;valign:top;text-align:right;font-size:6pt;width:29mm;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Fundraising" /></xsl:call-template></td>
    </tr>
    </xsl:for-each>    
</tbody>
</table>
<br />
</xsl:if>

  <!-- Part III table -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/ProgramServiceAccomplishments) &gt; 4)">
      <span class="styRepeatingDataTitle">Form 990, Part III -  Program Service Accomplishments:</span>
        <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" colspan="2" style="width:154.5mm;height:20mm;text-align:left;vertical-align:middle;">
                  All organizations must describe their exempt purpose achievements in a clear and concise manner. State the number
                  of clients served, publications issued, etc. Discuss achievements that are not measurable. (Section 501(c)(3) and (4)
                  organizations and 4947(a)(1) nonexempt charitable trusts must also enter the amount of grants and allocations to others.)
            </th>
            <th class="styDepTblCell" scope="col" style="width:32mm;height:20mm; border-right-width:0px">
              Program Service Expenses<br/>
                  (Required for 501(c)(3) and (4) orgs., and 4947(a)(1) trusts; but optional for others.)
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/ProgramServiceAccomplishments">
            <tr>
               <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="width:5mm;text-align:center;border-right-width:0px;" valign="top"><span class="styBoldText"><xsl:number value="position()" format="a" /></span></td>
              <td class="styDepTblCell" style="width:149.5mm;text-align:left;border-left-width:0px;" valign="top">
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="DescriptionProgramServiceAccom" /></xsl:call-template><span class="styTableCellPad"></span><br/>
                <span style="margin-top: 7mm;width:65mm;">(Grants and allocations $ <xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="GrantsAndAllocations" /></xsl:call-template>) </span>
                <span>If this amount includes foreign grants, check here <img src="{$ImagePath}/990_Bullet_Md.gif" alt="MediumBullet"/>
                <span style="width:2mm;"></span>
                  <input type="checkbox" class="styCkbox" name="Checkbox">
                    <xsl:call-template name="PopulateCheckbox">
                      <xsl:with-param name="TargetNode" select="GrantsAndAllocations/@includesForeignGrants" />
                      <xsl:with-param name="BackupName">IRS990ForeignGrants</xsl:with-param>
                    </xsl:call-template>
                  </input>
                  <label>
                    <xsl:call-template name="PopulateLabel">
                      <xsl:with-param name="TargetNode" select="GrantsAndAllocations/@includesForeignGrants" />
                      <xsl:with-param name="BackupName">IRS990ForeignGrants</xsl:with-param>
                    </xsl:call-template>
                  </label>                                   
                </span>              </td>
              <td class="styDepTblCell" style="border-right-width:0px;text-align:right;padding-right:0px;" valign="bottom"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ProgramServiceExpenses" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
</tbody>
</table>
<br />
</xsl:if>
   <!-- BEGIN Part V-A Table -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/OfcrDirTrusteesOrKeyEmployee) &gt; 10)">
      <span class="styRepeatingDataTitle">Form 990, Part V-A -  Current Officers, Directors, Trustees, and Key Employees:</span>
      <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead" style="font-size:7pt;">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" style="width:55mm;">(A) Name and address</th>
            <th class="styDepTblCell" scope="col" style="width:32mm;">(B) Title and average hours per week devoted to position</th>
            <th class="styDepTblCell" scope="col" style="width:32mm;">(C) Compensation<br/> (If not paid, enter -0-.)</th>
            <th class="styDepTblCell" scope="col" style="width:32mm;">(D) Contributions to employee benefit plans &amp; deferred compensation plans</th>
            <th class="styDepTblCell" scope="col" style="width:32mm; border-right-width:0px" >(E) Expense<br/> account and other<br/> allowances</th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/OfcrDirTrusteesOrKeyEmployee">
          <!-- Adding the separator section -->
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="width:55mm;text-align:left;">
                <xsl:choose>
                  <xsl:when test="PersonName">
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="PersonName" />    </xsl:call-template>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine1" />    </xsl:call-template>
                    <xsl:if test="BusinessName/BusinessNameLine2">
                      <br />
                      <xsl:call-template name="PopulateText">
                        <xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine2" />    
                      </xsl:call-template>
                    </xsl:if>
                  </xsl:otherwise>
                </xsl:choose>
                                <span style="width:2px;"></span>
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="PersonName"/>
                </xsl:call-template>  
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="BusinessName"/>
                </xsl:call-template>  


                <br/>            
                <xsl:choose>
                  <xsl:when test="AddressUS">
                    <div style="">
                      <xsl:call-template name="PopulateUSAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressUS" />
                      </xsl:call-template>
                    </div>
                  </xsl:when>
                  <xsl:otherwise>
                    <div style="">
                      <xsl:call-template name="PopulateForeignAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressForeign" />
                      </xsl:call-template>
                    </div>
                  </xsl:otherwise>  
                </xsl:choose>
              </td>
              <td class="styDepTblCell" style="width:36mm;text-align:left;">
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Title" /></xsl:call-template><br/>
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AvgHoursPerWkDevotedToPosition" /></xsl:call-template><span style="width:4px"></span>              
              </td>
              <td class="styDepTblCell" style="text-align:right;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Compensation" /></xsl:call-template><span style="width:1px;"></span></td>
              <td class="styDepTblCell" style="text-align:right;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ContriToEmplBenefitPlansEtc" /></xsl:call-template><span style="width:1px;"></span></td>
              <td class="styDepTblCell" style="border-right-width:0px;text-align:right;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExpenseAccountOtherAllowances" /></xsl:call-template><span style="width:1px;"></span></td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
    <br />
    </xsl:if>

   <!-- BEGIN Part V-B Table -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/FrmrOfcrDirTrstOrKeyEmployee) &gt; 10)">
      <span class="styRepeatingDataTitle">Form 990, Part V-B -  Former Officers, Directors, Trustees, and Key Employees That Received Compensation or Other Benefits:</span>
      <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead" style="font-size:7pt;">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" style="width:55mm;">(A) Name and address</th>
            <th class="styDepTblCell" scope="col" style="width:32mm;">(B) Loans and Advances</th>
            <th class="styDepTblCell" scope="col" style="width:32mm;">(C) Compensation</th>
            <th class="styDepTblCell" scope="col" style="width:32mm;">(D) Contributions to employee benefit plans and deferred compensation plans</th>
            <th class="styDepTblCell" scope="col" style="width:32mm; border-right-width:0px" >Expense account and other allowances</th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/FrmrOfcrDirTrstOrKeyEmployee">
          <!-- Adding the separator section -->
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="width:55mm;text-align:left;">
                <xsl:choose>
                  <xsl:when test="PersonName">
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="PersonName" />    </xsl:call-template>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine1" />    </xsl:call-template>
                    <xsl:if test="BusinessName/BusinessNameLine2">
                      <br />
                      <xsl:call-template name="PopulateText">
                        <xsl:with-param name="TargetNode" select="BusinessName/BusinessNameLine2" />    
                      </xsl:call-template>
                    </xsl:if>
                  </xsl:otherwise>
                </xsl:choose>
                 <span style="width:2px;"></span>
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="PersonName"/>
                </xsl:call-template>  
                <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="BusinessName"/>
                </xsl:call-template>  


                <br/>            
                <xsl:choose>
                  <xsl:when test="AddressUS">
                    <div style="">
                      <xsl:call-template name="PopulateUSAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressUS" />
                      </xsl:call-template>
                    </div>
                  </xsl:when>
                  <xsl:otherwise>
                    <div style="">
                      <xsl:call-template name="PopulateForeignAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressForeign" />
                      </xsl:call-template>
                    </div>
                  </xsl:otherwise>  
                </xsl:choose>
              </td>
              <td class="styDepTblCell" style="text-align:right;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="LoansAndAdvances" /></xsl:call-template><span style="width:1px;"></span></td>
              <td class="styDepTblCell" style="text-align:right;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="Compensation" /></xsl:call-template><span style="width:1px;"></span></td>
              <td class="styDepTblCell" style="text-align:right;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ContriToEmplBenefitPlansEtc" /></xsl:call-template><span style="width:1px;"></span></td>
              <td class="styDepTblCell" style="border-right-width:0px;text-align:right;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExpenseAccountOtherAllowances" /></xsl:call-template><span style="width:1px;"></span></td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
    <br />
    </xsl:if>


    <!-- Begin Part VI Line 80b -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/NameOfRelatedOrganization) &gt; 1)">
      <span class="styRepeatingDataTitle">Form 990, Part VI, Line 80b -  If "Yes", enter the name of the organization and whether it is exempt or nonexempt:</span>
          <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" style="width:101mm;">Name of the Organization</th>
            <th class="styDepTblCell" scope="col" style="width:43mm;">Exempt</th>
            <th class="styDepTblCell" scope="col" style="width:43mm;">Nonexempt</th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/NameOfRelatedOrganization">
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
                    <td class="styDepTblCell" style="width:101mm;text-align:left;">
                      <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessNameLine1" /></xsl:call-template>
                      <xsl:if test="BusinessNameLine2"><br />
                      <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessNameLine2" /></xsl:call-template>
                      </xsl:if><span class="styTableCellPad"></span>
                  </td>
                    <td class="styDepTblCell" style="width:43mm;vertical-align:bottom;"><xsl:call-template name="PopulateYesBox"><xsl:with-param name="TargetNode" select="@exempt" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styDepTblCell" style="width:43mm;vertical-align:bottom;"><xsl:call-template name="PopulateNoBox"><xsl:with-param name="TargetNode" select="@exempt" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
      </tbody>
    </table>
    <br />
</xsl:if>

    <!-- Begin Part VI Line 91b -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/ForeignFinancialAccountCountry) &gt; 1)">
      <span class="styRepeatingDataTitle">Form 990, Part VI, Line 91b -  If “Yes,” enter the name of the foreign country:</span>
          <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col">Country</th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/ForeignFinancialAccountCountry">
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
                    <td class="styDepTblCell" style="text-align:left;padding-left:80mm;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="." /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
      </tbody>
    </table>
    <br />
</xsl:if>

    <!-- Begin Part VI Line 91c -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/ForeignOfficeCountry) &gt; 1)">
      <span class="styRepeatingDataTitle">Form 990, Part VI, Line 91c -  If “Yes,” enter the name of the foreign country:</span>
          <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col">Country</th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/ForeignOfficeCountry">
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
                    <td class="styDepTblCell" style="text-align:left;padding-left:80mm;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="." /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
      </tbody>
    </table>
    <br />
</xsl:if>

    <xsl:if test="($Print = $Separated) and (count($Form990Data/StatesWhereCopyOfReturnIsFiled) &gt; 18)">
      <span class="styRepeatingDataTitle">Form 990, Part VI, Line 90a - List the states with which a copy of this return is filed:</span>
      <table class="styDepTbl"  style="font-size: 7pt">
        <thead class="styTableThead" />
        <tbody>
          <tr class="styDepTblRow1">
                <td class="styDepTblCell" style="text-align: left; width:80mm"> List the states with which a copy of this return is filed:</td>
                <td class="styDepTblCell" style="text-align: left; width: 104mm">
                  <xsl:for-each select="$Form990Data/StatesWhereCopyOfReturnIsFiled">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="."/>
                    </xsl:call-template>
                    <xsl:if test="position() != last()">,
                    </xsl:if>
                  </xsl:for-each>
                </td>
              </tr>
            </tbody>
          </table>
          <br />
        </xsl:if>
    
  
    
    <!-- Begin Part VII Line 93 -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/ProgramServiceRevenuePartVII) &gt; 5)">
      <span class="styRepeatingDataTitle">Form 990, Part VII, Line 93 -  Program service revenue:</span>
          <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" rowspan="2" colspan="3"  valign="top" style="text-align:left;vertical-align:middle;">
              <span class="styBoldText">Note:</span><span style="width:4px;"></span><span class="styItalicText" style="">Enter gross amounts unless otherwise indicated.</span>
            </th>
            <th class="styDepTblCell" scope="col" colspan="2" style="width:42mm;">Unrelated business income</th>
            <th class="styDepTblCell" scope="col" colspan="2" style="width:42mm;">Excluded by section 512, 513, or 514</th>
            <th class="styDepTblCell" scope="col" rowspan="2" style="width:27mm;border-right-width:0px;vertical-align:middle;">(E)<br/> Related or<br/> exempt function<br/> income</th>
          </tr>
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" style="width:15mm;">(A)<br/>Business code</th>
            <th class="styDepTblCell" scope="col" style="width:27mm;">(B)<br/>Amount</th>
            <th class="styDepTblCell" scope="col" style="width:15mm;">(C)<br/>Exclusion code</th>
            <th class="styDepTblCell" scope="col" style="width:27mm;">(D)<br/>Amount</th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/ProgramServiceRevenuePartVII">
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
                  <td class="styDepTblCell" style="height:4.5mm;border-right-width:0px;width:5mm;font-weight:bold;"><xsl:number value="position()" format="a"></xsl:number></td>
              <td class="styDepTblCell" style="width:74mm;text-align:left;;border-left-width:0px;border-right-width:0px;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template><span style="width:1px;"></span></td>
              <td class="styDepTblCell" style="width:2mm;border-left-width:0px;"></td>
              <td class="styDepTblCell" style="width:15mm;text-align:center;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styDepTblCell" style="width:15mm;text-align:center;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styDepTblCell" style="border-right-width:0px;width:26mm;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
      </tbody>
    </table>
    <br />
</xsl:if>

    <!-- Begin Part VII Line 103 -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/OtherRevenueDescribed) &gt; 5)">
      <span class="styRepeatingDataTitle">Form 990, Part VII, Line 103 -  Other revenue:</span>
          <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" rowspan="2" colspan="3"  valign="top" style="text-align:left;vertical-align:middle;">
              <span class="styBoldText">Note:</span><span style="width:4px;"></span><span class="styItalicText" style="">Enter gross amounts unless otherwise indicated.</span>
            </th>
            <th class="styDepTblCell" scope="col" colspan="2" style="width:42mm;">Unrelated business income</th>
            <th class="styDepTblCell" scope="col" colspan="2" style="width:42mm;">Excluded by section 512, 513, or 514</th>
            <th class="styDepTblCell" scope="col" rowspan="2" style="width:27mm;border-right-width:0px;vertical-align:middle;">(E)<br/> Related or<br/> exempt function<br/> income</th>
          </tr>
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" style="width:15mm;">(A)<br/>Business code</th>
            <th class="styDepTblCell" scope="col" style="width:27mm;">(B)<br/>Amount</th>
            <th class="styDepTblCell" scope="col" style="width:15mm;">(C)<br/>Exclusion code</th>
            <th class="styDepTblCell" scope="col" style="width:27mm;">(D)<br/>Amount</th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/OtherRevenueDescribed">
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
             <td class="styDepTblCell" style="height:4.5mm;border-right-width:0px;width:5mm;font-weight:bold;"> <xsl:number value="position()" format="a" /></td>
                    <td class="styDepTblCell" style="width:72mm;font-size:7pt;text-align:left;border-left-width:0px;border-right-width:0px;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Description" /></xsl:call-template><span style="width:1px;"></span></td>
                    <td class="styDepTblCell" style="width:2mm;border-left-width:0px;"></td>
                    <td class="styDepTblCell" style="width:15mm;text-align:center;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="BusinessCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="UnrelatedBusinessIncomeAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styDepTblCell" style="width:15mm;text-align:center;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="ExclusionCode" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="ExclusionAmount" /></xsl:call-template><span class="styTableCellPad"></span></td>
                    <td class="styDepTblCell" style="border-right-width:0px;width:26mm;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="RelatedOrExemptFunctionIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
      </tbody>
    </table>
    <br />
</xsl:if>




    <!-- Begin Part VIII table -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/RlnOfActyToAccomOfExemptPrps) &gt; 4)">
      <span class="styRepeatingDataTitle">Form 990, Part VIII -  Relationship of Activities to the Accomplishment of Exempt Purposes:</span>
      <table class="styDepTbl" style="font-size:7pt;float:none;clear:both;" cellspacing="0">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" style="width:12mm;">Line No. <br/><img src="{$ImagePath}/990_Bullet_Dn.gif" alt="DownBullet"/></th>
            <th class="styDepTblCell" scope="col" style="width:174mm;text-align:left;border-right-width:0px;">
              Explain how each activity for which income is reported in column (E) of Part VII contributed importantly
              to the accomplishment of the organization's exempt purposes (other than by providing funds for such purposes).
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/RlnOfActyToAccomOfExemptPrps">
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="width:12mm;text-align:center;vertical-align:bottom;vertical-align:top;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="LineNumber" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styDepTblCell" style="width:174mm;border-right-width:0px;text-align:left;vertical-align:bottom;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="RelationshipStatement" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
        <br />
  </xsl:if>
    <!-- Begin Part IX -->
    <xsl:if test="($Print = $Separated) and (count($Form990Data/TxblSbsdryDisregardedEntInfo) &gt; 4)">
      <span class="styRepeatingDataTitle">Form 990, Part IX -  Information Regarding Taxable Subsidiaries and Disregarded Entities:</span>
    <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" scope="col" style="width:56mm;">
              (A)<br/> Name, address, and EIN of corporation, partnership, or disregarded entity
            </th>
            <th class="styDepTblCell" scope="col" style="width:27mm;">
              (B)<br/>Percentage of ownership interest
            </th>
            <th class="styDepTblCell" scope="col" style="width:53mm;">
              (C)<br/>Nature of activities
            </th>
            <th class="styDepTblCell" scope="col" style="width:25mm;">
              (D)<br/>Total income
            </th>
            <th class="styDepTblCell" scope="col" style="width:25mm;border-right-width:0px;">
                (E)<br/>End-of-year<br/> assets
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:for-each select="$Form990Data/TxblSbsdryDisregardedEntInfo">
            <tr>
              <xsl:attribute name="class">
                <xsl:choose>
                   <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                   <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="width:56mm;text-align:left;padding-left:1mm;">
                <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Name/BusinessNameLine1" /></xsl:call-template>
                <xsl:if test="Name/BusinessNameLine2 != ''">
                  <br/><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="Name/BusinessNameLine2" /></xsl:call-template>
                </xsl:if>
                <br/>
                <xsl:choose>
                  <xsl:when test="AddressUS">  
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/AddressLine1" /></xsl:call-template>
                    <xsl:if test="AddressUS/AddressLine2 != ''">
                    <br/><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/AddressLine2" /></xsl:call-template>
                    </xsl:if>
                    <br/><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/City" /></xsl:call-template>,<span style="width:4px"></span><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/State" /></xsl:call-template>
                    <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="AddressUS/ZIPCode" /></xsl:call-template><br/>
                  </xsl:when>                  
                  <xsl:otherwise>
                    <div style="">
                      <xsl:call-template name="PopulateForeignAddressTemplate">
                        <xsl:with-param name="TargetNode" select="AddressForeign" />
                      </xsl:call-template>
                    </div>
                  </xsl:otherwise>  
                </xsl:choose>
                <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" select="EIN" /></xsl:call-template>
              </td>
              <td class="styDepTblCell" style="width:27mm;text-align:right;font-size:6pt;">                
                <xsl:call-template name="PopulatePercent">
                  <xsl:with-param name="TargetNode" select="PercentageOfOwnershipInterest" />
                </xsl:call-template>
                <xsl:if test="normalize-space(PercentageOfOwnershipInterest) = ''">%</xsl:if>
                <span class="styTableCellPad"></span>
              </td>
              <td class="styDepTblCell" style="width:53mm;text-align:left;"><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="NatureOfActivities" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styDepTblCell" style="width:25mm;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="TotalIncome" /></xsl:call-template><span class="styTableCellPad"></span></td>
              <td class="styDepTblCell" style="width:25mm;border-right-width:0px;text-align:right;font-size:6pt;padding-right:1px;"><xsl:call-template name="PopulateAmount"><xsl:with-param name="TargetNode" select="EndOfYearAssets" /></xsl:call-template><span class="styTableCellPad"></span></td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
  </xsl:if>

    
    
    
    
    
    
    
    
    </form>
  </body>
</html>

</xsl:template>

<!-- Below are a few templates designed to be filler rows for the tables in this form -->
<xsl:template name="IRS990PartVTableFillerRow">
  <tr>
    <td class="styTableCellText" style="width:71mm;">
    <br/><span style="width:4px"></span></td>
    <td class="styTableCell" style="width:36mm;text-align:left;"><span style="width:4px"></span></td>
    <td class="styTableCell"><span style="width:4px;"></span></td>
    <td class="styTableCell"><span style="width:4px;"></span></td>
    <td class="styTableCell" style="border-right-width:0px"><span style="width:4px;"></span></td>
  </tr>
</xsl:template>

<xsl:template name="IRS990PartVIIITableFillerRow">
  <tr>
    <td class="styTableCellText" style="width:8mm;"><span class="styTableCellPad"></span></td>
    <td class="styTableCellText" style="width:178mm;border-right-width:0px"><span class="styTableCellPad"></span></td>
  </tr>
</xsl:template>

<xsl:template name="IRS990PartIXTableFillerRow">
  <tr>
    <td class="styTableCellText" style="width:56mm;"><span style="width:4px"></span></td>
    <td class="styTableCell" style="width:25mm;"><span style="width:4px">%</span></td>
    <td class="styTableCell" style="width:55mm;"><span style="width:4px"></span></td>
    <td class="styTableCell" style="width:25mm;"><span style="width:4px"></span></td>
    <td class="styTableCell" style="width:25mm;border-right-width:0px"><span style="width:4px"></span></td>
  </tr>
</xsl:template>

</xsl:stylesheet>
