<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
    <!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddHeader.xsl"/>  
  <xsl:include href="AddOnTable.xsl"/>
  <xsl:include href="IRS990ScheduleAStyle.xsl"/>
  
  <xsl:output method="html" indent="yes"/>
  <xsl:strip-space elements="*"/>
  <!-- Defines the stage of the data, e.g. original or latest -->
  <!--xsl:param name="RtnSummaryData" select="/TEGEOrganizationReturn/ReturnSummary"/-->
  <xsl:param name="FormData" select="$RtnDoc/IRS990ScheduleA"/>
  <xsl:param name="FormDataVIA" select="$RtnDoc/IRS990ScheduleA/IRS990ScheduleAPartVIA"/>
  <xsl:param name="FormDataVIB" select="$RtnDoc/IRS990ScheduleA/IRS990ScheduleAPartVIB"/>
  
<xsl:template match="/">
<html>
<head>
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>

  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache" />
  <meta http-equiv="Cache-Control" content="no-cache" />
  <meta http-equiv="Expires" content="0" />
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private" />
  <!-- Define Character Set -->
  <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
  <meta name="Description" content="IRS Form 990 or 990EZ Schedule A" />

   <xsl:call-template name="GlobalStylesForm"/>

  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>
  <style type="text/css">
    <xsl:if test="not($Print) or $Print=''">
      <xsl:call-template name="IRS990ScheduleAStyle"/>
      <xsl:call-template name="AddOnStyle"></xsl:call-template>
    </xsl:if>
  </style>
</head>

<body class="styBodyClass">
<xsl:call-template name="DocumentHeader"></xsl:call-template>
<!-- BEGIN FORM HEADER -->
<div class="IRS990ScheduleA_LineContainer">
  <!-- Form Name -->
  <div class="IRS990ScheduleA_FormNumBlock" style="padding-top:5px;">
     <span style="font-size:11pt;font-weight:bold;font-familiy:'Arial Narrow';">SCHEDULE A</span>
     <br />
     <span style="font-size:10pt;font-weight:bold;font-family:'Arial Narrow';">(Form 990 or 990EZ)</span>
     <br />
       <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$FormData"/>      
       </xsl:call-template>
     <br />
     <span style=" font-family:Arial Narrow; ">Department of the Treasury</span>
     <br />
     <span style=" font-family:Arial Narrow; ">Internal Revenue Service</span>
  </div>

  <!-- Form Title Box -->
  <div class="IRS990ScheduleA_FormTitleBlock">
    <!-- Form Title -->
    <span class="styMainTitle">Organization Exempt Under Section 501(c)(3)</span>
    <!-- Form Subtitle -->
    <br />
    <span style="font-weight:bold">
      (Except Private Foundation) and Section 501(e), 501(f), 501(k),
      <br />
      501(n), or 4947(a)(1) Nonexempt Charitable Trust<br />
    <span style="font-size:9pt;"> Supplementary Information—(See separate instructions.)<br /></span>
    <div style="padding-top: 1.5mm">
       <img src="{$ImagePath}/990SchA_Bullet_Title.gif" alt="Right arrow" border="0"/>
       MUST be completed by the above organizations and attached to their Form 990 or 990-EZ
     </div>
    </span>
  </div>
  <!-- Tax Year Box -->
  <div class="IRS990ScheduleA_FormYearBlock">
    <!-- OMB No. -->
    <div class="IRS990ScheduleA_OMB">OMB No. 1545-0047</div>
    <!-- Tax Year -->
    <div class="IRS990ScheduleA_TaxYear">
       <span>20<span class="styTYColor">05</span></span>
    </div>
  </div>
</div>
<!-- Begin Name and Identifying Number Section-->      
<div class="styBB" style="width:187mm;clear:both;font-family:verdana;font-size:7pt;">
  <div class="styFNBox" style="width:134mm;height:8mm;">
     Name of the organization<br/>
    <div style="font-family:verdana;font-size:6pt;height:6.25mm">
     <xsl:call-template name="PopulateReturnHeaderFiler">
      <xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param>
    </xsl:call-template>
    <br />
    <xsl:call-template name="PopulateReturnHeaderFiler">
      <xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param>
    </xsl:call-template>
   </div> 
  </div>
  
  <div class="styGenericDiv" style="width:52mm;height:4mm;padding-left:1mm;">
    <span class="styBoldText">Employer identification number</span>
    <br/><br/>
    <xsl:call-template name="PopulateReturnHeaderFiler">
      <xsl:with-param name="TargetNode">EIN</xsl:with-param>
    </xsl:call-template>
  </div>
</div>
<!-- End Name and Identifying Number Section-->      

<!-- Part I header -->
<div class="styGenericDiv" style="width: 187mm">
  <div class="styPartName">Part I</div>
  <div class="styPartDesc">Compensation of the Five Highest Paid Employees Other Than Officers, Directors, and Trustees<br />
       <span class="styNormalText">(See page 1 of the instructions.  List each one. If there are none, enter "None.")</span>
  </div>
  <div class="styGenericDiv">
    <!-- button display logic -->
    <xsl:call-template name="SetDynamicTableToggleButton">
      <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl"/>
      <xsl:with-param name="containerHeight" select="5"/>
       <xsl:with-param name="headerHeight" select="1"/>
      <xsl:with-param name="containerID" select=" 'HPEmply' "/>
    </xsl:call-template>
    <!-- end button display logic -->
 </div>  

</div>
<!--Part I table -->
<div class="IRS990ScheduleA_TableContainer" style="border-bottom-width:0px;" id="HPEmply">
    <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
    <!-- end -->      
   <table cellspacing="0" style="font-size:7pt;">
     <tr>
      <th class="IRS990ScheduleA_CellPtI " style="width:70mm;text_align:center">(a)<span class="styNormalText"> Name and address of each employee paid more than $50,000</span></th>
      <th class="IRS990ScheduleA_CellPtI " style="width:40mm;text_align:center">(b)<span class="styNormalText"> Title and average hours per week devoted to position</span></th>
      <th class="IRS990ScheduleA_CellPtI " style="width:26mm;text_align:center">(c)<span class="styNormalText"> Compensation</span></th>
      <th class="IRS990ScheduleA_CellPtI " style="width:26mm;font-family:'arial narrow';text_align:center">(d)<span class="styNormalText"> Contributions to employee benefit plans &amp; deferred compensation</span></th>
      <th class="IRS990ScheduleA_CellPtI " style="width:26mm;border-right-width:0px;text_align:center">(e)<span class="styNormalText"> Expense account and other allowances</span></th>
    </tr>
    
    <!--xsl:for-each select="$FormData/CompensationOfHighestPaidEmpl"-->
    <!-- Part I begin 1 (name row + address row)-->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;">
      <xsl:if test=" $FormData/CompensationOfHighestPaidEmpl[1]/Name='' or not($FormData/CompensationOfHighestPaidEmpl[1]/Name) ">
      None
      </xsl:if>
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/Name"/>
      </xsl:call-template>
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/Name"/>
    </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/Title"/>
      </xsl:call-template>
      <br />
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/AverageHoursPerWeek"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/Compensation"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/EmployeeBenefits"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/ExpenseAccount"/>
      </xsl:call-template>
       </td>
    </tr> 
                
    <tr>
      <td class="IRS990ScheduleA_CellPtI">      
        <xsl:choose>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[1]/AddressUS and  $FormData/CompensationOfHighestPaidEmpl[1]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[1]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[1]/AddressForeign" />
               </xsl:call-template>
            </xsl:when>
          <xsl:otherwise>
             </xsl:otherwise>
       </xsl:choose>      
          <span style="width:1px;"/>            
       </td>
    </tr>     
    <!-- end 1 -->     
    
    <!-- Part I begin 2 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/Name"/>
      </xsl:call-template>
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/Name"/>
    </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/Title"/>
      </xsl:call-template>
      <br />
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/AverageHoursPerWeek"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/Compensation"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/EmployeeBenefits"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/ExpenseAccount"/>
      </xsl:call-template>
       </td>
    </tr>
             
    <tr>
      <td class="IRS990ScheduleA_CellPtI">      
        <xsl:choose>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[2]/AddressUS and  $FormData/CompensationOfHighestPaidEmpl[2]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[2]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[2]/AddressForeign" />
               </xsl:call-template>
            </xsl:when>
          <xsl:otherwise>
             </xsl:otherwise>
       </xsl:choose>      
          <span style="width:1px;"/>            
       </td>
    </tr>    
     <!-- end 2 -->     
    
    <!-- Part I begin 3 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/Name"/>
      </xsl:call-template>
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/Name"/>
    </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/Title"/>
      </xsl:call-template>
      <br />
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/AverageHoursPerWeek"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/Compensation"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/EmployeeBenefits"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/ExpenseAccount"/>
      </xsl:call-template>
       </td>
    </tr> 
            
    <tr> 
      <td class="IRS990ScheduleA_CellPtI">      
        <xsl:choose>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[3]/AddressUS and  $FormData/CompensationOfHighestPaidEmpl[3]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[3]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[3]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>
             <xsl:otherwise>
             </xsl:otherwise>
           </xsl:choose>      
          <span style="width:1px;"/>            
       </td>
    </tr>            
    <!-- end 3 -->     
      
    <!-- Part I begin 4 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/Name"/>
      </xsl:call-template>
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/Name"/>
    </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/Title"/>
      </xsl:call-template>
      <br />
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/AverageHoursPerWeek"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/Compensation"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/EmployeeBenefits"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/ExpenseAccount"/>
      </xsl:call-template>
       </td>
    </tr>             
    <tr>
      <td class="IRS990ScheduleA_CellPtI ">
          <xsl:choose>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[4]/AddressUS and  $FormData/CompensationOfHighestPaidEmpl[4]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>
                 <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[4]/AddressForeign != ''">
                   <xsl:call-template name="PopulateForeignAddressTemplate">
                     <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[4]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>
             <xsl:otherwise>
               </xsl:otherwise>
           </xsl:choose>      
          <span style="width:1px;"/>            
       </td>
    </tr>              
    <!-- end 4 -->     
    
    <!-- Part I begin 5 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/Name"/>
      </xsl:call-template>
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/Name"/>
    </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/Title"/>
      </xsl:call-template>
      <br />
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/AverageHoursPerWeek"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/Compensation"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2" style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/EmployeeBenefits"/>
      </xsl:call-template>
       </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/ExpenseAccount"/>
      </xsl:call-template>
       </td>
    </tr> 
            
    <tr>
      <td class="IRS990ScheduleA_CellPtI">      
        <xsl:choose>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[5]/AddressUS and  $FormData/CompensationOfHighestPaidEmpl[5]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>
             <xsl:when test="$FormData/CompensationOfHighestPaidEmpl[5]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl[5]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>
             <xsl:otherwise>
             </xsl:otherwise>
           </xsl:choose>      
          <span style="width:1px;"/>            
       </td>
    </tr> 
            
    <!-- end 5 -->         
    <!--/xsl:for-each-->          
<!-- Part I Total-->    
    <tr>
      <td class="IRS990ScheduleA_CellPtI ">
        Total number of other employees paid over $50,000
        <span class="IRS990ScheduleA_Dotspacing">...............</span>
        <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="text-align:right;">
       <xsl:call-template name="PopulateAmount">
       <xsl:with-param name="MaxSize" select="6"/>
        <xsl:with-param name="TargetNode" select="$FormData/TotNumberOfOthEmplPaidOver50k"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="background-color:lightgrey;border-right:0">&nbsp;</td>
      <td class="IRS990ScheduleA_CellPtI " style="background-color:lightgrey;border-right:0">&nbsp;</td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;background-color:lightgrey;">&nbsp;</td>
    </tr>             
   </table>
   <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$FormData/CompensationOfHighestPaidEmpl"/>
    <xsl:with-param name="containerHeight" select="5"/>
    <xsl:with-param name="headerHeight" select="1"/>
    <xsl:with-param name="containerID" select=" 'HPEmply' "/>
   </xsl:call-template>   
</div>

<!-- Part II-A header -->
<div class="styBB" style="width:187mm;">
  <div class="styPartName" style="width:20mm;">Part II-A</div>
  <div class="styPartDesc" style="width:162mm;">Compensation of the Five Highest Paid Independent Contractors for Professional Services<br />
      <span class="styNormalText">(See page 2 of the instructions.  List each one (whether individual or firms). If there are none, enter "None.")</span>
  </div>
  <div class="styGenericDiv">
    <!-- button display logic -->
    <xsl:call-template name="SetDynamicTableToggleButton">
      <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer"/>                                                                               
      <xsl:with-param name="containerHeight" select="5"/>
       <xsl:with-param name="headerHeight" select="1"/>
      <xsl:with-param name="containerID" select=" 'HPCntrct' "/>
    </xsl:call-template>
    <!-- end button display logic -->
  </div>
</div>

<!--Part II-A table -->
<div class="styTableContainer" style="border-bottom-width:0px;float:left;clear:both;" id="HPCntrct">
    <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
    <!-- end -->      
   <table class="styTable" cellspacing="0" style="font-size:7pt;">
     <thead class="styTableThead">
       <tr>
        <th class="IRS990ScheduleA_CellPtI " style="width:110mm;text-align:center" scope="col" colspan="2">
        (a)<span class="styNormalText"> Name and address of each independent contractor paid more than $50,000</span>
        </th>
        <th class="IRS990ScheduleA_CellPtI " style="width:52mm;text-align:center" scope="col">(b)<span class="styNormalText"> Type of service</span></th>
        <th class="IRS990ScheduleA_CellPtI " style="width:26mm;border-right-width:0px;text-align:center" scope="col">(c)<span class="styNormalText"> Compensation</span></th>
       </tr>
    </thead>
    <tfoot></tfoot>
    <tbody>    
    
    <!--xsl:for-each select="$FormData/CompOfHghstPaidCntrctProfSer"-->
    
    <!-- Part II-A begin 1 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">      
      <xsl:if test=" not($FormData/CompOfHghstPaidCntrctProfSer[1]/NamePerson) and not($FormData/CompOfHghstPaidCntrctProfSer[1]/NameBusiness) ">
      None
      </xsl:if>    
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[1]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[1]/NameBusiness">
        
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
         </span>
                   
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/NameBusiness"/>
          </xsl:call-template>
          <br/>          
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
         </span>      
          
        </xsl:when>
      </xsl:choose>
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr> 
    
   <tr> 
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[1]/AddressUS and  $FormData/CompOfHghstPaidCntrctProfSer[1]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[1]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[1]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>        
             <xsl:otherwise>   
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr>        
    <!-- end 1 -->
    
    <!-- Part II-A begin 2 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[2]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[2]/NameBusiness">
         <span style="font-family:verdana;font-size:6pt;">        
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
         </span> 
          
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/NameBusiness"/>
          </xsl:call-template>
          <br/>
           <span style="font-family:verdana;font-size:6pt;">
            <xsl:call-template name="PopulateText">
             <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/NameBusiness/BusinessNameLine2"/>
           </xsl:call-template>
          </span>
          
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr>
             
    <tr>
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[2]/AddressUS and  $FormData/CompOfHghstPaidCntrctProfSer[2]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[2]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[2]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>        
             <xsl:otherwise>   
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr>
    <!-- end 2 -->
    
    <!-- Part II-A begin 3 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[3]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[3]/NameBusiness">
        
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
         </span> 
          
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/NameBusiness"/>
          </xsl:call-template>
          <br/>
          
          <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
          </span>
          
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr> 

   <tr> 
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[3]/AddressUS and  $FormData/CompOfHghstPaidCntrctProfSer[3]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[3]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[3]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>        
             <xsl:otherwise>   
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr>    
     
    <!-- end 3 -->
    
    <!-- Part II-A begin 4 -->    
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[4]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[4]/NameBusiness">
        
          <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
        </span>
        
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/NameBusiness"/>
          </xsl:call-template>
          <br/>
          
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
         </span>  
          
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr> 
            
    <tr> 
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[4]/AddressUS and  $FormData/CompOfHghstPaidCntrctProfSer[4]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[4]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[4]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>        
             <xsl:otherwise>   
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr> 
    <!-- end 4 -->
    
    <!-- Part II-A begin 5 -->        
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[5]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[5]/NameBusiness">
        
          <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
      </span>
      
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/NameBusiness"/>
          </xsl:call-template>
          <br/>
          
          <span style="font-family:verdana;font-size:6pt;">         
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/NameBusiness/BusinessNameLine2"/>
           </xsl:call-template>
          </span>  
          
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr> 
               
    <tr>
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[5]/AddressUS and  $FormData/CompOfHghstPaidCntrctProfSer[5]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
             <xsl:when test="$FormData/CompOfHghstPaidCntrctProfSer[5]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer[5]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>        
             <xsl:otherwise>   
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr>
    <!-- end 5 -->
    
   <!-- total part II-A -->    
    <!--/xsl:for-each-->       
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="width:70mm;">
        Total number of others receiving over $50,000 for professional services
        <span class="IRS990ScheduleA_Dotspacing">.........</span>
        <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="width:40mm;text-align:right;">
       <xsl:call-template name="PopulateAmount">
       <xsl:with-param name="MaxSize" select="6"/>
        <xsl:with-param name="TargetNode" select="$FormData/TotNumOfCntrctPdOver50kProfSer"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="background-color:lightgrey;width:52mm;border-right:0">&nbsp;</td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;background-color:lightgrey;width:26mm;">&nbsp;</td>
    </tr> 
   </tbody>        
   </table>
   
   <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctProfSer"/>
    <xsl:with-param name="containerHeight" select="5"/>
    <xsl:with-param name="headerHeight" select="1"/>
    <xsl:with-param name="containerID" select=" 'HPCntrct' "/>
   </xsl:call-template>

</div>

 <!-- Part II-B begins -->
  
 <!-- Part II-B header -->
<div class="styBB" style="width:187mm;">  
  <div class="styPartName" style="width:20mm;">Part II-B</div>
     <div class="styPartDesc" style="width:162mm;">Compensation of the Five Highest Paid Independent Contractors for Other Services<br />
      <span class="styNormalText">(List each contractor who performed services other than professional services, whether individual or 
         firms. If there are none, enter "None". See page 2 for instructions.) 
      </span>
    </div>  
    <div class="styGenericDiv">
    <!-- button display logic -->
    <xsl:call-template name="SetDynamicTableToggleButton">
      <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer"/>
      <xsl:with-param name="containerHeight" select="5"/>
       <xsl:with-param name="headerHeight" select="1"/>
      <xsl:with-param name="containerID" select=" 'HPCntrct2' "/>
    </xsl:call-template>
    <!-- end button display logic -->
    </div>  
 </div>

<!--Part II-B table -->
<div class="styTableContainer" style="border-bottom-width:0px;float:left;clear:both;" id="HPCntrct2">
    <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
    <!-- end -->      
   <table class="styTable" cellspacing="0" style="font-size:7pt;">
     <thead class="styTableThead">
       <tr>
        <th class="IRS990ScheduleA_CellPtI " style="width:110mm;text-align:center" scope="col" colspan="2">
        (a)<span class="styNormalText"> Name and address of each independent contractor paid more than $50,000</span>
        </th>
        <th class="IRS990ScheduleA_CellPtI " style="width:52mm;text-align:center" scope="col">(b)<span class="styNormalText"> Type of service</span></th>
        <th class="IRS990ScheduleA_CellPtI " style="width:26mm;border-right-width:0px;text-align:center" scope="col">(c)<span class="styNormalText"> Compensation</span></th>
       </tr>
    </thead>
    <tfoot></tfoot>
    <tbody>

    <!--xsl:for-each select="$FormData/CompOfHghstPaidCntrctOthSer"-->
    <!-- Part II-B begin 1 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">      
      <xsl:if test=" not($FormData/CompOfHghstPaidCntrctOthSer[1]/NamePerson) and not($FormData/CompOfHghstPaidCntrctOthSer[1]/NameBusiness) ">
      None
      </xsl:if>    
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[1]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[1]/NameBusiness">
        
          <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/NameBusiness/BusinessNameLine1"/>
           </xsl:call-template>
          </span>
          
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/NameBusiness"/>
          </xsl:call-template>
          <br/>
        
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
         </span>    
          
        </xsl:when>
      </xsl:choose>
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr> 
            
    <tr>
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[1]/AddressUS and  $FormData/CompOfHghstPaidCntrctOthSer[1]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[1]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
              <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[1]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CCompOfHghstPaidCntrctOthSer[1]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>             
             <xsl:otherwise> 
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr> 
    
    <!-- end 1 -->
    
    <!-- Part II-B begin 2 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[2]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[2]/NameBusiness">
        
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
         </span> 
          
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/NameBusiness"/>
          </xsl:call-template>
          <br/>
          
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
         </span>
        
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr>             
    
    <tr>
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[2]/AddressUS and  $FormData/CompOfHghstPaidCntrctOthSer[2]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[2]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
              <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[2]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CCompOfHghstPaidCntrctOthSer[2]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>             
             <xsl:otherwise> 
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr>      
    <!-- end 2 -->
    
    <!-- Part II-B begin 3 -->
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[3]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[3]/NameBusiness">
        
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/NameBusiness/BusinessNameLine1"/>
           </xsl:call-template>
          </span>
          
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/NameBusiness"/>
          </xsl:call-template>
          <br/>
          
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
         </span>     
          
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr>    

    <tr>
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[3]/AddressUS and  $FormData/CompOfHghstPaidCntrctOthSer[3]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[3]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
              <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[3]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CCompOfHghstPaidCntrctOthSer[3]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>             
             <xsl:otherwise> 
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr>       
    <!-- end 3 -->
    
    <!-- Part II-B begin 4 -->    
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[4]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[4]/NameBusiness">
        
         <span style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
         </span>    
          
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/NameBusiness"/>
          </xsl:call-template>
          <br/>
          
        <span style="font-family:verdana;font-size:6pt;">  
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
        </span>   
          
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr> 
            
    <tr>
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[4]/AddressUS and  $FormData/CompOfHghstPaidCntrctOthSer[4]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[4]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
              <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[4]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CCompOfHghstPaidCntrctOthSer[4]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>             
             <xsl:otherwise> 
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr> 
 
    <!-- end 4 -->
    
    <!-- Part II-B begin 5 -->        
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="border-bottom-style:solid;" colspan="2">
      <xsl:choose>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[5]/NamePerson">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/NamePerson"/>
          </xsl:call-template>
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/Name"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[5]/NameBusiness">
        
         <span style="font-family:verdana;font-size:6pt;">  
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/NameBusiness/BusinessNameLine1"/>
          </xsl:call-template>
        </span>  
          
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/NameBusiness"/>
          </xsl:call-template>
          <br/>
          
         <span style="font-family:verdana;font-size:6pt;">   
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/NameBusiness/BusinessNameLine2"/>
          </xsl:call-template>
        </span>   
          
        </xsl:when>
      </xsl:choose>
        <span style="width:1px;"/>            
      </td>
      <td class="IRS990ScheduleA_CellPtI " rowspan="2">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/TypeOfService"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;text-align:right;" rowspan="2">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/Compensation"/>
      </xsl:call-template>
      </td>
    </tr>        
    
    <tr>
      <td class="IRS990ScheduleA_CellPtI " colspan="2">
            <xsl:choose>
             <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[5]/AddressUS and  $FormData/CompOfHghstPaidCntrctOthSer[5]/AddressUS!=''">
               <xsl:call-template name="PopulateUSAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer[5]/AddressUS" />
                 <xsl:with-param name="SpanWidth">4px;</xsl:with-param>
               </xsl:call-template>
             </xsl:when>             
              <xsl:when test="$FormData/CompOfHghstPaidCntrctOthSer[5]/AddressForeign != ''">
               <xsl:call-template name="PopulateForeignAddressTemplate">
                 <xsl:with-param name="TargetNode" select="$FormData/CCompOfHghstPaidCntrctOthSer[5]/AddressForeign" />
               </xsl:call-template>
             </xsl:when>             
             <xsl:otherwise> 
              </xsl:otherwise>
           </xsl:choose>          
           <span style="width:1px;"/>            
      </td>
    </tr>      
    <!-- end 5 -->
   
    <!--Total Part II-b--> 
    <!--/xsl:for-each-->       
    <tr>
      <td class="IRS990ScheduleA_CellPtI " style="width:70mm;">
        Total number of other contractors receiving over $50,000 for other services
        <span class="IRS990ScheduleA_Dotspacing">.........</span>
        <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="width:40mm;text-align:right;">
       <xsl:call-template name="PopulateAmount">
       <xsl:with-param name="MaxSize" select="6"/>
        <xsl:with-param name="TargetNode" select="$FormData/TotNumOfCntrctPdOver50kOthSer"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_CellPtI " style="background-color:lightgrey;width:52mm;border-right:0">&nbsp;</td>
      <td class="IRS990ScheduleA_CellPtI " style="border-right-width:0px;background-color:lightgrey;width:26mm;">&nbsp;</td>
    </tr> 
   </tbody>        
   </table>
   
   <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$FormData/CompOfHghstPaidCntrctOthSer"/>
    <xsl:with-param name="containerHeight" select="5"/>
    <xsl:with-param name="headerHeight" select="1"/>
    <xsl:with-param name="containerID" select=" 'HPCntrct2' "/>
   </xsl:call-template>

</div> 

<!-- Part II-B ends here --> 
 

<!-- footer line -->
<div class="pageEnd" style="width:187mm;float:none;clear:both;">

  <div class="IRS990ScheduleA_LineContainer">
    <div style="font-weight:bold;width:100mm;float:left;font-family:'arial narrow';">
      For Paperwork Reduction Act Notice, see the Instructions for Form 990 and Form 990-EZ.</div>
    <div style="width:40mm;float:left;">
      Cat. No. 11285F
    </div>
    <div style="width:47mm;text-align:right;float:left;font-family:'arial narrow';font-weight:bold;">Schedule A (Form 990 or 990-EZ) 2005</div>
  </div>
</div>



<!-- Page Header -->
  <div class="styBB" style="width:187mm; padding-bottom:.5mm;">  
    <div style="float:left;">Schedule A (Form 990 or 990-EZ) 2005</div>
    <div style="float:right;">Page <span style="font-weight:bold;font-size:8pt;">2</span></div>                    
  </div>  
<!-- END Page Header -->      

<!-- Part III header-->
<div class="styBB" style="width: 187mm">
  <div class="styPartName" style="margin-top: 2mm">Part III</div>
  <div class="styPartDesc" style="padding-top: 2mm;width: 157mm">Statements About Activities
        <span class="styNormalText">(See page 2 of the instructions.)</span>
  </div>

  <div class="IRS990ScheduleA_LineIndexMid" style="float: right; clear: none; height:8mm;font-size:8pt;border-right-width:0px;padding-top:8px;border-bottom-width: 0px; width: 7.25mm">No</div>
  <div class="IRS990ScheduleA_LineIndexMid" style="float: right; clear: none; height:8mm;font-size:8pt; padding-top:8px;border-bottom-width: 0px; border-left-width: 1px; width: 8.25mm">Yes</div>
</div>
<!-- part III line 1 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftNumBoxSD">1</div>
  <div class="IRS990ScheduleA_LineDesc" style="height: 4.5mm">
    During the year, has the organization attempted to influence national, state, or local legislation, include any attempt
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="height: 4.5mm"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="height: 4.5mm"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;height: 4.5mm"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    to influence public opinion on a legislative matter or referendum? If "Yes," enter the total expenses paid or incurred in
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    connection with the lobbying activities
    <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/>$
    <span style="width:29mm;border-bottom: 1 solid black">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/AmountOfLobbyingExpenditures"/>
      </xsl:call-template>
    </span>
    (Must equal amounts on line 38, Part VI-A, or line
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    i of Part VI-B.)
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">1</div>
  <div class="IRS990ScheduleA_LineIndexMid">
  <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/AnyLobbyingActivitiesDuringYr"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
  <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/AnyLobbyingActivitiesDuringYr"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    Organizations that made an election under section 501(h) by filing Form 5768 must complete Part VI-A. Other
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;background-color:lightgrey;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    organizations checking "Yes" must complete Part VI-B AND attach a statement giving a detailed description of the
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;background-color:lightgrey;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    lobbying activities.
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;background-color:lightgrey;"></div>
</div>
<!-- line 2 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftNumBox" style="padding-left: 2mm">2</div>
  <div class="IRS990ScheduleA_LineDesc" style="height: 4.5mm">
    During the year, has the organization, either directly or indirectly, engaged in any of the following acts with any
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;height: 4.5mm"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;height: 4.5mm"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;background-color:lightgrey;height: 4.5mm"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    substantial contributors, trustees, directors, officers, creators, key employees, or members of their families, or with 
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;background-color:lightgrey;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    any taxable organization with which any such person is affiliated as an officer, director, trustee, majority owner, or
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;background-color:lightgrey;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    principal beneficiary?
    <span style="font-style:italic;">
      (If the answer to any question is "Yes," attach a detailed statement explaining the transactions.)
    </span>
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities"/>
    </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;background-color:lightgrey;"></div>
</div>
 <!-- line 2 a -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">a</div>
  <div class="IRS990ScheduleA_LineDesc">
    Sale, exchange, or leasing property?
    <span class="IRS990ScheduleA_DotSpacing">....................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="height:4.25mm">2a</div>
  <div class="IRS990ScheduleA_LineIndexMid" style="height:4.25mm">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnySaleOfProperty"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnySaleOfProperty"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 2 b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">b</div>
  <div class="IRS990ScheduleA_LineDesc">
    Lending of money or other extension of credit?
    <span class="IRS990ScheduleA_DotSpacing">................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">2b</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyLending"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyLending"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 2 c -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">c</div>
  <div class="IRS990ScheduleA_LineDesc">
    Furnishing of goods, services, or facilities?
    <span class="IRS990ScheduleA_DotSpacing">.................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">2c</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyGoodsOrServices"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyGoodsOrServices"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 2 d -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">d</div>
  <div class="IRS990ScheduleA_LineDesc">
    Payment of compensation (or payment or reimbursement of expenses if more than $1,000)?
     <!-- Pen image -->
      <xsl:call-template name="LinkToLeftoverDataTableInline">
          <xsl:with-param name="Desc">Line 2d - Note on Compensation</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyCompensation/@note"/>      
      </xsl:call-template>

    <span class="IRS990ScheduleA_DotSpacing">...........</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">2d</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyCompensation"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyCompensation"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 2 e -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">e</div>
  <div class="IRS990ScheduleA_LineDesc">
    Transfer of any part of its income or assets?
    <span class="IRS990ScheduleA_DotSpacing">................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">2e</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyTransferOfAssets"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyTransferOfAssets"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 3 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftNumBox" style="padding-left: 2mm">3a</div>
  <div class="IRS990ScheduleA_LineDesc">
    Do you make grants for scholarships, fellowships, student loans, etc.? (If “Yes,” attach an explanation of how you</div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    determine that recipients qualify to receive payments.)
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormData/AwardScholarshipsEtc"/>
    </xsl:call-template>
    <span class="IRS990ScheduleA_DotSpacing">..........................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">3a</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/AwardScholarshipsEtc"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/AwardScholarshipsEtc"/>
      </xsl:call-template>
      </span>
  </div>
</div>

 <!-- line 3b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">b</div>
  <div class="IRS990ScheduleA_LineDesc">
    Do you have a section 403(b) annuity plan for your employees?
    <span class="IRS990ScheduleA_DotSpacing">........................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">3b</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/AnnuityPlan403bForEmployees"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/AnnuityPlan403bForEmployees"/>
      </xsl:call-template>
      </span>
  </div>
</div>

 <!-- line 3c -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">c</div>
  <div class="IRS990ScheduleA_LineDesc">
    During the year, did the organization receive a contribution of qualified real property interest under section 170(h)?
  </div>
 
  <div class="IRS990ScheduleA_LineIndexMid">3c</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/RealPropertyInterestContrib"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/RealPropertyInterestContrib"/>
      </xsl:call-template>
      </span>
  </div>
</div>

 <!-- line 4a -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftNumBox" style="padding-left: 2mm">4a</div>
  <div class="IRS990ScheduleA_LineDesc">
    Did you maintain any separate account for participating donors where donors have the right to provide advice
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    on the use or distribution of funds?
    <span class="IRS990ScheduleA_DotSpacing">.....................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">4a</div>

  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintainSeparateAccount"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintainSeparateAccount"/>
      </xsl:call-template>
      </span>
  </div>  
</div>

<!-- line 4b -->
<div class="styBB">
  <div class="styLNLeftLtrBox" style="padding-left: 4mm">b</div>
  <div class="IRS990ScheduleA_LineDesc">
    Do you provide credit counseling, debt management, credit repair, or debt negotiation services?
    <span class="IRS990ScheduleA_DotSpacing">..........</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-bottom:0">4b</div>

  <div class="IRS990ScheduleA_LineIndexMid" style="border-bottom:0">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/ProvideCreditDebtMgmtServices"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;border-bottom-width:0px">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/ProvideCreditDebtMgmtServices"/>
      </xsl:call-template>
      </span>
  </div>  
</div>

<!-- Part IV header-->
<div class="styBB" style="height: 8mm; width: 187mm">
  <div class="styPartName" style="width: 20mm; margin-top: 2mm"><span style="background-color:black;color:white;padding-left:5px;padding-right:5px;">Part IV</span></div>
  <div class="styPartDesc" style="padding-top:2mm; width: 167mm">Reason for Non-Private Foundation Status
       <span class="styNormalText">(See pages 3 through 6 of the instructions.)</span>
  </div>
</div>
<!-- comment line -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineDesc" style="width:188mm;border-right-width:0px;">
    The organization is not a private foundation because it is: (Please check only
    <span style="font-weight:bold;">
      ONE 
    </span>
    applicable box.)
  </div>
</div>
<!-- line 5 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">5</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/Church170b1Ai"/>
      </xsl:call-template>
    </input>  
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/Church170b1Ai"/>
      </xsl:call-template>
       A church, convention of churches, or association of churches.  Section 170(b)(1)(A)(i).
    </label>
  </div>
</div>
<!-- line 6 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">6</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/School170b1Aii"/>
      </xsl:call-template>
    </input>  
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/School170b1Aii"/>
      </xsl:call-template>
      A school. Section 170(b)(1)(A)(ii). (Also complete Part V.)
    </label> 
  </div>
</div>
<!-- line 7 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">7</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/Hospital170b1Aiii"/>
      </xsl:call-template>
    </input>
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/Hospital170b1Aiii"/>
      </xsl:call-template>
      A hospital or a cooperative hospital service organization. Section 170(b)(1)(A)(iii).
    </label> 
  </div>
</div>
<!-- line 8 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">8</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/GovernmentalUnit170b1Av"/>
      </xsl:call-template>
    </input>
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/GovernmentalUnit170b1Av"/>
      </xsl:call-template>
       A Federal, state, or local government or governmental unit. Section 170(b)(1)(A)(v).
    </label>
  </div>
</div>
<!-- line 9 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">9</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/MedicalResearchOrg170b1Aiii"/>
      </xsl:call-template>
    </input>  
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/MedicalResearchOrg170b1Aiii"/>
      </xsl:call-template>
      A medical research organization operated in conjunction with a hospital. Section 170(b)(1)(A)(iii).
    </label> 
    <span style="font-weight:bold;">Enter the hospital's name, city,</span>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV" style="width:18mm;">
    <span style="font-weight:bold;">and state<span style="width: 1.5mm" /></span>
    <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/>
  </div>
  <div class="IRS990ScheduleA_LineDescIV" style="width:154mm;border-bottom-width:1px;border-bottom-style:solid;">
    <!-- Display all rows: If the print parameter is not set to be Separated, OR -->
    <!-- If the print parameter is separated, but there are at most 2 data elements -->
    <xsl:choose>
      <xsl:when test="($Print != $Separated) or count($FormData/HospitalNameAndAddress) &lt;= 2">
        <xsl:for-each select="$FormData/HospitalNameAndAddress">
        
         <div style="font-family:verdana;font-size:6pt;">
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="Name/BusinessNameLine1"/>
          </xsl:call-template>
          </div>
          ,
          
          <div style="font-family:verdana;font-size:6pt;">
           <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="Name/BusinessNameLine2"/>
           </xsl:call-template>          
          </div>
          ,
          <xsl:call-template name="PopulateText">
           <xsl:with-param name="TargetNode" select="Address/City"/>
          </xsl:call-template>
          ,
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="Address/State"/>
          </xsl:call-template>
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="Address/Country"/>
          </xsl:call-template>
          ;
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="PopulateAdditionalDataTableMessage">
          <xsl:with-param name="TargetNode" select="$FormData/HospitalNameAndAddress" />
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </div>
</div>
<!-- line 10 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">10</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/CollegeSupportOrg170b1Aiv"/>
      </xsl:call-template>
    </input>
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/CollegeSupportOrg170b1Aiv"/>
      </xsl:call-template>
      An organization operated for the benefit of a college or university owned or operated by a governmental unit.
    </label> 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV">
   Section 170(b)(1)(A)(iv). (Also complete the <span style="font-weight:bold;">Support Schedule </span>in Part IV-A).
  </div>
</div>
<!-- line 11a -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex" style="padding-right:9px;">11a</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/PubliclySupportedOrg170b1Avi"/>
      </xsl:call-template>
    </input>  
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label> 
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/PubliclySupportedOrg170b1Avi"/>
      </xsl:call-template>
      An organization that normally receives a substantial part of its support from a governmental unit or from the general public. 
    </label>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label> 
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/PubliclySupportedOrg170b1Avi"/>
      </xsl:call-template>
    Section 170(b)(1)(A)(vi). (Also complete the <span style="font-weight:bold;">Support Schedule </span>in Part IV-A).
    </label>
  </div>
</div>
<!-- line 11b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex" style="padding-right:9px;">11b</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/CommunityTrust170b1Avi"/>
      </xsl:call-template>
    </input>  
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label> 
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/CommunityTrust170b1Avi"/>
      </xsl:call-template>
      A community trust. Section 170(b)(1)(A)(vi). (Also complete the <span style="font-weight:bold;">Support Schedule </span>in Part IV-A).
    </label>
  </div>
</div>
<!-- line 12 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">12</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/PubliclySupportedOrg509a2"/>
      </xsl:call-template>
    </input>
  </div>  
  <div class="IRS990ScheduleA_LineDescIV">
    <label> 
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/PubliclySupportedOrg509a2"/>
      </xsl:call-template>
      An organization that normally receives: <span style="font-weight:bold;">(1) more than 33<span style="font-size:5pt;">1/3</span>% </span>of its support from contributions, membership fees, and gross
    </label>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV">
    receipts from activities related to its charitable, etc., functions—subject to certain exceptions, and <span style="font-weight:bold;">(2) no more than 33<span style="font-size:5pt;">1/3</span>% </span> of 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV">
    its support from gross investment income and unrelated business taxable income (less section 511 tax) from businesses 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV">
    acquired by the organization after June 30, 1975. See section 509(a)(2). (Also complete the <span style="font-weight:bold;">Support Schedule </span>in Part IV-A.)
  </div>
</div>
<!-- line 13 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">13</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/SupportingOrganization509a3"/>
      </xsl:call-template>
    </input>
  </div>  
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/SupportingOrganization509a3"/>
      </xsl:call-template>
      An organization that is not controlled by any disqualified persons (other than foundation managers) and supports organizations
    </label> 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/SupportingOrganization509a3"/>
      </xsl:call-template>
    described in: <span style="font-weight:bold;"> (1) </span> lines 5 through 12 above; or  <span style="font-weight:bold;"> (2) </span> sections 501(c)(4), (5), or (6), if they meet the test of section 509(a)(2). 
    </label> 
  </div>
</div>

<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label>
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/SupportingOrganization509a3"/>
        <xsl:with-param name="BackupName">IRS990ScheduleAType1</xsl:with-param>
      </xsl:call-template>      
 <!-- line 13 check boxes --> 
       <span style="padding-right: 3mm">Check the box that describes the type of supporting organization: <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></span> 
         
      <span style="width:20mm;">
      <input type="checkbox" class="IRS990ScheduleA_Checkbox">
         <xsl:call-template name="PopulateCheckbox">
          <xsl:with-param name="TargetNode" select="$FormData/SupportingOrg509a3Type1" />
          <xsl:with-param name="BackupName">IRS990ScheduleAType1</xsl:with-param>
         </xsl:call-template>
        </input>
        <label>
          <xsl:call-template name="PopulateLabel">
            <xsl:with-param name="TargetNode" select="$FormData/SupportingOrg509a3Type1" />
            <xsl:with-param name="BackupName">IRS990ScheduleAType1
            </xsl:with-param>
          </xsl:call-template>
          Type 1
        </label>
      </span>     
      
      <span style="width:20mm;">
      <input type="checkbox" class="IRS990ScheduleA_Checkbox">
         <xsl:call-template name="PopulateCheckbox">
          <xsl:with-param name="TargetNode" select="$FormData/SupportingOrg509a3Type2" />
          <xsl:with-param name="BackupName">IRS990ScheduleAType2</xsl:with-param>
         </xsl:call-template>
        </input>
        <label>
          <xsl:call-template name="PopulateLabel">
            <xsl:with-param name="TargetNode" select="$FormData/SupportingOrg509a3Type2" />
            <xsl:with-param name="BackupName">IRS990ScheduleAType2
            </xsl:with-param>
          </xsl:call-template>
          Type 2
        </label>
      </span>

      <span style="width:20mm;">
      <input type="checkbox" class="IRS990ScheduleA_Checkbox">
         <xsl:call-template name="PopulateCheckbox">
          <xsl:with-param name="TargetNode" select="$FormData/SupportingOrg509a3Type3" />
          <xsl:with-param name="BackupName">IRS990ScheduleAType3</xsl:with-param>
         </xsl:call-template>
        </input>
        <label>
          <xsl:call-template name="PopulateLabel">
            <xsl:with-param name="TargetNode" select="$FormData/SupportingOrg509a3Type3" />
            <xsl:with-param name="BackupName">IRS990ScheduleAType3
            </xsl:with-param>
          </xsl:call-template>
          Type 3
        </label>
      </span>
         
    </label> 
  </div>
   
  <div style="float:right">                        
    <!-- button display logic -->          
    <xsl:call-template name="SetDynamicTableToggleButton">
      <xsl:with-param name="TargetNode" select="$FormData/SupportedOrgInformation" />
      <xsl:with-param name="headerHeight" select="2" />
      <xsl:with-param name="containerHeight" select="2" />
      <xsl:with-param name="containerID" select="'p4Ln13TbCtnr'" />                  
    </xsl:call-template>               
     <!-- end button display logic -->              
  </div> 
   
</div>
<!-- line 13 ends-->

  <!--Part IV line 13 table -->
  <div class="IRS990ScheduleAPart4_TableContainer" id="p4Ln13TbCtnr"> 
    <!-- print logic -->
    <xsl:call-template name="SetInitialState"/> 
    <!-- end -->        
    <table cellspacing="0" style="margin-left:16mm;font-size:7pt;">
      <tr>
        <th class="IRS990ScheduleA_GenericCell" style="width:165mm;height:4mm;border-right-width:0px;border-top-width:1px;text_align:center;font-weight:normal;" scope="col" colspan="2">
          Provide the following information about the supported organizations. (see page 6 of the instructions.)
        </th>
      </tr>
      <tr>
        <th class="IRS990ScheduleA_GenericCell" style="width:140mm;text_align:center" scope="col">(a)<span class="styNormalText"> Name(s) of supported organization(s)</span></th>
        <th class="IRS990ScheduleA_GenericCell" style="width:25mm;border-right-width:0px;text_align:center" scope="col">(b)<span class="styNormalText"> Line number from above</span></th>
      </tr>
      
        <!-- Display all rows: If the print parameter is not set to be Separated, OR -->
        <!-- If the print parameter is separated, but there are fewer elements than the container height (2) -->
        <xsl:if test="($Print != $Separated) or count($FormData/SupportedOrgInformation) &lt;= 2">
          <xsl:for-each select="$FormData/SupportedOrgInformation">
            <tr>
              <td class="IRS990ScheduleA_GenericCell" style="font-family:verdana;font-size:6pt;"> 
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="Name/BusinessNameLine1"/>
                </xsl:call-template>
                <br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="Name/BusinessNameLine2"/>
                </xsl:call-template>
              </td>
              
              <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;text-align:center">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="LineNumber"/>
                </xsl:call-template> 
              </td>      
            </tr>
          </xsl:for-each>
        </xsl:if>
        <!-- Display the first blank row if the data set is empty. If the number of data elements is more than 2 -->
        <!-- and the print option is separated, display a message in the first row directing the user to the -->
        <!-- additional data table -->
        <xsl:if test="count($FormData/SupportedOrgInformation) &lt; 1 or
            (($Print = $Separated) and (count($FormData/SupportedOrgInformation) &gt; 2)) ">
          <tr>
            <td class="IRS990ScheduleA_GenericCell">
              <xsl:call-template name="PopulateAdditionalDataTableMessage">
                <xsl:with-param name="TargetNode" select="$FormData/SupportedOrgInformation" />
              </xsl:call-template>
              <span style="width:3px" />
            </td>
            <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;text-align:center">
              <span style="width:3px" />
            </td>
          </tr>
        </xsl:if>
        <!--Display the second blank row if there is only one row of data. If the number of data elements is -->
        <!-- more than 2 and the print option is separated, also display a blank second row -->
        <xsl:if  test="count($FormData/SupportedOrgInformation) &lt; 2 or
            (($Print = $Separated) and (count($FormData/SupportedOrgInformation) &gt; 2)) ">
          <tr>
            <td class="IRS990ScheduleA_GenericCell">
              <span style="width:3px" />
            </td>
            <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;">
              <span style="width:3px" />
            </td>
          </tr>
        </xsl:if>
    </table> <br />
  </div> 
    
  <xsl:call-template name="SetInitialDynamicTableHeight">
    <xsl:with-param name="TargetNode" select="$FormData/SupportedOrgInformation" />
    <xsl:with-param name="headerHeight" select="2" />
    <xsl:with-param name="containerHeight" select="2"/>
    <xsl:with-param name="containerID" select="'p4Ln13TbCtnr'" />
  </xsl:call-template>
   
 
<!-- line 14 -->
<div class="styBB">
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">14</div>
  <div class="IRS990ScheduleA_LineIndex">
    <input class="IRS990ScheduleA_Checkbox" type="checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormData/TestingForPublicSafety509a4"/>
      </xsl:call-template>
    </input>  
  </div>
  <div class="IRS990ScheduleA_LineDescIV">
    <label> 
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormData/TestingForPublicSafety509a4"/>
      </xsl:call-template>
      An organization organized and operated to test for public safety.  Section 509(a)(4). (See page 6 of the instructions.)
    </label>
  </div>
</div>
</div>
<!--Page Footer-->
<div class="pageEnd" style="width:187mm">
  <div style="float:right;">
    <span style="width:80px;"></span>  
    <span class="styBoldText"> Schedule A (Form 990 or 990-EZ) 2005</span> 
  </div>  
</div>  
<!--END Page Footer-->

<!-- Page Header -->
  <div class="styBB" style="width:187mm; float: none; clear:none">  
    <div style="float:left">Schedule A (Form 990 or 990-EZ) 2005</div>
    <div style="float:right">Page <span style="font-weight:bold;font-size:8pt;">3</span></div>                    
  </div>  
<!-- END Page Header -->



<!-- Part IV_A header -->
<div class="styGenericDiv">
  <div class="styPartName" style="width:20mm;">Part IV-A</div>
  <div class="styPartDesc" style="width:167mm;">Support Schedule        
       <span class="styNormalText" style="font-size: 7pt">(Complete only if you checked a box on line 10, 11, or 12.)</span>
    <span style="font-weight:bold;font-style:italic;">
         Use cash method of accounting.
       </span>
 </div>
 <div class="IRS990ScheduleA_LineDescLong" style="border-right:0; width: 170mm">
    <span style="font-weight:bold">
         Note: 
       </span>
     <span style="font-style:italic;">
         You may use the worksheet in the instructions for converting from the accrual to the cash method of accounting.
       </span>           
  </div>
</div>

<!--Part IV-A table -->
<div class="IRS990ScheduleA_TableContainer" style="border-bottom-width:0px;">
   <table cellspacing="0" cellpadding="0" style="font-size:7pt;">
     <tr>
      <th class="IRS990ScheduleA_GenericCell" style="width:78mm;font-weight:bold" scope="col" colspan="2">
        <span style="float: left; clear: both"> Calendar year (or fiscal year beginning in)</span>
       <span style="float:right; clear: both"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></span> 
      </th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center" scope="col">(a)<span class="styNormalText"> 2004</span></th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center" scope="col">(b)<span class="styNormalText"> 2003</span></th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center" scope="col">(c)<span class="styNormalText"> 2002</span></th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center" scope="col">(d)<span class="styNormalText"> 2001</span></th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;border-right-width:0px;text_align:center" scope="col">(e)<span class="styNormalText"> Total</span></th>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="width:4mm;" valign="top">15</td>
      <td class="IRS990ScheduleA_GenericCell" style="width:74mm;">Gifts, grants, and contributions received. (Do not include unusual grants. See line 28.) <span class="IRS990ScheduleA_DotSpacing">.....</span></td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GiftsGrantsContribReceived/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GiftsGrantsContribReceived/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GiftsGrantsContribReceived/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GiftsGrantsContribReceived/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GiftsGrantsContribReceived/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">16</td>
      <td class="IRS990ScheduleA_GenericCell">Membership fees received<span class="IRS990ScheduleA_DotSpacing">..........</span></td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/MembershipFeesReceived/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/MembershipFeesReceived/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/MembershipFeesReceived/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/MembershipFeesReceived/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/MembershipFeesReceived/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">17</td>
      <td class="IRS990ScheduleA_GenericCell">Gross receipts from admissions, merchandise sold or services performed, or furnishing of facilities in any activity that is related to the organization's charitable, etc., purpose<span class="IRS990ScheduleA_DotSpacing">....</span></td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossReceiptsFromAdmissionsEtc/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossReceiptsFromAdmissionsEtc/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossReceiptsFromAdmissionsEtc/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossReceiptsFromAdmissionsEtc/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossReceiptsFromAdmissionsEtc/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">18</td>
      <td class="IRS990ScheduleA_GenericCell">Gross income from interest, dividends, amounts received from payments on securities loans (section 512(a)(5)), rents, royalties, and unrelated business taxable income (less section 511 taxes) from businesses acquired by the organization after June 30, 1975<span class="IRS990ScheduleA_DotSpacing">.......</span></td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossInvestmentIncmPost1975UBI/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossInvestmentIncmPost1975UBI/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossInvestmentIncmPost1975UBI/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossInvestmentIncmPost1975UBI/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossInvestmentIncmPost1975UBI/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">19</td>
      <td class="IRS990ScheduleA_GenericCell">Net income from unrelated business activities not included in line 18<span class="IRS990ScheduleA_DotSpacing">............</span></td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/NetUBIPre1975/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/NetUBIPre1975/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/NetUBIPre1975/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/NetUBIPre1975/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/NetUBIPre1975/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">20</td>
      <td class="IRS990ScheduleA_GenericCell">Tax revenues levied for the organization's benefit and either paid to it or expended on its behalf<span class="IRS990ScheduleA_DotSpacing">....................</span></td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TaxRevenuesLeviedForOrgBenefit/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TaxRevenuesLeviedForOrgBenefit/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TaxRevenuesLeviedForOrgBenefit/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TaxRevenuesLeviedForOrgBenefit/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TaxRevenuesLeviedForOrgBenefit/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <!-- Line 21 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">21</td>
      <td class="IRS990ScheduleA_GenericCell">The value of services or facilities furnished to the organization by a governmental unit without charge. Do not include the value of services or facilities generally furnished to the public without  charge<span class="IRS990ScheduleA_DotSpacing">....................</span></td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ValueSrvcFcltsFurnishedByGovt/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ValueSrvcFcltsFurnishedByGovt/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ValueSrvcFcltsFurnishedByGovt/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ValueSrvcFcltsFurnishedByGovt/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ValueSrvcFcltsFurnishedByGovt/Total"/>
      </xsl:call-template>
      </td>
    </tr>

    <!-- Line 22 -->
      <tr>  
        <td class="IRS990ScheduleA_IndexCell" valign="top">22</td>
        <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;">
          Other income. Attach a schedule. Do not include gain or (loss) from sale of capital assets
          <!-- Pen image -->
          <xsl:call-template name="LinkToLeftoverDataTableInline">
            <xsl:with-param name="Desc">Line 22 - Description</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncome/Description"/>
          </xsl:call-template>
          <span style="width:5mm" />
          <!-- Pushpin image -->
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncome"/>
          </xsl:call-template>
        </td>    
        <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncome/PriorYear"/>
          </xsl:call-template>
        </td>
        <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncome/PriorYearMinus1"/>
          </xsl:call-template>
        </td>
        <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncome/PriorYearMinus2"/>
          </xsl:call-template>
        </td>
        <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncome/PriorYearMinus3"/>
          </xsl:call-template>
        </td>
        <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncome/Total"/>
          </xsl:call-template>
        </td>
      </tr>  
    <!-- Line 23 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">23</td>
      <td class="IRS990ScheduleA_GenericCell">
        Total of lines 15 through 22
        <span class="IRS990ScheduleA_Dotspacing">.........</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncome/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncome/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncome/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncome/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncome/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">24</td>
      <td class="IRS990ScheduleA_GenericCell">
        Line 23 minus line 17
       <span class="IRS990ScheduleA_Dotspacing">............</span>  
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncomeMinusGroReceiptsEtc/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncomeMinusGroReceiptsEtc/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncomeMinusGroReceiptsEtc/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncomeMinusGroReceiptsEtc/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TotalIncomeMinusGroReceiptsEtc/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCell" valign="top">25</td>
      <td class="IRS990ScheduleA_GenericCell">
        Enter 1% of line 23
        <span class="IRS990ScheduleA_Dotspacing">.............</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OnePercentOfTotalIncome/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OnePercentOfTotalIncome/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OnePercentOfTotalIncome/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="font-size:6pt;Verdana;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OnePercentOfTotalIncome/PriorYearMinus3"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;background-color:lightgrey;font-size:6pt;Verdana;">&nbsp;</td>
    </tr>
  </table>
</div>
<!-- line 26 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">26</div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    <span style="font-weight:bold;">Organizations described on lines 10 or 11:</span>
    <span style="width:8mm;text-align:center;font-weight:bold;">a</span>
    Enter 2% of amount in column (e), line 24
    <span class="IRS990ScheduleA_Dotspacing">......</span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">26a</div>
  <div class="IRS990ScheduleA_MoneyField">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLines10or11/Pct2TotIncmMinusGroReceiptsEtc"/>
      </xsl:call-template>
  </div>
  </div>
</div>
<!-- line 26b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">b</div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    Prepare a list for your records to show the name of and amount contributed by each person (other than a
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace" style="height:4.5mm"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="height: 4.5mm"></div>
  <div class="IRS990ScheduleA_MoneyFieldFiller" style="background-color:lightgrey;height: 4.5mm"></div>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    governmental unit or publicly supported organization) whose total gifts for 2001 through 2004 exceeded
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_MoneyFieldFiller" style="background-color:lightgrey;"></div>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    the amount shown in line 26a.
    <span style="font-weight:bold;">Do not file this list with your return. </span>
    Enter the total of all these excess
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_MoneyFieldFiller" style="background-color:lightgrey;"></div>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    amounts
    <span class="IRS990ScheduleA_Dotspacing">...........................................</span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">26b</div>
  <div class="IRS990ScheduleA_MoneyField">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLines10or11/SumOfExcessContributions"/>
      </xsl:call-template>
  </div>
  </div>
</div>
<!-- line 26c -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">c</div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    Total support for section 509(a)(1) test: Enter line 24, column (e)
    <span class="IRS990ScheduleA_Dotspacing">.................</span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">26c</div>
  <div class="IRS990ScheduleA_MoneyField">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLines10or11/TotalSupport"/>
      </xsl:call-template>
  </div>
  </div>
</div>
<!-- line 26d -->
<!-- 
  Lines 18,19,22, and 26b are conditionally redisplayed for line 26d. These lines will only 
  be redisplayed when one or more of the line 10,11a, or 11b checkboxes are checked.
-->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">d</div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="width:56.25mm;">
    Add: Amounts from column (e) for lines:
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">18</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 18 should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/CollegeSupportOrg170b1Aiv='X' or $FormData/PubliclySupportedOrg170b1Avi='X' or $FormData/CommunityTrust170b1Avi='X'">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossInvestmentIncmPost1975UBI/Total"/>
      </xsl:call-template>
    </xsl:if>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">19</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 19 should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/CollegeSupportOrg170b1Aiv='X' or $FormData/PubliclySupportedOrg170b1Avi='X' or $FormData/CommunityTrust170b1Avi='X'">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/NetUBIPre1975/Total"/>
      </xsl:call-template>
    </xsl:if>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:19.75mm;"></div>  
  <div class="IRS990ScheduleA_ArrowSpace" style="width:2.5mm;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_MoneyFieldFiller" style="background-color:lightgrey;"></div>
</div>

<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="width:56.25mm;"></div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">22</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">
    <!-- 
      The value placed here should be the total of line 22. 
    -->
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">26b</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 26b should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/CollegeSupportOrg170b1Aiv='X' or $FormData/PubliclySupportedOrg170b1Avi='X' or $FormData/CommunityTrust170b1Avi='X'">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLines10or11/SumOfExcessContributions"/>
      </xsl:call-template>
    </xsl:if>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:16.25mm;">  
    <span class="IRS990ScheduleA_Dotspacing">......</span>
  </div>  
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">26d</div>
  <div class="IRS990ScheduleA_MoneyField">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLines10or11/TotalNonpublicSupport"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 26e -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">e</div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    Public support (line 26c minus line 26d total)
    <span class="IRS990ScheduleA_Dotspacing">...........................</span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">26e</div>
  <div class="IRS990ScheduleA_MoneyField">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLines10or11/PublicSupport"/>
      </xsl:call-template>
  </div>
  </div>
</div>
<!-- line 26f -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD" style="border-bottom-width:1px;">f</div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="font-weight:bold;border-bottom-width:1px;">
    Public support percentage (line 26e (numerator) divided by line 26c (denominator))
    <span class="IRS990ScheduleA_Dotspacing" style="font-weight:normal;border-bottom-width:1px;">.......</span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace" style="border-bottom-width:1px;"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-bottom-width:1px;">26f</div>
  <div class="IRS990ScheduleA_MoneyField" style="border-bottom-width:1px;">
    <xsl:call-template name="PopulatePercent">
      <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLines10or11/PublicSupportPercentage1"/>
    </xsl:call-template>  
  </div>
  </div>
</div>
<!-- line 27 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">27</div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    <span style="font-weight:bold;">Organizations described on line 12:</span><span style="width:8mm;font-weight:bold;text-align:center;">a</span>
    For amounts included in lines 15, 16, and 17 that were received from a "disqualified person,"
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    prepare a list for your records to show the name of, and total amounts received in each year from, each "disqualified person."
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    <span style="font-weight:bold;">Do not file this list with your return.</span>
    Enter the sum of such amounts for each year:
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2004)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromDisqualifiedPersons/PriorYear"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2003)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromDisqualifiedPersons/PriorYearMinus1"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2002)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromDisqualifiedPersons/PriorYearMinus2"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2001)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromDisqualifiedPersons/PriorYearMinus3"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 27b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">b</div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    For any amount included in line 17 that was received from each person (other than "disqualified persons"), prepare a list for your
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
     records to show the name of, and amount received for each year, that was more than the <span style="font-weight:bold;"> larger </span> of <span style="font-weight:bold;">(1) </span>the amount on line 25 for the year 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    or <span style="font-weight:bold;">(2) </span>$5,000. (Include in the list organizations described in lines 5 through 11b, as well as individuals.) <span style="font-weight:bold;"> Do not file this list with your </span> 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    <span style="font-weight:bold;"> return. </span> After computing the difference between the amount received and the larger amount described in <span style="font-weight:bold;">(1) </span>or <span style="font-weight:bold;">(2)</span>, enter the sum of 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    these differences (the excess amounts) for each year: 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2004)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromLargeContributors/PriorYear"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2003)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromLargeContributors/PriorYearMinus1"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2002)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromLargeContributors/PriorYearMinus2"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:10mm;">(2001)</div>
  <div class="IRS990ScheduleA_LineDescIVAL" style="width:35mm;border-bottom-width:1px;border-style:solid;">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/ContribFromLargeContributors/PriorYearMinus3"/>
      </xsl:call-template>
  </div>
</div>
<!-- spacer line -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL"></div>
</div>
<!-- line 27c -->
<!-- 
  Lines 18,19,22, and 26b are conditionally redisplayed for line 27c. These lines will only 
  be redisplayed when the line 12 checkbox is checked.
-->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">c</div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="width:60mm;">
    Add: Amounts from column (e) for lines:
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">15</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 15 should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/PubliclySupportedOrg509a2='X'">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GiftsGrantsContribReceived/Total"/>
      </xsl:call-template>
    </xsl:if>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">16</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 16 should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/PubliclySupportedOrg509a2='X'">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/MembershipFeesReceived/Total"/>
      </xsl:call-template>
    </xsl:if>
  </div>
 
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="width:20mm;"></div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">17</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 17 should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/PubliclySupportedOrg509a2='X'">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/GrossReceiptsFromAdmissionsEtc/Total"/>
      </xsl:call-template>
    </xsl:if>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">20</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 20 should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/PubliclySupportedOrg509a2='X'">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/TaxRevenuesLeviedForOrgBenefit/Total"/>
      </xsl:call-template>
    </xsl:if>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;">21</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
    <!-- Check to see if line 21 should be redisplayed (see comment above) -->
    <xsl:if test="$FormData/PubliclySupportedOrg509a2='X'">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/ValueSrvcFcltsFurnishedByGovt/Total"/>
      </xsl:call-template>
    </xsl:if>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:10mm;">  
    <span class="IRS990ScheduleA_Dotspacing">.....</span>
  </div>  
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">27c</div>
  <div class="IRS990ScheduleA_MoneyField">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/PublicSupportGross"/>
    </xsl:call-template>
  </div>
  </div>
</div>
<!-- line 27d -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">d</div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26.5mm;">Add: Line 27a total</div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:4mm;text-align:center;">.</div>
  <div style="float:right">
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/TotalFromDisqualifiedPersons"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;"></div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:25.5mm;">and line 27b total
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:8mm;text-align:center;"></div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:26mm;border-bottom-width:1px;font-size:6pt;text-align:right;">  
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/TotalFromLargeContributors"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineDescIVA" style="width:10mm;">  
    <span class="IRS990ScheduleA_Dotspacing">.....</span>
  </div>  
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">27d</div>
  <div class="IRS990ScheduleA_MoneyField">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/NonPublicSupport"/>
      </xsl:call-template>
  </div>
  </div>
</div>

<!-- line 27e -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">e</div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    Public support (line 27c total minus line 27d total)
    <span class="IRS990ScheduleA_Dotspacing">.........................</span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">27e</div>
  <div class="IRS990ScheduleA_MoneyField">
       <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/PublicSupport"/>
      </xsl:call-template>
  </div>
  </div>
</div>
<!-- line 27f -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">f</div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="width:106mm;">
    Total support for section 509(a)(2) test: Enter amount from line 23, column (e)
    <span class="IRS990ScheduleA_Dotspacing">.</span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid">27f</div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width: 1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/TotalSupport"/>
    </xsl:call-template>
    <span style="width:2px;"></span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="background-color:lightgrey;border-bottom-width:0px"></div>
  <div class="IRS990ScheduleA_MoneyField" style="background-color:lightgrey;border-bottom-width:0px"></div>
  </div>
</div>
<!-- line 27g -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">g</div>  
  <div class="IRS990ScheduleA_LineDescIVA">
    <span class="styBoldText">
      Public support percentage (line 27e (numerator) divided by line 27f (denominator)) 
    </span> 
    <span class="IRS990ScheduleA_Dotspacing">.......</span>
  </div>
  <div style="float:right;">
    <div class="IRS990ScheduleA_ArrowSpace"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
    <div class="IRS990ScheduleA_LineIndexMid">27g</div>
    <div class="IRS990ScheduleA_MoneyField">
        <xsl:call-template name="PopulatePercent">
          <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/PublicSupportPercentage2"/>
        </xsl:call-template>
    </div>
  </div>
</div>
<!-- line 27h -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD" style="border-bottom-width:1px;">h</div>  
  <div class="IRS990ScheduleA_LineDescIVA" style="border-bottom-width:1px">
    <span class="styBoldText">
      Investment income percentage (line 18, column (e) (numerator) divided by 
      line 27f (denominator))
    </span>
  </div>
  <div style="float:right;">
  <div class="IRS990ScheduleA_ArrowSpace" style="border-bottom-width:1px;"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-bottom-width:1px;">27h</div>
  <div class="IRS990ScheduleA_MoneyField" style="border-bottom-width:1px;">
    <xsl:call-template name="PopulatePercent">
      <xsl:with-param name="TargetNode" select="$FormData/OrgDescribedOnLine12/InvestmentIncomePercentage"/>
    </xsl:call-template>
  </div>
  </div>
</div>
<!-- line 28 -->
<div class="styBB">
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">28</div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    <span style="font-weight:bold;">Unusual Grants:</span>
    For an organization described in line 10, 11, or 12 that received any unusual grants during 2001 through 2004, 
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    prepare a list for your records to show, for each year, the name of the contributor, the date and amount of the grant, and a brief
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>  
  <div class="IRS990ScheduleA_LineDescIVAL">
    description of the nature of the grant. <span style="font-weight:bold;">Do not file this list with your return.</span> Do not include these grants in line 15.
  </div>
</div>
</div>

<!--Page Footer-->
<div class="pageEnd" style="width:187mm">
  <div style="float:right;">
    <span style="width:80px;"></span>  
    <span class="styBoldText"> Schedule A (Form 990 or 990-EZ) 2005</span> 
  </div>  
</div>  
<!--END Page Footer-->

<!-- Page Header -->
  <div class="styBB" style="width:187mm;float:none; clear:none">  
    <div style="float:left;">Schedule A (Form 990 or 990-EZ) 2005</div>
    <div style="float:right;">Page <span style="font-weight:bold;font-size:8pt;">4</span></div>                    
  </div>  
<!-- END Page Header -->

<!-- Part V header -->
<div class="styGenericDiv" style="width: 187mm">
  <div class="styPartName">Part V</div>
  <div class="styPartDesc">Private School Questionnaire <span class="styNormalText">(See page 7 of the instructions.)</span>
       <br />
         (To be completed ONLY by schools that checked the box on line 6 in Part IV) 
   </div>
</div>
 <!-- line 29 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex" style="border-top-width:1px;">29</div>
  <div class="IRS990ScheduleA_LineDesc" style="border-right-width:0px;border-top-width:1px;">
    Does the organization have a racially nondiscriminatory policy toward students by statement in its charter, bylaws, 
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-top-width:1px;"></div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-top-width:1px;">Yes</div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;border-top-width:1px;">No</div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    other governing instrument, or in a resolution of its governing body?
    <span class="IRS990ScheduleA_Dotspacing">......................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">29</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/NondiscriminatoryPolicyStmt"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/NondiscriminatoryPolicyStmt"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 30 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">30</div>
  <div class="IRS990ScheduleA_LineDesc">
    Does the organization include a statement of its racially nondiscriminatory policy toward students in all its
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    brochures, catalogues, and other written communications with the public dealing with student admissions,
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    programs, and scholarships?
    <span class="IRS990ScheduleA_Dotspacing">........................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">30</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PolicyStatementInBrochuresEtc"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PolicyStatementInBrochuresEtc"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 31 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">31</div>
  <div class="IRS990ScheduleA_LineDesc">
    Has the organization publicized its racially nondiscriminatory policy through newspaper or broadcast media during
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    the period of solicitation for students, or during the registration period if it has no solicitation program, in a way
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    that makes the policy known to all parts of the general community it serves?
    <span class="IRS990ScheduleA_Dotspacing">..................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">31</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PolicyPublViaBroadcastMedia"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PolicyPublViaBroadcastMedia"/>
      </xsl:call-template>
      </span>
  </div>
</div>

<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    If "Yes," please describe; if "No," please explain. (If you need more space, attach a separate statement.)
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer" style="height:4mm;">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;border-right-width:1px;">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/PubViaBroadcastMediaExpln"/>
      </xsl:call-template>
</div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="height:100%"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="height:100%"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;height:100%"></div>
</div>
<xsl:if test="string-length($FormData/PubViaBroadcastMediaExpln) &lt;1">
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
</xsl:if>
 <!-- line 32 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">32</div>
  <div class="IRS990ScheduleA_LineDesc">
    Does the organization maintain the following:
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">a</div>
  <div class="IRS990ScheduleA_LineDesc">
    Records indicating the racial composition of the student body, faculty, and administrative staff?
    <span class="IRS990ScheduleA_Dotspacing">.........</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">32a</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintRacialCompositionRecords"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintRacialCompositionRecords"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<!-- line 32b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">b</div>
  <div class="IRS990ScheduleA_LineDesc">
    Records documenting  that scholarships and other financial assistance are awarded on racially nondiscriminatory
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    basis?
    <span class="IRS990ScheduleA_Dotspacing">.................................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">32b</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintScholarshipsRecords"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintScholarshipsRecords"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<!-- line 32c -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">c</div>
  <div class="IRS990ScheduleA_LineDesc">
    Copies of all catalogues, brochures, announcements, and other written communications to the public dealing
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    with student admissions, programs, and scholarships?
    <span class="IRS990ScheduleA_Dotspacing">............................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">32c</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintCopiesOfBrochuresEtc"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintCopiesOfBrochuresEtc"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<!-- line 32d -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">d</div>
  <div class="IRS990ScheduleA_LineDesc">
    Copies of all material used by the organization or on its behalf to solicit contributions?
    <span class="IRS990ScheduleA_Dotspacing">..............</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">32d</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintCopiesOfAllSolicitations"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/MaintCopiesOfAllSolicitations"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    If you answered "No" to any of the above, please explain. (If you need more space, attach a separate statement.)
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<!-- combine comment lines, fix later -->
<div class="IRS990ScheduleA_LineContainer" style="height:4mm">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;border-right-width:1px;">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/OrgDoesNotMaintainExplanation"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="height:100%"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="height:100%"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;height:100%"></div>
</div>
<xsl:if test="string-length($FormData/OrgDoesNotMaintainExplanation) &lt;1">
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
</xsl:if>
 <!-- line 33 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex">33</div>
  <div class="IRS990ScheduleA_LineDesc">
    Does the organization discriminate by race in any way with respect to:
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">a</div>
  <div class="IRS990ScheduleA_LineDesc">
    Students' rights or privileges?
    <span class="IRS990ScheduleA_Dotspacing">.......................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33a</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceStudentsRights"/>
      </xsl:call-template>
       </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceStudentsRights"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 33b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">b</div>
  <div class="IRS990ScheduleA_LineDesc">
    Admissions policies?
    <span class="IRS990ScheduleA_Dotspacing">...........................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33b</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceAdmissPolicies"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceAdmissPolicies"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 33c -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">c</div>
  <div class="IRS990ScheduleA_LineDesc">
    Employment of faculty or administrative staff?
    <span class="IRS990ScheduleA_Dotspacing">................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33c</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceEmplmnFaculty"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceEmplmnFaculty"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 33d -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">d</div>
  <div class="IRS990ScheduleA_LineDesc">
    Scholarships or other financial assistance?
    <span class="IRS990ScheduleA_Dotspacing">.................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33d</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceScholarships"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceScholarships"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 33e -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">e</div>
  <div class="IRS990ScheduleA_LineDesc">
    Educational policies?
    <span class="IRS990ScheduleA_Dotspacing">...........................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33e</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceEducPolicies"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceEducPolicies"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 33f -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">f</div>
  <div class="IRS990ScheduleA_LineDesc">
    Use of facilities?
    <span class="IRS990ScheduleA_Dotspacing">.............................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33f</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceUseOfFclts"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceUseOfFclts"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 33g -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">g</div>
  <div class="IRS990ScheduleA_LineDesc">
    Athletic programs?
    <span class="IRS990ScheduleA_Dotspacing">............................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33g</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceAthleticProg"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceAthleticProg"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 33h -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">h</div>
  <div class="IRS990ScheduleA_LineDesc">
    Other extracurricular activities?
    <span class="IRS990ScheduleA_Dotspacing">......................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">33h</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceOtherActy"/>
      </xsl:call-template>
       </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceOtherActy"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<!-- supplemental info line -->
<!-- need to combine the multiple lines.  fix later -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    If you answered "Yes" to any of the above, please explain. (If you need more space, attach a separate statement.)
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer" style="height:4mm">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;border-right-width:1px;">
       <xsl:call-template name="PopulateText">
        <xsl:with-param name="TargetNode" select="$FormData/DiscriminateRaceExplanation"/>
      </xsl:call-template>
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="height:100%"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="height:100%"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;height:100%"></div>
</div>
<xsl:if test="string-length($FormData/DiscriminateRaceExplanation) &lt;1">
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="border-bottom-style:solid;border-bottom-width:1px;"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
</xsl:if>
 <!-- line 34a -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex" style="padding-right:5px;">34a</div>
  <div class="IRS990ScheduleA_LineDesc">
    Does the organization receive any financial aid or assistance from a governmental agency?
       <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$FormData/GovernmentFinancialAid"/>
      </xsl:call-template>
    <span class="IRS990ScheduleA_Dotspacing">...........</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">34a</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/GovernmentFinancialAid/Received"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/GovernmentFinancialAid/Received"/>
      </xsl:call-template>
      </span>
  </div>
</div>
 <!-- line 34b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">b</div>
  <div class="IRS990ScheduleA_LineDesc">
    Has the organization's right to such aid ever been revoked or suspended?
    <span class="IRS990ScheduleA_Dotspacing">....................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">34b</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/GovernmentFinancialAid/Revoked"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/GovernmentFinancialAid/Revoked"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<!-- supplemental info line -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    If you answered "Yes" to either 34a or b, please explain using an attached statement.
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray"></div>
  <div class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;"></div>
</div>
 <!-- line 35 -->
<div class="styBB">
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftNumBox">35</div>
  <div class="IRS990ScheduleA_LineDesc">
    Does the organization certify that it has complied with the applicable requirements of sections 4.01 through 4.05
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc">
    of Rev. Proc. 75-50, 1975-2 C.B. 587, covering racial nondiscrimination? If "No," attach an explanation
       <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$FormData/ComplianceWithRevProc75_50"/>
      </xsl:call-template>
    <span class="IRS990ScheduleA_Dotspacing">.....</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller">35</div>
  <div class="IRS990ScheduleA_LineIndexMidFiller">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/ComplianceWithRevProc75_50"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;">
   <span style="font-weight: normal">
       <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/ComplianceWithRevProc75_50"/>
      </xsl:call-template>
      </span>
  </div>
</div>
</div>

<!--Page Footer-->
<div class="pageEnd" style="width:187mm">
  <div style="float:right;">
    <span style="width:80px;"></span>  
    <span class="styBoldText"> Schedule A (Form 990 or 990-EZ) 2005</span> 
  </div>  
</div>  
<!--END Page Footer-->

<!-- Page Header -->
  <div class="styBB" style="width:187mm;float: none; clear:none">  
    <div style="float:left;">Schedule A (Form 990 or 990-EZ) 2005</div>
    <div style="float:right;">Page <span style="font-weight:bold;font-size:8pt;">5</span></div>                    
  </div>  
<!-- END Page Header -->



<!-- Part VI_A header -->
<div class="styGenericDiv" style="width: 187mm">
  <div class="styPartName" style="width:18mm;">Part VI-A</div>
  <div class="styPartDesc" style="width:169mm;"> Lobbying Expenditures by Electing Public Charities 
        <span class="styNormalText">
           (See page 9 of the instructions.)
      </span>
       <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$FormDataVIA"/>
      </xsl:call-template>
       <br />
         (To be completed 
    <span style="font-weight:bold;">
         ONLY
       </span>
    by an eligible organization that filed Form 5768)
  </div>
</div>
<!-- comment line -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineDesc" style="width:188mm;border-right-width:0px;border-top-width:1px;">
    Check <span style="width:4mm;"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></span><span style="font-weight:bold;width:4mm;">a</span>
    <span style="width:4mm;">
    <input type="checkbox" class="IRS990ScheduleA_Checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/OrgBelongsToAffiliatedGroup"/>
      </xsl:call-template>
    </input>
    </span>
    <label> 
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/OrgBelongsToAffiliatedGroup"/>
      </xsl:call-template>
      if the organization belongs to an affiliated group.
    </label>
    <span style="width:4mm;"></span>
    Check <span style="width:4mm;"><img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/></span><span style="font-weight:bold;width:4mm;">b</span>
    <span style="width:4mm;">
    <input type="checkbox" class="IRS990ScheduleA_Checkbox">
       <xsl:call-template name="PopulateCheckbox">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LimitedControlProvisionsApply"/>
      </xsl:call-template>
    </input></span>
    <label> 
       <xsl:call-template name="PopulateLabel">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LimitedControlProvisionsApply"/>
      </xsl:call-template>
      if you checked "a" and "limited control" provisions apply.
    </label>
  </div>
</div>
<!-- Part VI-A table -->
<div class="IRS990ScheduleA_TableContainer" style="border-bottom-width:0px;">
   <table cellspacing="0" cellpadding="0" style="font-size:7pt">
     <tr>
      <th class="IRS990ScheduleA_GenericCell" style="width:123mm;height:12mm;text_align:center;font-weight:normal;" scope="col" colspan="4">
        <span style="font-weight:bold;font-size:9pt;">Limits on Lobbying Expenditures</span>
        <br /><br />(The term "expenditures" means amounts paid or incurred.)
      </th>
      <th class="IRS990ScheduleA_GenericCell" style="width: 32mm; height:12mm; text_align:center; border-left-width: 0px;float: none" scope="col">(a)<br /><span class="styNormalText"> Affiliated group<br />totals</span></th>
      <th class="IRS990ScheduleA_GenericCell" style="width: 32mm; height:12mm; border-right-width:0px;text_align:center; float: none; padding-top: 0px; padding-bottom:0px; " scope="col">(b)<br /><span class="styNormalText"> To be completed<br />for ALL electing<br />organizations</span></th>
    </tr>
<!-- line 36 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">36</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Total lobbying expenditures to influence public opinion (grassroots lobbying)
        <span class="IRS990ScheduleA_Dotspacing">...</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">36</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalGrassrootsLobbying/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalGrassrootsLobbying/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- line 37 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">37</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Total lobbying expenditures to influence a legislative body (direct lobbying)
        <span class="IRS990ScheduleA_Dotspacing">....</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">37</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalDirectLobbying/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalDirectLobbying/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- line 38 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">38</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Total lobbying expenditures (add lines 36 and 37)
        <span class="IRS990ScheduleA_Dotspacing">...............</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">38</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalLobbyingExpenditures/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalLobbyingExpenditures/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- line 39 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">39</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Other exempt purpose expenditures
        <span class="IRS990ScheduleA_Dotspacing">......................</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">39</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/OtherExemptPurposeExpenditures/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/OtherExemptPurposeExpenditures/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- line 40 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">40</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Total exempt purpose expenditures (add lines 38 and 39)
        <span class="IRS990ScheduleA_Dotspacing">............</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">40</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalExemptPurposeExpenditures/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalExemptPurposeExpenditures/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- line 41 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">41</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Lobbying nontaxable amount. Enter the amount from the following table—</td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray">&nbsp; </td>
      <td class="styLNAmountBox" style="border-bottom-width:0px;background-color:lightgrey;border-left:0">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;background-color:lightgrey">&nbsp;</td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">&nbsp;</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">
        <span style="width:50mm;font-weight:bold;">If the amount on line 40 is—</span>
        <span style="width:57mm;font-weight:bold;">The lobbying nontaxable amount is—</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray">&nbsp;</td>
      <td class="styLNAmountBox" style="border-bottom-width:0px;background-color:lightgrey;border-left:0">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;background-color:lightgrey">&nbsp;</td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">&nbsp;</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:107mm;border-right:0">
        <span style="width:50mm; font-size: 6pt">Not over $500,000<span class="IRS990ScheduleA_Dotspacing">.........</span></span>
        <span style="width:57mm; font-size: 6pt">20% of the amount on line 40<span class="IRS990ScheduleA_Dotspacing">.........</span></span>
        <td rowspan="5" style="width: 4mm; border-style: solid; border-color:black; border-top-width: 0px; border-bottom-width: 0px; border-left-width:0px; border-right-width: 1px"> <img src="{$ImagePath}/990SchA_Bracket.gif" alt="Bracket" style="left:-5mm;top:8mm;"/></td>
      </td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray">&nbsp;</td>
      <td class="styLNAmountBox" style="border-bottom-width:0px;background-color:lightgrey;border-left:0; width: 29mm">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;background-color:lightgrey; width: 29mm">&nbsp;</td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">&nbsp;</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:107mm;border-right:0">
        <span style="width:50mm; font-size: 6pt">Over $500,000 but not over $1,000,000<span class="IRS990ScheduleA_Dotspacing">.</span></span>
        <span style="width:57mm; font-size: 6pt">$100,000 plus 15% of the excess over $500,000</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray">&nbsp;</td>
      <td class="styLNAmountBox" style="border-bottom-width:0px;background-color:lightgrey;border-left:0">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;background-color:lightgrey">&nbsp;</td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">&nbsp;</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:107mm;border-right:0">
        <span style="width:50mm; font-size: 6pt">Over $1,000,000 but not over $1,500,000<span class="IRS990ScheduleA_Dotspacing">.</span></span>
        <span style="width:57mm; font-size: 6pt">$175,000 plus 10% of the excess over $1,000,000</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">41</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingNontaxableAmount/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingNontaxableAmount/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">&nbsp;</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:107mm;border-right:0">
        <span style="width:50mm; font-size: 6pt">Over $1,500,000 but not over $17,000,000<span class="IRS990ScheduleA_Dotspacing">.</span></span>
        <span style="width:57mm; font-size: 6pt">$225,000 plus 5% of the excess over $1,500,000</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray">&nbsp;</td>
      <td class="styLNAmountBox" style="border-bottom-width:0px;background-color:lightgrey;border-left:0">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;background-color:lightgrey">&nbsp;</td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">&nbsp;</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:107mm;border-right:0">
        <span style="width:50mm; font-size: 6pt">Over $17,000,000<span class="IRS990ScheduleA_Dotspacing">.........</span></span>
        <span style="width:57mm; font-size: 6pt">$1,000,000<span class="IRS990ScheduleA_Dotspacing">................</span></span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray">&nbsp;</td>
      <td class="styLNAmountBox" style="border-bottom-width:0px;background-color:lightgrey;border-left:0;">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;background-color:lightgrey">&nbsp;</td>
    </tr>
<!-- line 42 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">42</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Grassroots nontaxable amount (enter 25% of line 41)
        <span class="IRS990ScheduleA_Dotspacing">..............</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">42</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsNontaxableAmount/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsNontaxableAmount/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- line 43 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">43</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Subtract line 42 from line 36. Enter -0- if line 42 is more than line 36
        <span class="IRS990ScheduleA_Dotspacing">.......</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">43</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotLobbyingGrassrootMinusNonTx/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotLobbyingGrassrootMinusNonTx/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- line 44 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA">44</td>
      <td class="IRS990ScheduleA_LineDesc" style="width:111mm;" colspan="2">Subtract line 41 from line 38. Enter -0- if line 41 is more than line 38
        <span class="IRS990ScheduleA_Dotspacing">.......</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMid">44</td>
      <td class="styLNAmountBox" style="border-left:0">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotLobbyExpendMnsLobbyingNontx/AffiliatedGroupTotals"/>
      </xsl:call-template>
      </td>
      <td class="styLNAmountBox" style="border-right-width:0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotLobbyExpendMnsLobbyingNontx/AllElectingOrganizations"/>
      </xsl:call-template>
      </td>
    </tr>
<!-- Notes line -->
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA"></td>
      <td class="IRS990ScheduleA_LineDesc" style="width:134mm;" colspan="2">&nbsp;</td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width:0px;">&nbsp;</td>
      <td class="styLNAmountBox" style="border-left:0;border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;border-left-width:0px;background-color:lightgrey;">&nbsp;</td>
    </tr>
    <tr>
      <td class="IRS990ScheduleA_IndexCellVIA"></td>
      <td class="IRS990ScheduleA_LineDesc" style="width:107mm;" colspan="2">
        <span style="font-weight:bold;;">Caution: </span>
        <span style="font-style:italic;">If there is an amount on either line 43 or line 44, you must file Form 4720.</span>
      </td>
      <td class="IRS990ScheduleA_LineIndexMidFillerGray" style="border-right-width: 0px;">&nbsp;</td>
      <td class="styLNAmountBox" style="border-left:0;border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="styLNAmountBox" style="border-right-width:0px;border-bottom-width:0px;border-left-width:0px;background-color:lightgrey;">&nbsp;</td>
    </tr>
  </table>
</div>
<!--Part VI-A table  part ii-->
<div class="IRS990ScheduleA_TableContainer" style="border-top-width: 0px">
   <table cellspacing="0" cellpadding="0" style="font-size:7pt;">
     <tr>
      <th class="IRS990ScheduleA_GenericCell" style="width:188mm;border-right-width:0px;border-top-width:1px;text_align:center;font-weight:normal;" colspan="7">
        <span style="font-weight:bold;font-size:8pt;">4-Year Averaging Period Under Section 501(h)</span>
        <br />
        (Some organizations that made a section 501(h) election do not have to complete all of the five columns below.
        <br />
        See the instructions for lines 45 through 50 on page 11 of the instructions.)
      </th>
    </tr>
    <tr>
      <th class="IRS990ScheduleA_GenericCell" style="width:78mm;height:8mm;text_align:center;font-weight:normal;" scope="col" colspan="2">&nbsp;</th>
      <th class="IRS990ScheduleA_GenericCell" style="width:105mm;height:8mm;font-weight:bold;border-right-width:0px;text_align:center;" scope="col" colspan="5">Lobbying Expenditures During 4-Year Averaging Period</th>
    </tr>
     <tr>
      <th class="IRS990ScheduleA_IndexCell" style="width:4mm;text_align:center;font-weight:normal;" valign="top">&nbsp;</th>
      <th class="IRS990ScheduleA_GenericCell" style="width:74mm;font-weight:bold;text-align:left;" scope="col">
        Calendar year (or<br /> fiscal year beginning in)
        <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/>
      </th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center;font-weight:normal;" scope="col"><span style="font-weight:bold;">(a)</span><br /> 2005</th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center;font-weight:normal;" scope="col"><span style="font-weight:bold;">(b)</span><br />  2004</th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center;font-weight:normal;" scope="col"><span style="font-weight:bold;">(c)</span><br />  2003</th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;text_align:center;font-weight:normal;" scope="col"><span style="font-weight:bold;">(d)</span><br />  2002</th>
      <th class="IRS990ScheduleA_GenericCell" style="width:21mm;border-right-width:0px;text_align:center;font-weight:normal;" scope="col"><span style="font-weight:bold;">(e)</span><br />  Total</th>
    </tr>
    <!-- filler row -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="border-bottom-width:0px;" valign="top">&nbsp;</td>
      <td class="IRS990ScheduleA_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>
    <!-- line 45 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="vertical-align:top;">45</td>
      <td class="IRS990ScheduleA_GenericCell">Lobbying nontaxable amount
        <span class="IRS990ScheduleA_Dotspacing">...........</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingNontaxableAmount2/CurrentYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingNontaxableAmount2/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingNontaxableAmount2/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingNontaxableAmount2/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingNontaxableAmount2/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <!-- filler row -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="border-bottom-width:0px;" valign="top">&nbsp;</td>
      <td class="IRS990ScheduleA_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>
    <!-- line 46 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="vertical-align:top;">46</td>
      <td class="IRS990ScheduleA_GenericCell">Lobbying ceiling amount (150% of line 45(e))
        <span class="IRS990ScheduleA_Dotspacing">...</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell"  style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/LobbyingCeilingAmount"/>
      </xsl:call-template>
      </td>
    </tr>
    <!-- filler row -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="border-bottom-width:0px;" valign="top">&nbsp;</td>
      <td class="IRS990ScheduleA_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>
    <!-- line 47 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="vertical-align:top;">47</td>
      <td class="IRS990ScheduleA_GenericCell">Total lobbying expenditures
        <span class="IRS990ScheduleA_Dotspacing">............</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalLobbyingExpenditures2/CurrentYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalLobbyingExpenditures2/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalLobbyingExpenditures2/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalLobbyingExpenditures2/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/TotalLobbyingExpenditures2/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <!-- filler row -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="border-bottom-width:0px;" valign="top">&nbsp;</td>
      <td class="IRS990ScheduleA_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>
    <!-- line 48 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="vertical-align:top;">48</td>
      <td class="IRS990ScheduleA_GenericCell">Grassroots nontaxable amount
        <span class="IRS990ScheduleA_Dotspacing">..........</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsNontaxableAmount2/CurrentYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsNontaxableAmount2/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsNontaxableAmount2/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsNontaxableAmount2/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsNontaxableAmount2/Total"/>
      </xsl:call-template>
      </td>
    </tr>
    <!-- filler row -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="border-bottom-width:0px;" valign="top">&nbsp;</td>
      <td class="IRS990ScheduleA_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>
    <!-- line 49 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="vertical-align:top;">49</td>
      <td class="IRS990ScheduleA_GenericCell">Grassroots ceiling amount (150% of line 48(e))
        <span class="IRS990ScheduleA_Dotspacing">...</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell"  style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="background-color:lightgrey;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsCeilingAmount"/>
      </xsl:call-template>
      </td>
    </tr>
    <!-- filler row -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="border-bottom-width:0px;" valign="top">&nbsp;</td>
      <td class="IRS990ScheduleA_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>
    <!-- line 50 -->
    <tr>
      <td class="IRS990ScheduleA_IndexCell" style="vertical-align:top;border-bottom-width: 0px">50</td>
      <td class="IRS990ScheduleA_GenericCell" style="border-bottom-width: 0px">Grassroots lobbying expenditures
        <span class="IRS990ScheduleA_Dotspacing">.........</span>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsLobbyingExpenditures/CurrentYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsLobbyingExpenditures/PriorYear"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsLobbyingExpenditures/PriorYearMinus1"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsLobbyingExpenditures/PriorYearMinus2"/>
      </xsl:call-template>
      </td>
      <td class="IRS990ScheduleA_MoneyCell" style="border-right-width:0px;border-bottom-width: 0px">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIA/GrassrootsLobbyingExpenditures/Total"/>
      </xsl:call-template>
      </td>
    </tr>
  </table>
</div>
<!-- Part VI_B header -->
<div class="styGenericDiv" style="width: 187mm">
  <div class="styPartName" style="width:18mm;">Part VI-B</div>
  <div class="styPartDesc" style="width:169mm;">Lobbying Activity by Nonelecting Public Charities 
       <br />
       <span class="styNormalText">
         (For reporting only by organizations that did not complete Part VI-A) (See page 11 of the instructions.)
         </span>
    <xsl:call-template name="SetFormLinkInline">
      <xsl:with-param name="TargetNode" select="$FormDataVIB"/>
    </xsl:call-template>
  </div>
</div>
 <!-- header line -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineDescVIB" style="width:146mm;height:8mm;border-top-width:1px;">
    During the year, did the organization attempt to influence national, state or local legislation, including any 
    attempt to influence public opinion on a legislative matter or referendum, through the use of:
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="height:8mm;border-top-width:1px;padding-top:2mm;">Yes</div>
  <div class="IRS990ScheduleA_LineIndexMid" style="height:8mm;border-top-width:1px;padding-top:2mm;">No</div>
  <div class="IRS990ScheduleA_LineIndexMid" style="height:8mm;border-right-width:0px;width:26mm;border-top-width:1px;padding-top:2mm;">Amount</div>
</div>
<!-- line 50a -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">a</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Volunteers
    <span class="IRS990ScheduleA_Dotspacing">.........................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/Volunteers"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/Volunteers"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;border-bottom-width:0px;background-color:lightgrey;"></div>
</div>
<!-- line 50b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">b</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Paid staff or management (Include  compensation in expenses reported on lines<span class="styBoldText"> c </span>through<span class="styBoldText"> h.</span>)
    <span class="IRS990ScheduleA_Dotspacing">...</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/PaidStaffOrManagement"/>
      </xsl:call-template>
     </span> 
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/PaidStaffOrManagement"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;background-color:lightgrey;"></div>
</div>
<!-- line 50c -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">c</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Media advertisements
    <span class="IRS990ScheduleA_Dotspacing">....................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/MediaAdvertisements/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/MediaAdvertisements/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/MediaAdvertisements/Amount"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 50d -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">d</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Mailings to members, legislators, or the public
    <span class="IRS990ScheduleA_Dotspacing">..........................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/MailingsToMembersEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/MailingsToMembersEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/MailingsToMembersEtc/Amount"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 50e -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">e</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Publications, or published or broadcast statements
    <span class="IRS990ScheduleA_Dotspacing">.......................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/PublicationsEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/PublicationsEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/PublicationsEtc/Amount"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 50f -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">f</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Grants to other organizations for lobbying purposes
    <span class="IRS990ScheduleA_Dotspacing">.......................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/GrantsToOtherOrgForLobbying/YesOrNo"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/GrantsToOtherOrgForLobbying/YesOrNo"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/GrantsToOtherOrgForLobbying/Amount"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 50g -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">g</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Direct contact with legislators, their staffs, government officials, or a legislative body
    <span class="IRS990ScheduleA_Dotspacing">........</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/DirContactWithLegislatorsEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/DirContactWithLegislatorsEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/DirContactWithLegislatorsEtc/Amount"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 50h -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">h</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Rallies, demonstrations, seminars, conventions, speeches, lectures, or any other means
    <span class="IRS990ScheduleA_Dotspacing">.......</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/RalliesDemonstrationsEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/RalliesDemonstrationsEtc/YesOrNo"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/RalliesDemonstrationsEtc/Amount"/>
      </xsl:call-template>
  </div>
</div>
<!-- line 50i -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex">i</div>
  <div class="IRS990ScheduleA_LineDescVIB">
    Total lobbying expenditures (Add lines<span class="styBoldText"> c </span>through<span class="styBoldText"> h.</span>)
    <span class="IRS990ScheduleA_Dotspacing">.......................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="background-color:lightgrey;border-right-width:0px;"></div>
  <div class="IRS990ScheduleA_LineIndexMid" style="background-color:lightgrey;"></div>
  <div class="IRS990ScheduleA_MoneyField" style="border-right-width:0px;">
      <xsl:call-template name="PopulateAmount">
        <xsl:with-param name="TargetNode" select="$FormDataVIB/TotalLobbyingExpenditures3"/>
      </xsl:call-template>
  </div>
</div>
<!-- concluding line -->
<div class="styBB">
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDescVIB" style="width:180mm;border-right-width:0px;">
    If "Yes" to any of the above, also attach a statement giving a detailed description of the lobbying activities.
  </div>
</div>
</div>

<!--Page Footer-->
<div class="pageEnd" style="width:187mm">
  <div style="float:right;">
    <span style="width:80px;"></span>  
    <span class="styBoldText"> Schedule A (Form 990 or 990-EZ) 2005</span> 
  </div>  
</div>  
<!--END Page Footer-->

<!-- Page Header -->
  <div class="styBB" style="width:187mm">  
    <div style="float:left;">Schedule A (Form 990 or 990-EZ) 2005</div>
    <div style="float:right;">Page <span style="font-weight:bold;font-size:8pt;">6</span></div>                    
  </div>  
<!-- END Page Header -->

<!-- Part VII header -->
<div class="styGenericDiv">
  <div class="styPartName" style="width:20mm;">Part VII</div>
  <div class="styPartDesc" style="width:167mm;">Information Regarding Transfers To and Transactions and Relationships With Noncharitable<br />Exempt Organizations 
       <span class="styNormalText">(See page 12 of the instructions.)</span>
  </div>
</div>
 <!-- line 51 -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex" style="border-top-width:1px;">51</div>
  <div class="IRS990ScheduleA_LineDesc" style="width:180mm;border-right-width:0px;border-top-width:1px;">
    Did the reporting organization directly or indirectly engage in any of the following with any other organization described in section
  </div>
</div>
 <div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width:180mm;border-right-width:0px;">
    501(c) of the Code (other than section 501(c)(3) organizations) or in section 527, relating to political organizations? 
  </div>
</div>
<!-- line 51 a -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">a</div>
  <div class="IRS990ScheduleA_LineDesc" style="border-right-width:0px; width: 150mm">
    Transfers from the reporting organization to a noncharitable exempt organization of:
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm"></div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-top-width:1px;">Yes</div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;border-top-width:1px;">No</div>
</div>
<!-- line 51ai -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center;">(i)</span>
     Cash
    <span class="IRS990ScheduleA_Dotspacing">.............................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">51a(i)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/TrnsfrOfCashToNoncharitableEO"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/TrnsfrOfCashToNoncharitableEO"/>
      </xsl:call-template>
    </span>  
  </div>
</div>
<!-- line 51aii -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center;">(ii)</span>
    Other assets
    <span class="IRS990ScheduleA_Dotspacing">.........................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">a(ii)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/TrnsfrOthAssetsNoncharitableEO"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/TrnsfrOthAssetsNoncharitableEO"/>
      </xsl:call-template>
     </span> 
  </div>
</div>
<!-- line 51 b -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">b</div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    Other transactions:
  </div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="width: 10mm"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller"></div>
  <div class="IRS990ScheduleA_LineIndexMidFiller" style="border-right-width:0px;"></div>
</div>
<!-- line 51bi -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center">(i)</span>
     Sales or exchanges of assets with a noncharitable exempt organization
    <span class="IRS990ScheduleA_Dotspacing">................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">b(i)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SalesOrExchangesOfAssets"/>
      </xsl:call-template>
      </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SalesOrExchangesOfAssets"/>
      </xsl:call-template>
      </span>
  </div>
</div>
<!-- line 51bii -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center;">(ii)</span>
     Purchases of assets from a noncharitable exempt organization
    <span class="IRS990ScheduleA_Dotspacing">....................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">b(ii)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PurchaseAssetsNoncharitableEO"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PurchaseAssetsNoncharitableEO"/>
      </xsl:call-template>
     </span> 
  </div>
</div>
<!-- line 51biii -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center;">(iii)</span>
     Rental of facilities, equipment, or other assets
    <span class="IRS990ScheduleA_Dotspacing">............................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">b(iii)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/RentalOfFacilitiesEtc"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/RentalOfFacilitiesEtc"/>
      </xsl:call-template>
    </span>  
  </div>
</div>
<!-- line 51biv -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center;">(iv)</span>
     Reimbursement arrangements
    <span class="IRS990ScheduleA_Dotspacing">..................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">b(iv)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/ReimbursementArrangements"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/ReimbursementArrangements"/>
      </xsl:call-template>
    </span>  
  </div>
</div>
<!-- line 51bv -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center;">(v)</span>
     Loans or loan guarantees
    <span class="IRS990ScheduleA_Dotspacing">....................................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">b(v)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/LoansOrLoanGuarantees"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/LoansOrLoanGuarantees"/>
      </xsl:call-template>
    </span>  
  </div>
</div>
<!-- line 51bi -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
    <span style="width:8mm;font-weight:bold;text-align:center;">(vi)</span>
     Performance of services or membership or fundraising solicitations
    <span class="IRS990ScheduleA_Dotspacing">..................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">b(vi)</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PerformanceOfServicesEtc"/>
      </xsl:call-template>
    </span>  
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/PerformanceOfServicesEtc"/>
     </xsl:call-template>
     </span>
  </div>
</div>
<!-- line 51c -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">c</div>
  <div class="IRS990ScheduleA_LineDesc" style="width: 150mm">
     Sharing of facilities, equipment, mailing lists, other assets, or paid employees
    <span class="IRS990ScheduleA_Dotspacing">................</span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="width: 10mm">c</div>
  <div class="IRS990ScheduleA_LineIndexMid">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateYesBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SharingOfFacilitiesEtc"/>
     </xsl:call-template>
     </span>
  </div>
  <div class="IRS990ScheduleA_LineIndexMid" style="border-right-width:0px;">
   <span style="font-weight: normal">
      <xsl:call-template name="PopulateNoBoxText">
        <xsl:with-param name="TargetNode" select="$FormData/SharingOfFacilitiesEtc"/>
      </xsl:call-template>
    </span>  
  </div>
</div>
<!-- line 51d -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="styLNLeftLtrBoxDD">d</div>
  <div class="IRS990ScheduleA_LineDesc" style="width:180mm;border-right-width:0px;">
     If the answer to any of the above is "Yes," complete the following schedule. Column (b) should always show the fair market value of the
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width:180mm;border-right-width:0px;">
    goods, other assets, or services given by the reporting organization. If the organization received less than fair market value in any
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer" style="float:none;clear:none;">
  <div class="IRS990ScheduleA_SubLineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width:180mm;border-right-width:0px;">
    transaction or sharing arrangement, show in column (d) the value of the goods, other assets, or services received:
  </div>
  <div style="float:right">                        
    <!-- button display logic -->          
    <xsl:call-template name="SetDynamicTableToggleButton">
      <xsl:with-param name="TargetNode" select="$FormData/TransferSchedule" />
      <xsl:with-param name="headerHeight" select="1" />
      <xsl:with-param name="containerHeight" select="16"/>
      <xsl:with-param name="containerID" select="'p7Ln51TbCtnr'" />                  
    </xsl:call-template>                                
     <!-- end button display logic -->              
  </div>  
</div>
    <!-- Line 51d table -->
    <div class="IRS990ScheduleA_TableContainer" id="p7Ln51TbCtnr" style="float:left;clear:none;border-bottom-width: 0px">
      <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
      <!-- end -->        
      <table cellspacing="0" cellpadding="0" style="font-size:7pt;">
        <thead class="styTableThead">
          <tr>
            <th class="IRS990ScheduleA_GenericCell" style="width:14mm;height:8mm;text_align:center;font-weight:normal;" scope="col">
              <span style="font-weight:bold">(a)</span><br />Line no.</th>
            <th class="IRS990ScheduleA_GenericCell" style="width:26mm;height:8mm;text_align:center;font-weight:normal;" scope="col">
              <span style="font-weight:bold">(b)</span><br />Amount involved</th>
            <th class="IRS990ScheduleA_GenericCell" style="width:70mm;height:8mm;text_align:center;font-weight:normal;" scope="col">
              <span style="font-weight:bold">(c)</span><br />Name of noncharitable exempt organization</th>
            <th class="IRS990ScheduleA_GenericCell" style="width:70mm;height:8mm;border-right-width:0px;text_align:center;font-weight:normal;" scope="col">
              <span style="font-weight:bold">(d)</span><br />Description of transfers, transactions, and sharing arrangements
            </th>
          </tr>
        </thead>
        <tfoot></tfoot>
        <tbody>
          <xsl:choose>
            <!-- Display all rows: If the print parameter is not set to be Separated, OR -->
            <!-- If the print parameter is separated, but there are fewer elements than the container height (16) -->
            <xsl:when test="($Print != $Separated) or count($FormData/TransferSchedule) &lt;= 16">
              <xsl:for-each select="$FormData/TransferSchedule">  
                <tr>
                  <td class="IRS990ScheduleA_GenericCell"  style="vertical-align:top;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="LineNumber"/>
                    </xsl:call-template>
                  </td>
                  <td class="IRS990ScheduleA_MoneyFieldMid" style="padding-left:none;padding-right:none;vertical-align:top;">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="AmountInvolved"/>
                    </xsl:call-template>
                  </td>
                  <td class="IRS990ScheduleA_GenericCell" style="padding-left:none;padding-right:none;vertical-align:top;font-family:verdana;font-size:6pt;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="NameOfNoncharitableEO/BusinessNameLine1"/>
                    </xsl:call-template>
                    <br/>
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="NameOfNoncharitableEO/BusinessNameLine2"/>
                    </xsl:call-template>
                  </td>
                  
                  <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;vertical-align:top;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="DescriptionOfTransfersEtc"/>
                    </xsl:call-template>
                  </td>
                </tr>
              </xsl:for-each>
              <!--Add blank filler rows -->
              <xsl:call-template name="Part7Line51dFillerRows">
                <xsl:with-param name="NumOfTotRows" select="16" />
                <xsl:with-param name="CurrentRowCount" select="count($FormData/TransferSchedule)" />
              </xsl:call-template>
            </xsl:when>
            <!-- When the print option is separated and there are more rows than the allowed container height, then -->
            <!-- display a message in the first row directing the user to the additional data table, followed by blank rows -->
            <xsl:otherwise>
              <tr>
                <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/></td>
                <td class="IRS990ScheduleA_MoneyFieldMid" style="vertical-align:top;text-align:center">
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$FormData/TransferSchedule" />
                    <xsl:with-param name="ShortMessage" select="'true'" />
                  </xsl:call-template>
                </td>
                <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/></td>
                <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;vertical-align:top;">
                  <span style="width:1px;"/>
                </td>
              </tr>
              <xsl:call-template name="Part7Line51dFillerRows">
                <xsl:with-param name="NumOfTotRows" select="16" />
                <xsl:with-param name="CurrentRowCount" select="1" />
              </xsl:call-template>
            </xsl:otherwise>
          </xsl:choose>
        </tbody>
      </table>
    </div>
  
<xsl:call-template name="SetInitialDynamicTableHeight">
  <xsl:with-param name="TargetNode" select="$FormData/TransferSchedule" />
  <xsl:with-param name="headerHeight" select="1" />
  <xsl:with-param name="containerHeight" select="16"/>
  <xsl:with-param name="containerID" select="'p7Ln51TbCtnr'" />                  
</xsl:call-template>               

<!-- line 52a -->
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex" style="padding-right:10px;">52a</div>
  <div class="IRS990ScheduleA_LineDesc" style="width:180mm;border-right-width:0px;">
    Is the organization directly or indirectly affiliated with, or related to, one or more tax-exempt organizations
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_LineIndex"></div>
  <div class="IRS990ScheduleA_LineDesc" style="width:150mm;border-right-width:0px;">
    described in section 501(c) of the Code (other than section 501(c)(3)) or in section 527?
    <span class="IRS990ScheduleA_Dotspacing">..........</span>
    <img src="{$ImagePath}/990SchA_Bullet_Line.gif" alt="right arrow"/>
  </div>
  <div class="IRS990ScheduleA_LineDesc" style="width:15mm;border-right-width:0px;text-align:right;">
   <span>
      <xsl:call-template name="PopulateSpan">
          <xsl:with-param name="TargetNode" select="$FormData/RelationshipsNoncharitableEOs" />
      </xsl:call-template>
      <input type="checkbox" class="IRS990ScheduleA_Checkbox">
          <xsl:call-template name="PopulateYesCheckbox">
            <xsl:with-param name="TargetNode" select="$FormData/RelationshipsNoncharitableEOs" />
          </xsl:call-template>
        </input>
    </span>
    <span style="width:3mm;"></span>
    <label>
      <xsl:call-template name="PopulateLabelYes">
        <xsl:with-param name="TargetNode" select="$FormData/RelationshipsNoncharitableEOs" />
      </xsl:call-template>
      <span style="font-weight:bold;">Yes</span>
    </label>  
  </div>
  <div class="IRS990ScheduleA_LineDesc" style="width:15mm;border-right-width:0px;text-align:right;">
    <span>
      <xsl:call-template name="PopulateSpan">
          <xsl:with-param name="TargetNode" select="$FormData/RelationshipsNoncharitableEOs" />
      </xsl:call-template>
      <input type="checkbox" class="IRS990ScheduleA_Checkbox">
        <xsl:call-template name="PopulateNoCheckbox">
          <xsl:with-param name="TargetNode" select="$FormData/RelationshipsNoncharitableEOs" />
        </xsl:call-template>
      </input>
    </span>
    <span style="width:3mm;"></span>
    <label>
      <xsl:call-template name="PopulateLabelNo">
        <xsl:with-param name="TargetNode" select="$FormData/RelationshipsNoncharitableEOs" />
      </xsl:call-template>
      <span style="font-weight:bold;">No</span>
    </label>  
  </div>
</div>
<div class="IRS990ScheduleA_LineContainer">
  <div class="IRS990ScheduleA_SubLineIndex" style="padding-left: 1mm">b</div>
  <div class="IRS990ScheduleA_LineDesc" style="width:180mm;border-right-width:0px;">
    If "Yes," complete the following schedule:
  </div>
  <div style="float:right">                        
    <!-- button display logic -->          
    <xsl:call-template name="SetDynamicTableToggleButton">
      <xsl:with-param name="TargetNode" select="$FormData/RelationshipSchedule" />
      <xsl:with-param name="containerHeight" select="16"/>
      <xsl:with-param name="headerHeight" select="1" />
      <xsl:with-param name="containerID" select="'p7Ln52TbCtnr'" />                  
    </xsl:call-template>                       
     <!-- end button display logic -->              
  </div>  
</div>
    <!-- line 52b table -->
    <div class="IRS990ScheduleA_TableContainer" id="p7Ln52TbCtnr" style="float:none;clear:none;">
      <!-- print logic -->
      <xsl:call-template name="SetInitialState"/>
      <!-- end -->            
      <table cellspacing="0" cellpadding="0" style="font-size:7pt;">
        <thead class="styTableHead">
          <tr>
            <th class="IRS990ScheduleA_GenericCell" style="width:70mm;height:8mm;text_align:center;font-weight:normal;" scope="col">
              <span style="font-weight:bold;">(a)</span><br />Name of organization
            </th>
            <th class="IRS990ScheduleA_GenericCell" style="width:40mm;height:8mm;text_align:center;font-weight:normal;" scope="col">
              <span style="font-weight:bold;">(b)</span><br />Type of organization
            </th>
            <th class="IRS990ScheduleA_GenericCell" style="width:70mm;height:8mm;border-right-width:0px;text_align:center;font-weight:normal;" scope="col">
              <span style="font-weight:bold;">(c)</span><br />Description of relationship
            </th>
          </tr>
        </thead>
        <tfoot>
        </tfoot>
        <tbody>
          <xsl:choose>
            <!-- Display all rows: If the print parameter is not set to be Separated, OR -->
            <!-- If the print parameter is separated, but there are fewer elements than the container height (16) -->
            <xsl:when test="($Print != $Separated) or count($FormData/RelationshipSchedule) &lt;= 16">
              <xsl:for-each select="$FormData/RelationshipSchedule">
                <tr>
                  <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;font-family:verdana;font-size:6pt;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="NameOfOrganization/BusinessNameLine1"/>
                    </xsl:call-template>
                    <br/>
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="NameOfOrganization/BusinessNameLine2"/>
                    </xsl:call-template>
                  </td>
                  
                  <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="TypeOfOrganization"/>
                    </xsl:call-template>
                  </td>
                  <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;vertical-align:top;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="DescriptionOfRelationship"/>
                    </xsl:call-template>
                  </td>
                </tr>
              </xsl:for-each>
              <!--Add blank filler rows -->
              <xsl:call-template name="Part7Line52bFillerRows">
                <xsl:with-param name="NumOfTotRows" select="16" />
                <xsl:with-param name="CurrentRowCount" select="count($FormData/RelationshipSchedule)" />
              </xsl:call-template>
            </xsl:when>
            <!-- When the print option is separated and there are more rows than the allowed container height, then -->
            <!-- display a message in the first row directing the user to the additional data table, followed by blank rows -->
            <xsl:otherwise>
              <tr>
                <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/>
                  <xsl:call-template name="PopulateAdditionalDataTableMessage">
                    <xsl:with-param name="TargetNode" select="$FormData/RelationshipSchedule" />
                  </xsl:call-template>
                </td>
                <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/></td>
                <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;vertical-align:top;">
                  <span style="width:1px;"/>
                </td>
              </tr>
              <xsl:call-template name="Part7Line52bFillerRows">
                <xsl:with-param name="NumOfTotRows" select="16" />
                <xsl:with-param name="CurrentRowCount" select="1" />
              </xsl:call-template>
            </xsl:otherwise>
          </xsl:choose>
    
        </tbody>
      </table>
    </div>
  
<xsl:call-template name="SetInitialDynamicTableHeight">
  <xsl:with-param name="TargetNode" select="$FormData/RelationshipSchedule" />
  <xsl:with-param name="containerHeight" select="16"/>
  <xsl:with-param name="headerHeight" select="1" />
  <xsl:with-param name="containerID" select="'p7Ln52TbCtnr'" />                  
</xsl:call-template>               

<!--Page Footer-->
<div class="pageEnd" style="width:187mm;float:none;clear:both;">
  <div style="float:right;">
    <span style="width:80px;"></span>  
    <span class="styBoldText"> Schedule A (Form 990 or 990-EZ) 2005</span> 
  </div>  
</div>  
<!--END Page Footer-->

<br/>
<!-- leftover data table -->
<div class="styLeftOverTitleLine" id="LeftoverData">
  <div class="styLeftOverTitle">
    Additional Data        
  </div>
  <div class="styLeftOverButtonContainer">
    <input class="styLeftoverTableBtn" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
  </div>      
</div>  
<table class="styLeftOverTbl">
  <xsl:call-template name="PopulateCommonLeftover">
    <xsl:with-param name="TargetNode" select="$FormData" />
    <xsl:with-param name="DescWidth" select="100"/>
  </xsl:call-template>
  <xsl:call-template name="PopulateLeftoverRow">
    <xsl:with-param name="Desc">Line 2d - Note on Compensation</xsl:with-param>
    <xsl:with-param name="TargetNode" select="$FormData/SelfDealingActivities/AnyCompensation/@note"/>
    <xsl:with-param name="DescWidth" select="100"/>
  </xsl:call-template>
  <xsl:call-template name="PopulateLeftoverRow">
    <xsl:with-param name="Desc">Line 22 - Description</xsl:with-param>
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncome/Description"/>
    <xsl:with-param name="DescWidth" select="100"/>
  </xsl:call-template>
</table>

    <!-- Additonal Data Table for separated data from Part IV, Line 9 -->
    <xsl:if test="($Print = $Separated) and (count($FormData/HospitalNameAndAddress) &gt; 2) ">
      <span class="styRepeatingDataTitle">
        <br/>Form 990, Schedule A, Part IV, Line 9 - A medical research organization operated in conjunction with a hospital. Section 170(b)(1)(A)(iii). Enter the hospital's name, city, and state:
      </span>
      <table class="styDepTbl" style="font-size:7pt">
        <thead class="styTableHead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell">Hospital Name, City, and State</th>
          </tr>
        </thead>
        <tbody>
          <xsl:for-each select="$FormData/HospitalNameAndAddress">
            <tr>
              <!--Define background colors to the rows -->
              <xsl:attribute name="class">
                <xsl:choose>
                  <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                  <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="text-align:left;font-size:7pt;">
              
              <span style="font-family:verdana;font-size:6pt;">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="Name/BusinessNameLine1"/>
                </xsl:call-template><br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="Name/BusinessNameLine2"/>
                </xsl:call-template>
              </span>
                
                <br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="Address/City"/>
                </xsl:call-template>,<span style="width:3px" />
                <xsl:choose>
                  <xsl:when test="Address/State">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="Address/State"/>
                    </xsl:call-template>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="Address/Country"/>
                    </xsl:call-template>
                  </xsl:otherwise>
                </xsl:choose>
              </td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
    </xsl:if>
    <!-- End Part IV, Line 9 separated data -->
    
    <!-- Additonal Data Table for separated data from Part IV, Line 13 -->
    <xsl:if test="($Print = $Separated) and (count($FormData/SupportedOrgInformation) &gt; 2) ">
      <span class="styRepeatingDataTitle">
        <br/>Form 990, Schedule A, Part IV, Line 13 - An organization that is not controlled by any disqualified persons (other than foundation managers) and supports organizations described in: (1) lines 5 through 12 above; or (2) section 501(c)(4), (5), or (6), if they meet the test of section 509(a)(2). (See section 509(a)(3).):
      </span>
      <table class="styDepTbl" style="font-size:7pt">
        <thead class="styTableHead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" >(a) Name(s) of supported organization(s)</th>
            <th class="styDepTblCell" style="width:25mm;">(b) Line number from above</th>
          </tr>
        </thead>
        <tbody>
          <xsl:for-each select="$FormData/SupportedOrgInformation">
            <tr>
              <!--Define background colors to the rows -->
              <xsl:attribute name="class">
                <xsl:choose>
                  <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                  <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="text-align:left;font-family:verdana;font-size:6pt">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="Name/BusinessNameLine1"/>
                </xsl:call-template><br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="Name/BusinessNameLine2"/>
                </xsl:call-template>
              </td>
              
              <td class="styDepTblCell" style="text-align:center">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="LineNumber"/>
                </xsl:call-template>
              </td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
    </xsl:if>
    <!-- End Part IV, Line 13 separated data -->
        
    <!-- Additonal Data Table for separated data from Part VII, Line 51d -->
    <xsl:if test="($Print = $Separated) and (count($FormData/TransferSchedule) &gt; 16) ">
      <span class="styRepeatingDataTitle">
        <br/>Form 990, Schedule A, Part IV, Line 51d - If the answer to any of the above is "Yes," complete the following schedule. Column (b) should always show the fair market value of the goods, other assets, or services given by the reporting organization. If the organization received less than fair market value in any transaction or sharing arrangement, show in column (d) the value of the goods, other assets, or services received:
      </span>
      <table class="styDepTbl" style="font-size:7pt">
        <thead class="styTableHead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" style="width:14mm;text_align:center;" >
              <span style="font-weight:bold">(a)</span><br />Line no.
            </th>
            <th class="styDepTblCell" style="width:26mm;text_align:center;" >
              <span style="font-weight:bold">(b)</span><br />Amount involved
            </th>
            <th class="styDepTblCell" style="width:70mm;text_align:center;" >
              <span style="font-weight:bold">(c)</span><br />Name of noncharitable exempt organization
            </th>
            <th class="styDepTblCell" style="width:70mm;text_align:center;" >
              <span style="font-weight:bold">(d)</span><br />Description of transfers, transactions, and sharing arrangement
            </th>
          </tr>
        </thead>
        <tbody>
          <xsl:for-each select="$FormData/TransferSchedule">
            <tr>
              <!--Define background colors to the rows -->
              <xsl:attribute name="class">
                <xsl:choose>
                  <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                  <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              <td class="styDepTblCell" style="text-align:center">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="LineNumber"/>
                </xsl:call-template>
              </td>
              <td class="styDepTblCell" style="text-align:right">
                <xsl:call-template name="PopulateAmount">
                  <xsl:with-param name="TargetNode" select="AmountInvolved"/>
                </xsl:call-template>
              </td>
              
              <td class="styDepTblCell" style="text-align:left;font-family:verdana;font-size:6pt">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfNoncharitableEO/BusinessNameLine1"/>
                </xsl:call-template>
                <br/>
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfNoncharitableEO/BusinessNameLine2"/>
                </xsl:call-template>
              </td>
              
              <td class="styDepTblCell" style="text-align:left">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="DescriptionOfTransfersEtc"/>
                </xsl:call-template>
              </td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
    </xsl:if>
    <!-- End Part VII, Line 51d separated data -->
    
    <!-- Additonal Data Table for separated data from Part VII, Line 52b -->
    <xsl:if test="($Print = $Separated) and (count($FormData/RelationshipSchedule) &gt; 16) ">
      <span class="styRepeatingDataTitle">
        <br/>Form 990, Schedule A, Part IV, Line 52b - If "Yes," complete the following schedule:
      </span>
      <table class="styDepTbl" style="font-size:7pt">
        <thead class="styTableHead">
          <tr class="styDepTblHdr">
            <th class="styDepTblCell" style="width:70mm;text_align:center;">
              <span style="font-weight:bold;">(a)</span><br />Name of organization
            </th>
            <th class="styDepTblCell" style="width:40mm;text_align:center;">
              <span style="font-weight:bold;">(b)</span><br />Type of organization
            </th>
            <th class="styDepTblCell" style="width:70mm;text_align:center;">
              <span style="font-weight:bold;">(c)</span><br />Description of relationship
            </th>
          </tr>
        </thead>
        <tbody>
          <xsl:for-each select="$FormData/RelationshipSchedule">
            <tr>
              <!--Define background colors to the rows -->
              <xsl:attribute name="class">
                <xsl:choose>
                  <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
                  <xsl:otherwise>styDepTblRow2</xsl:otherwise>
                </xsl:choose>
              </xsl:attribute>
              
              <td class="styDepTblCell" style="text-align:left,font-family:verdana;font-size:6pt">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfOrganization/BusinessNameLine1"/>
                </xsl:call-template><br />
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="NameOfOrganization/BusinessNameLine2"/>
                </xsl:call-template>
              </td>
              
              <td class="styDepTblCell" style="text-align:center">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="TypeOfOrganization"/>
                </xsl:call-template>
              </td>
              <td class="styDepTblCell" style="text-align:left">
                <xsl:call-template name="PopulateText">
                  <xsl:with-param name="TargetNode" select="DescriptionOfRelationship"/>
                </xsl:call-template>
              </td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
    </xsl:if>
    <!-- End Part VII, Line 52b separated data -->

   </body>
</html>
</xsl:template>

<!-- This template is used to add blank rows to the table in Part VII Line 51d where the number of rows of data -->
<!-- is fewer than the container height (in this case 16). This template will continue to add blank rows until the -->
<!-- total number of rows have been filled in, including data rows and blank rows. -->
<xsl:template name="Part7Line51dFillerRows">
  <xsl:param name="NumOfTotRows" />
  <xsl:param name="CurrentRowCount" />
  <!-- Test condition to populate a blank row -->
  <xsl:if test="$CurrentRowCount &lt; $NumOfTotRows">
    <tr>
      <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/></td>
      <td class="IRS990ScheduleA_MoneyFieldMid" style="vertical-align:top;"><span style="width:1px;"/></td>
      <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/></td>
      <td class="IRS990ScheduleA_GenericCell" style="border-right-width:0px;vertical-align:top;">
        <span style="width:1px;"/>
      </td>
    </tr>
    <!-- Recursive call to itself after incrementing the CurrentRowCount. -->
    <xsl:call-template name="Part7Line51dFillerRows">
      <xsl:with-param name="NumOfTotRows" select="$NumOfTotRows" />
      <xsl:with-param name="CurrentRowCount" select="$CurrentRowCount + 1" />
    </xsl:call-template>
  </xsl:if>
</xsl:template>

<!-- This template is used to add blank rows to the table in Part VII Line 52b where the number of rows of data -->
<!-- is fewer than the container height (in this case 16). This template will continue to add blank rows until the -->
<!-- total number of rows have been filled in, including data rows and blank rows. -->
<xsl:template name="Part7Line52bFillerRows">
  <xsl:param name="NumOfTotRows" />
  <xsl:param name="CurrentRowCount" />
  <!-- Test condition to populate a blank row -->
  <xsl:if test="$CurrentRowCount &lt; $NumOfTotRows">
    <tr>
      <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/></td>
      <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;"><span style="width:1px;"/></td>
      <td class="IRS990ScheduleA_GenericCell" style="vertical-align:top;border-right:none;">
        <span style="width:1px;"/>
      </td>
    </tr>
    <!-- Recursive call to itself after incrementing the CurrentRowCount. -->
    <xsl:call-template name="Part7Line52bFillerRows">
      <xsl:with-param name="NumOfTotRows" select="$NumOfTotRows" />
      <xsl:with-param name="CurrentRowCount" select="$CurrentRowCount + 1" />
    </xsl:call-template>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>
